(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   3390819,      87716]
NotebookOptionsPosition[   2978819,      79578]
NotebookOutlinePosition[   2985333,      79769]
CellTagsIndexPosition[   2984337,      79734]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Surfaces 
in the Euclidean 3-Space\
\>", "Title",
 CellChangeTimes->{
  3.588487292274865*^9, {3.6997690664318*^9, 3.6997690868557262`*^9}},
 TextAlignment->Center,ExpressionUUID->"d91aa4b7-bcd9-45a5-9a98-c281548a33ed"],

Cell["by Rolf Sulanke", "Subtitle",
 CellChangeTimes->{{3.5942757655247216`*^9, 3.594275786184903*^9}, 
   3.59427585467282*^9, {3.5942759066557937`*^9, 3.594275907880864*^9}, {
   3.6210775010971065`*^9, 3.621077519098136*^9}, {3.6236556769993553`*^9, 
   3.6236556822253647`*^9}},
 TextAlignment->Center,ExpressionUUID->"2ee9d221-e9ec-4152-a9bb-44db9c445c55"],

Cell[TextData[{
 "Finished v3: March 29, 2017\nRevised July 6, 2017\nTested with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v. 9.0.1.0, 11.1.1.0"
}], "Text",
 CellChangeTimes->{{3.594368087244899*^9, 3.5943680914569063`*^9}, {
  3.614665568276914*^9, 3.6146656059665804`*^9}, {3.6174421006498613`*^9, 
  3.6174421041850634`*^9}, {3.6189956491303053`*^9, 3.618995673793949*^9}, {
  3.620532390543178*^9, 3.620532431056449*^9}, {3.626855473912151*^9, 
  3.626855489044177*^9}, {3.6291885008789363`*^9, 3.6291885014873376`*^9}, {
  3.686289143619051*^9, 3.6862891531788*^9}, {3.6862891863783197`*^9, 
  3.68628919309063*^9}, {3.6997688439055567`*^9, 3.6997688982409887`*^9}, {
  3.707967811127418*^9, 3.707967823702833*^9}, {3.708330117605459*^9, 
  3.7083301663248034`*^9}},ExpressionUUID->"9afc5a46-e66d-481f-987a-\
f5665aaca679"],

Cell[CellGroupData[{

Cell["Preface", "Subsection",
 CellChangeTimes->{
  3.541836408310753*^9, 3.5418367181098843`*^9, {3.5992053438926544`*^9, 
   3.5992053481638985`*^9}, {3.5994627461488314`*^9, 
   3.599462748535635*^9}},ExpressionUUID->"11494bff-4cd3-44ec-8866-\
836e688f5af9"],

Cell[TextData[{
 "In this notebook we develop ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " tools for applications  to Euclidean differential geometry of surfaces. We \
construct modules for the calculation of all Euclidean invariants like \
fundamental forms and curvatures for surfaces in the 3-space, and some also \
for immersions into the n-dimensional Euclidean spaces.  This notebook may be \
considered as a continuation of the notebook EuCurvesv3.nb devoted to  \
Euclidean curve theory which is contained in EDG.zip and may be downloaded \
from my ",
 ButtonBox["homepage",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www-irm.mathematik.hu-berlin.de/~sulanke/"], None},
  ButtonNote->"http://www-irm.mathematik.hu-berlin.de/~sulanke/"],
 ". It may be useful to compare and to complete this notebook studying the \
pioneering work of Alfred Gray on applying ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to differential geometry, see  the book [",
 ButtonBox["G06",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray"],
 "], or the German translation of the first edition [",
 ButtonBox["G94",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray3"],
 "]. The third edition [G06] is accompanied by a series of 27 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebooks corresponding to the chapters of the book, which can be \
downloaded from the website ",
 ButtonBox["[G06nb]",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray2"],
 ".  Alfred Gray presented Euclidean differential geometry with many \
applications of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Writing his book Alfred Gray collected about 200 definitions of concrete \
curves and as many of concrete surfaces with short descriptions (formulated \
as usages) and implementations into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". These catalogs are contained in his ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " packages  CURVES.m and SURFS.m  included in EDG.zip too.  They open many \
opportunities to apply the functions and miniprograms developed here, to \
deepen the insight into the differential geometry of curves and surfaces \
comparing the calculated invariants, e. g. the curvatures, with the shape of \
the geometric objects using the graphical tools of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".  I am much obliged to Alfred Gray for providing this material and for \
many discussions introducing me into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Preparing the third version I completely reworked the notebook, \
introduced many improvements and some corrections intending to make it usable \
as an interactive introduction to Euclidean differential geometry.\n\nChapter \
1 of the notebook is devoted to E. Cartan\[CloseCurlyQuote]s method of moving \
frames using exterior differential forms. It gives the structure forms and \
the Frenet formulas including the integrability conditions for surfaces in \
the Euclidean space. Here I followed the presentation of ",
 ButtonBox["W. Blascke and H. Reichardt",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 " using the differential forms ad hoc as elementary as possible. Also the \
first and the second fundamental forms of surface theory are treated as \
fields of bilinear forms not using concepts of tensor analysis. Spherical \
image and Gauss curvature are the subject of Chapter 2 containing a proof of \
Gauss famous Theorema Egregium.  Chapter 3 is devoted to the second \
fundamental form of the surface, studying the geometry of curves on the \
surface, in particular their normal curvature. Ruled surfaces and surfaces of \
revolution are presented very detailed. Chapter 4 contains the absolute \
differentiation on surfaces, expressed by the Christoffel symbols as a part \
of the inner geometry of the surface,  invariant under isometries. It is \
applied to describe the geodesic curvature of a curve on the surface and to \
define the geodesics as auto-parallel curves. The basic concepts are \
formulated avoiding the tensor concept, but admitting a straightforward \
extension to higher dimensional Riemannian and more general geometries, which \
are treated in the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook RG.nb titled \[OpenCurlyDoubleQuote]Pseudo-Riemannian Geometry \
and Tensor Analysis\[CloseCurlyDoubleQuote], see the packed file RG.zip \
downloadable from my homepage.\n\nI hope that the notebook will help students \
to understand the Euclidean differential geometry of surfaces. By its \
interactive character it may serve as a starting point for further excursions \
into this interesting field, which joins algebraic and analytic methods to \
explore the heart of mathematics: the geometry. Studying older or modern \
textbooks or monographs of classical differential geometry it may be an \
exciting challenge to express the objects and concepts in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " terms aiming to explore or illustrate their properties, to verify well \
known facts, and, with some luck, to gain new insight.   \n\nI shall be very \
thankful for comments and corrections, please send them to \n\
sulanke@mathematik.hu-berlin.de.\n\n",
 StyleBox["Important Hint. ",
  FontColor->RGBColor[1, 0, 0]],
 "\n",
 StyleBox["Before starting working with the notebook read the Copyrigth and \
make the necessary adaption of the Section Initialization to your computer! \n\
",
  FontSlant->"Italic"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.446645069921875*^9, 3.44664509953125*^9}, 
   3.446645156828125*^9, {3.446645243484375*^9, 3.446645462125*^9}, {
   3.448159668953125*^9, 3.448159713765625*^9}, 3.449203063109375*^9, {
   3.4542178296875*^9, 3.4542180669375*^9}, {3.454218801*^9, 
   3.454218865875*^9}, {3.4542223853125*^9, 3.4542224753125*^9}, {
   3.454222520640625*^9, 3.45422255271875*^9}, {3.45422428384375*^9, 
   3.45422444978125*^9}, {3.45422448125*^9, 3.454224575171875*^9}, 
   3.541681068146072*^9, {3.541682273824328*^9, 3.5416824190006227`*^9}, {
   3.541827375454864*^9, 3.541827387969111*^9}, {3.5418316529213343`*^9, 
   3.541831653441086*^9}, 3.5418317494023857`*^9, {3.541831858219041*^9, 
   3.541832023482676*^9}, {3.5418320577240677`*^9, 3.5418320930359087`*^9}, {
   3.541832178020227*^9, 3.541832187404354*^9}, {3.5418322197005577`*^9, 
   3.541832219702417*^9}, {3.5418322675411787`*^9, 3.541832354019971*^9}, 
   3.541836408310801*^9, {3.5418366180057*^9, 3.541836621524942*^9}, 
   3.541836718109921*^9, {3.59919611723792*^9, 3.599196122851241*^9}, {
   3.5991962025988026`*^9, 3.5991962289503098`*^9}, {3.5991962615901766`*^9, 
   3.599196336339452*^9}, {3.5991963763887424`*^9, 3.5991964222833676`*^9}, {
   3.5991964577643967`*^9, 3.599196467277941*^9}, {3.599196506140164*^9, 
   3.5991965150836754`*^9}, {3.5991965605252743`*^9, 3.5991965712928905`*^9}, 
   3.5992019728598423`*^9, {3.5992020307651544`*^9, 3.5992021570203757`*^9}, 
   3.599202305491868*^9, 3.5992032715491233`*^9, {3.59920388218805*^9, 
   3.599203905548386*^9}, {3.5992040181558266`*^9, 3.599204028124397*^9}, {
   3.599204085731692*^9, 3.599204105851843*^9}, {3.5992041385407124`*^9, 
   3.59920414934033*^9}, {3.599204190283672*^9, 3.5992042911484413`*^9}, {
   3.5992043640766125`*^9, 3.599204371660046*^9}, {3.59920441124231*^9, 
   3.599204411255311*^9}, {3.5992044716767664`*^9, 3.5992045492682047`*^9}, {
   3.5992045954358454`*^9, 3.599204629315783*^9}, {3.599204741172181*^9, 
   3.599204764548518*^9}, {3.5992047948372507`*^9, 3.5992048358365955`*^9}, {
   3.5992050362200565`*^9, 3.5992050588603516`*^9}, {3.599205134556681*^9, 
   3.599205261883964*^9}, 3.59920536304775*^9, {3.5992053937465057`*^9, 
   3.5992053939325166`*^9}, {3.5992054591412463`*^9, 
   3.5992055378927507`*^9}, {3.5992056833880725`*^9, 
   3.5992057380601997`*^9}, {3.59920582041291*^9, 3.599205820627922*^9}, {
   3.5992058827964783`*^9, 3.599206043644678*^9}, {3.5992060798207474`*^9, 
   3.599206163004505*^9}, {3.5992062112202625`*^9, 3.5992062367237215`*^9}, {
   3.5992063417807302`*^9, 3.5992063865722923`*^9}, {3.599206474428317*^9, 
   3.5992064839718633`*^9}, {3.599206598188396*^9, 3.599206636628595*^9}, {
   3.5992066825932236`*^9, 3.5992066871884866`*^9}, 3.5992067173322105`*^9, {
   3.599206779087743*^9, 3.599206830683694*^9}, {3.5992068737641582`*^9, 
   3.5992069266761847`*^9}, {3.5992069590400352`*^9, 
   3.5992069796602154`*^9}, {3.5992070286610174`*^9, 
   3.5992070416127586`*^9}, {3.5992070903205442`*^9, 3.599207090334545*^9}, {
   3.5992078881661787`*^9, 3.59920812438869*^9}, {3.599226725980919*^9, 
   3.599226730632185*^9}, {3.599226794136817*^9, 3.5992268145319834`*^9}, 
   3.5992268515100985`*^9, {3.599227048665375*^9, 3.599227050600486*^9}, {
   3.599227089888733*^9, 3.599227090432764*^9}, {3.5992274882425175`*^9, 
   3.599227521310409*^9}, {3.5992276061852636`*^9, 3.5992276061962643`*^9}, {
   3.599227931864891*^9, 3.599227961944612*^9}, {3.599227993192399*^9, 
   3.59922802048096*^9}, {3.5992282650969515`*^9, 3.5992282958327093`*^9}, {
   3.59922839935363*^9, 3.5992285024725285`*^9}, 3.59928617084793*^9, {
   3.5992862198164163`*^9, 3.599286314914183*^9}, {3.5994012750208035`*^9, 
   3.599401312258069*^9}, {3.5994013738781776`*^9, 3.5994014292114744`*^9}, {
   3.5994014605675297`*^9, 3.599401482969169*^9}, {3.599401529472851*^9, 
   3.5994018439226027`*^9}, 3.59940195034599*^9, 3.5994020589533806`*^9, 
   3.5994020911986375`*^9, {3.599402465084494*^9, 3.5994026765740657`*^9}, {
   3.599402733092965*^9, 3.5994027337949657`*^9}, {3.5994028421371565`*^9, 
   3.599402909529275*^9}, {3.599402944488936*^9, 3.599403082112378*^9}, {
   3.5994045003111925`*^9, 3.599404706743*^9}, {3.599405087461776*^9, 
   3.5994053763022966`*^9}, {3.5994054519166217`*^9, 
   3.5994054540677443`*^9}, {3.5994056666029005`*^9, 3.5994057112824564`*^9}, 
   3.599405747266515*^9, {3.599405778443298*^9, 3.5994057958012905`*^9}, 
   3.59940586659534*^9, {3.599462817206956*^9, 3.5994629289187517`*^9}, {
   3.599462978480039*^9, 3.59946316121876*^9}, {3.5994633805518007`*^9, 
   3.599463389584317*^9}, 3.614665761857654*^9, {3.6146658697162437`*^9, 
   3.6146659078115106`*^9}, {3.6146660355913353`*^9, 
   3.6146660382433395`*^9}, {3.6189973384975014`*^9, 
   3.6189973435597906`*^9}, {3.686289272124634*^9, 3.6862892737360983`*^9}, 
   3.699770711634968*^9, {3.69977262983079*^9, 3.6997727298844557`*^9}, 
   3.699772834897607*^9, {3.69977286968421*^9, 3.699772905924469*^9}, {
   3.6997729567694473`*^9, 3.699773016538191*^9}, {3.699773231606366*^9, 
   3.6997732612116337`*^9}, {3.6997733097430563`*^9, 3.699773311803608*^9}, 
   3.699773344903407*^9, {3.699773406745521*^9, 3.6997734067593393`*^9}, 
   3.6997735129574413`*^9, {3.699794405802997*^9, 3.699794410243959*^9}, {
   3.699794602546709*^9, 3.6997946618689404`*^9}, {3.699794723268437*^9, 
   3.699794731151882*^9}, {3.708330847580394*^9, 3.708330878241702*^9}, {
   3.708330959217226*^9, 3.708330959247569*^9}, {3.708331060934127*^9, 
   3.7083310609656487`*^9}, {3.7083311051719847`*^9, 
   3.7083311468894243`*^9}, {3.70833138155203*^9, 3.708331421732821*^9}, {
   3.708331600068831*^9, 3.708331705065947*^9}, {3.7083317445844307`*^9, 
   3.70833182978743*^9}, {3.708331948558484*^9, 
   3.708332059533272*^9}},ExpressionUUID->"906fac9a-13bc-46f3-9a75-\
47ea3553ddfc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Keywords", "Subsection",
 CellChangeTimes->{{3.541686221104368*^9, 3.541686224511538*^9}, 
   3.5418364083108387`*^9, 
   3.54183671810995*^9},ExpressionUUID->"61d05635-94c6-4ba8-aadc-\
5296c2792d18"],

Cell["\<\
absolute differential, absolute parallel, arc length, area, asymptotic \
curves, Christoffel symbols, cone, conical surface, cylindrical surface, \
developable surface, diffeomorphism, differential, envelope, Euler\
\[CloseCurlyQuote]s formula, evolute, exterior differential, exterior \
product, flat points, Frenet formulas, fundamental forms, Gauss curvature, \
Gauss map, geodesic, geodesic curvature, graph, helix, hypersurface, \
immersion,  integrability conditions, integral curvature, involute, isogonal \
trajectory, Jacobian matrix, line congruences, loxodrome, mean curvature, \
Meusnier\[CloseCurlyQuote]s proposition,  minimal surface, moving frame, \
normal congruence, normal curvature, normal vector, orientation, osculating \
sphere, parallel displacement, parameter, Pl\[UDoubleDot]cker\
\[CloseCurlyQuote]s conoid, principal curvatures, principal curves, principal \
directions,  regular, Riemannian curvature tensor, Riemannian manifold, R\
\[UDoubleDot]ckkehrkante,  ruled surface, schiebfl\[ADoubleDot]che, singular, \
spherical image, spiral, structure forms, submanifold, surface, surface of \
revolution, surface with constant Gauss curvature, tangent plane, tangent \
surface, tangent vector, Theorema egregium, torus, total differential, \
umbilic point, vector field, volume element.\
\>", "Text",
 CellChangeTimes->{
  3.6146702447129803`*^9, {3.6146743760906925`*^9, 3.6146744046253242`*^9}, {
   3.614674471174131*^9, 3.6146744956065283`*^9}, {3.6146745698667755`*^9, 
   3.6146745918020306`*^9}, 3.6146746377306576`*^9, 3.6146748836907253`*^9, {
   3.614774678232683*^9, 3.6147746844320374`*^9}, {3.61477471629686*^9, 
   3.614774744056448*^9}, {3.6151888712415533`*^9, 3.615188905226497*^9}, {
   3.6151890327547913`*^9, 3.615189040579239*^9}, {3.615361391244278*^9, 
   3.6153614969653244`*^9}, {3.615362023628448*^9, 3.615362032140935*^9}, {
   3.617442283553323*^9, 3.6174423273218265`*^9}, {3.6174423670821004`*^9, 
   3.617442374049499*^9}, {3.6174426996831245`*^9, 3.617442706369507*^9}, {
   3.617443035034305*^9, 3.6174430418576956`*^9}, {3.6174431918342733`*^9, 
   3.6174432005217705`*^9}, {3.617443243458226*^9, 3.6174432561699533`*^9}, {
   3.6174433063858256`*^9, 3.6174433213856835`*^9}, 3.617443397977064*^9, {
   3.6174460763694725`*^9, 3.6174461022459526`*^9}, {3.6176052340530386`*^9, 
   3.617605238296246*^9}, {3.6177013931950407`*^9, 3.617701402755587*^9}, {
   3.6179404294297233`*^9, 3.6179404672753897`*^9}, {3.6179405303463*^9, 
   3.617940542997923*^9}, {3.617940949144636*^9, 3.617940969565072*^9}, {
   3.61795167381975*^9, 3.6179516976201115`*^9}, {3.6183981333230515`*^9, 
   3.618398144002662*^9}, {3.6260675001325064`*^9, 3.6260675184001384`*^9}, {
   3.626067551493797*^9, 3.626067557735808*^9}, 3.626855590005945*^9, {
   3.627114607273288*^9, 3.627114624464518*^9}, {3.627187931915095*^9, 
   3.6271879412283115`*^9}, {3.629188541491808*^9, 3.6291885699054585`*^9}, {
   3.629188618322344*^9, 3.629188632489169*^9}, {3.6868306052477837`*^9, 
   3.686830622167899*^9}, {3.6868306721168327`*^9, 
   3.686830692439604*^9}},ExpressionUUID->"17ae517b-45fd-4c8a-837e-\
cbad241090ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Copyright", "Subsection",
 CellChangeTimes->{{3.541686221104368*^9, 3.541686224511538*^9}, {
   3.541686639857975*^9, 3.541686645161036*^9}, 3.541836408310912*^9, 
   3.541836718110009*^9},ExpressionUUID->"171f4455-19f7-404c-a837-\
1b71b1446006"],

Cell["\<\
This notebook and the accompanying packages are  public. Authors who intend \
to publish a changed or completed version of them should do it under their \
own names with the condition that they cite the original notebook with the \
Internet address or other source where they got it. I am not responsible for \
errors or damages originated by the use of the procedures contained in my \
notebooks or packages; everybody who applies them should test carefully \
whether they are appropriate for his purposes.\
\>", "Text",
 CellChangeTimes->{{3.470471120664312*^9, 3.470471146997974*^9}, {
   3.498225321006962*^9, 3.498225323459318*^9}, 3.541836408310948*^9, 
   3.541836718110042*^9, 
   3.5994668492244267`*^9},ExpressionUUID->"acd044ff-55e4-469a-b6d2-\
253dacacc7df"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 CellChangeTimes->{{3.572085090826617*^9, 3.572085097846629*^9}, {
   3.614675039233622*^9, 3.614675041977779*^9}, 
   3.61468526962821*^9},ExpressionUUID->"b1beae35-4a24-416f-b170-\
8dda257d634e"],

Cell[CellGroupData[{

Cell["Preparation", "Subsection",
 CellChangeTimes->{{3.686289461416059*^9, 
  3.686289467032009*^9}},ExpressionUUID->"cfe94814-9eea-4f8b-9e30-\
778e1d47440b"],

Cell["\<\
Before starting the first session insert the address of your working \
directory, e.g. for Windows 7:\
\>", "Text",
 CellChangeTimes->{{3.599463466951742*^9, 3.599463520087782*^9}, {
   3.599463875888132*^9, 3.5994638948642178`*^9}, 3.59946686361625*^9, {
   3.624770686442224*^9, 
   3.6247707098734655`*^9}},ExpressionUUID->"438e5a64-e05b-4570-a20e-\
781382ad67c1"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  "\"\<E:\\\\mymath\\\\diffgeo\\\\EuclSfTheoryv2\>\"", "]"}]], "Input",
 Evaluatable->False,
 InitializationCell->True,
 CellChangeTimes->{{3.571294164375502*^9, 3.5712942516264553`*^9}, 
   3.5919452705433164`*^9, 3.5920226711016054`*^9, 3.6089604686226373`*^9, 
   3.6089669513028173`*^9, 3.609849899827975*^9, 3.6114596276456995`*^9, 
   3.6225992444605618`*^9, {3.622883761555369*^9, 3.622883763286972*^9}, 
   3.623755959921055*^9, 3.6277079613261795`*^9, 
   3.627712256148449*^9},ExpressionUUID->"43e6512c-e599-454e-b411-\
0d66579e11ab"],

Cell["For Linux:", "Text",
 CellChangeTimes->{{3.6247705161991253`*^9, 
  3.624770522922737*^9}},ExpressionUUID->"223a2058-a892-4bc0-9aed-\
431f3201383e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<~/mymath/diffgeo/eudiffgeo\>\"", 
  "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.571294164375502*^9, 3.5712942516264553`*^9}, 
   3.5919452705433164`*^9, 3.5920226711016054`*^9, 3.6089604686226373`*^9, 
   3.6089669513028173`*^9, 3.609849899827975*^9, 3.6114596276456995`*^9, 
   3.6225992444605618`*^9, {3.622883761555369*^9, 3.622883763286972*^9}, 
   3.623755959921055*^9, {3.6247705367911615`*^9, 3.624770550487985*^9}, {
   3.624770639532942*^9, 3.6247706546493683`*^9}, 3.660714010371863*^9, {
   3.7073686134842043`*^9, 
   3.707368618778409*^9}},ExpressionUUID->"ae0b8abf-15ee-4571-bc52-\
9b831cde0262"],

Cell[BoxData["\<\"/home/rolf/mymath/diffgeo/eudiffgeo\"\>"], "Output",
 CellChangeTimes->{
  3.708321845503289*^9},ExpressionUUID->"257b5042-9650-448b-a51d-\
5cc99b637040"]
}, Open  ]],

Cell["\<\
Regard  eventually deviating notations depending on your operating system! \
Ensure that the corresponding cell is an initialization cell, and the other \
cell doesn\[CloseCurlyQuote]t have this property (Menu Cell/ Cell Properties).\
\>", "Text",
 CellChangeTimes->{{3.599463651304287*^9, 3.599463772472217*^9}, 
   3.599466052630864*^9, {3.608967233202941*^9, 3.6089672358820944`*^9}, 
   3.6247707634127593`*^9, {3.6247709006692357`*^9, 3.6247710039882174`*^9}, {
   3.6247711621314993`*^9, 3.624771186016141*^9}, 3.6268556704224873`*^9, {
   3.6271881066198015`*^9, 
   3.627188135901053*^9}},ExpressionUUID->"f061795b-d55b-4245-93d0-\
c82799939a4d"],

Cell[BoxData["$Path"], "Input",ExpressionUUID->"546363b4-4279-4db8-b7d1-4df183c52794"],

Cell[TextData[{
 " Copy all the needed ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " packages into your working directory, or a directory of $Path. \n\
Obligatory are the packages\ntensalgv3.m, euvecv2.m, eudiffgeov3.m, Alfred \
Gray\[CloseCurlyQuote]s catalog SURFS.m, and Alfred Gray\[CloseCurlyQuote]s \
catalog CURVES.m. "
}], "Text",
 CellChangeTimes->{{3.5994639548406477`*^9, 3.599463992919826*^9}, {
   3.5994640376963873`*^9, 3.599464151447893*^9}, {3.5994642220319304`*^9, 
   3.5994642628482647`*^9}, {3.599464422128375*^9, 3.599464461632635*^9}, 
   3.5994644995758047`*^9, {3.599465959441534*^9, 3.5994660385980616`*^9}, 
   3.5994664734869356`*^9, {3.59948869731579*^9, 3.599488700560596*^9}, {
   3.6089672770904512`*^9, 3.608967282066736*^9}, {3.6089686143229365`*^9, 
   3.6089686872831097`*^9}, {3.6147521287995605`*^9, 3.614752179214444*^9}, {
   3.627188375438616*^9, 3.627188376561818*^9}, {3.68628790781339*^9, 
   3.686287947052701*^9}, 
   3.692595257989847*^9},ExpressionUUID->"901b3b9e-c459-4e07-b960-\
307b9786fd81"],

Cell["\<\
All these packages together with this notebook are contained in the file \
DGC.zip  which can be downloaded from my homepage.\
\>", "Text",
 CellChangeTimes->{{3.5994661710726385`*^9, 3.5994662775667295`*^9}, {
  3.6190050343161287`*^9, 3.6190050353701887`*^9}, {3.6271884497495513`*^9, 
  3.6271884511691537`*^9}, {3.686288029707841*^9, 
  3.686288045027549*^9}},ExpressionUUID->"8616df95-ef53-495d-b5a9-\
3b2185daf998"],

Cell["Now save the notebook with your changes. ", "Text",
 CellChangeTimes->{{3.5994665178194714`*^9, 3.5994666645828657`*^9}, 
   3.599466711174531*^9},ExpressionUUID->"497810bd-1b48-449b-9cbf-\
5de8dcfd4333"]
}, Closed]],

Cell[CellGroupData[{

Cell["Start Initialization", "Subsection",
 CellChangeTimes->{{3.586059422846844*^9, 3.586059429305256*^9}, {
  3.5994666801267548`*^9, 
  3.5994666865821238`*^9}},ExpressionUUID->"f39ee561-ff90-4f73-8cdb-\
8ce5ffc7f832"],

Cell[TextData[{
 "Start the session with the menu entry\n",
 StyleBox["Evaluation/Evaluate Initialization Cells",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{3.5994667527829103`*^9, 3.5994668982962337`*^9, 
  3.6174540239292994`*^9},ExpressionUUID->"02858510-ca01-4926-a195-\
93f6a46c3357"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<eudiffgeov3`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5866138547444267`*^9, 3.5866138692368517`*^9}, {
   3.586613950076194*^9, 3.5866139579230075`*^9}, {3.5866140674976*^9, 
   3.5866140721308084`*^9}, {3.599488731869851*^9, 3.5994887396542645`*^9}, {
   3.6146876112871456`*^9, 3.6146876600459347`*^9}, 3.620195830390541*^9, 
   3.62019876191989*^9, {3.622600738722787*^9, 3.6226007397367887`*^9}, 
   3.686288076779375*^9, {3.692595328200387*^9, 3.692595353469903*^9}},
 EmphasizeSyntaxErrors->
  True,ExpressionUUID->"f1f680a0-9ce0-4c12-8ed6-407e29326026"],

Cell["\<\
With this command the packages euvecv2.m and tensalgv3.m are loaded \
automatically.\
\>", "Text",
 CellChangeTimes->{{3.6147522693505993`*^9, 3.614752329286028*^9}, 
   3.6147549420204678`*^9, 3.686288684480364*^9, 3.6862888421167583`*^9, 
   3.692595209248332*^9},ExpressionUUID->"99727518-a240-4c51-8c37-\
a63fb62c2c56"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SURFS`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.585969335797983*^9, 
  3.5859693845168686`*^9}},ExpressionUUID->"82c185fa-c99b-4493-91c4-\
47a4be4aed36"],

Cell["\<\
We occasionally apply some definitions of  Alfred Gray`s list of curve:\
\>", "Text",
 CellChangeTimes->{{3.585969287625098*^9, 3.585969330509574*^9}, {
   3.599467063031656*^9, 3.599467071758155*^9}, 3.608968714234651*^9, {
   3.614749854875474*^9, 3.614749855920676*^9}, {3.614751974502735*^9, 
   3.614752017430191*^9}},ExpressionUUID->"aa38288c-d6f8-41d6-b03d-\
4b235a7b6aa0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<CURVES`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.585969335797983*^9, 3.5859693845168686`*^9}, {
  3.599467094937481*^9, 
  3.599467126408281*^9}},ExpressionUUID->"a2449302-2161-465d-bef7-\
c7facdb28382"],

Cell[TextData[{
 "We will mainly consider surfaces in the Euclidean pace ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]],ExpressionUUID->
  "5df23dd2-8a1b-497a-9998-fba4ed469d56"],
 "; thus we define the dimension dim = 2 and the dimension of the space spdim \
=3; these values may be changed during the session."
}], "Text",
 CellChangeTimes->{{3.5859759313146715`*^9, 3.585975988666952*^9}, {
  3.599464337184517*^9, 3.5994643851282587`*^9}, {3.6960671435421047`*^9, 
  3.6960671783814287`*^9}, {3.6960777248516483`*^9, 3.69607784357085*^9}, {
  3.696573436126583*^9, 3.696573439358242*^9}, {3.696573573677512*^9, 
  3.6965735748322477`*^9}},ExpressionUUID->"3c8e655c-fe20-45cd-bb45-\
ff16d833f233"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", "2"}], ";", 
  RowBox[{"spdim", " ", "=", " ", "3"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5712056261758223`*^9, 3.571205633008634*^9}, {
   3.571290521047902*^9, 3.5712905431843405`*^9}, 3.572246357078577*^9, {
   3.5859758815878277`*^9, 3.585975898307784*^9}, 3.5994643960898857`*^9, 
   3.69606712166708*^9, {3.696077850506908*^9, 
   3.696077860731032*^9}},ExpressionUUID->"07750388-505c-4aa2-b32b-\
6f7a39ca470e"],

Cell[BoxData[
 RowBox[{"Context", "[", "dim", "]"}]], "Input",
 CellChangeTimes->{{3.6184698263965397`*^9, 
  3.6184698367237577`*^9}},ExpressionUUID->"06305b5b-f269-4d80-8839-\
8adc0b78a7d5"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Symbols and their Usages", "Subsection",
 CellChangeTimes->{{3.6271886490659027`*^9, 3.6271886537927113`*^9}, {
  3.6271969984494023`*^9, 
  3.627197006672617*^9}},ExpressionUUID->"bc68fb4d-dce9-49d5-b942-\
8087a8549533"],

Cell[CellGroupData[{

Cell["Some Hints to Usages and Help Pages", "Subsubsection",
 CellChangeTimes->{{3.686289515743649*^9, 3.686289520351625*^9}, {
  3.6960683013557653`*^9, 
  3.6960683203554277`*^9}},ExpressionUUID->"235e96cf-caf5-4c0d-a00d-\
da3dfe77ee8a"],

Cell["\<\
The next Subsections contain tables of the symbols defined in the package \
named in the title. Click the symbol (or use ?symbol) to read the usage: a \
short description of the content and the syntax of the function called with \
the symbol, e.g.\
\>", "Text",
 CellChangeTimes->{{3.627189064555636*^9, 3.6271891325329556`*^9}, {
  3.6271893877476053`*^9, 3.6271895372584705`*^9}, {3.6271896925739117`*^9, 
  3.627189757351226*^9}},ExpressionUUID->"459029d8-635c-4cb5-8be9-\
a5a93b395af3"],

Cell[BoxData[
 RowBox[{"?", "vec"}]], "Input",
 CellChangeTimes->{{3.6271897619064336`*^9, 
  3.6271897862776766`*^9}},ExpressionUUID->"95af507d-65e5-4e20-840b-\
49356011b620"],

Cell["More information can be obtained by", "Text",
 CellChangeTimes->{{3.6960675547780037`*^9, 
  3.696067574305895*^9}},ExpressionUUID->"59b8ff17-d039-4b29-911f-\
ae1c1ec413fa"],

Cell[BoxData[
 RowBox[{"??", "vec"}]], "Input",
 CellChangeTimes->{{3.696067452996483*^9, 
  3.696067506202529*^9}},ExpressionUUID->"26cce74a-aa65-485a-9a82-\
c23375e1ca37"],

Cell["\<\
I recommend to look into the package and see the definition without the \
prefixed context, here eudiffgeov3`Private`.\
\>", "Text",
 CellChangeTimes->{{3.6271907081877027`*^9, 3.6271909014054437`*^9}, 
   3.6271925396807213`*^9, 3.627192628438278*^9, {3.627192938764891*^9, 
   3.6271929510421124`*^9}, {3.6271930081724496`*^9, 3.62719300846885*^9}, {
   3.686288932500313*^9, 
   3.686288934540328*^9}},ExpressionUUID->"acc270a5-ba57-45e3-a325-\
1c99b89b7f92"],

Cell[TextData[{
 "The ?-method may be applied to all built-in symbols of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " too, e.g. "
}], "Text",
 CellChangeTimes->{{3.627189871044626*^9, 3.6271898728230295`*^9}, {
   3.627189904807086*^9, 3.6271900373493195`*^9}, 3.6271926848071775`*^9, {
   3.696067654545702*^9, 
   3.696067655865217*^9}},ExpressionUUID->"4ae7f3e0-bac0-4368-90ea-\
2a14bf662802"],

Cell[BoxData[
 RowBox[{"?", "D"}]], "Input",
 CellChangeTimes->{{3.62718999802925*^9, 
  3.62718999802925*^9}},ExpressionUUID->"73b2565a-a3e5-4a21-9fc4-\
a74d9e3a0851"],

Cell[TextData[{
 "Click ",
 Cell[BoxData[
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/D"]], "PrintUsage",
  CellChangeTimes->{3.6271899996516533`*^9},ExpressionUUID->
  "5bc134a5-ae19-4ca7-8b30-e55f62f2fd9e"],
 " to read the corresponding help page. To see the explicit definition use"
}], "Text",
 CellChangeTimes->{{3.627190069972977*^9, 3.6271900917838154`*^9}, {
  3.62719012261347*^9, 
  3.6271901802635717`*^9}},ExpressionUUID->"cb59419b-c0e6-44fb-a9e4-\
902da3397f44"],

Cell[BoxData[
 RowBox[{"??", "D"}]], "Input",
 CellChangeTimes->{{3.696067678998776*^9, 
  3.696067680721431*^9}},ExpressionUUID->"9b019aa0-4206-4876-ac06-\
56581494a0af"],

Cell["\<\
The help-page for a built-in function can be seen marking the corresponding \
Symbol and pressing the key F1, e.g. mark Symbol. 
As a rule, the names of the built-in functions begin with a capital, during \
the names of the functions defined in our packages begin with a small letter.\
\>", "Text",
 CellChangeTimes->{{3.6960678991110764`*^9, 3.696068017558298*^9}, {
  3.6960680788777018`*^9, 
  3.696068271308123*^9}},ExpressionUUID->"1740bd6c-081e-4ba6-a537-\
9e1c4080bf23"]
}, Closed]],

Cell[CellGroupData[{

Cell["tensalgv3.m", "Subsubsection",
 CellChangeTimes->{{3.5860594705829277`*^9, 3.5860594762925377`*^9}, {
   3.5866141508017464`*^9, 3.586614156807757*^9}, {3.5994887803547363`*^9, 
   3.599488783396742*^9}, {3.68628823116998*^9, 3.6862882329376497`*^9}, 
   3.6925951806132917`*^9},ExpressionUUID->"8861c3be-2a00-4aff-82e4-\
dc542f20f68c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "tensalgv3`*"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.571131128509915*^9, 3.57113114290874*^9}, {
   3.571326268599413*^9, 3.5713262712705655`*^9}, 3.5866141747165885`*^9, {
   3.59948905583562*^9, 3.5994890593768263`*^9}, {3.686288171607883*^9, 
   3.686288174890792*^9}, 
   3.692595165490885*^9},ExpressionUUID->"1d863dec-c94b-49c5-b816-\
0d2997b2d588"],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["tensalgv3`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["tensalgv3`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["afftr",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"afftr", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["cova",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"cova", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["null",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"null", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["tensorproduct",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"tensorproduct", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["altform",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"altform", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["covalt",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"covalt", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["nullmatrix",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"nullmatrix", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["tensorToArray",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"tensorToArray", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["andtest",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"andtest", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["covec",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"covec", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["nulltensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"nulltensor", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["times",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"times", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["ArrayTotensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"ArrayTotensor", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["covector",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"covector", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["one",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"one", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["tp",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"tp", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["basis",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"basis", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["covecTotensor",
          BaseStyle->"InformationLink",
          ButtonData:>{
           "Info63708329047-6824778", {"covecTotensor", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["ortest",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"ortest", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["tpl",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"tpl", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["blf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"blf", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["covpermute",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"covpermute", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["outzero",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"outzero", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["trace",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"trace", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["cbary",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"cbary", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["covs",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"covs", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["plus",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"plus", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["tradf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"tradf", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["cc",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"cc", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["covsym",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"covsym", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["point",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"point", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["transpose",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"transpose", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["cc$",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"cc$", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["cr",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"cr", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["projpt",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"projpt", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["trp",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"trp", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["cgeo",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"cgeo", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["dotnorme",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"dotnorme", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["projpt3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"projpt3D", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["tstb",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"tstb", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["coalttensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"coalttensor", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["eps",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"eps", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["ptind",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"ptind", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["type",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"type", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["contra",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"contra", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["epst",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"epst", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["randommatrix",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"randommatrix", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["vec",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"vec", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["contraalttensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"contraalttensor", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["eps$",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"eps$", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["randomv",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"randomv", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["vector",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"vector", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["contraction",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"contraction", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["equi",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"equi", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["rank",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"rank", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["vecTotensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"vecTotensor", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["contralt",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"contralt", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["extprod",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"extprod", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["renorm",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"renorm", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["vtstb",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"vtstb", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["contrapermute",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"contrapermute", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["lf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"lf", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["smoothing",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"smoothing", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["wedge",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"wedge", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["contras",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"contras", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["linform",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"linform", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["stb",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"stb", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["wedgeform",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"wedgeform", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["contrasym",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"contrasym", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["lts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"lts", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["strictcoords",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"strictcoords", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["wedgevector",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"wedgevector", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["contrasymtensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"contrasymtensor", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["mathff",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"mathff", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["symform",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"symform", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["wtstb",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"wtstb", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["coords",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"coords", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["matrix",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"matrix", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["tensor",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"tensor", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["zero",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"zero", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"]},
        {
         ButtonBox["cosymtensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"cosymtensor", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["noprops",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info63708329047-6824778", {"noprops", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], 
         ButtonBox["tensorbasis",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info63708329047-6824778", {"tensorbasis", "tensalgv3`"}},
          ButtonNote->"tensalgv3`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.2375]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{
  3.708321847146674*^9},ExpressionUUID->"f0ad0d3d-1f94-40b9-8fb0-\
d6fb5aa8e639"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["euvecv2.m", "Subsubsection",
 CellChangeTimes->{{3.586059450100092*^9, 3.5860594543120995`*^9}, 
   3.6115594634664087`*^9, {3.686288241937818*^9, 
   3.686288243977635*^9}},ExpressionUUID->"8162adf9-0d6a-4cd8-bea4-\
3e7999b325f4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "euvecv2`*"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5711311501159525`*^9, 3.5711311592419686`*^9}, {
  3.686288314980022*^9, 
  3.686288317057757*^9}},ExpressionUUID->"eb229808-b0a4-4656-9968-\
9091eeae0290"],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["euvecv2`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["euvecv2`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["center3pts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"center3pts", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["normed",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"normed", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["sphericalreflection",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info73708329047-6824778", {"sphericalreflection", "euvecv2`"}},
          ButtonNote->"euvecv2`"]},
        {
         ButtonBox["circle3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"circle3D", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["orthocomplement",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info73708329047-6824778", {"orthocomplement", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["spherpt3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"spherpt3D", "euvecv2`"}},
          ButtonNote->"euvecv2`"]},
        {
         ButtonBox["circle3pts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"circle3pts", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["plotcircle3D",
          BaseStyle->"InformationLink",
          ButtonData:>{
           "Info73708329047-6824778", {"plotcircle3D", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["sterproj",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"sterproj", "euvecv2`"}},
          ButtonNote->"euvecv2`"]},
        {
         ButtonBox["cross",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"cross", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["plotcircle3pts",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info73708329047-6824778", {"plotcircle3pts", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["subsphere",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"subsphere", "euvecv2`"}},
          ButtonNote->"euvecv2`"]},
        {
         ButtonBox["esorthonorm",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"esorthonorm", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["plotgencircle",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info73708329047-6824778", {"plotgencircle", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["subspheremf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"subspheremf", "euvecv2`"}},
          ButtonNote->"euvecv2`"]},
        {
         ButtonBox["gencircle",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"gencircle", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["posvec3pts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"posvec3pts", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["tg4frame",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"tg4frame", "euvecv2`"}},
          ButtonNote->"euvecv2`"]},
        {
         ButtonBox["hyperplane",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"hyperplane", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["print",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"print", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["tube",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"tube", "euvecv2`"}},
          ButtonNote->"euvecv2`"]},
        {
         ButtonBox["innerprod",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"innerprod", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["radius3pts",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"radius3pts", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["unit",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"unit", "euvecv2`"}},
          ButtonNote->"euvecv2`"]},
        {
         ButtonBox["invsterproj",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"invsterproj", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["sph3D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"sph3D", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["unitvec",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"unitvec", "euvecv2`"}},
          ButtonNote->"euvecv2`"]},
        {
         ButtonBox["neglect",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"neglect", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["sphere",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"sphere", "euvecv2`"}},
          ButtonNote->"euvecv2`"], ""},
        {
         ButtonBox["norm",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info73708329047-6824778", {"norm", "euvecv2`"}},
          ButtonNote->"euvecv2`"], 
         ButtonBox["sphereplot3D",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info73708329047-6824778", {"sphereplot3D", "euvecv2`"}},
          ButtonNote->"euvecv2`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.31666666666666665`]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{
  3.708321847279293*^9},ExpressionUUID->"131a30a2-58cd-4949-956f-\
7df3efc53211"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"?", "Norm"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.61155672679888*^9, 3.611556761217849*^9}, {
  3.6115568297847705`*^9, 
  3.61155684060939*^9}},ExpressionUUID->"2f75035e-6f87-403b-8e2f-\
c1ec9689aef9"]
}, Closed]],

Cell[CellGroupData[{

Cell["eudiffgeov3", "Subsubsection",
 CellChangeTimes->{{3.6226128203622694`*^9, 3.622612837241499*^9}, 
   3.627188607300629*^9, 
   3.686288250929929*^9},ExpressionUUID->"5da4ef17-4e19-4c10-a4a3-\
f6ff952e2408"],

Cell["eudiffgeov3.m is an enlargement of eudiffgeo.m.", "Text",
 CellChangeTimes->{{3.622729922965193*^9, 3.6227299695936747`*^9}, 
   3.627192704106411*^9, {3.6271927442980824`*^9, 3.6271927490092907`*^9}, 
   3.6271927930385685`*^9, 
   3.6862889842258053`*^9},ExpressionUUID->"91529811-9f00-4124-8ecb-\
e84eb41d3f13"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "eudiffgeov3`*"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5860674081371207`*^9, 3.586067416311535*^9}, {
   3.6225995153774376`*^9, 3.6225995164850397`*^9}, 
   3.686288365394783*^9},ExpressionUUID->"4106378d-0f16-4428-8e4b-\
21faa606c071"],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["eudiffgeov3`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["eudiffgeov3`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["amf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"amf", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["d",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"d", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["graph",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"graph", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["spirgr",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"spirgr", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["arc",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"arc", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["dA",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"dA", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["identity",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"identity", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["tangent",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"tangent", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["arclength",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"arclength", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["dd",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"dd", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["inverse",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"inverse", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["tangsf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"tangsf", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["assu",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"assu", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["DD",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"DD", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["invRG",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"invRG", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["tangsp",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"tangsp", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["cf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"cf", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["DD1",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"DD1", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["invrgT",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"invrgT", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["torsion",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"torsion", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["cg",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"cg", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["DDimm",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"DDimm", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["jac",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"jac", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["tplane",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"tplane", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["christoffel1",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"christoffel1", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["dV",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"dV", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["meancurvature",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"meancurvature", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["tv",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"tv", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["circ2D",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"circ2D", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["dVol",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"dVol", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["normalcurvature",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"normalcurvature", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["tvf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"tvf", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["circle2D",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"circle2D", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["euclid",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"euclid", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["normals",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"normals", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["vv",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"vv", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["conesf",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"conesf", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["fd2",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"fd2", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["pluckerconoid",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"pluckerconoid", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["vv$",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"vv$", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["covR",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"covR", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["fr",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"fr", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["prcurvatures",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"prcurvatures", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["\[CapitalGamma]",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"\[CapitalGamma]", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["covRimm",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"covRimm", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["frame",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"frame", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["pT",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"pT", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["\[CapitalGamma]rgT",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"\[CapitalGamma]rgT", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["curvature",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"curvature", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["frenet",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"frenet", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["R",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"R", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["\[Gamma]\[Gamma]",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"\[Gamma]\[Gamma]", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["curvatures",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"curvatures", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["fund1",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"fund1", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["rgT",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"rgT", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["\[Sigma]",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"\[Sigma]", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["curvaturevector",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"curvaturevector", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["fund2",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"fund2", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["RGT",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"RGT", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["\[Omega]",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"\[Omega]", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"]},
        {
         ButtonBox["curve",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"curve", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["gauss",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"gauss", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["Rimm",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"Rimm", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], ""},
        {
         ButtonBox["cylindersf",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"cylindersf", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["geodcurvature",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info83708329047-6824778", {"geodcurvature", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], 
         ButtonBox["spiral",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info83708329047-6824778", {"spiral", "eudiffgeov3`"}},
          ButtonNote->"eudiffgeov3`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.2375]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{
  3.708321847437192*^9},ExpressionUUID->"90a98186-8c65-413e-b807-\
b1224f88b5ee"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"frenet", "[", "curve", "]"}], "[", "s", "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6282285451661806`*^9, 
  3.6282285860694523`*^9}},ExpressionUUID->"cfc8a4e9-ef4b-497b-8014-\
ecb042e15126"],

Cell[BoxData[
 RowBox[{"Head", "[", "pluckerconoid", "]"}]], "Input",
 CellChangeTimes->{{3.627635308007902*^9, 3.6276353189163218`*^9}, 
   3.6276354207255015`*^9, 
   3.6276357861763473`*^9},ExpressionUUID->"d2e1e341-829d-46d9-aee1-\
834290d053ba"],

Cell[BoxData[
 RowBox[{"Context", "[", "pluckerconoid", "]"}]], "Input",
 CellChangeTimes->{{3.6276353364059525`*^9, 3.627635359374193*^9}, {
  3.6276357266688423`*^9, 
  3.627635733550454*^9}},ExpressionUUID->"45799b1b-ab81-4f65-aa22-\
7198b4183480"],

Cell[BoxData[
 RowBox[{"?", "pluckerconoid"}]], "Input",
 CellChangeTimes->{{3.62763516519485*^9, 3.6276351671448536`*^9}, {
   3.6276352277161603`*^9, 3.627635234270172*^9}, 3.627635277878249*^9, {
   3.6276357478088794`*^9, 
   3.627635761742704*^9}},ExpressionUUID->"6ebd0982-52fc-42fb-b850-\
ef398d04f73f"]
}, Closed]],

Cell[CellGroupData[{

Cell["SURFS.m", "Subsubsection",
 CellChangeTimes->{{3.5860594887413597`*^9, 3.586059509489396*^9}, {
  3.5994638339537334`*^9, 3.5994638358238406`*^9}},
 CellTags->"Gsf",ExpressionUUID->"ef0056b5-478d-4b80-8800-ceb18e11bfaf"],

Cell["\<\
Evaluating the next cell yields Alfred Gray\[CloseCurlyQuote]s catalog of \
surfaces:\
\>", "Text",
 CellChangeTimes->{{3.627193786044938*^9, 3.6271938278766127`*^9}, {
  3.6271938611262712`*^9, 
  3.627193869004285*^9}},ExpressionUUID->"543d793c-d8bd-4193-a106-\
17cbc4560a07"],

Cell[BoxData[
 RowBox[{"?", "SURFS`*"}]], "Input",
 CellChangeTimes->{{3.6201990028108015`*^9, 
  3.620199018676029*^9}},ExpressionUUID->"ce553396-f604-4b8a-9819-\
1bf99403a7f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Names", "[", "\"\<SURFS`*\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.6271942446677475`*^9, 3.6271942486633544`*^9}, {
   3.6271963024853754`*^9, 3.6271963626148815`*^9}, {3.627196538152791*^9, 
   3.627196539993594*^9}, 
   3.627196640250371*^9},ExpressionUUID->"c9bef079-e16a-4f7a-bbe8-\
5c28139e2e67"],

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.627196370947296*^9, 
  3.6271963824933167`*^9}},ExpressionUUID->"3a50edde-7438-4353-8305-\
93f82ad770d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"3", 
    RowBox[{"Pi", "/", "2"}]}], ",", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",ExpressionUUID->"aa037684-a5af-\
4396-a684-4743fffcbea9"],

Cell["\<\
I replaced the name  \[OpenCurlyDoubleQuote]sphere\[CloseCurlyDoubleQuote] as \
defined by Alfred Gray with \[OpenCurlyDoubleQuote]sphero\
\[CloseCurlyDoubleQuote], since sphere has been defined more general in \
euvecv2.m:\
\>", "Text",
 CellChangeTimes->{{3.585970879065495*^9, 3.5859709333067904`*^9}, {
   3.5859710012426877`*^9, 3.5859710386748285`*^9}, {3.585971099242293*^9, 
   3.585971118058369*^9}, 3.5859754962357864`*^9, 
   3.68628885869487*^9},ExpressionUUID->"d1e62a04-2520-4c00-9a8d-\
4ffe36eea828"],

Cell[BoxData[
 RowBox[{"?", "sphere"}]], "Input",
 CellChangeTimes->{{3.585970828271806*^9, 
  3.58597083093941*^9}},ExpressionUUID->"09f62588-625b-4e80-b074-\
54f198c34b6e"],

Cell[BoxData[
 RowBox[{"Context", "[", "sphere", "]"}]], "Input",
 CellChangeTimes->{{3.585971045570223*^9, 
  3.585971062668201*^9}},ExpressionUUID->"062bf915-6863-4238-9d33-\
d636c4809162"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sphere", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "1"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"sphero", "[", "1", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.58597550835948*^9, 
  3.5859755988446555`*^9}},ExpressionUUID->"a5067f5b-f860-450b-a129-\
957fac4adea7"],

Cell["Don' t confuse this with the built-in Graphics3D primitive", "Text",
 CellChangeTimes->{{3.5859715472679186`*^9, 3.585971593930588*^9}, {
  3.585971635217949*^9, 
  3.5859716626585183`*^9}},ExpressionUUID->"3a77affe-98ae-4290-a1eb-\
c6d18c274dd0"],

Cell[BoxData[
 RowBox[{"?", "Sphere"}]], "Input",
 CellChangeTimes->{{3.585969549128358*^9, 
  3.5859695523263636`*^9}},ExpressionUUID->"c1ccd43c-6e1f-46de-956b-\
5a1f066b982b"],

Cell[BoxData[
 RowBox[{"Sphere", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", "1"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.614752453779148*^9, 3.6147525783602743`*^9}, 
   3.6147526639211683`*^9},ExpressionUUID->"834a8d8d-009b-4dd4-8ba1-\
e045ddf19d67"],

Cell[BoxData[
 RowBox[{"Sphere", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", 
   RowBox[{"1", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6147526670623474`*^9, 3.6147526670953493`*^9}, {
  3.614752714673071*^9, 
  3.6147527157761335`*^9}},ExpressionUUID->"b80fee63-ba7c-40d9-b570-\
1c30cda60d3a"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"Graphics3D", "[", "%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6147525998515034`*^9, 3.6147526487042975`*^9}, 
   3.6147526791610394`*^9},ExpressionUUID->"e8fc7502-b25b-4924-9216-\
a4dec290ece4"]
}, Closed]],

Cell[CellGroupData[{

Cell["CURVES.m", "Subsubsection",
 CellChangeTimes->{{3.5860594887413597`*^9, 3.586059509489396*^9}, {
  3.5994638339537334`*^9, 3.5994638358238406`*^9}, {3.599469927037876*^9, 
  3.5994699297330303`*^9}},ExpressionUUID->"e7b51531-6e40-4b98-b7cb-\
b2ed776f1633"],

Cell["\<\
Evaluating the next cell yields Alfred Gray\[CloseCurlyQuote]s catalog of \
curves:\
\>", "Text",
 CellChangeTimes->{{3.627193786044938*^9, 3.6271938278766127`*^9}, {
  3.6271938611262712`*^9, 3.627193869004285*^9}, {3.627193916871169*^9, 
  3.627193918540372*^9}},ExpressionUUID->"3526dda7-b8a3-4d6d-a857-\
89b592221634"],

Cell[BoxData[
 RowBox[{"?", "CURVES`*"}]], "Input",
 CellChangeTimes->{{3.61475153190962*^9, 
  3.614751542782839*^9}},ExpressionUUID->"5c0f7610-3570-4961-9b3b-\
46af35623202"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Names", "[", "\"\<CURVES`*\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.6271942446677475`*^9, 3.6271942486633544`*^9}, {
   3.6271963024853754`*^9, 3.6271963626148815`*^9}, {3.6271965685300446`*^9, 
   3.6271965796860647`*^9}, 
   3.627196623057141*^9},ExpressionUUID->"e5610bbc-aa9c-4e60-8060-\
3fb5a1366f8d"],

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.627196370947296*^9, 
  3.6271963824933167`*^9}},ExpressionUUID->"8c31b61b-f3e9-4cc6-9638-\
8f64b38ed620"]
}, Closed]],

Cell[CellGroupData[{

Cell["Global", "Subsubsection",
 CellChangeTimes->{{3.5860594887413597`*^9, 3.586059509489396*^9}, {
  3.5994638339537334`*^9, 3.5994638358238406`*^9}, {3.599469927037876*^9, 
  3.5994699297330303`*^9}, {3.6201992683798122`*^9, 
  3.620199272233019*^9}},ExpressionUUID->"9618eda6-5c1b-4486-a845-\
31b760601338"],

Cell["\<\
Evaluate the next cell to see the symbols actually used in Global Context\
\>", "Text",
 CellChangeTimes->{{3.6201992773654275`*^9, 
  3.620199340423375*^9}},ExpressionUUID->"e260c51f-0238-4afc-9b7e-\
8f7522b3d17e"],

Cell[BoxData[
 RowBox[{"?", "Global`*"}]], "Input",
 CellChangeTimes->{{3.6201992089418144`*^9, 
  3.6201992164298277`*^9}},ExpressionUUID->"ebc7a4da-e05b-41fc-8880-\
a45a1ff6b8c1"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. The Local Structure Forms of a Surface", "Section",
 CellChangeTimes->{{3.5720851282978826`*^9, 3.5720851431179085`*^9}, {
   3.5722464122558737`*^9, 3.5722464218342905`*^9}, 3.572613861614375*^9, {
   3.5860591355255394`*^9, 3.58605916430759*^9}, 3.5860595807347217`*^9, {
   3.586924985356963*^9, 3.586924992786388*^9}, {3.5872723940085163`*^9, 
   3.5872723973337064`*^9}, {3.5994702008395367`*^9, 3.59947020282165*^9}, 
   3.599487297135331*^9, {3.6245220427340345`*^9, 3.624522046088041*^9}, {
   3.6271999044935236`*^9, 3.627199906381127*^9}, 3.627287277418764*^9, {
   3.6900064172809896`*^9, 3.690006421744822*^9}, 
   3.690283361076742*^9},ExpressionUUID->"4b5771b4-d760-4c94-ae38-\
68743d778d19"],

Cell[CellGroupData[{

Cell["1.1.  Differential and Parameter Representation of Surfaces", \
"Subsection",
 CellChangeTimes->{{3.572614110263212*^9, 3.5726141131960173`*^9}, {
  3.58605919842485*^9, 3.5860592061936636`*^9}, {3.587272403656068*^9, 
  3.587272408134324*^9}, {3.627104472934962*^9, 3.6271044757117667`*^9}, {
  3.6271046284048347`*^9, 3.6271046373592505`*^9}, {3.6865518320491877`*^9, 
  3.6865518891839867`*^9}},ExpressionUUID->"47948dce-9f12-451b-9822-\
71f42458ee37"],

Cell[CellGroupData[{

Cell["1.1.1. Surfaces. Tangent Planes. Regular and Singular Points", \
"Subsubsection",
 CellChangeTimes->{{3.68655194583191*^9, 3.686551966415503*^9}, {
   3.686708153503846*^9, 3.6867082540218363`*^9}, {3.690009546040063*^9, 
   3.69000957780742*^9}, 
   3.693396415934434*^9},ExpressionUUID->"a84524ce-481d-434b-ac7e-\
d14f37ab32c4"],

Cell[TextData[{
 "A  ",
 StyleBox["general surface",
  FontColor->RGBColor[0, 0, 1]],
 " in a  space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "25fd6ab9-0c26-4d77-9aaf-ea1c7e2cb7c5"],
 " with arbitrary coordinates is defined by"
}], "Text",
 CellChangeTimes->{{3.572855115891306*^9, 3.572855271251192*^9}, 
   3.588919489132287*^9, 3.5994873207225723`*^9, {3.6175282598773465`*^9, 
   3.6175282606261477`*^9}, {3.686551994203944*^9, 3.686551994204156*^9}, {
   3.6865520437276087`*^9, 3.6865520744951563`*^9}, {3.686552112495398*^9, 
   3.686552113759325*^9}},ExpressionUUID->"9d552528-bb6d-434c-b324-\
4eb52e64b864"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sf", "[", 
   RowBox[{"u_", ",", "v_", ",", 
    RowBox[{"n_:", "spdim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "i", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5728552771865315`*^9, 3.5728553233421717`*^9}, {
   3.6175282729813695`*^9, 3.6175282741981716`*^9}, {3.686405571173374*^9, 
   3.686405592849399*^9}, {3.68655201090835*^9, 3.686552024160572*^9}, {
   3.696077458994488*^9, 3.696077459758288*^9}, {3.696077496742341*^9, 
   3.696077558598494*^9}, 3.6960776102742863`*^9, 
   3.696077643611249*^9},ExpressionUUID->"9a978b70-4ba5-4cf1-be61-\
65fd6e3ab4b4"],

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.57285533188666*^9, 3.5728553521568193`*^9}, {
   3.6175282908278008`*^9, 3.617528294915008*^9}, {3.696077593333208*^9, 
   3.6960775938132467`*^9}, 
   3.696077978903709*^9},ExpressionUUID->"ff2562bc-a4e7-46bd-b704-\
21cd54657606"],

Cell[TextData[{
 StyleBox["Example 1",
  FontColor->RGBColor[0, 0, 1]],
 ". Chose one of the surfaces from ",
 ButtonBox["A. Gray\[CloseCurlyQuote]s catalog",
  BaseStyle->"Hyperlink",
  ButtonData->"Gsf"],
 ", e.g."
}], "Text",
 CellChangeTimes->{{3.686624900460184*^9, 3.686624963689372*^9}, {
  3.686625163400269*^9, 
  3.6866251634018707`*^9}},ExpressionUUID->"e848169d-7ba1-4da0-83df-\
4a602e5a0671"],

Cell[BoxData[
 RowBox[{"?", "catenoid"}]], "Input",
 CellChangeTimes->{{3.686624974373966*^9, 
  3.6866249796446953`*^9}},ExpressionUUID->"1a0ba42f-6758-4764-95fe-\
e1f82fe6b6d0"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"catenoid", "[", "1", "]"}], "[", 
   RowBox[{"0", ",", 
    RowBox[{"3", 
     RowBox[{"Pi", "/", "2"}]}], ",", 
    RowBox[{"-", "1.5"}], ",", "1.5"}], "]"}], "MSG"]], "Input",
 CellChangeTimes->{{3.6925974256030073`*^9, 
  3.6925974514322777`*^9}},ExpressionUUID->"f7ae1417-3d88-4a05-95a7-\
40bf2560b88d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"catenoid", "[", "1", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.686625183145443*^9, 
  3.6866252143270683`*^9}},ExpressionUUID->"9b6ae95d-ef51-4076-b295-\
fbcb06cf3959"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"catenoid", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686625226313533*^9, 
  3.686625286118516*^9}},ExpressionUUID->"cf8781fb-ee28-4f26-9dfa-\
1cb746513d48"],

Cell["\<\
Click with the left mouse button on the figure, hold the button, and move the \
mouse to move the surface. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.6866253386187887`*^9, 3.686625393567437*^9}, {
  3.6866254254018707`*^9, 
  3.686625433668646*^9}},ExpressionUUID->"b385c442-a6a8-485a-a55a-\
0a3ce5a4679a"],

Cell[TextData[{
 "It is generally assumed that sf is defined on an open domain  U of real ",
 StyleBox["parameters",
  FontColor->RGBColor[0, 0, 1]],
 " u,v: {u,v} \[Epsilon] U\[Subset]",
 Cell[BoxData[
  SuperscriptBox["R", "2"]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.5889229806212196`*^9, 3.58892300926287*^9}, {
   3.588923056577753*^9, 3.5889230913970137`*^9}, {3.588941572646332*^9, 
   3.5889415857815547`*^9}, {3.686549175495696*^9, 3.686549207580677*^9}, {
   3.686549243164425*^9, 3.686549327244527*^9}},ExpressionUUID->
  "155e9555-c974-4141-855f-9a57aeaa4b8c"],
 ", and that the components of sf are smooth functions. In this notebook it \
is assumed mostly that sf[u,v] is a point in the Euclidean 3-space with  \
orthonormal Cartesian coordinates f[i][u,v].  Essential for the application \
of analysis  to geometry is the concept of the ",
 StyleBox["differential",
  FontColor->RGBColor[0, 0, 1]],
 ". If f: U \[RightArrow] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "m"], TraditionalForm]],ExpressionUUID->
  "24f25d6f-4329-4146-b168-02817acd9be0"],
 " is a map of an open set U\[Subset]",
 Cell[BoxData[
  SuperscriptBox["M", "m"]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.5889229806212196`*^9, 3.58892300926287*^9}, {
   3.588923056577753*^9, 3.5889230913970137`*^9}, {3.588941572646332*^9, 
   3.5889415857815547`*^9}, {3.686549175495696*^9, 3.686549207580677*^9}, {
   3.686549243164425*^9, 3.686549327244527*^9}},ExpressionUUID->
  "90f8b93b-4eb9-4710-8eea-fd006797ad93"],
 " of the m-dimensional space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "m"], TraditionalForm]],ExpressionUUID->
  "415ea3f5-407d-4c02-a113-251d4b3ffd61"],
 " with real coordinates {x,y,...} and values in an n-dimensional manifold ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["v", "n"], TraditionalForm]],ExpressionUUID->
  "9d7a13c1-f045-412e-acdd-1ff5f6008ae1"],
 ", its differential is defined in  eudiffgeov3.m:"
}], "Text",
 CellChangeTimes->{{3.5859775598738203`*^9, 3.5859775914046235`*^9}, {
   3.585977684324938*^9, 3.5859776866680717`*^9}, 3.585979278963146*^9, {
   3.585979493235402*^9, 3.585979610219093*^9}, {3.5859796687544413`*^9, 
   3.585979806419315*^9}, {3.5859799516676226`*^9, 3.5859799900988207`*^9}, {
   3.5859805402112856`*^9, 3.585980561378496*^9}, {3.58598075813875*^9, 
   3.5859807637550716`*^9}, 3.588919461957039*^9, {3.5889196555689793`*^9, 
   3.5889199692387304`*^9}, {3.588920019283618*^9, 3.588920055085681*^9}, {
   3.5889201160973883`*^9, 3.5889201311202145`*^9}, {3.614755195935991*^9, 
   3.61475531480779*^9}, {3.61752837015394*^9, 3.6175283750055485`*^9}, {
   3.6271031468078327`*^9, 3.6271031481650352`*^9}, {3.627103252934819*^9, 
   3.627103262029635*^9}, 3.6272831932018433`*^9, 3.686288989228394*^9, {
   3.686452741119886*^9, 3.686452744176757*^9}, {3.686552166555357*^9, 
   3.6865521665571938`*^9}, {3.686552249421475*^9, 3.686552260605763*^9}, 
   3.686552330578268*^9, {3.686552367502163*^9, 3.686552403222637*^9}, {
   3.6865524376997547`*^9, 3.6865524627722*^9}, {3.686625522542927*^9, 
   3.686625525292852*^9}, {3.686625555760868*^9, 3.686625576216041*^9}, {
   3.6866256809786053`*^9, 3.686625685122294*^9}, {3.686625724940096*^9, 
   3.6866257587461653`*^9}},ExpressionUUID->"f0102807-c4d8-4b9d-bae1-\
64e7da8cc12b"],

Cell[BoxData[
 RowBox[{"?", "d"}]], "Input",
 CellChangeTimes->{{3.61754602990119*^9, 
  3.6175460314767923`*^9}},ExpressionUUID->"a2031fe0-77b3-4928-9ca3-\
454d101a49f7"],

Cell[TextData[{
 StyleBox["Remark.",
  FontColor->RGBColor[0, 0, 1]],
 " I here used the concepts \[OpenCurlyDoubleQuote]manifold\
\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]space\
\[CloseCurlyDoubleQuote] without explicit definitions. For this notebook it \
suffices to assume that a n-dimensional manifold is an open set in the real \
n-dimensional vector space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "n"], TraditionalForm]],ExpressionUUID->
  "27c2dfb6-a813-48e7-a8b3-5c44f719725c"],
 " with Cartesian coordinates x[i ]\[Element] R, i= 1,...,n, e.g. for n = 2:"
}], "Text",
 CellChangeTimes->{{3.6272832860008073`*^9, 3.627283326830079*^9}, {
   3.627283379018572*^9, 3.627283483830557*^9}, {3.6272835614734087`*^9, 
   3.6272835689790215`*^9}, {3.62728384450554*^9, 3.6272838469235444`*^9}, {
   3.6272838871736155`*^9, 3.6272839539039326`*^9}, {3.627284077260751*^9, 
   3.6272841039835978`*^9}, {3.627284141384864*^9, 3.627284176208125*^9}, {
   3.62728420719378*^9, 3.6272842142917924`*^9}, {3.627284254949464*^9, 
   3.627284259773873*^9}, {3.6272843147055693`*^9, 3.627284348187228*^9}, {
   3.6272843983337173`*^9, 3.627284412689742*^9}, {3.627284453876815*^9, 
   3.6272844592588243`*^9}, {3.62728505210124*^9, 3.6272851089185405`*^9}, 
   3.627285144067402*^9, 3.6272851952902927`*^9, 3.68628899099475*^9, {
   3.686626188149148*^9, 3.686626189604347*^9}, 3.6866292529690638`*^9, {
   3.6866293046355057`*^9, 3.6866293650112553`*^9}, {3.686629397274992*^9, 
   3.686629413443001*^9}, {3.686629444762751*^9, 3.68662968050535*^9}, 
   3.686629718865508*^9, {3.686629853000429*^9, 3.6866298997676*^9}, 
   3.686630434852578*^9, {3.6866306077472067`*^9, 3.6866306268669157`*^9}, 
   3.696078197840547*^9},ExpressionUUID->"47c20547-4b16-4702-a4e6-\
c4a0bed3abff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", "x", "]"}], " ", "\[Element]", " ", 
  SuperscriptBox["R", "2"]}]], "Input",
 CellChangeTimes->{{3.6866297833384113`*^9, 3.6866298281366453`*^9}, 
   3.696078223756878*^9},ExpressionUUID->"9fdcd6b8-7aeb-4568-b5e8-\
a717af86a0cf"],

Cell[TextData[{
 "Generally, a n-dimensional ",
 StyleBox["manifold",
  FontColor->RGBColor[0, 0, 1]],
 " is a topological space for which each point has a neighborhood \
homeomorphic to  an open connected subset of the ",
 Cell[BoxData[
  SuperscriptBox["R", "n"]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellChangeTimes->{3.686629836879191*^9},ExpressionUUID->
  "88d85a40-286b-4005-b1a3-20a8de5889c5"],
 "; such a homeomorphism is called a ",
 StyleBox["chart",
  FontColor->RGBColor[0, 0, 1]],
 " of the manifold. In this notebook the manifold  containing the surface, \
that is the image of the map sf,  sf[u,v]\[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "dd3b888a-3f01-43b2-acf4-fb3540e2f85a"],
 ", is a n-dimensional Euclidean space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "7ea88f5a-943f-48f7-88e5-24a9c4b6bf3b"],
 "with a given orthonormal Cartesian coordinate system. The word \
\[OpenCurlyDoubleQuote]space\[CloseCurlyDoubleQuote] means always a set \
provided with a topology or an algebraic structure; it is used mostly in a \
special context, e.g. vector space.\nManifolds are considered in more details \
in our notebook ",
 ButtonBox["RG.nb",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www-irm.mathematik.hu-berlin.de/~sulanke/diffgeo.html#Riem"], 
    None},
  ButtonNote->
   "http://www-irm.mathematik.hu-berlin.de/~sulanke/diffgeo.html#Riem"],
 " about Riemannian geometry. \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.686630759497407*^9, 3.686630770937667*^9}, {
   3.686630803737391*^9, 3.686630866905077*^9}, {3.686630956864582*^9, 
   3.686630989448241*^9}, {3.6866310368639*^9, 3.686631194638986*^9}, {
   3.686631417717579*^9, 3.686631519861024*^9}, 3.6866316008687773`*^9, {
   3.6866316329403553`*^9, 3.6866317063876743`*^9}, {3.686631738243906*^9, 
   3.686631904365982*^9}, {3.686631969573135*^9, 3.6866320297006073`*^9}, {
   3.686632060033609*^9, 3.6866321599478617`*^9}, {3.686632192904129*^9, 
   3.686632253081298*^9}, {3.68663231185533*^9, 3.686632571516765*^9}, {
   3.686632688695088*^9, 3.686632688697645*^9}, {3.686632795637122*^9, 
   3.686632795639942*^9}, {3.692597780911755*^9, 3.69259778910325*^9}, {
   3.692597909823597*^9, 3.6925979110779257`*^9}, {3.6925979659568787`*^9, 
   3.692597977637892*^9}},ExpressionUUID->"d7bcb71f-5501-4c46-b1c0-\
6e865045e92d"],

Cell["\<\
In the next cell one sees the definition of d. The cell is set to be \
unevaluatable to avoid conflicts with the protected definition in \
eudiffgeov3.m. Also further on, to give easy readable information,  I copy \
the definitions of some important operations from the package into  \
unevaluatable cells.\
\>", "Text",
 CellChangeTimes->{{3.6272832860008073`*^9, 3.627283326830079*^9}, {
   3.627283379018572*^9, 3.627283483830557*^9}, {3.6272835614734087`*^9, 
   3.6272835689790215`*^9}, {3.62728384450554*^9, 3.6272838469235444`*^9}, {
   3.6272838871736155`*^9, 3.6272839539039326`*^9}, {3.627284077260751*^9, 
   3.6272841039835978`*^9}, {3.627284141384864*^9, 3.627284176208125*^9}, {
   3.62728420719378*^9, 3.6272842142917924`*^9}, {3.627284254949464*^9, 
   3.627284259773873*^9}, {3.6272843147055693`*^9, 3.627284348187228*^9}, {
   3.6272843983337173`*^9, 3.627284412689742*^9}, {3.627284453876815*^9, 
   3.6272844592588243`*^9}, {3.62728505210124*^9, 3.6272851089185405`*^9}, 
   3.627285144067402*^9, 3.6272851952902927`*^9, 3.68628899099475*^9, {
   3.686626188149148*^9, 3.686626189604347*^9}, {3.686632835418453*^9, 
   3.6866328401382923`*^9}},ExpressionUUID->"67e23ab2-416d-46d6-8aa9-\
40e852b057eb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Attributes", "[", "d", "]"}], "=", 
   RowBox[{"{", "Listable", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "f_", "]"}], "[", "x___", "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "x", "}"}], "]"}]}], ",", "u", ",", "v", ",", "i"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"m", "==", "0"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Function \>\"", ",", "f", ",", "\"\< needs arguments!\>\""}], 
          "]"}], ";", " ", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"{", "x", "}"}], ",", "f"}], "]"}], ",", " ", 
        RowBox[{"Return", "[", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"{", "x", "}"}], ",", "f"}], "]"}], "]"}]}], "]"}], ";", 
      "\n", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "<=", "m"}], ",", 
        RowBox[{"i", "++"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", 
            RowBox[{
             RowBox[{"{", "x", "}"}], "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], "==", "List"}], ",", "\n", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<Argument \>\"", ",", 
             RowBox[{
              RowBox[{"{", "x", "}"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             "\"\< is not a variable!\>\""}], "]"}], ";", " ", 
           RowBox[{"Return", "[", "]"}]}]}], "]"}]}], "]"}], ";", "\n", 
      RowBox[{"u", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"v", "[", "i", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "m"}], "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"m", "==", "1"}], ",", 
        RowBox[{"Return", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"f", "[", "v", "]"}], ",", "v"}], "]"}], "/.", " ", 
          RowBox[{"v", "->", "x"}]}], "]"}]}], "]"}], ";", "\n", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"u", "/.", 
           RowBox[{"List", "->", "Sequence"}]}], "]"}], ",", 
         RowBox[{"{", "u", "}"}]}], "]"}], "/.", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"v", "[", "i", "]"}], "->", 
          RowBox[{
           RowBox[{"{", "x", "}"}], "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "m"}], "}"}]}], " ", "]"}]}]}]}], "]"}]}], 
  ";"}]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.61754602990119*^9, 3.6175460314767923`*^9}, {
   3.686553108648807*^9, 3.68655343000786*^9}, 3.686553469646965*^9, {
   3.6865535102955513`*^9, 3.6865537659092283`*^9}, {3.686553881780119*^9, 
   3.686553890067698*^9}, {3.6865539356596403`*^9, 3.686553969075718*^9}, {
   3.686554036635344*^9, 3.686554070730412*^9}, {3.686554231976549*^9, 
   3.686554244345594*^9}, {3.686554470601953*^9, 3.6865544817276154`*^9}, {
   3.6865546432300673`*^9, 3.686554756581439*^9}, {3.686620611948222*^9, 
   3.68662066522182*^9}, {3.686620891122712*^9, 3.6866209232787724`*^9}, 
   3.686621337437991*^9, {3.6866213821341267`*^9, 3.686621525492502*^9}, 
   3.686621581964798*^9, {3.6866216131812077`*^9, 3.6866216247805653`*^9}, {
   3.686621672220532*^9, 3.68662168425342*^9}, {3.686621747899351*^9, 
   3.6866217609558*^9}, 3.686621903941905*^9, 3.6866245690790873`*^9, 
   3.686624789721539*^9},ExpressionUUID->"cb85e98f-a844-4aed-8bec-\
f60f07a4e3fe"],

Cell[TextData[StyleBox["Tests:",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.68662622150842*^9, 
  3.686626227228497*^9}},ExpressionUUID->"21e0c740-4ce4-4171-9aac-\
8db829d3c7af"],

Cell[BoxData[
 RowBox[{"Attributes", "[", "d", "]"}]], "Input",ExpressionUUID->"8fab0c5b-43dd-4a52-91df-239d6fee8ee0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "g", "]"}], ";", 
  RowBox[{
   RowBox[{"g", "[", "x___", "]"}], "=", "Pi"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "g", "]"}], "[", "x", "]"}]}]], "Input",
 CellChangeTimes->{{3.686453903210384*^9, 3.686453942545746*^9}, {
  3.6864543518301067`*^9, 3.686454354112438*^9}, {3.686454419332817*^9, 
  3.686454427872856*^9}, {3.686455497744175*^9, 3.686455510539166*^9}, {
  3.686455565684556*^9, 3.686455572034877*^9}, {3.68645583704135*^9, 
  3.686455886368506*^9}, {3.6864562193360977`*^9, 3.6864562196461763`*^9}, {
  3.6864640724715767`*^9, 
  3.6864640891652308`*^9}},ExpressionUUID->"cae8795a-146c-409a-96a9-\
afc59a7b5052"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"u", ",", "v"}], "]"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "g", "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6864562340375423`*^9, 3.6864562396537943`*^9}, {
  3.686461195783412*^9, 3.6864611978759747`*^9}, {3.686465598870026*^9, 
  3.686465612913378*^9}, {3.686475408931638*^9, 
  3.686475425254917*^9}},ExpressionUUID->"182f7e0c-3723-4ca8-883c-\
cadc1ad6c298"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"u", ",", "v"}], "]"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "g", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6864562340375423`*^9, 3.6864562396537943`*^9}, {
  3.686461195783412*^9, 3.6864611978759747`*^9}, {3.686465598870026*^9, 
  3.686465612913378*^9}, {3.686475408931638*^9, 3.686475425254917*^9}, {
  3.6864844951687937`*^9, 
  3.686484507077919*^9}},ExpressionUUID->"140912d1-1218-4388-a7fe-\
667849cfb001"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "g", "]"}], "[", "]"}]], "Input",
 CellChangeTimes->{{3.6864562340375423`*^9, 3.6864562396537943`*^9}, {
   3.686461195783412*^9, 3.6864611978759747`*^9}, 3.6864624088758907`*^9, 
   3.686462452009975*^9},ExpressionUUID->"401caa83-da00-4561-ab8c-\
d8a191d62a1a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "Sin", "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"x", "*", "y"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5954889643645163`*^9, 3.5954889724609303`*^9}, {
  3.686475467489555*^9, 3.686475472302919*^9}, {3.686489702496134*^9, 
  3.686489704196865*^9}},ExpressionUUID->"828e8299-294d-439c-95e6-\
fa4844cffaf9"],

Cell["\<\
If a function depends o a tuple of variables its differential is not defined. \
To get the differential one has to transit to tzhe corresponding \
\[OpenCurlyDoubleQuote]Sequence\[CloseCurlyDoubleQuote]:\
\>", "Text",
 CellChangeTimes->{{3.692598350928545*^9, 3.692598389784643*^9}, {
  3.692598434784157*^9, 
  3.692598577591113*^9}},ExpressionUUID->"1f717104-34fe-4481-ba1f-\
6db7172d9500"],

Cell[BoxData[
 RowBox[{"?", "Sequence"}]], "Input",
 CellChangeTimes->{{3.692598557666799*^9, 
  3.6925985640315323`*^9}},ExpressionUUID->"3424373b-ca40-4cae-8ae1-\
408471aeb5db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "Sin", "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", "*", "y"}], "}"}], "/.", 
   RowBox[{"List", "\[Rule]", "Sequence"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.692598627487351*^9, 
  3.692598640822806*^9}},ExpressionUUID->"e5dd2f85-23f4-469e-aeaa-\
cb3f4825aa0a"],

Cell["This coincides with", "Text",
 CellChangeTimes->{{3.6925989123163424`*^9, 
  3.6925989212040033`*^9}},ExpressionUUID->"5fdbf53a-3e35-4dd2-b723-\
bf5e8bdb5085"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "Sin", "]"}], "[", 
  RowBox[{"x", "*", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.5954889643645163`*^9, 3.5954889724609303`*^9}, {
  3.686475467489555*^9, 3.686475472302919*^9}, {3.6864845327608*^9, 
  3.68648454503714*^9}, {3.686489762813921*^9, 
  3.686489764340275*^9}},ExpressionUUID->"0551ebf6-c0ad-4c40-9d17-\
8854f091edd2"],

Cell["or", "Text",
 CellChangeTimes->{{3.69259894014806*^9, 
  3.6925989412520847`*^9}},ExpressionUUID->"19ca7d63-f05b-4231-8799-\
2caa1ff4cb34"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "Sin", "]"}], "[", "x", "]"}], "/.", " ", 
  RowBox[{"x", "\[Rule]", " ", 
   RowBox[{"x", "*", "y"}]}]}]], "Input",
 CellChangeTimes->{{3.692599032581333*^9, 
  3.692599069030192*^9}},ExpressionUUID->"d401f6ec-f55f-4fe2-95d8-\
ad8888ceec79"],

Cell["\<\
In this example the differential is that of the function Sin[x] of one \
variable x, considered at the special argument x*y. To get a function of two \
independent variables x,y  define first\
\>", "Text",
 CellChangeTimes->{{3.692599500039959*^9, 
  3.6925996816624527`*^9}},ExpressionUUID->"fc5c2bc9-a4db-4311-9e9a-\
f72ec05daf9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fsin", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"x", "*", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.69259873364019*^9, 3.69259877967828*^9}, {
  3.692598957872321*^9, 
  3.692598970340329*^9}},ExpressionUUID->"f04d00a7-425b-4208-82df-\
64150cf03b27"],

Cell["Then the differential is a covector with the coordinates", "Text",
 CellChangeTimes->{{3.692599746021777*^9, 
  3.692599791573292*^9}},ExpressionUUID->"3d74cf57-cbac-4a0d-a752-\
bfddaaf0a424"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "fsin", "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.692598784990288*^9, 3.69259879663739*^9}, {
  3.692598982409453*^9, 
  3.692598984052102*^9}},ExpressionUUID->"222c3e1a-cbc0-481a-be2f-\
f8aa7fc24925"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "x", "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.609226322838493*^9, 3.6092263283568087`*^9}, {
  3.6092263655099335`*^9, 3.609226372605339*^9}, {3.68647549739806*^9, 
  3.686475504645217*^9}, {3.6864767098088827`*^9, 3.686476716189076*^9}, {
  3.686484561094976*^9, 
  3.6864845703332767`*^9}},ExpressionUUID->"c270b07e-e4e0-4dbd-9c90-\
7e1bbf3f1650"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "y", "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.686476831420027*^9, 3.686476836788044*^9}, 
   3.686484584437159*^9},ExpressionUUID->"82889054-bbd7-447f-b34b-\
90cbe890f155"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "x", "]"}], "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.609226322838493*^9, 3.6092263283568087`*^9}, {
  3.6092263655099335`*^9, 3.609226372605339*^9}, {3.61752795990442*^9, 
  3.617527968266034*^9}},ExpressionUUID->"4ca3642f-3ca6-4974-a554-\
096d1f45d5d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "f", "]"}], "[", "]"}]], "Input",
 CellChangeTimes->{3.589005713465705*^9, 
  3.6175285317078238`*^9},ExpressionUUID->"7b953b66-7350-458d-9ce2-\
10be900ef5cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "f", "]"}], "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.588941818019162*^9, 3.5889418578304324`*^9}, {
   3.5889419056445165`*^9, 3.5889419058317165`*^9}, 3.5889419679354258`*^9, {
   3.5889422053522425`*^9, 3.5889422222314725`*^9}, 
   3.68654326006839*^9},ExpressionUUID->"e90ca77e-8422-4296-a742-\
0484d64aae05"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.588941818019162*^9, 3.5889418578304324`*^9}, {
   3.5889419056445165`*^9, 3.5889419058317165`*^9}, 3.5889419679354258`*^9, {
   3.5889422053522425`*^9, 3.5889422222314725`*^9}, {3.588942287455187*^9, 
   3.588942303554415*^9}, {3.5890059000743785`*^9, 3.5890059004574003`*^9}, {
   3.686475527473963*^9, 3.686475535590002*^9}, {3.686484647984795*^9, 
   3.686484654332131*^9}, 
   3.686543274542326*^9},ExpressionUUID->"09310338-bf5d-4a69-9108-\
b6dc79c698f9"],

Cell[TextData[{
 "\[FilledRectangle]\nFor a function the differential is the same as the ",
 StyleBox["gradient",
  FontColor->RGBColor[0, 0, 1]],
 " Grad"
}], "Text",
 CellChangeTimes->{{3.58892064103831*^9, 3.5889206417871113`*^9}, {
   3.5889209049439735`*^9, 3.588920957594066*^9}, {3.608968397882557*^9, 
   3.608968427011223*^9}, 3.686543333581427*^9, {3.686632899634082*^9, 
   3.6866329014813967`*^9}},ExpressionUUID->"d058c06d-cc60-4606-afc4-\
8da40dba81a5"],

Cell[BoxData[
 RowBox[{"?", "Grad"}]], "Input",
 CellChangeTimes->{{3.614773387141837*^9, 
  3.614773389891994*^9}},ExpressionUUID->"2794cb73-5b99-45da-aad8-\
7ee657f3ad99"],

Cell[BoxData[
 RowBox[{"Grad", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5889209644736786`*^9, 3.5889209987625384`*^9}, 
   3.6865432957343893`*^9},ExpressionUUID->"93b8db10-fb24-4fd3-859d-\
4633e49147c1"],

Cell["\<\
The main differences are 1. d[f][x,...]  defines an object explicitly as a \
function of x,...,  and 2. Grad can be related to many concrete coordinate \
systems often used in physical and technical applications:\
\>", "Text",
 CellChangeTimes->{{3.588921241093364*^9, 3.5889214769189787`*^9}, 
   3.588998676512214*^9, 3.5994913695242205`*^9, {3.686626320949623*^9, 
   3.6866263357892237`*^9}},ExpressionUUID->"a3db7b04-ed72-43b9-b44b-\
65c7b19b0763"],

Cell[BoxData[
 RowBox[{"Grad", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "\"\<Polar\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5889209644736786`*^9, 3.5889209987625384`*^9}, {
   3.588921087745095*^9, 3.588921103157922*^9}, {3.5889211371191816`*^9, 
   3.5889211390847845`*^9}, 
   3.6865434147900476`*^9},ExpressionUUID->"0d754463-aa87-4638-8e25-\
b22d3b205624"],

Cell["For the parameter representation  of a surface we have", "Text",
 CellChangeTimes->{{3.588921573436348*^9, 
  3.5889216404540653`*^9}},ExpressionUUID->"b204783c-6c14-4fcd-a09f-\
5573718134d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.588921645711275*^9, 3.5889216694545164`*^9}, {
   3.617599579612307*^9, 3.617599585197117*^9}, 3.696138460190727*^9, 
   3.6961385320595207`*^9},ExpressionUUID->"c5098179-4d49-4201-ac19-\
f4e2d92d79bd"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", " ", 
  RowBox[{"Grad", "[", 
   RowBox[{
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6175286024851484`*^9, 
  3.6175286391140127`*^9}},ExpressionUUID->"6d63dbd3-482c-4f34-b0a2-\
6d2715d316f1"],

Cell["Here is the function property of d[sf][u,v]:", "Text",
 CellChangeTimes->{{3.686485458125146*^9, 3.686485511972924*^9}, 
   3.690007834197275*^9, 3.692600029795538*^9, {3.696138490736602*^9, 
   3.6961385008852043`*^9}},ExpressionUUID->"7bed10d3-bf70-4338-8781-\
251311c9e5a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "sf", "]"}], "[", 
  RowBox[{"2", ",", "22"}], "]"}]], "Input",
 CellChangeTimes->{{3.6864594549814777`*^9, 
  3.6864594906421137`*^9}},ExpressionUUID->"b691c267-9d1d-426c-a775-\
5d7d3ae67480"],

Cell["Using Grad one has to set", "Text",
 CellChangeTimes->{{3.686485529501322*^9, 
  3.686485564727027*^9}},ExpressionUUID->"fceeed76-0e6b-44e4-90ed-\
cbcf1c623a7a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Grad", "[", 
   RowBox[{
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", "2"}], ",", 
    RowBox[{"v", "\[Rule]", "22"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.686485242916875*^9, 3.686485375086487*^9}, 
   3.686485410292379*^9},ExpressionUUID->"5195b28d-f22e-4e0e-ab7d-\
94ad3faebfd9"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", "%%"}]], "Input",
 CellChangeTimes->{{3.68648542301705*^9, 
  3.686485425869356*^9}},ExpressionUUID->"6b6808c9-422b-4830-86eb-\
853434772257"],

Cell["or", "Text",
 CellChangeTimes->{{3.686543505613749*^9, 
  3.686543506109662*^9}},ExpressionUUID->"ee7e09d5-85e4-427e-b12b-\
061fad7710c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sff", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
  RowBox[{"Grad", "[", 
   RowBox[{
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686485579859571*^9, 3.6864856394206743`*^9}, 
   3.68648570964569*^9, {3.686485746559496*^9, 3.686485752843149*^9}, 
   3.69260017559048*^9},ExpressionUUID->"f2470a40-90a6-4a65-ab99-\
8ee390c001e9"],

Cell[BoxData[
 RowBox[{"sff", "[", 
  RowBox[{"2", ",", "22"}], "]"}]], "Input",
 CellChangeTimes->{{3.686485648730496*^9, 
  3.6864856647721233`*^9}},ExpressionUUID->"ffcd753b-4462-40ea-8e87-\
6b2ef03d2a71"],

Cell["Using := (SetDelayed) leads to a failure", "Text",
 CellChangeTimes->{{3.686485881904461*^9, 3.686485949474958*^9}, 
   3.6864859942881317`*^9, {3.6865435294619904`*^9, 
   3.686543533381905*^9}},ExpressionUUID->"35d04a56-afd7-43a7-a351-\
28c35efa02f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"sff", ",", "u", ",", "v"}], "]"}], ";", 
  RowBox[{
   RowBox[{"sff", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"Grad", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u1", ",", "u2"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"u1", ",", "u2"}], "}"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u1", "\[Rule]", "u"}], ",", 
      RowBox[{"u2", "\[Rule]", "v"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.686485579859571*^9, 3.6864856394206743`*^9}, 
   3.68648570964569*^9, {3.686485746559496*^9, 3.686485752843149*^9}, {
   3.686485792158121*^9, 3.686485830063199*^9}, {3.707368988947988*^9, 
   3.707368991881938*^9}, {3.7073690649389677`*^9, 
   3.70736916261913*^9}},ExpressionUUID->"7db4a2fb-0679-469d-8164-\
33251c0dd42e"],

Cell[BoxData[
 RowBox[{"sff", "[", 
  RowBox[{"2", ",", "22"}], "]"}]], "Input",ExpressionUUID->"9ec28d41-7576-\
44ea-8ef0-1dca4a7e3097"],

Cell[BoxData["                                                                \
                      "], "Input",
 CellChangeTimes->{{3.707369437820999*^9, 3.707369441670391*^9}, 
   3.707369697293853*^9},ExpressionUUID->"cc2bde6d-57d6-4f42-bf48-\
35f5ad2836d1"],

Cell[BoxData[
 RowBox[{"Clear", "[", "sff", "]"}]], "Input",
 CellChangeTimes->{{3.686543624051392*^9, 
  3.686543638102188*^9}},ExpressionUUID->"c756307a-503e-4e43-9717-\
da671348fa88"],

Cell["Now we choose a general curve on the surface:", "Text",
 CellChangeTimes->{{3.627103887169533*^9, 3.6271039046571636`*^9}, {
  3.686543952012586*^9, 
  3.686543956092368*^9}},ExpressionUUID->"1b3ecfa5-6699-41d1-957d-\
76515b6bf972"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Clear", "[", "cu", "]"}], ";", 
   RowBox[{
    RowBox[{"cu", "[", "t_", "]"}], ":=", " ", 
    RowBox[{"sf", "[", 
     RowBox[{
      RowBox[{"h1", "[", "t", "]"}], ",", 
      RowBox[{"h2", "[", "t", "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.686543822460969*^9, 3.686543824550823*^9}, 
   3.686543907914125*^9, {3.68654398857732*^9, 3.68654399149345*^9}, {
   3.68654408818188*^9, 3.686544135516271*^9}, {3.686544926804884*^9, 
   3.686544941721322*^9}},ExpressionUUID->"fc185909-38fb-4985-87d9-\
3e3164cade3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "cu", "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.627103609052244*^9, 3.627103631079483*^9}, {
   3.686405298903675*^9, 3.6864053264426613`*^9}, 
   3.686543838866344*^9},ExpressionUUID->"cbc6815e-99a5-4285-be43-\
62fe625a254f"],

Cell[TextData[{
 "The differential along the curve coincides with the ",
 StyleBox["velocity vector",
  FontColor->RGBColor[0, 0, 1]],
 ", if the curve is interpreted as a motion, t as time.The  derivative D \
yields the same result:"
}], "Text",
 CellChangeTimes->{{3.627104191916068*^9, 3.627104216220911*^9}, {
   3.6271042699162054`*^9, 3.62710428975944*^9}, {3.686405461401393*^9, 
   3.68640546969698*^9}, {3.686467655833227*^9, 3.68646765941704*^9}, {
   3.686544198691173*^9, 3.686544281010419*^9}, {3.686544430570365*^9, 
   3.686544432978022*^9}, {3.68654448373792*^9, 3.686544519890254*^9}, 
   3.686632928881271*^9},ExpressionUUID->"051c0686-e155-417d-8473-\
0a2528f75137"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"cu", "[", "t", "]"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6271036592375326`*^9, 3.6271036603139343`*^9}, {
  3.6271036909367886`*^9, 3.6271037109984236`*^9}, {3.686405358650324*^9, 
  3.686405409018867*^9}, {3.686544296707234*^9, 
  3.686544338058744*^9}},ExpressionUUID->"b39bfef9-1824-4756-9df9-\
3c47a7e17fa2"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{
   RowBox[{"d", "[", "cu", "]"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.686456833756878*^9, 3.686456839753994*^9}, {
   3.686467680421114*^9, 3.6864676830651827`*^9}, {3.686467725885364*^9, 
   3.686467745878772*^9}, {3.686544562410718*^9, 3.6865445696265507`*^9}, 
   3.686544703067033*^9},ExpressionUUID->"af8113bd-4f0f-49a0-be88-\
96821d238e6b"],

Cell["and Grad almost the same", "Text",
 CellChangeTimes->{{3.6865445805587387`*^9, 
  3.686544611747685*^9}},ExpressionUUID->"07cc3f35-7ba2-417f-9280-\
8b3552754989"],

Cell[BoxData[
 RowBox[{"Grad", "[", 
  RowBox[{
   RowBox[{"cu", "[", "t", "]"}], ",", 
   RowBox[{"{", "t", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6271036592375326`*^9, 3.6271036603139343`*^9}, {
  3.6271036909367886`*^9, 3.6271037109984236`*^9}, {3.686405358650324*^9, 
  3.686405409018867*^9}, {3.686544296707234*^9, 3.6865443024191236`*^9}, {
  3.686544371576499*^9, 
  3.6865444099950523`*^9}},ExpressionUUID->"cb7b850d-3409-461c-ab6b-\
568b38c4e2d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Flatten", "[", "%", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"d", "[", "cu", "]"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.686456833756878*^9, 3.686456839753994*^9}, {
   3.686467680421114*^9, 3.6864676830651827`*^9}, {3.686467725885364*^9, 
   3.686467745878772*^9}, {3.686544562410718*^9, 3.6865445696265507`*^9}, {
   3.686544665953936*^9, 3.686544677809441*^9}, 
   3.686544718826685*^9},ExpressionUUID->"4e54b34f-0118-418a-b070-\
7a4ad43c7a6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "cu", "]"}], "[", 
  RowBox[{"Pi", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.686484990448819*^9, 
  3.68648499400861*^9}},ExpressionUUID->"695faf51-4771-4b4a-bee3-\
5d331a6b6e08"],

Cell["We introduce the curve in the parameter region {u, v} \[Element] U :", \
"Text",
 CellChangeTimes->{{3.686545101300808*^9, 3.686545167519288*^9}, {
  3.686545204139441*^9, 
  3.686545237825293*^9}},ExpressionUUID->"ce8ed0bc-bb41-40a6-9436-\
f0bce6dd11f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gf", "[", "t_", "]"}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h1", "[", "t", "]"}], ",", 
     RowBox[{"h2", "[", "t", "]"}]}], "}"}]}], ";"}]], "Input",ExpressionUUID-\
>"9dc90e02-a140-4bff-8bd6-e6f327efc8d2"],

Cell["One expects", "Text",
 CellChangeTimes->{{3.68654526363831*^9, 
  3.686545269046101*^9}},ExpressionUUID->"e894cc34-c25d-4dc2-b184-\
81dc03dbe0d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cu", "[", "t", "]"}], " ", "\[Equal]", " ", 
  RowBox[{"sf", "[", 
   RowBox[{"gf", "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6865452747383137`*^9, 
  3.68654529823877*^9}},ExpressionUUID->"57b92b7f-913a-4d42-8fec-\
9abf9e0e61c3"],

Cell["\<\
This is false.sf[g[t]] can\[CloseCurlyQuote]t be evaluated since  g[t] is a \
List\
\>", "Text",
 CellChangeTimes->{{3.6865461563826227`*^9, 3.686546168334488*^9}, {
  3.6865462665017443`*^9, 3.686546273173464*^9}, {3.686546310156946*^9, 
  3.6865463401168137`*^9}, {3.692600900148574*^9, 
  3.6926009952993603`*^9}},ExpressionUUID->"727c6215-7c8b-4671-a829-\
5c5cccfa27bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "sf", "]"}], "[", 
  RowBox[{"gf", "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.686545326061222*^9, 
  3.686545371102249*^9}},ExpressionUUID->"ae6f1402-0e04-4475-863c-\
1d6ea851adae"],

Cell["\<\
One has to transform the List into the corresponding Sequence\
\>", "Text",
 CellChangeTimes->{{3.686546451664917*^9, 3.6865465071790323`*^9}, {
  3.6926011144427853`*^9, 3.6926011153386707`*^9}, {3.692601318616975*^9, 
  3.692601343081153*^9}},ExpressionUUID->"ce7ce776-c810-4029-a2e7-\
04b8d8d89c65"],

Cell["This is done by the function lts (\[OpenCurlyDoubleQuote]List To \
Sequence\[CloseCurlyDoubleQuote]):", "Text",
 CellChangeTimes->{{3.6865469839737873`*^9, 3.686547000413722*^9}, {
  3.686547179883792*^9, 3.6865471805797577`*^9}, {3.686548261754813*^9, 
  3.686548323066119*^9}},ExpressionUUID->"f21020b1-ac33-46e6-9a85-\
0cdfd00fb957"],

Cell[BoxData[
 RowBox[{"??", "lts"}]], "Input",
 CellChangeTimes->{{3.686548244834199*^9, 3.686548248411194*^9}, 
   3.696138770690048*^9},ExpressionUUID->"b6138da3-c768-487e-abcd-\
bf05427dd489"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lts", "[", "h__", "]"}], ":=", " ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", "h", "]"}], "===", " ", "List"}], ",", 
    RowBox[{"h", "/.", 
     RowBox[{"List", "\[Rule]", "Sequence"}]}], ",", " ", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"h", ",", "\"\< is not a List!\>\""}], "]"}], ";", "Null"}]}], 
   "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6865454127299213`*^9, 3.686545471940813*^9}, {
  3.686547023193202*^9, 3.686547155189234*^9}, {3.6865472722618237`*^9, 
  3.686547306514834*^9}},ExpressionUUID->"9254e15e-86aa-4673-a7b6-\
93ac8941b93a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "ccu", "]"}], ";", 
  RowBox[{
   RowBox[{"ccu", "[", "t_", "]"}], ":=", 
   RowBox[{"sf", "[", 
    RowBox[{"lts", "[", 
     RowBox[{"gf", "[", "t", "]"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.686545483792203*^9, 3.6865455228290663`*^9}, 
   3.686545659105405*^9, {3.686545749200555*^9, 3.686545796555181*^9}, 
   3.686545915118218*^9, {3.6865460179876013`*^9, 3.6865460295729113`*^9}, 
   3.686546945443749*^9},ExpressionUUID->"e9b42b4d-0fd2-407d-a9f1-\
c59965068046"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cu", "[", "t", "]"}], "\[Equal]", 
  RowBox[{"ccu", "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.686545871434265*^9, 3.686545885250342*^9}, {
  3.6865459828540077`*^9, 3.686545994817377*^9}, {3.686546038645459*^9, 
  3.6865460472489*^9}},ExpressionUUID->"dee2f2c3-f64e-415c-a223-e247490dbc6e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "cu", "]"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"d", "[", "ccu", "]"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.6865456025215473`*^9, 3.686545625780437*^9}, {
  3.6865456777091503`*^9, 3.686545697892058*^9}, {3.686545773448608*^9, 
  3.686545783203493*^9}},ExpressionUUID->"1a9d9d48-0ba1-434d-bb99-\
766ee156eab5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "cu", "]"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{
     RowBox[{"h1", "[", "t", "]"}], ",", " ", 
     RowBox[{"h2", "[", "t", "]"}]}], "]"}], ".", 
   RowBox[{
    RowBox[{"d", "[", "gf", "]"}], "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6864569259962873`*^9, 3.686456962465252*^9}, {
   3.686456994201717*^9, 3.686457110143938*^9}, {3.686457171512946*^9, 
   3.686457403541851*^9}, 3.6864577846165953`*^9, {3.686457817422009*^9, 
   3.6864578287854357`*^9}, {3.6864674775913153`*^9, 
   3.6864675301304693`*^9}, {3.686544844345502*^9, 
   3.686544856785486*^9}},ExpressionUUID->"a7076517-bd00-4890-b679-\
f9803c15b807"],

Cell[TextData[{
 StyleBox["This identity is a special case of \n",
  FontSlant->"Italic"],
 StyleBox["Lemma 1. ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["For the composition f\[SmallCircle]g of smooth functions f,g the",
  FontSlant->"Italic"],
 StyleBox[ButtonBox[" chain rule",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ChainRule.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ChainRule.html"],
  FontSlant->"Italic"],
 StyleBox[" for the differential is valid:",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.627104384092806*^9, 3.627104450377322*^9}, {
  3.68645787558384*^9, 3.6864578925361137`*^9}, {3.686458042623157*^9, 
  3.686458102342546*^9}, {3.686458165967312*^9, 3.686458165970055*^9}, {
  3.686548564944422*^9, 3.686548602400666*^9}, {3.6865487920307426`*^9, 
  3.686548839598399*^9}, {3.686548886342655*^9, 3.6865489165910883`*^9}, {
  3.6866267420297527`*^9, 3.6866267439336777`*^9}, {3.686626791470044*^9, 
  3.686626805110763*^9}, {3.686626904244626*^9, 3.686626915028453*^9}, {
  3.686626946525444*^9, 
  3.6866269474201107`*^9}},ExpressionUUID->"c0d72a51-9b96-4c6c-a3ca-\
86352d0ebc9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"f", "\[SmallCircle]", "g"}], "]"}], "[", "x", "]"}], " ", 
  "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"g", "[", "x", "]"}], "]"}], ".", 
   RowBox[{
    RowBox[{"d", "[", "g", "]"}], "[", "x", "]"}], 
   StyleBox[".",
    FontColor->GrayLevel[0]], 
   StyleBox["\[FilledSquare]",
    FontColor->GrayLevel[0]]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6865486125651817`*^9, 3.686548747447249*^9}, 
   3.686548932709936*^9},ExpressionUUID->"e277336a-5d68-4010-8fcc-\
192ecd8015ec"],

Cell["\<\
The differential of the map f is a family of linear maps defined by\
\>", "Text",
 CellChangeTimes->{{3.5889228641358147`*^9, 3.588922920763914*^9}, {
  3.68654953419409*^9, 
  3.686549535114965*^9}},ExpressionUUID->"1b5b73a7-3b16-4527-8438-\
4759f792a574"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["x", "1"], ",", "..", " ", ",", 
    SuperscriptBox[
     RowBox[{"x", " "}], "m"]}], "}"}], "\[Element]", 
  RowBox[{"U", "\[RightTeeArrow]", " ", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{
     SuperscriptBox["x", "1"], ",", "..", " ", ",", 
     SuperscriptBox[
      RowBox[{"x", " "}], "m"]}], " ", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6865493632360764`*^9, 
  3.686549429924816*^9}},ExpressionUUID->"870304a1-fa45-4dd3-8569-\
53580664865f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{
    SuperscriptBox["x", "1"], ",", "..", " ", ",", 
    SuperscriptBox[
     RowBox[{"x", " "}], "m"]}], " ", "]"}], ":", " ", 
  RowBox[{"vv", "\[Element]", 
   RowBox[{
    SuperscriptBox["R", "m"], " ", "\[RightTeeArrow]", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{
       SuperscriptBox["x", "1"], ",", "..", " ", ",", 
       SuperscriptBox[
        RowBox[{"x", " "}], "m"]}], " ", "]"}], ".", "vv"}]}], "\[Element]", 
   " ", 
   SuperscriptBox["R", "n"]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5889229806212196`*^9, 3.58892300926287*^9}, {
  3.588923056577753*^9, 3.5889230913970137`*^9}, {3.588941572646332*^9, 
  3.5889415857815547`*^9}, {3.686549175495696*^9, 3.686549207580677*^9}, {
  3.686549243164425*^9, 3.686549327244527*^9}, {3.6926017232863092`*^9, 
  3.692601729902423*^9}},ExpressionUUID->"0e1bfc5d-36e0-4763-8592-\
7daa45b3a511"],

Cell[TextData[{
 "depending on the variables (or \[OpenCurlyDoubleQuote]parameters\
\[CloseCurlyDoubleQuote]) ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "1"], ",", "..", " ", ",", 
   SuperscriptBox[
    RowBox[{"x", " "}], "m"]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.5889229806212196`*^9, 3.58892300926287*^9}, {
   3.588923056577753*^9, 3.5889230913970137`*^9}, {3.588941572646332*^9, 
   3.5889415857815547`*^9}, {3.686549175495696*^9, 3.686549207580677*^9}, {
   3.686549243164425*^9, 3.686549327244527*^9}},ExpressionUUID->
  "2b7e0cc4-cb37-4d6c-b1c9-41276059299c"],
 "."
}], "Text",
 CellChangeTimes->{{3.588923126356675*^9, 3.588923177306365*^9}, 
   3.588923467466874*^9, {3.588998814856127*^9, 3.588998820839469*^9}, 
   3.686549528458489*^9, {3.686549567431275*^9, 
   3.68654957705797*^9}},ExpressionUUID->"a8e9048c-4915-4f3c-b458-\
995843528841"],

Cell[TextData[{
 StyleBox["Example 2.",
  FontColor->RGBColor[0, 0, 1]],
 " Consider the function f: ",
 Cell[BoxData[
  SuperscriptBox["R", "2"]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.5889229806212196`*^9, 3.58892300926287*^9}, {
   3.588923056577753*^9, 3.5889230913970137`*^9}, {3.588941572646332*^9, 
   3.5889415857815547`*^9}, {3.686549175495696*^9, 3.686549207580677*^9}, {
   3.686549243164425*^9, 3.686549327244527*^9}},ExpressionUUID->
  "e0e5badf-90d2-414d-8c0a-7c0383d9e66b"],
 "\[RightArrow]",
 Cell[BoxData[
  RowBox[{
   RowBox[{"R", ".", " ", "Then"}], " ", "the", " ", "differential", " ", 
   "is"}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.5889229806212196`*^9, 3.58892300926287*^9}, {
   3.588923056577753*^9, 3.5889230913970137`*^9}, {3.588941572646332*^9, 
   3.5889415857815547`*^9}, {3.686549175495696*^9, 3.686549207580677*^9}, {
   3.686549243164425*^9, 3.686549327244527*^9}},ExpressionUUID->
  "c4c40e6c-5aa9-4ee5-95b9-30d02f50703c"]
}], "Text",
 CellChangeTimes->{{3.686549654529405*^9, 3.686549774675784*^9}, {
  3.686622383994652*^9, 3.686622395354508*^9}, {3.686626995195635*^9, 
  3.6866269959715023`*^9}},ExpressionUUID->"9d01f955-fbe0-41a7-a5d2-\
3c46bd2630fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v2", " ", "=", 
   RowBox[{"vec", "[", 
    RowBox[{"a", ",", "2"}], "]"}]}], ";", " ", 
  RowBox[{"v2", " ", "\[RightTeeArrow]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", "v2"}]}]}]], "Input",
 CellChangeTimes->{{3.5889232076484184`*^9, 3.5889232636993165`*^9}, {
   3.588923319843815*^9, 3.5889234056907663`*^9}, {3.5889234950945234`*^9, 
   3.5889235095245485`*^9}, {3.5889235406622033`*^9, 3.588923649097994*^9}, {
   3.6865503236342688`*^9, 3.68655033622929*^9}, 3.6865504721965523`*^9, {
   3.686550514400258*^9, 3.686550543976774*^9}, 
   3.686627026591202*^9},ExpressionUUID->"6828496c-857b-416b-bfbd-\
d39181620ff9"],

Cell["We test the basis forms d[u], d[v]:", "Text",
 CellChangeTimes->{{3.609226511524285*^9, 
  3.6092265438751354`*^9}},ExpressionUUID->"1a85f12b-a520-4513-b899-\
813ef783e240"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",ExpressionUUID->"0c725e6b-2abb-\
44b5-906f-bdf9a58bf22d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "==", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", "u", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", "v", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6092245895043516`*^9, 3.6092247048079467`*^9}, {
  3.6092247607681475`*^9, 3.609224765470416*^9}, {3.6092248053196955`*^9, 
  3.609224817127371*^9}, {3.6092248482401505`*^9, 
  3.609224859735808*^9}},ExpressionUUID->"62256401-9c1b-4d92-969f-\
ddb8ccba3c54"],

Cell["For vector function this rule is not valid:", "Text",
 CellChangeTimes->{{3.609226650900257*^9, 3.6092266800509243`*^9}, 
   3.6147549747243385`*^9},ExpressionUUID->"3f024191-8ec6-4c89-8178-\
0e3214909fde"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", "u", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", "v", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6092245895043516`*^9, 3.6092247048079467`*^9}, {
   3.6092247607681475`*^9, 3.609224765470416*^9}, {3.6092248053196955`*^9, 
   3.609224817127371*^9}, {3.6092248482401505`*^9, 3.609224859735808*^9}, {
   3.6092266116680126`*^9, 3.6092266305930953`*^9}, {3.6147743020511665`*^9, 
   3.6147743524020467`*^9}, {3.6864887133453693`*^9, 3.686488723932742*^9}, {
   3.6864887750617228`*^9, 3.6864888817716208`*^9}, {3.686488915337225*^9, 
   3.686488965786388*^9}, 3.686550241662771*^9, {3.686627436482932*^9, 
   3.686627446496921*^9}},ExpressionUUID->"d80d5c82-c7ae-46cd-9aef-\
efe41e7ec577"],

Cell["Instead one has to use the TensorProduct;", "Text",
 CellChangeTimes->{{3.6092267184271193`*^9, 
  3.609226736707165*^9}},ExpressionUUID->"d034656e-4ddb-49cc-989e-\
1ae041c18401"],

Cell[BoxData[
 RowBox[{"?", "TensorProduct"}]], "Input",
 CellChangeTimes->{{3.686487766526143*^9, 3.6864877726029177`*^9}, {
  3.68648780308855*^9, 
  3.6864878337068567`*^9}},ExpressionUUID->"2593a261-fe05-43e0-9586-\
57dc4cd63c0b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "==", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "\[TensorProduct]", 
    RowBox[{
     RowBox[{"d", "[", "u", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], "\[TensorProduct]", 
    RowBox[{
     RowBox[{"d", "[", "v", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6092255700064335`*^9, 3.6092255957509055`*^9}, {
   3.6092256366472445`*^9, 3.6092256596085577`*^9}, {3.6092257240252423`*^9, 
   3.6092257378640337`*^9}, {3.6092259323801594`*^9, 3.6092259767666984`*^9}, 
   3.6175997262681646`*^9},ExpressionUUID->"ce138d6e-9d01-438c-8136-\
cc7b1b440206"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", "vl"}], "\[Equal]", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"sf", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], 
      "\[TensorProduct]", 
      RowBox[{
       RowBox[{"d", "[", "u", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"sf", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], 
      "\[TensorProduct]", 
      RowBox[{
       RowBox[{"d", "[", "v", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], ".", "vl"}]}]], "Input",
 CellChangeTimes->{{3.6092255700064335`*^9, 3.6092255957509055`*^9}, {
   3.6092256366472445`*^9, 3.6092256596085577`*^9}, {3.6092257240252423`*^9, 
   3.6092257378640337`*^9}, {3.6092259323801594`*^9, 3.6092259767666984`*^9}, 
   3.6175997262681646`*^9, {3.686627762473218*^9, 
   3.686627784814115*^9}},ExpressionUUID->"15f4cf7d-cf78-4ff0-9986-\
1ab8536e3d87"],

Cell["or the evaluated functions", "Text",
 CellChangeTimes->{{3.6866275275113153`*^9, 
  3.686627540359024*^9}},ExpressionUUID->"79ec762a-5abd-42e5-a3c2-\
8b08c1b553bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vl", "=", 
   RowBox[{"vec", "[", 
    RowBox[{"a", ",", "2"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", "vl"}], "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "u", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", "vl"}]}], " ", "+", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "v", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", "vl"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.6092245895043516`*^9, 3.6092247048079467`*^9}, {
  3.6092247607681475`*^9, 3.609224765470416*^9}, {3.6092248053196955`*^9, 
  3.609224817127371*^9}, {3.6092248482401505`*^9, 3.609224859735808*^9}, {
  3.6092266116680126`*^9, 3.6092266305930953`*^9}, {3.6147743020511665`*^9, 
  3.6147743524020467`*^9}, {3.6864887133453693`*^9, 3.686488723932742*^9}, {
  3.6864887750617228`*^9, 3.6864888817716208`*^9}, {3.686488915337225*^9, 
  3.686488965786388*^9}, {3.6866270997349043`*^9, 3.686627108139348*^9}, {
  3.686627142725061*^9, 3.6866271720585213`*^9}, {3.68662720515557*^9, 
  3.686627238162601*^9}, {3.686627278363727*^9, 
  3.6866272933459387`*^9}},ExpressionUUID->"8f79e95b-fc34-4e95-bf30-\
1c425ab8a4eb"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.686627857787697*^9, 
  3.686627857789741*^9}},ExpressionUUID->"5b27ba6e-1cd7-49f3-9e63-\
225564a6b042"],

Cell["\<\
Let the surface be given by the parameter representation sf[u,v].  The \
differential of sf is the matrix\
\>", "Text",
 CellChangeTimes->{{3.686491808834898*^9, 3.6864918119627934`*^9}, {
  3.686628682800015*^9, 3.686628684815606*^9}, {3.6866287298234577`*^9, 
  3.68662878662288*^9}, {3.686633271837549*^9, 
  3.6866333699895287`*^9}},ExpressionUUID->"cdf6cc56-1efa-43e3-9a30-\
e2302a95fa94"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.614773800266466*^9, 3.6147738434019337`*^9}, {
  3.6147739088996797`*^9, 
  3.6147741230419283`*^9}},ExpressionUUID->"6be695d0-03b2-4367-bd95-\
1dcd982e5808"],

Cell["\<\
The columns of this matrix are the coordinates of the tangent vectors of the \
coordinate lines u = t,v=constant resp. u= constant, v = t:\
\>", "Text",
 CellChangeTimes->{{3.686633412708849*^9, 3.686633506612278*^9}, {
  3.68663354194799*^9, 
  3.686633601019579*^9}},ExpressionUUID->"aad9a9a8-92c2-4d2b-921a-\
16dcb16c45a9"],

Cell[BoxData[
 RowBox[{"?", "tv"}]], "Input",
 CellChangeTimes->{{3.686633612272726*^9, 
  3.686633613891519*^9}},ExpressionUUID->"fa8c310c-dc34-4217-bda2-\
fd82c6456eea"],

Cell[BoxData[
 RowBox[{"Context", "[", "tv", "]"}]], "Input",
 CellChangeTimes->{{3.693807969140937*^9, 
  3.693807979482552*^9}},ExpressionUUID->"0b341673-aa29-4950-8647-\
3739ff53ad71"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.686633639063663*^9, 
  3.686633657219522*^9}},ExpressionUUID->"08c9287b-87e2-4bea-a9b7-\
7c5f9309ffc8"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.68663369239082*^9, 3.686633745890811*^9}, 
   3.686633785077833*^9},ExpressionUUID->"6bd4840f-2f65-4b39-8f32-\
b9ad5414ec3b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686633639063663*^9, 3.686633678524016*^9}, {
   3.686633846089724*^9, 3.6866338599946613`*^9}, 
   3.686633895073888*^9},ExpressionUUID->"44ce372e-28a6-4285-a911-\
af76712aaaa8"],

Cell[TextData[{
 " A point sf[u0,v0] of the parameter representation is said to be",
 StyleBox[" regular",
  FontColor->RGBColor[0, 0, 1]],
 ", if"
}], "Text",
 CellChangeTimes->{{3.5859775598738203`*^9, 3.5859775914046235`*^9}, {
   3.585977684324938*^9, 3.5859776866680717`*^9}, 3.585979278963146*^9, {
   3.585979493235402*^9, 3.585979610219093*^9}, {3.5859796687544413`*^9, 
   3.585979806419315*^9}, {3.5859799516676226`*^9, 3.5859799900988207`*^9}, {
   3.5859805402112856`*^9, 3.585980561378496*^9}, {3.58598075813875*^9, 
   3.5859807637550716`*^9}, 3.588919461957039*^9, 
   3.588921688034149*^9},ExpressionUUID->"fbdae33a-ef2e-4ce5-9b83-\
bb72710c1d73"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u0", ",", "v0"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5859805724181275`*^9, 3.5859806608291845`*^9}, {
  3.5859807142702413`*^9, 3.5859807199815674`*^9}, {3.585980775894766*^9, 
  3.585980799256102*^9}, {3.5889217292026215`*^9, 3.588921746565452*^9}, {
  3.627286051265602*^9, 
  3.627286087914067*^9}},ExpressionUUID->"7f28cbcf-be9b-42bd-9277-\
6d8bb60681d3"],

Cell[TextData[{
 "is maximal, here equal 2, what ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "generally supposes. A smooth map of manifolds f: ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "df6632ee-1056-417c-a89d-b920c0be39f5"],
 " \[RightArrow] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "n"], TraditionalForm]],ExpressionUUID->
  "c414efd3-a394-4453-b3ea-ddbdd26ae8f6"],
 ",  m \[LessEqual] n the dimensions of the manifolds, is said to be an ",
 StyleBox["immersion",
  FontColor->RGBColor[0, 0, 1]],
 ", if it is regular at all points x \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "e649ca87-8b3b-4d3f-b01b-b1c33a369448"],
 ", that means that the differential d[f][x] has maximal rank m at each point \
x.  For the immersions considered in this notebook ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "fa14aae3-39bd-4c74-9bac-d944f764e806"],
 " is supposed  to be an open connected subset of the m-dimensional real \
parameter space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalR]", "m"], TraditionalForm]],
  ExpressionUUID->"05f194dd-4e81-4542-a9f4-5c93b1c54543"],
 ".  Such considerations are said to be ",
 StyleBox["local",
  FontColor->RGBColor[0, 0, 1]],
 "; for global results  consult the textbooks. The vector subspace spanned by \
the tangent vectors tv[i][f][ u0,v0,...], i= 1,...,m, at a regular point \
f[u0,v0,...] of the immersion is called the",
 StyleBox[" tangent space",
  FontColor->RGBColor[0, 0, 1]],
 " of the immersion at this point; for m=2 it is the ",
 StyleBox["tangent plane",
  FontColor->RGBColor[0, 0, 1]],
 ". We denote the tangent space of the immersion by"
}], "Text",
 CellChangeTimes->{{3.5859808863310823`*^9, 3.585981001738683*^9}, 
   3.5859812042752676`*^9, {3.58892214405415*^9, 3.5889221553329697`*^9}, {
   3.599489421188262*^9, 3.599489423153865*^9}, {3.6147748706876907`*^9, 
   3.614774889639775*^9}, 3.6175287613558273`*^9, {3.6176041768079815`*^9, 
   3.6176043174578285`*^9}, {3.6176043528230906`*^9, 
   3.6176044069395857`*^9}, {3.6176044518832645`*^9, 
   3.6176046332803836`*^9}, {3.617604677288061*^9, 3.6176047310457554`*^9}, {
   3.6176047705762243`*^9, 3.617604883754423*^9}, {3.617604917356882*^9, 
   3.6176049802249928`*^9}, {3.617605013109851*^9, 3.617605033795487*^9}, {
   3.61760506986275*^9, 3.617605161341311*^9}, {3.6866289056000233`*^9, 
   3.686628938943328*^9}, {3.686634847307129*^9, 3.686635133306142*^9}, {
   3.686635164911476*^9, 3.686635190850259*^9}, {3.686635286671112*^9, 
   3.686635297852141*^9}, 3.690006950780141*^9, {3.690007116094324*^9, 
   3.690007143942399*^9}},ExpressionUUID->"f2b55ea3-3efe-4390-a26b-\
dd081a3fd6bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["T", "x"], 
   RowBox[{"f", "[", 
    SuperscriptBox["X", "m"], "]"}]}], " ", ":=", " ", 
  RowBox[{"image", "[", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", "x", "]"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.690007153813271*^9, 3.69000728400342*^9}, 
   3.690007380530484*^9},ExpressionUUID->"c82d03ff-606c-4856-a592-\
86ab9e3ee112"],

Cell[TextData[{
 StyleBox["Lemma 2",
  FontColor->RGBColor[0, 0, 1]],
 ". At any regular point f[u,...]  of the immersion f: ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "3e58486c-3856-404c-ae48-821d9671ee79"],
 " \[RightArrow] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "n"], TraditionalForm]],ExpressionUUID->
  "9801a4c0-cf63-489f-b3cc-7af672929939"],
 " the tangent vectors  tv[i][f][x], i=1, ..., m, are a basis of the tangent \
vector space ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "x"], 
   RowBox[{"f", "[", 
    SuperscriptBox["X", "m"], "]"}]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.690007153813271*^9, 3.69000728400342*^9}, 
    3.690007380530484*^9},ExpressionUUID->
  "da24f68c-3898-41ac-a40c-bf1b04614104"],
 ", ",
 StyleBox["often this basis is named the",
  FontColor->GrayLevel[0]],
 StyleBox[" standard basis field of the immersion f.",
  FontColor->RGBColor[0, 0, 1]],
 "  The tangent vector space T[f][u,...]  consists of all vectors"
}], "Text",
 CellChangeTimes->{{3.5859846820571856`*^9, 3.5859849956431217`*^9}, 
   3.588922731067581*^9, 3.6176000239010873`*^9, 3.617600085723996*^9, {
   3.617603202555071*^9, 3.617603223053507*^9}, 3.6176036724278955`*^9, {
   3.6176037379480104`*^9, 3.617603739086813*^9}, {3.6176037930629077`*^9, 
   3.6176038505646086`*^9}, {3.617615688281189*^9, 3.6176157025396137`*^9}, {
   3.6227747642993546`*^9, 3.6227748548575134`*^9}, {3.627286495826786*^9, 
   3.627286519057227*^9}, {3.6866549343041487`*^9, 3.686654957655005*^9}, {
   3.686655006967897*^9, 3.6866550275226088`*^9}, {3.686655077893888*^9, 
   3.686655244188767*^9}, 3.68665555397854*^9, {3.6866557179846478`*^9, 
   3.686655720113224*^9}, {3.690007956735897*^9, 3.69000795673621*^9}, {
   3.6900080348128843`*^9, 
   3.690008064554689*^9}},ExpressionUUID->"af24ab89-6c4e-4e4a-9349-\
6352b74ff525"],

Cell[BoxData[
 RowBox[{"?", "tangsp"}]], "Input",
 CellChangeTimes->{{3.6147768255615034`*^9, 3.614776948794552*^9}, 
   3.614776996347272*^9, {3.622773295051772*^9, 3.622773314317806*^9}, {
   3.6227733699007034`*^9, 3.622773445950837*^9}, {3.6227741322926426`*^9, 
   3.622774141028658*^9}},ExpressionUUID->"73314e9e-9602-4fae-b887-\
2c572beacf54"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tangsp", "[", "f_", "]"}], "[", "u__", "]"}], "[", "x__", "]"}], 
  ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Not", "[", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"{", "x", "}"}], "]"}], "\[Equal]", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"{", "u", "}"}], "]"}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"Print", "[", "\"\<invalid arguments!\>\"", "]"}], ";", 
     RowBox[{"Return", "[", "]"}]}], ",", 
    RowBox[{"Return", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}], ".", 
      RowBox[{"{", "x", "}"}]}], "]"}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6227728201235375`*^9, 3.6227728854252524`*^9}, {
   3.622772920978715*^9, 3.6227730892718105`*^9}, {3.622773126056675*^9, 
   3.6227731974268007`*^9}, 
   3.622774638734734*^9},ExpressionUUID->"47c617ed-785a-48d1-89ca-\
09810e573009"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tangsp", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.6227732270980525`*^9, 3.6227732613401127`*^9}, {
   3.622773330448234*^9, 3.622773340057851*^9}, 
   3.622774876635152*^9},ExpressionUUID->"6a0f7563-b8fe-4458-88ae-\
3258be2a4da0"],

Cell[TextData[{
 "The ",
 StyleBox["tangent plane",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface f at the point f[u0,v0] has the parameter representation \
(with u0, v0  fixed, x ,y the variable parameters)"
}], "Text",
 CellChangeTimes->{{3.5859851459307175`*^9, 3.585985220786999*^9}, {
  3.588946109087499*^9, 3.588946114765909*^9}, {3.5889990371028385`*^9, 
  3.5889990799832916`*^9}, {3.6271053085504293`*^9, 
  3.6271053144316397`*^9}},ExpressionUUID->"db4adc24-d131-4ffb-ac9f-\
e3f1893f73a4"],

Cell[BoxData[
 RowBox[{"?", "tplane"}]], "Input",
 CellChangeTimes->{{3.6147771023553348`*^9, 3.614777261106415*^9}, 
   3.6174557564293923`*^9, {3.62277389139602*^9, 3.6227739369948997`*^9}, {
   3.6227743400702095`*^9, 
   3.6227743474646225`*^9}},ExpressionUUID->"eedb2772-25f9-4c65-b0d4-\
558283db31ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tplane", "[", "f_", "]"}], "[", 
    RowBox[{"u0_", ",", "v0_"}], "]"}], "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", "+", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"tangsp", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Rule]", "u0"}], ",", 
     RowBox[{"v", "\[Rule]", "v0"}]}], "}"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.585985258936181*^9, 3.585985353414585*^9}, {
   3.5859991971198626`*^9, 3.585999204311475*^9}, {3.5859996025801744`*^9, 
   3.585999633468229*^9}, {3.588945457053154*^9, 3.5889454978784256`*^9}, 
   3.588945546441311*^9, {3.5889991214026604`*^9, 3.5889991285400686`*^9}, {
   3.6227735926222944`*^9, 
   3.622773593511496*^9}},ExpressionUUID->"0fce594d-e55e-48a9-a6ef-\
3114edef370d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tplane", "[", "sf", "]"}], "[", 
   RowBox[{"u0", ",", "v0"}], "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.585985258936181*^9, 3.585985353414585*^9}, {
   3.5859991971198626`*^9, 3.585999204311475*^9}, {3.5859996025801744`*^9, 
   3.585999633468229*^9}, {3.588945457053154*^9, 3.5889454978784256`*^9}, 
   3.588945546441311*^9, {3.5889991214026604`*^9, 3.5889991285400686`*^9}, {
   3.5889992556603394`*^9, 
   3.588999298920814*^9}},ExpressionUUID->"713a422e-d299-46fd-bb55-\
31c1f838286c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "1", "]"}], "[", 
     RowBox[{"u0", ",", "v0"}], "]"}], "+", 
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "2", "]"}], "[", 
     RowBox[{"u0", ",", "v0"}], "]"}], "+", 
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "3", "]"}], "[", 
     RowBox[{"u0", ",", "v0"}], "]"}], "+", 
    RowBox[{"y", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}], "+", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u0", ",", "v0"}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.708321847644499*^9},ExpressionUUID->"7fbb358f-3980-48b8-9554-\
0981a643d461"]
}, Open  ]],

Cell["\<\
The tangential plane  tplane[sf][u0, v0][x, y] is defined at regular points \
sf[u0,v0] only; at non regular points the function tplane doesn\
\[CloseCurlyQuote]t yield a plane, see the next example. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.6272867521310377`*^9, 3.6272869185877314`*^9}, 
   3.6272870472103577`*^9, {3.6900083053297443`*^9, 
   3.6900083904462137`*^9}},ExpressionUUID->"cb6510f0-9b59-4fb3-8f62-\
a8efb14aa2a4"],

Cell[TextData[{
 "For concrete surfaces may exist ",
 StyleBox["singular",
  FontColor->RGBColor[0, 0, 1]],
 " (i.e. non regular) points."
}], "Text",
 CellChangeTimes->{{3.5859808863310823`*^9, 3.585981001738683*^9}, 
   3.5859812042752676`*^9, {3.58892214405415*^9, 3.5889221553329697`*^9}, {
   3.599489421188262*^9, 3.599489423153865*^9}, {3.6147748706876907`*^9, 
   3.614774889639775*^9}, 3.6175287613558273`*^9, {3.6176041768079815`*^9, 
   3.6176043174578285`*^9}, {3.6176043528230906`*^9, 
   3.6176044069395857`*^9}, {3.6176044518832645`*^9, 
   3.6176046332803836`*^9}, {3.617604677288061*^9, 3.6176047310457554`*^9}, {
   3.6176047705762243`*^9, 3.617604883754423*^9}, {3.617604917356882*^9, 
   3.6176049802249928`*^9}, {3.617605013109851*^9, 3.617605033795487*^9}, {
   3.61760506986275*^9, 3.617605161341311*^9}, {3.6866289056000233`*^9, 
   3.686628938943328*^9}, {3.686634847307129*^9, 3.686635133306142*^9}, {
   3.686635164911476*^9, 3.686635190850259*^9}, {3.686635286671112*^9, 
   3.686635297852141*^9}},ExpressionUUID->"eb32c254-c95c-4cc1-83fe-\
40836bb72a44"],

Cell[TextData[{
 StyleBox["Example 3",
  FontColor->RGBColor[0, 0, 1]],
 ". The unit sphere"
}], "Text",
 CellChangeTimes->{{3.686635446924842*^9, 
  3.6866354652287188`*^9}},ExpressionUUID->"1afe63be-e426-4642-a83f-\
8d8a859cc1a0"],

Cell[BoxData[
 RowBox[{"?", "sphero"}]], "Input",
 CellChangeTimes->{{3.686635493713806*^9, 3.686635496796773*^9}},
 CellTags->"Ex1.1.3",ExpressionUUID->"ac5f48dd-ebe1-40d4-934c-4f1c34b77a5f"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"sphero", "[", "1", "]"}], "[", 
   RowBox[{"0", ",", 
    RowBox[{"3", 
     RowBox[{"Pi", "/", "2"}]}], ",", 
    RowBox[{
     RowBox[{"-", "Pi"}], "/", "2"}], ",", 
    RowBox[{"Pi", "/", "2"}]}], "]"}], "MSG"]], "Input",
 CellChangeTimes->{{3.686635558229292*^9, 
  3.686635567309042*^9}},ExpressionUUID->"fa7a7886-b6e8-4101-bc08-\
4a30f316759d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5859810215718174`*^9, 
  3.5859810412209415`*^9}},ExpressionUUID->"db1d3c8b-4bbe-4a6b-b42f-\
985cde7e87dd"],

Cell[BoxData[
 RowBox[{"sph1", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686635611834937*^9, 3.686635698380333*^9}, {
  3.686635729171916*^9, 
  3.686635748515608*^9}},ExpressionUUID->"ff2d3048-b5ac-4b5f-bd2f-\
2ca6ad11667a"],

Cell[TextData[{
 "The coordinates on the sphere are the parameters u,v; the chosen coordinate \
system is named the ",
 ButtonBox["geographic coordinate system",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Geographic_coordinate_system"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Geographic_coordinate_system"],
 ". The curves u = t, v =constant, are called the",
 StyleBox[" latitude lines",
  FontColor->RGBColor[0, 0, 1]],
 ", e.g"
}], "Text",
 CellChangeTimes->{{3.6866369840229053`*^9, 3.68663713765702*^9}, {
  3.686637192952401*^9, 3.686637207600524*^9}, {3.686639044193995*^9, 
  3.6866391098499727`*^9}, {3.686639475799219*^9, 3.6866395060546007`*^9}, {
  3.6866395535895*^9, 3.686639553591692*^9}, {3.686639599150526*^9, 
  3.686639619382153*^9}},ExpressionUUID->"36f4455f-071e-402d-934f-\
6f6cde756211"],

Cell[BoxData[
 RowBox[{"t1", " ", "=", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], "[", 
     RowBox[{"t", ",", " ", ".6"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
    RowBox[{"PlotStyle", " ", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", " ", "Thick"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.68663714250942*^9, 3.686637169793188*^9}, {
   3.6866372215209293`*^9, 3.686637347847866*^9}, {3.686637381914645*^9, 
   3.686637410839611*^9}, 
   3.686638676074251*^9},ExpressionUUID->"d4f12fdb-64c8-445a-9c73-\
161dda4f7f3b"],

Cell[TextData[{
 "The curves u= constant, v=t are the ",
 StyleBox["meridians ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["or",
  FontColor->GrayLevel[0]],
 StyleBox[" longitude lines",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.6866374609979553`*^9, 3.6866374994856663`*^9}, {
  3.686639632477725*^9, 
  3.686639642173429*^9}},ExpressionUUID->"26406ffa-6b50-47f4-bfd6-\
809cc26cb443"],

Cell[BoxData[
 RowBox[{"t2", " ", "=", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], "[", 
     RowBox[{".2", ",", "t"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
    RowBox[{"PlotStyle", " ", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", " ", "Thick"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6866375617425213`*^9, 
  3.686637622054685*^9}},ExpressionUUID->"4ffb5466-ce99-4575-a10a-\
cae8788b510e"],

Cell["The tangent vectors at the crossing point ", "Text",
 CellChangeTimes->{{3.686637708244237*^9, 3.68663772660397*^9}, {
  3.686639732213257*^9, 
  3.686639760052808*^9}},ExpressionUUID->"aa6f8dc1-a21d-474e-8fc4-\
857c9f0add25"],

Cell[BoxData[
 RowBox[{"pt", " ", "=", 
  RowBox[{
   RowBox[{"sphero", "[", "1", "]"}], "[", 
   RowBox[{".2", ",", ".6"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.686639790933008*^9},ExpressionUUID->"85014c8c-c7c6-4cb8-8d58-\
d78b4f9e03ba"],

Cell["are", "Text",
 CellChangeTimes->{{3.6866398507962217`*^9, 
  3.686639851468055*^9}},ExpressionUUID->"753f00b7-2801-43a2-b98d-\
6fc372ecb4a6"],

Cell[BoxData[
 RowBox[{"tvs", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dotnorme", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "1", "]"}], "[", 
       RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
      RowBox[{".2", ",", ".6"}], "]"}], "]"}], ",", 
    RowBox[{"dotnorme", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "2", "]"}], "[", 
       RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
      RowBox[{".2", ",", ".6"}], "]"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.686637741776608*^9, 3.6866378961476393`*^9}, {
  3.686638697482773*^9, 3.686638705893516*^9}, {3.686837079294278*^9, 
  3.686837127697426*^9}},ExpressionUUID->"d49ebd2c-2e97-4ac8-abd0-\
491e41dbb893"],

Cell["\<\
Mathematica has a built-in function Arrow to present the vectors as \
Graphics3D objects:\
\>", "Text",
 CellChangeTimes->{{3.686639862851828*^9, 
  3.6866399460192966`*^9}},ExpressionUUID->"097dd641-50fb-4f1e-be3e-\
ae9bc5876829"],

Cell[BoxData[
 RowBox[{"?", "Arrow"}]], "Input",
 CellChangeTimes->{{3.68663790394029*^9, 
  3.68663790726757*^9}},ExpressionUUID->"67c134b2-e7de-49d0-afe2-\
2416289782d9"],

Cell["We define", "Text",
 CellChangeTimes->{{3.686639957795321*^9, 
  3.686639960779245*^9}},ExpressionUUID->"88f33705-cc2b-4df0-a89b-\
b339e08bf340"],

Cell[BoxData[
 RowBox[{"ars", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Arrow", "[", 
     RowBox[{"{", 
      RowBox[{"pt", ",", 
       RowBox[{"pt", "+", 
        RowBox[{"tvs", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], "]"}], ",", 
    RowBox[{"Arrow", "[", 
     RowBox[{"{", 
      RowBox[{"pt", ",", 
       RowBox[{"pt", "+", 
        RowBox[{"tvs", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.68663807388977*^9, 3.686638086375814*^9}, {
   3.6866381325178967`*^9, 3.6866382500011787`*^9}, {3.686638294489932*^9, 
   3.6866384195354853`*^9}, 3.686638726282761*^9, {3.686639775324843*^9, 
   3.686639781029437*^9}},ExpressionUUID->"1f82f053-9dfe-4410-a84b-\
d700066f1055"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tgs", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics3D", "[", "ars", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.686638438472722*^9, 3.6866384865748158`*^9}, {
   3.6866385209795732`*^9, 3.686638544094542*^9}, 
   3.686638744032854*^9},ExpressionUUID->"45895d7d-bea1-4f16-8470-\
0a6231341ad1"],

Cell[BoxData[
 RowBox[{"figsph", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sph1", ",", "t1", ",", "t2", ",", "tgs"}], "}"}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
    RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
    RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686637516987986*^9, 3.686637534030368*^9}, {
  3.6866376370454073`*^9, 3.686637660917395*^9}, {3.686638589286819*^9, 
  3.686638626629992*^9}, {3.686638796976171*^9, 3.686638850308106*^9}, {
  3.68665639504904*^9, 
  3.68665640197221*^9}},ExpressionUUID->"8ae54edd-b545-4e6f-a9b5-\
73e3de67744c"],

Cell["\<\
Clearly, these tangent vectors are linearly independent, thus the point pt is \
regular.\
\>", "Text",
 CellChangeTimes->{{3.68663890938694*^9, 3.686638973090558*^9}, {
  3.686640006595149*^9, 
  3.686640006922991*^9}},ExpressionUUID->"d681d2a0-eba2-44ac-ac57-\
229316557060"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{".2", ",", ".6"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.585981072950756*^9, 3.5859810781580544`*^9}, {
  3.5859811219425583`*^9, 3.5859811247027164`*^9}, {3.5889218032715516`*^9, 
  3.588921824487589*^9}, {3.5889218603208513`*^9, 3.588921938492589*^9}, {
  3.6271047782430983`*^9, 3.6271047934687247`*^9}, {3.686640052195196*^9, 
  3.686640058538692*^9}},ExpressionUUID->"e0630b57-47b0-42e7-a51a-\
fa1b1581b736"],

Cell["The situation changes at the North Pole ", "Text",
 CellChangeTimes->{{3.686640300528708*^9, 
  3.686640358744151*^9}},ExpressionUUID->"1f0167b9-2ffb-47a9-8b65-\
620414137b10"],

Cell[BoxData[
 RowBox[{"ptn", "=", 
  RowBox[{
   RowBox[{"sphero", "[", "1", "]"}], "[", 
   RowBox[{".2", ",", 
    RowBox[{"Pi", "/", "2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686638223264792*^9, 3.6866382256649446`*^9}, {
  3.686640110362887*^9, 
  3.686640167314652*^9}},ExpressionUUID->"cd6a5a84-1d54-4e1f-81c8-\
396b23d77664"],

Cell["or the South Pole pts", "Text",
 CellChangeTimes->{{3.686640426191681*^9, 3.686640438751576*^9}, {
  3.6900086417825537`*^9, 
  3.6900086445902567`*^9}},ExpressionUUID->"08e18fa7-33bf-4b86-9c9d-\
55f5868f5380"],

Cell[BoxData[
 RowBox[{"pts", "=", 
  RowBox[{
   RowBox[{"sphero", "[", "1", "]"}], "[", 
   RowBox[{".2", ",", 
    RowBox[{
     RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686640467080517*^9, 
  3.686640470143639*^9}},ExpressionUUID->"8f25c07f-607a-4e94-95b7-\
0f2282ce74fd"],

Cell["These points are singular", "Text",
 CellChangeTimes->{{3.686640479726719*^9, 
  3.686640509870812*^9}},ExpressionUUID->"b5c8bc6d-83b5-4b2e-9637-\
f1f17bc06ed1"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{".2", ",", 
    RowBox[{"Pi", "/", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.585981072950756*^9, 3.5859810781580544`*^9}, {
  3.5859811219425583`*^9, 3.5859811247027164`*^9}, {3.5889218032715516`*^9, 
  3.588921824487589*^9}, {3.5889218603208513`*^9, 3.588921938492589*^9}, {
  3.6271047782430983`*^9, 3.6271047934687247`*^9}, {3.686640052195196*^9, 
  3.686640058538692*^9}, {3.6866402196503973`*^9, 
  3.686640222922143*^9}},ExpressionUUID->"5576eb07-9ea7-4102-aa8d-\
b2809b9d1f51"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"u", ",", 
    RowBox[{"Pi", "/", "2"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.6271047226758003`*^9, 3.6271047333774195`*^9}, {
  3.686640245758041*^9, 
  3.686640252497867*^9}},ExpressionUUID->"ec26a9a4-1897-4b1c-b205-\
84e61f56ed56"],

Cell["\<\
since the latitude lines at these points degenerate to a point\
\>", "Text",
 CellChangeTimes->{{3.686640574578558*^9, 
  3.686640621774035*^9}},ExpressionUUID->"dfb7a188-4c19-43ab-ab1e-\
c2e4e8992871"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"t", ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686640645451766*^9, 
  3.686640667630322*^9}},ExpressionUUID->"26351bcd-da6d-401e-8476-\
fbdd3cdedbac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"t", ",", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686640645451766*^9, 
  3.686640681390539*^9}},ExpressionUUID->"b9309a06-00ca-4da3-8909-\
98ebc6ab8d92"],

Cell["Only the points  with v =\[PlusMinus] \[Pi]/2 are singular:", "Text",
 CellChangeTimes->{{3.617602935342201*^9, 3.617602952377431*^9}, {
  3.617602984887888*^9, 
  3.6176030247771587`*^9}},ExpressionUUID->"f54467d1-43b4-424c-976b-\
2a0b9464e735"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "1", "]"}], "[", 
   RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
  RowBox[{"u", ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5859826492939177`*^9, 3.617600023854287*^9, {3.6271048543244314`*^9, 
   3.6271048649636507`*^9}},ExpressionUUID->"deff1dca-ab43-44b4-a33f-\
4113a39514da"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "2", "]"}], "[", 
   RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
  RowBox[{"u", ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5859826492939177`*^9, 3.5859826628216915`*^9}, 
   3.6176000856927958`*^9, {3.627104876975672*^9, 
   3.6271048869752893`*^9}},ExpressionUUID->"aaf0f880-93a1-4660-8d70-\
e5f2c0606eb7"],

Cell["\<\
The tangent planes at the poles remain undefined in the geographical \
parametrization, the function tplane degenerates:\
\>", "Text",
 CellChangeTimes->{{3.690009041595456*^9, 
  3.6900091373546886`*^9}},ExpressionUUID->"f79eb88c-bf6e-458d-860a-\
571dbdc8e213"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tplane", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"u0", ",", 
    RowBox[{"Pi", "/", "2"}]}], "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.6272866582566724`*^9, 3.6272866825811152`*^9}, 
   3.690008797005896*^9},ExpressionUUID->"4586d611-fa39-41d9-90a3-\
c09a93da7e62"],

Cell["\<\
Thus the poles are singularities of the geographical parameter representation \
of the sphere in spite of the fact that geometrically all points of the \
sphere have the same properties. Remark that singular is a property of the \
parameter representation, here the graphic coordinate system, not of the \
surface, considered as the image of the presenting function sf. \
\[FilledSmallSquare]\
\>", "Text",
 CellChangeTimes->{{3.585983439303104*^9, 3.585983656011499*^9}, {
   3.5859837425554495`*^9, 3.585983800018736*^9}, 3.588937868466625*^9, 
   3.5889388391471305`*^9, 3.599489609168592*^9, {3.617603095211282*^9, 
   3.6176031171137204`*^9}, {3.686640828069199*^9, 3.686640897354661*^9}, {
   3.6900091775000467`*^9, 
   3.690009184554501*^9}},ExpressionUUID->"db0c14bd-983c-47f5-b7a0-\
89772c4e3955"],

Cell["\<\
 The vertex of a cone is an example of a singularity reflecting a geometric \
property of the surface:\
\>", "Text",
 CellChangeTimes->{{3.585983439303104*^9, 3.585983656011499*^9}, {
   3.5859837425554495`*^9, 3.585983800018736*^9}, 
   3.588937868466625*^9},ExpressionUUID->"12fa5307-ed55-43b9-9a96-\
3059825cc979"],

Cell[TextData[{
 StyleBox["Example 4",
  FontColor->RGBColor[0, 0, 1]],
 ". Circular cone"
}], "Text",
 CellChangeTimes->{{3.686637968690255*^9, 3.6866379865222197`*^9}},
 CellTags->"cone",ExpressionUUID->"9eaeaff0-9343-4c42-accf-74fc5d252e11"],

Cell[BoxData[
 RowBox[{"?", "circularcone"}]], "Input",
 CellChangeTimes->{{3.6147755833974557`*^9, 
  3.614775607648843*^9}},ExpressionUUID->"8eb2e4ef-0e3e-4855-98b7-\
a3c8958679b9"],

Cell[BoxData[
 RowBox[{"con", "=", 
  RowBox[{
   RowBox[{"circularcone", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "[", 
   RowBox[{
    RowBox[{"-", "Pi"}], ",", "Pi", ",", 
    RowBox[{"-", "1"}], ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5859838112913804`*^9, 3.585983897230296*^9}, {
   3.614775887921873*^9, 3.6147759149784207`*^9}, {3.6147759454011607`*^9, 
   3.6147760046025467`*^9}, {3.614776258627076*^9, 3.6147762664975266`*^9}, {
   3.686834917473825*^9, 3.686834920537753*^9}, 
   3.6868353453379307`*^9},ExpressionUUID->"84efad01-6c57-4c15-ad2c-\
f93c4ce08f6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6147761956744757`*^9},ExpressionUUID->"8080314d-28c4-487d-828b-\
88f8dfc14f3c"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", 
      RowBox[{"circularcone", "[", 
       RowBox[{"a", ",", "b"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", 
      RowBox[{"circularcone", "[", 
       RowBox[{"a", ",", "b"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5859839125391717`*^9, 3.585983965798218*^9}, {
   3.6147756341853604`*^9, 3.6147756746416745`*^9}, 3.614775705002411*^9, {
   3.6147757402034245`*^9, 3.6147757465467873`*^9}, 3.6176000238698874`*^9, 
   3.617600085708396*^9},ExpressionUUID->"682c9832-ec45-48cf-8e55-\
45d4b3ecad83"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"v", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.5859840514991198`*^9, 3.5859840750214653`*^9}, {
  3.614775781144766*^9, 
  3.6147757874811287`*^9}},ExpressionUUID->"33912e44-34a9-4e5d-b7e5-\
dc2491acf719"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pv", " ", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", " ", 
      RowBox[{"PointSize", "[", ".015", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{
        RowBox[{"circularcone", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", 
        RowBox[{"1", ",", "0"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.585984234159567*^9, 3.5859843523663282`*^9}, {
   3.5859844135268264`*^9, 3.585984470358077*^9}, {3.585984555310936*^9, 
   3.585984577831224*^9}, {3.614775846146484*^9, 3.614775861514363*^9}, {
   3.614776134090953*^9, 3.6147761364340878`*^9}, {3.614776216867688*^9, 
   3.614776226506239*^9}, {3.6147763213466635`*^9, 3.614776385643341*^9}, 
   3.686835372770875*^9, {3.68683665749586*^9, 
   3.6868366589888487`*^9}},ExpressionUUID->"66679ff0-d334-4d10-b3f8-\
ac267baedc4c"],

Cell[BoxData[
 RowBox[{"figcon", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"{", 
    RowBox[{"pv", ",", "con"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.585984508907282*^9, 3.5859845240771494`*^9}, {
  3.686834886450346*^9, 
  3.686834895770029*^9}},ExpressionUUID->"4c5327de-ebd7-4e8d-8060-\
faa4cfc5764b"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.686655547541688*^9, 
  3.686655547543016*^9}},ExpressionUUID->"e6324105-b528-4449-affa-\
24d163bc1216"],

Cell[TextData[{
 "\n",
 StyleBox["Example 5",
  FontColor->RGBColor[0, 0, 1]],
 ". This is a continuation of ",
 ButtonBox["Example 3",
  BaseStyle->"Hyperlink",
  ButtonData->"Ex1.1.3"],
 "; first evaluate the cells of \nExample 3."
}], "Text",
 CellChangeTimes->{{3.686655615463149*^9, 3.686655632313114*^9}, {
   3.6866557380966463`*^9, 3.686655772920231*^9}, {3.686655996190777*^9, 
   3.686656051878661*^9}, {3.686656142791654*^9, 3.686656142793193*^9}, 
   3.686656214109606*^9},ExpressionUUID->"14706ba4-2eb3-4628-9f79-\
1fde47180f34"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tplane", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{".2", ",", ".6"}], "]"}], "[", 
  RowBox[{"x", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.5889390507927017`*^9, 3.5889390514323034`*^9}, 
   3.5889455743653603`*^9, {3.686656237115162*^9, 
   3.686656255581028*^9}},ExpressionUUID->"632b0d2e-5578-4f89-bd07-\
6e17a8a863d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpl1", " ", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tplane", "[", 
         RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
        RowBox[{".2", ",", ".6"}], "]"}], "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"Mesh", "\[Rule]", " ", "None"}], ",", " ", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5859987751547213`*^9, 3.5859990333351746`*^9}, 
   3.5859992311435223`*^9, {3.5859993118268642`*^9, 3.585999327910492*^9}, 
   3.5859996610334773`*^9, 3.5859997184727783`*^9, {3.5859997699684687`*^9, 
   3.585999786676098*^9}, {3.585999823258162*^9, 3.5859998785290594`*^9}, {
   3.5860001388935165`*^9, 3.5860001718407745`*^9}, {3.586000360788306*^9, 
   3.586000380413141*^9}, 3.5860004924525375`*^9, {3.6147774414607306`*^9, 
   3.614777461979904*^9}, {3.686656315741743*^9, 3.686656324806052*^9}, {
   3.6868374460481787`*^9, 
   3.686837461686323*^9}},ExpressionUUID->"31ee244d-162f-4875-8e10-\
4fad536a04ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpn", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"PointSize", "[", ".02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{
        RowBox[{"sphero", "[", "1", "]"}], "[", 
        RowBox[{".2", ",", " ", ".6"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.585981598798833*^9, 3.585981608132367*^9}, {
   3.5859816511338263`*^9, 3.5859816640615664`*^9}, {3.585981694846327*^9, 
   3.585981764203294*^9}, {3.5859818411426945`*^9, 3.58598188005392*^9}, {
   3.5859999785564346`*^9, 3.5860000137656965`*^9}, 3.5860001190502815`*^9, 
   3.586000241026896*^9, {3.6866565257154303`*^9, 3.686656536875901*^9}, {
   3.6866568581000338`*^9, 3.68665691860977*^9}, {3.686656963900693*^9, 
   3.686657003819366*^9}},ExpressionUUID->"58f59c31-02c4-4556-9b1a-\
aebd3e561391"],

Cell[BoxData[
 RowBox[{"figsph2", "=", 
  RowBox[{"tpsph", " ", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tpl1", ",", " ", "tpn", ",", "figsph"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}], ",", " ", 
     RowBox[{"Axes", "\[Rule]", " ", "False"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.585999915313924*^9, 3.585999934267957*^9}, {
  3.586000024560916*^9, 3.5860001012818503`*^9}, {3.5860004230324154`*^9, 
  3.586000447462058*^9}, {3.58600067040205*^9, 3.5860006744112573`*^9}, {
  3.68665674482617*^9, 3.686656747585808*^9}, {3.6866580360750513`*^9, 
  3.686658043519267*^9}},ExpressionUUID->"a9c6bf2d-a2fa-41b4-86a1-\
0ff12401a010"],

Cell["\<\
Figure: The tangent plane of the unit sphere at the regular point pt. \
\[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.686657165853612*^9, 
  3.686657259798623*^9}},ExpressionUUID->"d1d28da3-c19c-489f-a1cd-\
b027bec64185"],

Cell[TextData[{
 "The ",
 StyleBox["normal vector",
  FontColor->RGBColor[0, 0, 1]],
 " of the  surface sf at the regular point sf[u,v] is defined as the normal \
unit vector of  the oriented tangent plane; the orientation is defined by the \
numbering of the parameters:"
}], "Text",
 CellChangeTimes->{{3.586000726421748*^9, 3.5860008523139696`*^9}, {
   3.58600106321074*^9, 3.5860010810883713`*^9}, {3.5889225134315987`*^9, 
   3.588922539031244*^9}, {3.588922572540103*^9, 3.5889225905893345`*^9}, 
   3.5889466155267887`*^9, {3.588999331519678*^9, 3.5889993553910437`*^9}, 
   3.617615934153221*^9, {3.6272869386533666`*^9, 3.6272869442069764`*^9}, 
   3.6866574923713503`*^9, 3.6866575792344017`*^9, {3.686657672233922*^9, 
   3.686657725185104*^9}, 3.686664094334968*^9, {3.686664287959696*^9, 
   3.686664299805716*^9}, 3.686831058936365*^9, {3.686831097503501*^9, 
   3.6868311038235197`*^9}},ExpressionUUID->"82f2a50e-3931-433e-bcb9-\
5edf0ea60f16"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"nor", "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"dotnorme", "[", 
    RowBox[{"Cross", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "1", "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "2", "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], " ", "\[Equal]", " ", "List"}],
      "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "3"}]}], 
    ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.686657742890539*^9, 3.686657939713704*^9}, {
   3.686657971200247*^9, 3.6866579761841908`*^9}, 3.686831000775433*^9, 
   3.6900113254856157`*^9, {3.690011512682225*^9, 3.690011516452259*^9}},
 CellTags->"nor",ExpressionUUID->"645d395f-c346-4b65-b4c9-3797feb83265"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"nor", "::", "usage"}], " ", "=", " ", 
    "\"\<nor[f_][u_,v_] is the unit normal vector of the oriented surface \
f[u,v] in the Euclidean 3-space at the point f[u,v]\>\""}], ";"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.686750929686439*^9, 3.6867510655283422`*^9}, 
   3.6867510993441277`*^9},ExpressionUUID->"bf5ceb88-19ab-4b90-bd94-\
99e1a0d56c2c"],

Cell["\<\
For the unit sphere the normal vector coincides with the radius vector\
\>", "Text",
 CellChangeTimes->{{3.686663936899232*^9, 
  3.6866640330306997`*^9}},ExpressionUUID->"bac139ba-94fc-4495-8c77-\
2e8084f09736"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"nor", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "v", "]"}], ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6866581389469357`*^9, 3.6866581688621397`*^9}, {
   3.686658225357807*^9, 3.686658263917262*^9}, 3.6866583123203697`*^9, {
   3.6866638427690983`*^9, 3.6866638562013083`*^9}, 
   3.6866639229748907`*^9},ExpressionUUID->"bca7af93-d4a6-4644-b4ab-\
951dc550c96f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphn", " ", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Arrow", "[", 
     RowBox[{"{", 
      RowBox[{"pt", ",", 
       RowBox[{"2", "*", "pt"}]}], "}"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6866642503804283`*^9, 3.6866642804644327`*^9}, {
  3.6866643136061*^9, 
  3.686664369241149*^9}},ExpressionUUID->"80609658-e6e2-4388-967e-\
ed41aea01c74"],

Cell[BoxData[
 RowBox[{"figsph3", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"figsph2", ",", "%"}], "}"}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686664185584979*^9, 3.686664242598609*^9}, {
  3.686664377917582*^9, 3.686664408301405*^9}},
 CellTags->"figsph3",ExpressionUUID->"4b6a0a77-3b13-42e9-9691-7fbbad5960bb"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.1.2. Linearity of the Differential. Product Rule", "Subsubsection",
 CellChangeTimes->{{3.686708422360429*^9, 3.686708459656542*^9}, {
   3.696147762441311*^9, 3.696147769088894*^9}, 
   3.696172013785922*^9},ExpressionUUID->"1d7b7cd8-5526-4352-829f-\
dde7ad5faba9"],

Cell[TextData[{
 "In this subsection we prove some often used properties of the differential. \
First we show its additivity. Denote by ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "\[Infinity]"], TraditionalForm]],ExpressionUUID->
  "b1ab5ec0-aff1-45f8-a6e5-abfdebcaaef5"],
 "[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "aa8703a0-2d6b-4d77-bf20-5ac72d2527ac"],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "n"], TraditionalForm]],ExpressionUUID->
  "509748fa-14fc-42d7-9a63-5c088305aa7b"],
 "] the set of all smooth functions f:",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "0f23eff9-110e-471f-9ff6-130be7ff2319"],
 "\[RightArrow] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "n"], TraditionalForm]], "Input",ExpressionUUID->
  "283acd7d-fe5e-438b-98ab-18703a8dd262"],
 ". Then the operations of addition and multiplication with a real number are \
well defined in this set and give it the structure of an infinite dimensional \
real vector space. These operations are "
}], "Text",
 CellChangeTimes->{{3.686708484726178*^9, 3.686708561088567*^9}, {
  3.6867086119287643`*^9, 3.686708648176682*^9}, {3.686708680808716*^9, 
  3.686708686200601*^9}, {3.6867087304483852`*^9, 3.686708875089364*^9}, {
  3.686708924310047*^9, 3.68670893394068*^9}, {3.686708968398386*^9, 
  3.6867090260171423`*^9}, {3.686709068009*^9, 3.68670919493626*^9}, {
  3.686709235208856*^9, 3.6867092575122833`*^9}, {3.690009721799152*^9, 
  3.690009725511281*^9}},ExpressionUUID->"0a968b87-a2c6-4f6b-bd4b-\
377f684e97ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "2"}], ";", "spdim"}]], "Input",
 CellChangeTimes->{{3.696171457580187*^9, 
  3.6961715288307247`*^9}},ExpressionUUID->"6952ceca-c957-4178-be93-\
57887981f7bc"],

Cell[BoxData[
 RowBox[{"?", "plus"}]], "Input",
 CellChangeTimes->{{3.686709262050804*^9, 
  3.686709264175695*^9}},ExpressionUUID->"8399312b-89d6-46e9-8067-\
3912aaf654b6"],

Cell[BoxData[
 RowBox[{"?", "times"}]], "Input",
 CellChangeTimes->{{3.686709366801526*^9, 
  3.6867093817433233`*^9}},ExpressionUUID->"06e9c5f2-73c5-4a76-b5fe-\
61f2de44ea70"],

Cell["Tests.", "Text",
 CellChangeTimes->{{3.686717771026556*^9, 
  3.686717774898643*^9}},ExpressionUUID->"acd6b22c-b1b1-4ac9-a2d8-\
79d579f2ce5c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plus", "[", 
    RowBox[{"f1", ",", "f2"}], "]"}], "[", "x", "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"f1", "[", "x", "]"}], "+", 
   RowBox[{"f2", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.686709312100563*^9, 
  3.686709354399644*^9}},ExpressionUUID->"36ab7914-bd85-4874-a4f7-\
351ca2f891e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"times", "[", 
    RowBox[{"a", ",", "f"}], "]"}], "[", "x", "]"}], " ", "\[Equal]", " ", 
  RowBox[{"a", "*", 
   RowBox[{"f", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.686709396383659*^9, 
  3.686709419911663*^9}},ExpressionUUID->"4c188a27-b7ef-41a4-b0db-\
5018a925dc64"],

Cell["\<\
plus and times act for functions, the built-in  functions Plus and Times act \
on the values only.  \
\>", "Text",
 CellChangeTimes->{{3.6867181342720327`*^9, 3.686718183399231*^9}, {
   3.6867182435832167`*^9, 3.6867182877669487`*^9}, {3.686719264047433*^9, 
   3.6867192940472593`*^9}, 3.686720701179881*^9, 
   3.6867207393638268`*^9},ExpressionUUID->"89fe5a9a-c001-47be-8cbb-\
ba60e29af241"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Plus", "[", 
     RowBox[{"f1", ",", "f2"}], "]"}], "[", "x", "]"}], " ", "\[Equal]", 
   RowBox[{
    RowBox[{"f1", "[", "x", "]"}], "+", 
    RowBox[{"f2", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686717822976007*^9, 3.6867179036264753`*^9}, {
  3.686718032348586*^9, 3.686718056169264*^9}, {3.686718210949823*^9, 
  3.686718228944359*^9}},ExpressionUUID->"5cf49ce1-bdb5-4e5a-bcd4-\
9956f814f182"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Times", "[", 
      RowBox[{"a", ",", "f"}], "]"}], "[", "x", "]"}], " ", "\[Equal]", " ", 
    RowBox[{"a", "*", 
     RowBox[{"f", "[", "x", "]"}]}]}], ",", 
   RowBox[{"a", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686709396383659*^9, 3.6867094485758553`*^9}, {
  3.686716840941276*^9, 3.686716877659132*^9}, {3.686716941611462*^9, 
  3.686716945082336*^9}, {3.686717108042973*^9, 3.686717115689063*^9}, {
  3.6867171956898317`*^9, 
  3.686717216584468*^9}},ExpressionUUID->"e54b425b-4ec1-4417-b254-\
45f5c467319c"],

Cell[TextData[{
 "We formulate the following general \n",
 StyleBox["Proposition 1",
  FontColor->RGBColor[0, 0, 1]],
 ". The set  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "\[Infinity]"], TraditionalForm]],ExpressionUUID->
  "d83afb6a-ce1d-46f8-bf05-07d581dbc323"],
 "[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "7b7d97d0-370a-4895-9b4c-0203312a5dc3"],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "n"], TraditionalForm]],ExpressionUUID->
  "5a9284f4-8256-43d3-9153-19f3630a70bf"],
 "]  provided with the operations"
}], "Text",
 CellChangeTimes->{{3.686720817970868*^9, 3.6867208639146347`*^9}, {
  3.686720962441895*^9, 
  3.686721036049444*^9}},ExpressionUUID->"6fd1af3c-2b2f-456c-a29f-\
bc9ecf607e39"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plus", ":", " ", "f"}], ",", 
  RowBox[{"g", " ", "\[Element]", "  ", 
   RowBox[{
    RowBox[{
     FormBox[
      SuperscriptBox["C", "\[Infinity]"],
      TraditionalForm], "[", 
     RowBox[{
      FormBox[
       SuperscriptBox["X", "m"],
       TraditionalForm], ",", 
      FormBox[
       SuperscriptBox["R", "n"],
       TraditionalForm]}], "]"}], " ", "\[LongRightArrow]", " ", 
    RowBox[{"plus", "[", 
     RowBox[{"f", ",", "g"}], "]"}]}], " ", "\[Element]", "  ", 
   RowBox[{
    FormBox[
     SuperscriptBox["C", "\[Infinity]"],
     TraditionalForm], "[", 
    RowBox[{
     FormBox[
      SuperscriptBox["X", "m"],
      TraditionalForm], ",", 
     FormBox[
      SuperscriptBox["R", "n"],
      TraditionalForm]}], "]"}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.686721043371573*^9, 3.686721121337523*^9}, {
  3.686721160000513*^9, 
  3.6867211683610773`*^9}},ExpressionUUID->"6fd7362c-727c-4e07-a6c4-\
6458b59f587d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"plus", "[", 
     RowBox[{"f", ",", "g"}], "]"}], "[", "x", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x", "]"}], "+", 
     RowBox[{"g", "[", "x", "]"}]}], "\[Element]", "  ", 
    RowBox[{
     FormBox[
      SuperscriptBox["C", "\[Infinity]"],
      TraditionalForm], "[", 
     RowBox[{
      FormBox[
       SuperscriptBox["X", "m"],
       TraditionalForm], ",", 
      FormBox[
       SuperscriptBox["R", "n"],
       TraditionalForm]}], "]"}]}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.686721198512773*^9, 3.6867212367603483`*^9}, {
   3.686721287328104*^9, 3.6867212907202797`*^9}, 3.686721505403553*^9, {
   3.6867215720777597`*^9, 
   3.686721573718772*^9}},ExpressionUUID->"94d8d11b-85d6-44c9-9048-\
11106d55e31f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"For", " ", "a"}], "\[Element]", " ", 
   RowBox[{"R", " ", "is", " ", "also", " ", 
    RowBox[{"times", "[", 
     RowBox[{"a", ",", "f"}], "]"}]}], "\[Element]", " ", 
   RowBox[{
    FormBox[
     SuperscriptBox["C", "\[Infinity]"],
     TraditionalForm], "[", 
    RowBox[{
     FormBox[
      SuperscriptBox["X", "m"],
      TraditionalForm], ",", 
     FormBox[
      SuperscriptBox["R", "n"],
      TraditionalForm]}], "]"}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6867213930430803`*^9, 3.686721486014583*^9}, {
  3.686721519486195*^9, 3.6867215276459713`*^9}, {3.686721584461388*^9, 
  3.686721628759966*^9}},ExpressionUUID->"307fbd40-c8e3-4f4d-a9b7-\
dfdbc14ecacb"],

Cell["\<\
is an infinite dimensional real vector space. 
1. The differential operator d is linear, what means (in traditional notation)\
\>", "Text",
 CellChangeTimes->{{3.686721688115793*^9, 3.686721789947371*^9}, {
  3.686721852042952*^9, 3.6867218731705914`*^9}, {3.6867219064185057`*^9, 
  3.68672191920222*^9}, {3.686722091976781*^9, 3.686722106712905*^9}, {
  3.686723911786826*^9, 3.686723917674529*^9}, {3.696171594061873*^9, 
  3.6961715947016478`*^9}},ExpressionUUID->"b6cc7d47-2569-4240-8c39-\
94c35ff03b59"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"f", "+", "g"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], " ", "+", " ", 
    RowBox[{"d", "[", "g", "]"}]}]}], ",", "         ", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"a", "*", "f"}], "]"}], " ", "=", " ", 
   RowBox[{"a", "*", "df"}]}], ",", "   ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "\[Element]", "R"}], ")"}], ".", " "}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6867219279269333`*^9, 3.6867220266824427`*^9}, 
   3.686722131281369*^9, {3.686722167265071*^9, 
   3.686722199488625*^9}},ExpressionUUID->"9a28352e-babe-4e2f-bbad-\
c844778ff2fb"],

Cell[TextData[{
 "2. For a smooth real function f\[Element] ",
 Cell[BoxData[
  RowBox[{
   FormBox[
    SuperscriptBox["C", "\[Infinity]"],
    TraditionalForm], "[", 
   FormBox[
    SuperscriptBox["X", "m"],
    TraditionalForm]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.686721043371573*^9, 3.686721121337523*^9}, {
   3.686721160000513*^9, 3.6867211683610773`*^9}},ExpressionUUID->
  "aaf1035e-2cd4-4c64-833c-8b5b18eaf5f9"],
 "] := ",
 Cell[BoxData[
  RowBox[{
   FormBox[
    SuperscriptBox["C", "\[Infinity]"],
    TraditionalForm], "[", 
   RowBox[{
    FormBox[
     SuperscriptBox["X", "m"],
     TraditionalForm], ",", 
    FormBox["R",
     TraditionalForm]}], "]"}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.686721043371573*^9, 3.686721121337523*^9}, {
   3.686721160000513*^9, 3.6867211683610773`*^9}},ExpressionUUID->
  "46a81a43-cc4c-40a7-a6b9-236bfa60eefa"],
 " and g\[Element] ",
 Cell[BoxData[
  RowBox[{
   FormBox[
    SuperscriptBox["C", "\[Infinity]"],
    TraditionalForm], "[", 
   RowBox[{
    FormBox[
     SuperscriptBox["X", "m"],
     TraditionalForm], ",", 
    FormBox[
     SuperscriptBox["R", "n"],
     TraditionalForm]}], "]"}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.686721043371573*^9, 3.686721121337523*^9}, {
   3.686721160000513*^9, 3.6867211683610773`*^9}},ExpressionUUID->
  "98e52e79-70d3-4ea2-af9a-81f7c718acf4"],
 " the following product rule is valid:"
}], "Text",
 CellChangeTimes->{{3.68672394306642*^9, 3.6867239451941843`*^9}, {
  3.686724028777267*^9, 
  3.686724268991878*^9}},ExpressionUUID->"df54eb15-562f-4d5b-a562-\
a7d60f03251e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"f", "*", "g"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "*", "g"}], " ", "+", " ", 
   RowBox[{"f", "*", 
    RowBox[{"d", "[", "g", "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.686724282876031*^9, 3.686724362015377*^9}, 
   3.7073701748271303`*^9},ExpressionUUID->"f5a4b34e-6e82-41d6-a6bb-\
e4439c91109e"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". We prove the proposition for m=2, n=3, ",
 Cell[BoxData[
  RowBox[{
   FormBox[
    SuperscriptBox["X", "2"],
    TraditionalForm], "=", " ", 
   RowBox[{"U", " ", "\[Subset]", 
    FormBox[
     SuperscriptBox["R", "2"],
     TraditionalForm]}]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.6867213930430803`*^9, 3.686721486014583*^9}, {
   3.686721519486195*^9, 3.6867215276459713`*^9}, {3.686721584461388*^9, 
   3.686721628759966*^9}},ExpressionUUID->
  "adb9f592-1829-4719-b1c4-898ccd6e8011"],
 " an open set. "
}], "Text",
 CellChangeTimes->{{3.686722211871801*^9, 3.686722217271812*^9}, {
  3.6867223468629293`*^9, 
  3.6867225268935413`*^9}},ExpressionUUID->"f8ceefe4-8b78-455c-a346-\
f1a4576068b9"],

Cell["A second surface is defined by", "Text",
 CellChangeTimes->{{3.6867236845801907`*^9, 
  3.6867237059640408`*^9}},ExpressionUUID->"81d90a0f-64b6-40a3-b9b3-\
8aadb5f49e14"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sf2", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
  RowBox[{"vec", "[", 
   RowBox[{
    RowBox[{"f2", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", "spdim"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6867194419421787`*^9, 3.68671952338234*^9}, {
  3.696078385935041*^9, 
  3.6960784003665648`*^9}},ExpressionUUID->"0e2b6dc2-9d48-455d-bcb1-\
73ff9527d242"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plus", "[", 
   RowBox[{"sf", ",", "sf2"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.68672372205352*^9, 
  3.68672373778827*^9}},ExpressionUUID->"1a7276ee-8b9a-4292-aad2-\
d9dfed584d95"],

Cell["We get", "Text",
 CellChangeTimes->{{3.6867195342513103`*^9, 3.686719556733529*^9}, {
  3.686723770599201*^9, 
  3.6867237811631536`*^9}},ExpressionUUID->"2b17cd71-db2b-42f8-9cf7-\
6da157134db5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"plus", "[", 
     RowBox[{"sf", ",", "sf2"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"plus", "[", 
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], ",", 
     RowBox[{"d", "[", "sf2", "]"}]}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.686719327138011*^9, 3.686719335445422*^9}, {
  3.686719571022091*^9, 
  3.686719648102153*^9}},ExpressionUUID->"5ff2a88b-c8c5-40ec-a7c4-\
0e5d3f17da32"],

Cell["For the multiplication with a real number we get", "Text",
 CellChangeTimes->{{3.686723809971293*^9, 3.686723861394854*^9}, 
   3.6867244181184387`*^9},ExpressionUUID->"b33b2abf-3fc7-4760-976a-\
f258b67ba8f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"times", "[", 
     RowBox[{"a", ",", "sf"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"times", "[", 
    RowBox[{"a", ",", 
     RowBox[{"d", "[", "sf", "]"}]}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686719694951219*^9, 
  3.686719788747308*^9}},ExpressionUUID->"20f8eb44-1225-45fd-a9c6-\
aceebeb8beae"],

Cell["\<\
To confirm the product rule we define the product function for g = sf:\
\>", "Text",
 CellChangeTimes->{{3.686724435414323*^9, 3.6867245006779947`*^9}, {
   3.6867245485813837`*^9, 3.6867245994771214`*^9}, 
   3.69338173632613*^9},ExpressionUUID->"b9a5221d-ac67-4a12-84d7-\
5d1820e76de5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pf", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", 
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], ";", 
  RowBox[{"pf", "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686719694951219*^9, 3.686719788747308*^9}, {
   3.686719881075605*^9, 3.68671989181919*^9}, {3.686719929242403*^9, 
   3.6867200542017736`*^9}, {3.686720171509789*^9, 3.686720243040224*^9}, {
   3.686720383918776*^9, 3.686720395718995*^9}, {3.686720475256287*^9, 
   3.686720491269614*^9}, 
   3.686724540444289*^9},ExpressionUUID->"3a598e19-5a8e-44a1-9d1d-\
8f0806b169ba"],

Cell[TextData[{
 "Clearly, it belongs to ",
 Cell[BoxData[
  RowBox[{
   FormBox[
    SuperscriptBox["C", "\[Infinity]"],
    TraditionalForm], "[", 
   RowBox[{
    FormBox[
     SuperscriptBox["X", "m"],
     TraditionalForm], ",", 
    FormBox["R",
     TraditionalForm]}], "]"}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.686721043371573*^9, 3.686721121337523*^9}, {
   3.686721160000513*^9, 3.6867211683610773`*^9}},ExpressionUUID->
  "0acf143d-9b53-4e00-908f-7d73655d1901"],
 ". We obtain"
}], "Text",
 CellChangeTimes->{{3.6867246141887817`*^9, 3.686724666644371*^9}, {
  3.693381772854216*^9, 
  3.693381775501742*^9}},ExpressionUUID->"5decfc68-821f-4f97-b170-\
c33ca6581629"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "pf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.693379210202208*^9, 
  3.69337922526362*^9}},ExpressionUUID->"5723225a-ebfc-4199-a677-\
991b06b7f90a"],

Cell["\<\
We have to find an interpretation of the last term of the product formula 
df*g = df*sf. Aiming this we first calculate the difference\
\>", "Text",
 CellChangeTimes->{{3.6933830537089357`*^9, 3.693383247195609*^9}, 
   3.6933833216992598`*^9, {3.6933834082902317`*^9, 3.693383478386055*^9}, {
   3.693395580716151*^9, 
   3.693395616204129*^9}},ExpressionUUID->"ee5524aa-eadc-4a06-8828-\
f4b9c7b60de5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mdiff", ":=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "pf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "-", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{"d", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "]"}]}], ";", 
  RowBox[{"mdiff", "//", "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.6933805785313997`*^9, 3.693380697491131*^9}, {
  3.693380742279986*^9, 3.693380777965439*^9}, {3.693380831023985*^9, 
  3.693380835709145*^9}, {3.693396030398089*^9, 
  3.6933960602915487`*^9}},ExpressionUUID->"c5f2c5cb-c45f-4ee5-978b-\
9768f0a64942"],

Cell["\<\
This matrix is the matrix of all products of the coordinates of the 3-vector \
sf with those of the 2-form df[u,v]:\
\>", "Text",
 CellChangeTimes->{
  3.693395666236073*^9, {3.6933956983711243`*^9, 
   3.6933957287231007`*^9}},ExpressionUUID->"0a71e0ac-98a5-4e1b-8a3c-\
eb9c37ef0d17"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "i", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.693382109303281*^9, 3.693382236363991*^9}, {
  3.693382316195804*^9, 
  3.693382323443615*^9}},ExpressionUUID->"2af0dde4-0667-4105-9a50-\
10acef04358f"],

Cell["It coincides with the matrix of the", "Text",
 CellChangeTimes->{{3.693395947822906*^9, 
  3.6933959933478737`*^9}},ExpressionUUID->"5aca6386-45ff-4d7e-abb2-\
fd3bd80470d0"],

Cell[BoxData[
 RowBox[{"?", "TensorProduct"}]], "Input",
 CellChangeTimes->{{3.693383502379188*^9, 
  3.693383522025923*^9}},ExpressionUUID->"9dd67403-ddf8-46b8-84dc-\
5803d57a812f"],

Cell[BoxData[
 RowBox[{"mdiff", " ", "==", 
  RowBox[{"TensorProduct", "[", 
   RowBox[{
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.693383685208902*^9, 3.693383703257063*^9}, {
  3.69339608233955*^9, 
  3.6933960862012873`*^9}},ExpressionUUID->"892c1b98-4db9-44ec-8ad0-\
1b05b81022da"],

Cell["\<\
It can be written as a 3-vector whose components are differential forms:\
\>", "Text",
 CellChangeTimes->{{3.693396805563292*^9, 
  3.693396847043549*^9}},ExpressionUUID->"4893bb2b-9758-448c-9274-\
0520bb282e71"],

Cell[BoxData[
 RowBox[{"mdiff", "\[Equal]", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "i", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "spdim"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.693382525399343*^9, 3.6933826044172487`*^9}, 
   3.6933837881566677`*^9, {3.6933961333102427`*^9, 3.693396135904461*^9}, 
   3.696078281030834*^9},ExpressionUUID->"82d53515-091c-4b01-b3c7-\
76bc63918406"],

Cell[TextData[{
 "As such it yields a field of linear maps of the two-dimensional vector \
space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]],ExpressionUUID->
  "b2b78837-9527-4be0-8f4e-a6de7c6a78a1"],
 " into the 3-space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "3"], TraditionalForm]],ExpressionUUID->
  "bfc4f199-a523-4353-a7c7-768677371a01"],
 ", for an arbitrary vector"
}], "Text",
 CellChangeTimes->{{3.693396872579855*^9, 3.693397067957728*^9}, {
  3.6933977243029013`*^9, 
  3.693397753221415*^9}},ExpressionUUID->"b70bea43-7dba-4e80-9886-\
f16829a3afc3"],

Cell[BoxData[
 RowBox[{"vl", " ", "=", 
  RowBox[{"vec", "[", "a", "]"}]}]], "Input",
 CellChangeTimes->{{3.6867249632970457`*^9, 3.686725022706305*^9}, 
   3.686725252629456*^9, {3.693379354086751*^9, 3.693379363769987*^9}, {
   3.696078685892622*^9, 
   3.6960786863246317`*^9}},ExpressionUUID->"aa2750dc-70aa-44fb-b49e-\
38205f217a74"],

Cell["one obtains ", "Text",
 CellChangeTimes->{{3.6933978101407137`*^9, 
  3.693397872908474*^9}},ExpressionUUID->"a7910323-3383-4b0a-95b3-\
fb5d4ac16bd7"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"mdiff", ".", "vl"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", ".", "vl"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6933978837477083`*^9, 3.6933978941806993`*^9}, {
  3.693397938638777*^9, 
  3.693398043140029*^9}},ExpressionUUID->"11f89357-e5dd-4efc-bb20-\
59a9a305a2a6"],

Cell["\<\
and the product  rule appears as a decomposition of linear maps:\
\>", "Text",
 CellChangeTimes->{{3.6933980977226*^9, 
  3.6933981292103024`*^9}},ExpressionUUID->"d07f930f-4420-45fb-83f5-\
fa71fcc4d752"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"d", "[", "pf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", "vl"}], " ", "\[Equal]", 
   " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", "vl"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "vl"}], ")"}], "*", 
     RowBox[{"sf", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686724694405087*^9, 3.686724696566415*^9}, {
  3.6867251956302347`*^9, 
  3.6867252038253937`*^9}},ExpressionUUID->"d94e82ac-e93d-4bd4-9a7d-\
c067c94419cd"],

Cell["\<\
what confirms the statement, which can be proved analogously for other \
dimensions m, n.  \[FilledSmallSquare]\
\>", "Text",
 CellChangeTimes->{{3.686725287467845*^9, 3.686725363670877*^9}, {
  3.686727499541875*^9, 
  3.6867275048114357`*^9}},ExpressionUUID->"37222f77-5dd6-4874-85c1-\
8096757b2e4d"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.1.3. Example \[OpenCurlyDoubleQuote]Schiebfl\[ADoubleDot]chen\
\[CloseCurlyDoubleQuote]", "Subsubsection",
 CellChangeTimes->{{3.686747879639545*^9, 3.6867479245031967`*^9}, 
   3.6961720411224117`*^9, 
   3.69617241894153*^9},ExpressionUUID->"39a20d0d-7ca8-4f65-895f-\
4fd453392a4e"],

Cell[TextData[{
 "In this subsection we consider a class of surfaces in German called \
Schiebfl\[ADoubleDot]chen. I didn\[CloseCurlyQuote]t found an English \
translation; let us call them Schiebfl\[ADoubleDot]chen in English too. Let \
cu, cv be two smooth curves in the Euclidean space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]],ExpressionUUID->
  "6462a744-a1f6-4c78-b833-16703f61ba20"],
 ":"
}], "Text",
 CellChangeTimes->{{3.686747971934654*^9, 3.686747990798497*^9}, {
  3.68674803663815*^9, 3.6867480658141212`*^9}, {3.686748124581438*^9, 
  3.686748274988793*^9}, {3.686748312895166*^9, 3.686748417627365*^9}, {
  3.69607915764051*^9, 3.696079165319873*^9}, {3.6960791980239353`*^9, 
  3.6960792867698593`*^9}, {3.6960811095124187`*^9, 
  3.696081111736226*^9}},ExpressionUUID->"bde77ce1-607e-413b-975a-\
f257e2479315"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cu", "[", "u_", "]"}], "=", " ", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], ",", "3"}], "]"}]}], ";", " ", 
  RowBox[{
   RowBox[{"cv", "[", "v_", "]"}], " ", "=", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"g", "[", "v", "]"}], ",", "3"}], "]"}]}], ";", " ", 
  RowBox[{
   RowBox[{"fs", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"cu", "[", "u", "]"}], "+", 
    RowBox[{"cv", "[", "v", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.686748399139319*^9, 3.6867485706828203`*^9}, {
  3.696079315219631*^9, 
  3.6960793252198067`*^9}},ExpressionUUID->"9fc436a4-02b8-481a-b96d-\
637d49881ef9"],

Cell[BoxData[
 RowBox[{"fs", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.686748576560893*^9, 
  3.686748581810487*^9}},ExpressionUUID->"36125031-f88f-4e22-b953-\
12c3e56ddf83"],

Cell["The differential is", "Text",
 CellChangeTimes->{{3.686748667353279*^9, 
  3.6867486749772673`*^9}},ExpressionUUID->"64000853-c721-46d9-8363-\
ada4837cb322"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "fs", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6867486914028482`*^9, 
  3.686748718321314*^9}},ExpressionUUID->"ea428f5b-53f8-467d-8887-\
dea60abe2f16"],

Cell[BoxData[
 RowBox[{"%", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.686748785945573*^9, 3.686748795056595*^9}, {
  3.696172195706423*^9, 
  3.696172198664345*^9}},ExpressionUUID->"45f9d972-b97c-4e39-b734-\
5a061bc205e6"],

Cell[BoxData[
 RowBox[{"%%", "\[Equal]", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"cu", "[", "u", "]"}], ",", "u"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"cv", "[", "v", "]"}], ",", "v"}], "]"}]}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.686748811279192*^9, 3.686748943472371*^9}, {
  3.68674898388494*^9, 
  3.686748987095667*^9}},ExpressionUUID->"54b61e5d-0c0a-4f8f-b36d-\
05cb985d8a2e"],

Cell["\<\
The coordinate lines are translates of the generating curves, and the tangent \
basis vectors are tangent vectors of these curves.\
\>", "Text",
 CellChangeTimes->{{3.686749396195928*^9, 
  3.6867495129077473`*^9}},ExpressionUUID->"fbe32433-9fe3-4d96-8e66-\
f9c98da32878"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "1", "]"}], "[", "fs", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"cu", "[", "u", "]"}], ",", "u"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6867492257892427`*^9, 3.6867492346857033`*^9}, 
   3.686749351171064*^9},ExpressionUUID->"2effea26-7927-406c-b932-\
8586ce6764b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "2", "]"}], "[", "fs", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"cv", "[", "v", "]"}], ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6867492257892427`*^9, 
  3.6867492907645073`*^9}},ExpressionUUID->"b677012a-2856-4c09-bc4f-\
54b68c043ccc"],

Cell["The singular points form the set", "Text",
 CellChangeTimes->{{3.686749152373747*^9, 3.6867491585253*^9}, {
  3.686749521651195*^9, 
  3.686749560714761*^9}},ExpressionUUID->"295a4e9d-a65d-42b2-8971-\
9406d6e05d22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"singularities", "[", "fs", "]"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"fs", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "|", 
    RowBox[{
     RowBox[{"MatrixRank", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"cu", "[", "u", "]"}], ",", "u"}], "]"}], ",", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"cv", "[", "v", "]"}], ",", "v"}], "]"}]}], "}"}], "]"}], 
     "<", " ", "2"}]}], "}"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.686749584245603*^9, 3.6867496429474583`*^9}, {
   3.686749683490596*^9, 3.686749717562509*^9}, 
   3.6867505042290897`*^9},ExpressionUUID->"51d628f9-503e-4d7b-9d88-\
f6e2827c4e89"],

Cell["and this set is the union ", "Text",
 CellChangeTimes->{{3.686749777017365*^9, 3.6867498052653027`*^9}, 
   3.6867498584006977`*^9},ExpressionUUID->"cd1d0af0-e142-43dc-95a4-\
564fb09a2c45"],

Cell[BoxData[
 RowBox[{
  RowBox[{"singularities", "[", "fs", "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fs", "[", 
      RowBox[{"u", ",", "v"}], "]"}], "|", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"cu", "[", "u", "]"}], ",", "u"}], "]"}], "\[Equal]", 
      RowBox[{"null", "[", "3", "]"}]}]}], "}"}], "\[Union]", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fs", "[", 
      RowBox[{"u", ",", "v"}], "]"}], "|", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"cv", "[", "v", "]"}], ",", "v"}], "]"}], "\[Equal]", 
      RowBox[{"null", "[", "3", "]"}]}]}], "}"}], "\[Union]", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fs", "[", 
      RowBox[{"u", ",", "v"}], "]"}], "|", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"cv", "[", "v", "]"}], ",", "v"}], "]"}], "parallel", " ", 
      "to", " ", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"cu", "[", "u", "]"}], ",", "u"}], "]"}]}]}], 
    "}"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6867498632096033`*^9, 3.6867500792567053`*^9}, {
   3.686750483165234*^9, 3.686750490461266*^9}, 
   3.6868157168568363`*^9},ExpressionUUID->"b4c81148-b518-405c-a087-\
c0c51ebe29d6"],

Cell[TextData[{
 StyleBox["Example 6",
  FontColor->RGBColor[0, 0, 1]],
 ". "
}], "Text",
 CellChangeTimes->{{3.6867501736807957`*^9, 3.686750185014698*^9}, 
   3.6867505538456583`*^9, 
   3.686815895350545*^9},ExpressionUUID->"7e0cda0c-be11-4bb7-97db-\
5b874f9b335c"],

Cell["\<\
The following Schiebfl\[ADoubleDot]che is generated by two circles lying in \
orthogonal planes:\
\>", "Text",
 CellChangeTimes->{{3.6868159706697693`*^9, 3.686815972253841*^9}, {
  3.6868160126777*^9, 
  3.686816078188998*^9}},ExpressionUUID->"6e97c0a5-ace4-46f4-bcf8-\
800cad554386"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"cu", "[", "u_", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "u", "]"}], ",", 
     RowBox[{"Sin", "[", "u", "]"}], ",", "0"}], "}"}]}], ";", " ", 
  RowBox[{
   RowBox[{"cv", "[", "v_", "]"}], " ", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Cos", "[", "v", "]"}], ",", 
      RowBox[{"Sin", "[", "v", "]"}]}], "}"}], "/", "2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"fs", "[", 
  RowBox[{"u", ",", "v"}], "]"}]}], "Input",
 CellChangeTimes->{{3.686750206252577*^9, 3.686750377213314*^9}, {
  3.6867504096375513`*^9, 3.686750452193153*^9}, {3.6868099916929617`*^9, 
  3.686810003357183*^9}, {3.686815750962393*^9, 3.68681575548866*^9}, {
  3.686816665981729*^9, 
  3.686816676312845*^9}},ExpressionUUID->"9757458e-280f-4911-9c70-\
17d3d4b313e4"],

Cell[BoxData[
 RowBox[{"fig", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"fs", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
     RowBox[{"Opacity", "[", ".4", "]"}]}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686750572010149*^9, 3.686750704674611*^9}, {
   3.686810167848341*^9, 3.686810224180228*^9}, {3.686810343229806*^9, 
   3.6868103679220743`*^9}, {3.686810400318528*^9, 3.6868104122181997`*^9}, {
   3.6868104762147093`*^9, 3.68681048899304*^9}, {3.686810557075591*^9, 
   3.6868105981601877`*^9}, {3.686810634677251*^9, 3.6868106505761757`*^9}, {
   3.686810737601707*^9, 3.686810764471181*^9}, 3.6868157780857973`*^9, {
   3.68681743732479*^9, 
   3.686817439867381*^9}},ExpressionUUID->"28490e39-8d73-4449-9b2e-\
6c1193b59cc6"],

Cell["\<\
The surface looks like a slightly deformed torus with two opposite dented \
regions. Here is such a region cut off:\
\>", "Text",
 CellChangeTimes->{{3.686816187364168*^9, 3.6868162213638487`*^9}, {
  3.6868162530117493`*^9, 3.686816273779793*^9}, {3.6868163674988823`*^9, 
  3.6868164306985273`*^9}, {3.686816592089354*^9, 
  3.686816594208881*^9}},ExpressionUUID->"bf2eeb76-d5d3-4863-a43e-\
48b4a4aab8df"],

Cell[BoxData[
 RowBox[{"fig1", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"fs", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "4"}], ",", 
      RowBox[{"Pi", "/", "4"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
     RowBox[{"Opacity", "[", ".4", "]"}]}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686750572010149*^9, 3.686750704674611*^9}, {
   3.686810167848341*^9, 3.686810224180228*^9}, {3.686810343229806*^9, 
   3.6868103679220743`*^9}, {3.686810400318528*^9, 3.6868104122181997`*^9}, {
   3.6868104762147093`*^9, 3.68681048899304*^9}, {3.686810557075591*^9, 
   3.6868105981601877`*^9}, {3.686810634677251*^9, 3.6868106505761757`*^9}, {
   3.686811677961328*^9, 3.686811693055722*^9}, {3.68681482282835*^9, 
   3.6868148773914957`*^9}, 
   3.686816697190116*^9},ExpressionUUID->"d9fd257b-b5c3-4d56-a8e9-\
ed996a045547"],

Cell["The normal unit vector field of the surface is", "Text",
 CellChangeTimes->{{3.686816808871271*^9, 
  3.686816841390724*^9}},ExpressionUUID->"1c740801-9c18-4c7c-976c-\
cf1e4461fea2"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"nor", "[", "fs", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.686751360474907*^9, 3.686751420797532*^9}, {
   3.6868166371819067`*^9, 3.686816637425516*^9}, 
   3.686816945275886*^9},ExpressionUUID->"4eb8bbbe-a5f6-4768-873a-\
3b2a15ae7248"],

Cell["\<\
The normal vector is not defined at some points, namely if the denominator of \
the coordinates is zero, e.g.\
\>", "Text",
 CellChangeTimes->{{3.686817084405036*^9, 
  3.6868171628044*^9}},ExpressionUUID->"ce2104ff-2304-4858-b58e-d8922275e534"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nor", "[", "fs", "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686813345486271*^9, 
  3.686813374297615*^9}},ExpressionUUID->"a046ebeb-d1db-4f5c-95a9-\
4d49812a0bdf"],

Cell["To sketch the normal vectors we set", "Text",
 CellChangeTimes->{{3.686817200036253*^9, 3.686817203356303*^9}, {
  3.686817290907477*^9, 
  3.6868173162353573`*^9}},ExpressionUUID->"e55d5301-2854-4bad-9a53-\
d740513101e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ar", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{"Arrow", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fs", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{"fs", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"nor", "[", "fs", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "/", "2"}]}]}], "}"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.686811104509796*^9, 3.686811171657238*^9}, {
   3.686811202995243*^9, 3.686811330650457*^9}, {3.686811416570245*^9, 
   3.6868114267932873`*^9}, 3.686817337624372*^9, 
   3.686822495623704*^9},ExpressionUUID->"7e4fcf6b-eaee-447e-a74b-\
85f46fa182df"],

Cell[BoxData[
 RowBox[{
  RowBox[{"arfam", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ar", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{
        RowBox[{"-", "Pi"}], "/", "4"}], ",", 
       RowBox[{"Pi", "/", "4"}], ",", ".2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "0", ",", "Pi", ",", ".2"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6868114865695753`*^9, 3.68681150536909*^9}, {
   3.686811537653862*^9, 3.6868115993766613`*^9}, 3.686811630949585*^9, {
   3.6868118005462513`*^9, 
   3.6868118046787853`*^9}},ExpressionUUID->"08862e24-43e0-44d5-bcec-\
21a0aa11b243"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"fig", ",", "arfam"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{
  3.686817473674856*^9},ExpressionUUID->"e07fe16c-9616-47f3-884c-\
aeed7417757f"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"fig1", ",", "arfam"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.6868117291308327`*^9, 
  3.686811747318634*^9}},ExpressionUUID->"d1bc13b8-6595-4130-84a0-\
aaf33a9ab19a"],

Cell["We consider the normal vectors along the circle v=0:", "Text",
 CellChangeTimes->{{3.686822875459712*^9, 
  3.686822915235599*^9}},ExpressionUUID->"c11fbedb-0109-496f-abae-\
08ddc32fab54"],

Cell[BoxData[
 RowBox[{
  RowBox[{"arfam0", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ar", "[", 
      RowBox[{"0", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}], ",", ".2"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6868144109622707`*^9, 3.6868144358018703`*^9}, {
  3.6868144880668793`*^9, 
  3.6868144937938623`*^9}},ExpressionUUID->"fa14edf7-e4f3-4f3e-8ca0-\
f7759fd09deb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ars0", "=", 
   RowBox[{"Show", "[", "arfam0", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6868135875685863`*^9, 3.686813640351802*^9}, {
   3.686813679127811*^9, 3.686813691991466*^9}, {3.686813782294825*^9, 
   3.686813823894622*^9}, 3.686814034978313*^9, {3.686814305359559*^9, 
   3.686814335306404*^9}, {3.6868144534160843`*^9, 3.686814456913722*^9}, {
   3.686814530325143*^9, 3.686814549129311*^9}, 
   3.686823038421468*^9},ExpressionUUID->"fdb6f663-beeb-4f25-8b6e-\
e11626447252"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Circ0", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fs", "[", 
       RowBox[{"0", ",", "t"}], "]"}], "/.", 
      RowBox[{"r", "\[Rule]", ".5"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"3", "*", "Pi"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.686814562643236*^9, 3.686814652632786*^9}, {
  3.6868229353431168`*^9, 
  3.686822975509675*^9}},ExpressionUUID->"552fb4fe-546b-4e29-9956-\
9a7b02dcee56"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pts", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", ".02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"fs", "[", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", "Pi"}], "/", "2"}]}], "]"}], "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"fs", "[", 
        RowBox[{"0", ",", 
         RowBox[{"Pi", "/", "2"}]}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.686823046760853*^9, 
  3.68682324164487*^9}},ExpressionUUID->"b582ef46-ce05-4276-9f60-\
b65037699d8a"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"ars0", ",", "Circ0", ",", "pts"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.686814661385243*^9, 3.686814713759877*^9}, {
   3.686814778793838*^9, 3.686814782487245*^9}, 3.6868230012541723`*^9, {
   3.6868232504050198`*^9, 
   3.686823252386038*^9}},ExpressionUUID->"29365930-46af-4026-b07b-\
65f79a0918f3"],

Cell["\<\
The normal vector jumps to the other side at the points pts. \
\>", "Text",
 CellChangeTimes->{{3.686823417871562*^9, 3.686823527702808*^9}, 
   3.6868238938607616`*^9},ExpressionUUID->"41acc83f-b6d1-492b-8ceb-\
d7446298c2a1"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"nor", "[", "fs", "]"}], "[", 
    RowBox[{"0", ",", "v"}], "]"}], ",", 
   RowBox[{"v", "\[Rule]", 
    RowBox[{"Pi", "/", "2"}]}], ",", 
   RowBox[{"Direction", " ", "\[Rule]", " ", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686751657478633*^9, 3.686751684219089*^9}, {
   3.6867517634314203`*^9, 3.6867518017145777`*^9}, {3.686751926326707*^9, 
   3.6867519349452143`*^9}, 3.686751993345323*^9, {3.68675293692553*^9, 
   3.686752945384973*^9}, 3.686752995132763*^9, {3.686810942620887*^9, 
   3.6868109468533688`*^9}, {3.686813471795747*^9, 
   3.6868134828492537`*^9}},ExpressionUUID->"7a825d9f-e258-416d-8331-\
b68aa09f48d4"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"nor", "[", "fs", "]"}], "[", 
    RowBox[{"0", ",", "v"}], "]"}], ",", 
   RowBox[{"v", "\[Rule]", 
    RowBox[{"Pi", "/", "2"}]}], ",", 
   RowBox[{"Direction", " ", "\[Rule]", " ", 
    RowBox[{"-", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686751657478633*^9, 3.686751684219089*^9}, {
   3.6867517634314203`*^9, 3.6867518017145777`*^9}, {3.686751926326707*^9, 
   3.6867519349452143`*^9}, 3.686751993345323*^9, {3.68675293692553*^9, 
   3.686752960512973*^9}, 3.686753007261251*^9, {3.686810961125016*^9, 
   3.686810965548854*^9}, {3.686813493851905*^9, 
   3.6868135055688562`*^9}},ExpressionUUID->"7760d3a7-f9e8-40d1-9de6-\
60f8308ec9d5"],

Cell["\<\
These points are singularities. Indeed, the tangent vectors of the coordinate \
lines at this point are parallel:\
\>", "Text",
 CellChangeTimes->{{3.686823922500403*^9, 
  3.686823985619047*^9}},ExpressionUUID->"e38ee91f-3bb8-4755-82d5-\
4320b16abf32"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "1", "]"}], "[", "fs", "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686823700403178*^9, 
  3.686823749165759*^9}},ExpressionUUID->"73ab0545-fa03-46d0-ba54-\
9e0969c6dc16"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "2", "]"}], "[", "fs", "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686823700403178*^9, 
  3.68682376556565*^9}},ExpressionUUID->"14d5d8f7-5832-4821-ac83-\
77171a1ac4cf"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"tv", "[", "1", "]"}], "[", "fs", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{
    RowBox[{
     RowBox[{"tv", "[", "1", "]"}], "[", "fs", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686812039733478*^9, 3.686812131843725*^9}, {
  3.686812189881864*^9, 
  3.686812253835335*^9}},ExpressionUUID->"dee60999-fe80-4b1e-90c4-\
e27c22f68ed7"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", "fs", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", "fs", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "*", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.686812039733478*^9, 3.686812131843725*^9}, {
  3.686812189881864*^9, 3.686812271603487*^9}, {3.686812361644312*^9, 
  3.6868123721056013`*^9}, {3.686825325041162*^9, 
  3.686825326645257*^9}},ExpressionUUID->"33e0b238-4446-4fb7-9617-\
e7b90e685502"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", "fs", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", "fs", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "*", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.686812039733478*^9, 3.686812131843725*^9}, {
   3.686812189881864*^9, 3.686812296555253*^9}, {3.6868123858542747`*^9, 
   3.686812421857481*^9}, 3.686824010904541*^9, {3.686824043302153*^9, 
   3.686824055990189*^9}},ExpressionUUID->"c494bda5-f79f-4ff5-963e-\
3207972d92a9"],

Cell["\<\
Thus the cosinus of the angle between the tangent vectors of the coordinate \
lines is given by\
\>", "Text",
 CellChangeTimes->{{3.68682450839098*^9, 
  3.686824560314403*^9}},ExpressionUUID->"04f1a0ef-f256-45dd-897f-\
e4d6d676ad04"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fcos", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "1", "]"}], "[", "fs", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "2", "]"}], "[", "fs", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "*", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686824155252283*^9, 3.6868242515457363`*^9}, {
  3.686824322777334*^9, 3.6868243850005198`*^9}, {3.6868244317180443`*^9, 
  3.686824440672493*^9}},ExpressionUUID->"6f8ec002-c735-4822-afab-\
9e2b28cf9553"],

Cell["\<\
A point of the surface fs is singular if the tangent vectors to the parameter \
lines are linearly dependent, also  if its angle \[Alpha] is k*Pi, they are \
parallel:  Cos[\[Alpha]] = \[PlusMinus]1. The finitely many singularities can \
be find looking at the plot of fcos as the points with fcos]u,v]= \
\[PlusMinus]1. \
\>", "Text",
 CellChangeTimes->{{3.6868246267216673`*^9, 3.686824746329018*^9}, {
  3.686824787464723*^9, 3.6868250668224907`*^9}, {3.6868251091421957`*^9, 
  3.686825275238291*^9}, {3.6934056584348392`*^9, 3.693405746530364*^9}, {
  3.69340578141852*^9, 
  3.69340579204177*^9}},ExpressionUUID->"82dbc4bd-224b-435d-8fb5-\
6cb3ee17bbee"],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"fcos", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686812879157267*^9, 3.686812912509411*^9}, {
  3.6868129619102793`*^9, 3.6868129661250353`*^9}, {3.686824454140169*^9, 
  3.6868244601927567`*^9}},ExpressionUUID->"5f1a1082-e401-436c-a107-\
847de20fd54c"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fcos", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", "1"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.693405937050879*^9, 
  3.693406025641011*^9}},ExpressionUUID->"ec83907f-8858-44b5-aa06-\
ea71ecb0fce4"],

Cell["\[FilledSmallSquare]", "Text",
 CellChangeTimes->{{3.68682530190874*^9, 
  3.686825301910488*^9}},ExpressionUUID->"5fe84235-0f53-49ee-9253-\
5b8e399c03c6"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2. An Adapted  Orthonormal Moving 3-Frame of the Surface", \
"Subsection",
 CellChangeTimes->{{3.5721739619617743`*^9, 3.5721739801278133`*^9}, {
   3.5860011060172153`*^9, 3.5860011130840273`*^9}, {3.587272413023604*^9, 
   3.5872724205980372`*^9}, {3.588487546773712*^9, 3.588487560267736*^9}, {
   3.5994914425513973`*^9, 3.5994914450615406`*^9}, 3.599552816652402*^9, {
   3.614777404959643*^9, 3.614777407655797*^9}, 3.614951503403132*^9, {
   3.6176159535908546`*^9, 3.617615958161663*^9}, 3.617616389845621*^9, 
   3.6272869628842096`*^9, {3.686664113702238*^9, 3.6866641157981567`*^9}, 
   3.6868380800091143`*^9, {3.68683811655309*^9, 3.686838119856512*^9}, 
   3.6868982941865263`*^9, {3.6903587629122047`*^9, 3.690358770703794*^9}, {
   3.693406374565737*^9, 3.693406377757537*^9}, 
   3.693483027082103*^9},ExpressionUUID->"852bfb36-1014-4746-a224-\
dcd2f28ab08f"],

Cell[CellGroupData[{

Cell["1.2.1. The Definition", "Subsubsection",
 CellChangeTimes->{{3.5860011346276655`*^9, 3.586001146530486*^9}, {
   3.5860678825807543`*^9, 3.586067896183978*^9}, {3.5872724267433887`*^9, 
   3.587272433749789*^9}, 3.6176163958204317`*^9, 3.6176185661766634`*^9, 
   3.627287284893177*^9, 3.62730821645765*^9, 3.696172477989478*^9, 
   3.696173307102331*^9},ExpressionUUID->"af836172-602d-4649-a1fd-\
058b6609624d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spdim", " ", "=", " ", "3"}], ";", 
  RowBox[{"dim", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.61761719716236*^9, 3.6176172042407646`*^9}, {
  3.696081407830394*^9, 3.696081408942336*^9}, {3.696147308597406*^9, 
  3.6961473101251993`*^9}, {3.696172493405087*^9, 
  3.6961724957970037`*^9}},ExpressionUUID->"90963356-3cd9-4624-9bd1-\
c1bc12c828d1"],

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.617617219455635*^9, 
  3.617617242201936*^9}},ExpressionUUID->"a4a8e712-eba4-4b63-86a8-\
f53b0475a0fc"],

Cell["\<\
The adapted moving frame amf of a surface f[u,v] is defined in eudiffgeov3.m:\
\>", "Text",
 CellChangeTimes->{{3.6226001123748865`*^9, 3.6226001345581255`*^9}, 
   3.686289005153948*^9, {3.686831389660829*^9, 3.686831461012259*^9}, 
   3.68683260888384*^9, {3.68698768527374*^9, 
   3.68698772368143*^9}},ExpressionUUID->"a09f9f17-0e98-4de9-b52f-\
86570526b5ca"],

Cell[BoxData[
 RowBox[{"?", "amf"}]], "Input",
 CellChangeTimes->{{3.6148635430116963`*^9, 3.6148637222872114`*^9}, {
   3.6148638592242517`*^9, 3.6148639120303445`*^9}, {3.6148639626212335`*^9, 
   3.6148639914500837`*^9}, 3.614917824758619*^9, {3.614918015094553*^9, 
   3.6149180265449734`*^9}, {3.6226001544637604`*^9, 
   3.622600173183793*^9}},ExpressionUUID->"180ddc97-3bac-43c2-bbce-\
010fad49dd70"],

Cell["\<\
The vectors amf[1][sf][u,v], amf[2][sf][u,v] are an orthonormal basis of the \
tangent plane of sf at the point sf[u,v]:\
\>", "Text",
 CellChangeTimes->{{3.6868314926279593`*^9, 
  3.68683160854732*^9}},ExpressionUUID->"ec189f8d-c543-45c7-b6f8-\
4fc06f4b6971"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "1", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"dotnorme", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", "f", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], " ", "\[Equal]", " ", "List"}],
      "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "3"}]}], 
    ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.553950276121236*^9, {3.5860012023005843`*^9, 3.586001242361455*^9}, {
   3.5860012820791245`*^9, 3.586001290471939*^9}, {3.614861848911121*^9, 
   3.6148618489267206`*^9}, {3.6148619944905767`*^9, 3.614862019809421*^9}, 
   3.6149178247118187`*^9, 3.614917951836442*^9, 3.617600023979088*^9, {
   3.6176169240037365`*^9, 3.6176169255228233`*^9}, {3.6176170208992786`*^9, 
   3.6176170992707605`*^9}, 3.617617644972973*^9, {3.617617700828168*^9, 
   3.617617748052869*^9}, 
   3.627304505615427*^9},ExpressionUUID->"25a7f2d7-da1f-47d2-92ad-\
b4ac33f2c8e2"],

Cell[BoxData[
 RowBox[{"?", "dotnorme"}]], "Input",
 CellChangeTimes->{{3.692604834047855*^9, 
  3.692604839317389*^9}},ExpressionUUID->"882ed020-630b-48f9-89ff-\
1f15da48a753"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5718247469642887`*^9, 3.5718247900827646`*^9}, {
   3.5721744197469583`*^9, 3.572174420562005*^9}, 3.6148618489267206`*^9, 
   3.614917824727419*^9, 3.6149179629904613`*^9, {3.6273044458769217`*^9, 
   3.6273044687661624`*^9}, {3.696172593740234*^9, 
   3.6961725970039673`*^9}},ExpressionUUID->"3a984cc5-1df7-49b0-99f6-\
a0270d02ae81"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", "\[LineSeparator]", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "1", "]"}], "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], " ", "\[Equal]", " ", "List"}],
      "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "3"}]}], 
    ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.5718421091490374`*^9, 3.5718421511287107`*^9, {3.5718422225768366`*^9, 
   3.571842229035248*^9}, {3.5718433048599377`*^9, 3.5718433055619383`*^9}, {
   3.586001531227162*^9, 3.586001556202806*^9}, {3.614861848973521*^9, 
   3.614861848973521*^9}, {3.614917824743019*^9, 3.614917824758619*^9}, {
   3.614917976219285*^9, 3.614918000305727*^9}, 3.617617135587838*^9, 
   3.6176248570180454`*^9, 3.686832884867217*^9, {3.692605189995213*^9, 
   3.6926051988277273`*^9}},ExpressionUUID->"1cc0227d-b75b-4255-9558-\
37cdb023a45f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5718247469642887`*^9, 3.5718247900827646`*^9}, 
   3.571824823950424*^9, {3.571824855134879*^9, 3.5718248677553015`*^9}, 
   3.5718426714520245`*^9, {3.5721742134671593`*^9, 3.5721742146832294`*^9}, 
   3.572174471475917*^9, 3.614861848989121*^9, 3.614917824774219*^9, 
   3.6149180333933854`*^9, {3.686831754884227*^9, 3.686831760978956*^9}, {
   3.686831802282537*^9, 3.686831804572472*^9}, {3.6868318831983852`*^9, 
   3.686831905709507*^9}, {3.6868320500192213`*^9, 3.6868320799128733`*^9}, {
   3.6868329482952757`*^9, 3.686833032632698*^9}, {3.686833081473074*^9, 
   3.686833081817059*^9}, 
   3.686833505153489*^9},ExpressionUUID->"e75fac03-6c60-4e9a-a67e-\
9aeb180790cc"],

Cell[TextData[{
 "Here amf[3][f][u,v] is the ",
 StyleBox["normal vector",
  FontColor->RGBColor[0, 0, 1]],
 " of the oriented surface f at the point f[u,v]:"
}], "Text",
 CellChangeTimes->{{3.5718418633550053`*^9, 3.5718418720286207`*^9}, {
  3.586001385070505*^9, 3.586001418438964*^9}, {3.586001462259441*^9, 
  3.586001488514287*^9}, {3.686833554892499*^9, 
  3.686833628291821*^9}},ExpressionUUID->"8d98f70b-d6c1-426a-aadc-\
7fb11fab132c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"dotnorme", "[", 
    RowBox[{"Cross", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "1", "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "2", "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], " ", "\[Equal]", " ", "List"}],
      "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "3"}]}], 
    ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.571841915895898*^9, 3.5718420523961377`*^9}, {
   3.5860013177251873`*^9, 3.586001351670847*^9}, {3.614861848957921*^9, 
   3.614861848957921*^9}, 3.614862118307994*^9, 3.614917824727419*^9, 
   3.6149179656580667`*^9, 3.6176000239946876`*^9, 3.617600085723996*^9, 
   3.617617128124411*^9, 
   3.6176248811064234`*^9},ExpressionUUID->"b6610a0a-03d2-4983-a73a-\
839d473a7943"],

Cell[TextData[{
 "It coincides with the normal vector nor define in ",
 ButtonBox["1.1.1",
  BaseStyle->"Hyperlink",
  ButtonData->"nor"],
 ":"
}], "Text",
 CellChangeTimes->{{3.686833688002857*^9, 3.6868337100345173`*^9}, {
  3.690011384937726*^9, 3.690011393849929*^9}, {3.69001145834415*^9, 
  3.690011458346505*^9}},ExpressionUUID->"86d63b3f-7760-4088-8040-\
18b09d655534"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{"nor", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5718247469642887`*^9, 3.5718247900827646`*^9}, 
   3.571824823950424*^9, {3.571824855134879*^9, 3.5718248677553015`*^9}, 
   3.5718426714520245`*^9, {3.5721742134671593`*^9, 3.5721742146832294`*^9}, 
   3.614861848989121*^9, 3.614917824758619*^9, 3.6149180316617823`*^9, {
   3.627304553807912*^9, 3.627304570800342*^9}, {3.686833664804331*^9, 
   3.686833677524085*^9}},ExpressionUUID->"6e5b3162-7c93-4680-bb61-\
d3e9daa57765"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5718247469642887`*^9, 3.5718247900827646`*^9}, 
   3.571824823950424*^9, {3.571824855134879*^9, 3.5718248677553015`*^9}, 
   3.5718426714520245`*^9, {3.5721742134671593`*^9, 3.5721742146832294`*^9}, 
   3.572174471475917*^9, 3.614861848989121*^9, 3.614917824774219*^9, 
   3.6149180333933854`*^9, 
   3.686834275431451*^9},ExpressionUUID->"fd6fd187-c1e4-4468-b145-\
300d4176ff55"],

Cell["The orthogonality conditions are fulfilled:", "Text",
 CellChangeTimes->{{3.572174706905383*^9, 3.572174739048221*^9}, 
   3.572175509736302*^9},ExpressionUUID->"f835890b-d8f3-4da7-86d6-\
c20152b4cdd6"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "j", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5718249735702868`*^9, 3.571825082302478*^9}, {
   3.571825121474147*^9, 3.571825217539116*^9}, {3.5718423315118275`*^9, 
   3.571842382430317*^9}, {3.572174517435546*^9, 3.5721745795881004`*^9}, {
   3.6148618490047207`*^9, 3.6148618490047207`*^9}, 3.6148635013128233`*^9, {
   3.614917824774219*^9, 3.614917824774219*^9}, {3.614918034984588*^9, 
   3.614918038853395*^9}, {3.6149467734835796`*^9, 
   3.6149467756675835`*^9}},ExpressionUUID->"a182b713-1080-4862-8b16-\
38a2842f4acc"],

Cell["and the frame is positively oriented", "Text",
 CellChangeTimes->{{3.5885663623766937`*^9, 
  3.5885663832495303`*^9}},ExpressionUUID->"d208e7dd-9bbc-4277-b831-\
199d96fa3ec0"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5885663928903475`*^9, 3.588566463870472*^9}, {
   3.6148618490047207`*^9, 3.6148618490047207`*^9}, 3.6148635013128233`*^9, 
   3.614917824774219*^9, 
   3.614918046637809*^9},ExpressionUUID->"47a11afe-1300-4bd7-b32b-\
31216a8a0539"],

Cell[TextData[{
 "The frame {amf[i][f][u,v]} defined above is named the",
 StyleBox[" orthonormal moving frame adapted to the parameter representation",
  FontColor->RGBColor[0, 0, 1]],
 " f[u,v]. A picture of an adapted moving frame on the sphere we constructed \
already in Subsection 1.1.1, see ",
 ButtonBox["figsph3",
  BaseStyle->"Hyperlink",
  ButtonData->"figsph3"],
 "."
}], "Text",
 CellChangeTimes->{{3.586002264085249*^9, 3.5860023096529293`*^9}, {
   3.586002387465866*^9, 3.5860024607859945`*^9}, 3.614861849035921*^9, 
   3.614917824789819*^9, 3.6149180502102146`*^9, {3.6868376593085413`*^9, 
   3.686837791595806*^9}, {3.686837939345992*^9, 
   3.6868379460109377`*^9}},ExpressionUUID->"c7580c31-6e47-43ab-bd2a-\
3ea3cb31d1b7"],

Cell[TextData[{
 "The",
 StyleBox[" tangent plane",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface at the point f[u,v] is also obtained by "
}], "Text",
 CellChangeTimes->{{3.572174857303985*^9, 3.572174923024744*^9}, 
   3.572255761617314*^9, 3.586002208315151*^9, 
   3.58600250944248*^9},ExpressionUUID->"2bf8a3d5-4b75-4002-8e07-\
9582b94e630d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tplane2", "[", "f_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], "[", 
   RowBox[{"s1_", ",", "s2_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "1", "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", "s1"}], " ", "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "2", "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", "s2"}]}], ")"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Head", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], " ", "\[Equal]", " ", "List"}],
      "&&", 
     RowBox[{
      RowBox[{"Length", "[", 
       RowBox[{"f", "[", 
        RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", " ", "3"}]}], 
    ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5721749454350257`*^9, 3.5721751309256353`*^9}, {
   3.5860025164312925`*^9, 3.58600253769413*^9}, {3.5889995834210863`*^9, 
   3.5889995911395283`*^9}, {3.5889996328979163`*^9, 3.588999681604702*^9}, {
   3.599552093004184*^9, 3.599552117262227*^9}, {3.6148618490515213`*^9, 
   3.6148618490671215`*^9}, {3.614917824805419*^9, 3.614917824805419*^9}, {
   3.614918053626621*^9, 3.614918054999423*^9}, {3.6176173159571543`*^9, 
   3.6176173279088383`*^9}, 3.622781337067371*^9, {3.6273046857825446`*^9, 
   3.6273046926153564`*^9}, 3.6273047310266247`*^9, {3.627305109362291*^9, 
   3.627305125543519*^9}, 
   3.627305353654521*^9},ExpressionUUID->"c4d6d234-d687-4e04-8ef3-\
93c28ce918bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tplane2", "::", "usage"}], " ", "=", " ", 
   "\"\<tplane2[f][uo,vo][x,y] is the parameter representation of the tangent \
plane of the surface f[u,v] in the Euclidean 3-space adapted to the moving \
frame of the surface. x,y are orthonormal Cartesian parameters of the tangent \
plane at the point {uo,vo} of the surface.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6148641539087696`*^9, 3.614864405428011*^9}, {
   3.6148644494668884`*^9, 3.6148644830069475`*^9}, 3.614864538574245*^9, 
   3.617617381974931*^9, {3.6227813534629993`*^9, 3.6227813555222034`*^9}, 
   3.622781397377077*^9},ExpressionUUID->"641ed957-a675-49ee-bcd5-\
6d050ce5e74c"],

Cell["\<\
or as the set of the solutions {x,y,z} of the linear equation\
\>", "Text",
 CellChangeTimes->{{3.5721752650483065`*^9, 3.5721752988642406`*^9}, {
   3.5721754466666946`*^9, 3.57217544781676*^9}, {3.5860026178782706`*^9, 
   3.5860026297342916`*^9}, {3.5860027381388817`*^9, 
   3.5860027435364914`*^9}, {3.589000353591138*^9, 3.5890003553912406`*^9}, 
   3.589000402351927*^9},ExpressionUUID->"e7da7b6c-80d3-435b-892d-\
f4e94f99968c"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "-", 
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ")"}]}], " ", "\[Equal]", " ", 
    "0"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5721753037755213`*^9, 3.5721754164589667`*^9}, {
   3.586001703139464*^9, 3.586001727569107*^9}, {3.586002570703788*^9, 
   3.5860025763353977`*^9}, {3.5860026404515104`*^9, 3.5860026441331167`*^9}, 
   3.5860026891235957`*^9, {3.589000060667383*^9, 3.5890000674507713`*^9}, {
   3.589000200076357*^9, 3.58900020817082*^9}, {3.5890004665876007`*^9, 
   3.5890004846996365`*^9}, {3.614861849098321*^9, 3.614861849098321*^9}, 
   3.614864650832042*^9, 3.614917824805419*^9, 3.6149180817846704`*^9, {
   3.6149471868219056`*^9, 3.614947213201552*^9}, {3.617617424587368*^9, 
   3.617617437755121*^9}, 
   3.6273058974630795`*^9},ExpressionUUID->"e88342be-ee86-4c5d-bfe8-\
111d530c760d"],

Cell[TextData[{
 StyleBox["Example 1",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["Circular Cone",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.5995526058523445`*^9, 3.5995526242033944`*^9}, {
  3.68683465258757*^9, 
  3.686834669971218*^9}},ExpressionUUID->"fb498a18-167a-4ab8-b353-\
57f0306ecd42"],

Cell[TextData[{
 "First evaluate ",
 ButtonBox["Example 1.1.4",
  BaseStyle->"Hyperlink",
  ButtonData->"cone"],
 "."
}], "Text",
 CellChangeTimes->{{3.686834676316098*^9, 3.686834766410768*^9}, {
  3.686835091734346*^9, 3.6868350917366734`*^9}, {3.692605888349187*^9, 
  3.692605913124795*^9}},ExpressionUUID->"6eeea42c-385e-4ef5-88be-\
bf7e28995b4e"],

Cell[BoxData[
 RowBox[{"?", "circularcone"}]], "Input",
 CellChangeTimes->{{3.5995522936517363`*^9, 3.5995522964441414`*^9}, {
  3.6148647754450607`*^9, 
  3.6148648052411137`*^9}},ExpressionUUID->"0b9ebfb5-4c9a-420a-b308-\
f2e9562ffd4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6148649822702246`*^9, 
  3.6148649910374393`*^9}},ExpressionUUID->"32a76f9d-ecb0-4ef0-8d42-\
8f1203022d52"],

Cell["For a =b=1 the cone is", "Text",
 CellChangeTimes->{{3.6868354382049103`*^9, 
  3.6868354565413837`*^9}},ExpressionUUID->"ef1c970d-bf66-4ce1-b93d-\
5633ddec66dc"],

Cell[BoxData["figcon"], "Input",
 CellChangeTimes->{{3.686835164564974*^9, 3.686835177455533*^9}, 
   3.6868352486200047`*^9},ExpressionUUID->"7559e5f5-0919-43f0-aa94-\
ceab02183b27"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"tplane2", "[", 
      RowBox[{"circularcone", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"s1", ",", "s2"}], "]"}], ",", " ", 
   RowBox[{"Element", "[", 
    RowBox[{"v", ",", "Reals"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588999525808791*^9, 3.5889995544654303`*^9}, {
   3.5889998476021967`*^9, 3.5889998692254333`*^9}, {3.588999967738068*^9, 
   3.5889999693361597`*^9}, {3.5995521295394487`*^9, 
   3.5995521337046556`*^9}, {3.614864925345724*^9, 3.614864937404546*^9}, {
   3.614865041753129*^9, 3.6148650786939936`*^9}, 3.622781388953062*^9, 
   3.627304843640623*^9, {3.6273053996318026`*^9, 3.62730540400181*^9}, {
   3.6273055995037546`*^9, 3.6273056885743113`*^9}, {3.62730578452048*^9, 
   3.627305809422124*^9}},ExpressionUUID->"cef81ba0-f07f-40a8-80c6-\
6d4b66605664"],

Cell["In the case of f = circularcone[1,1][0,1]:", "Text",
 CellChangeTimes->{{3.5721752650483065`*^9, 3.5721752988642406`*^9}, {
   3.5721754466666946`*^9, 3.57217544781676*^9}, {3.5860026178782706`*^9, 
   3.5860026297342916`*^9}, {3.5860027381388817`*^9, 
   3.5860027435364914`*^9}, {3.589000353591138*^9, 3.5890003553912406`*^9}, 
   3.589000402351927*^9, {3.5890004969433365`*^9, 3.589000503406707*^9}, {
   3.6148651258996763`*^9, 3.6148651590185347`*^9}, {3.614947245400008*^9, 
   3.614947251000418*^9}, {3.6149472930736923`*^9, 
   3.614947322557744*^9}},ExpressionUUID->"0a380c3b-b085-487b-9d55-\
70d6b18382ff"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", 
    RowBox[{"circularcone", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.617617511883361*^9, 3.6176175360677443`*^9}, {
   3.6176182028678827`*^9, 3.617618245404316*^9}, {3.6273059976836557`*^9, 
   3.6273060012112617`*^9}, 3.6273060669693775`*^9, 3.627307186882518*^9, {
   3.686835525938146*^9, 
   3.6868355719887543`*^9}},ExpressionUUID->"a7484fa3-121c-4c2c-98cb-\
e7da5b10c726"],

Cell["\<\
Clearly, the tangential plane of the circular cone doesn\[CloseCurlyQuote]t \
depend on v; it is constant along the generating lines.\
\>", "Text",
 CellChangeTimes->{{3.5890002696153345`*^9, 3.5890003178870955`*^9}, 
   3.6148653107288013`*^9, 3.614948837819605*^9, 
   3.6151172062957406`*^9},ExpressionUUID->"b0fdd680-39fd-4622-b6a1-\
60075dfdf137"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"v", ">", "0"}], ",", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"%", "/.", 
         RowBox[{"u", "\[Rule]", "0"}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}], "-", 
         RowBox[{
          RowBox[{"circularcone", "[", 
           RowBox[{"1", ",", "1"}], "]"}], "[", 
          RowBox[{"0", ",", "v"}], "]"}]}], ")"}]}], " ", "\[Equal]", " ", 
      "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5721753037755213`*^9, 3.5721754164589667`*^9}, {
   3.586001703139464*^9, 3.586001727569107*^9}, {3.586002570703788*^9, 
   3.5860025763353977`*^9}, {3.5860026404515104`*^9, 3.5860026441331167`*^9}, 
   3.5860026891235957`*^9, {3.589000060667383*^9, 3.5890000674507713`*^9}, {
   3.589000200076357*^9, 3.58900020817082*^9}, {3.614861849098321*^9, 
   3.614861849098321*^9}, 3.614864659848858*^9, 3.6148647314217834`*^9, {
   3.6148651794857707`*^9, 3.6148652085018215`*^9}, 3.614917824821019*^9, 
   3.6149180935314913`*^9, {3.6149473500449924`*^9, 3.6149473675482225`*^9}, 
   3.6149474635039916`*^9, 3.617618271444805*^9, 3.6176183090049534`*^9, {
   3.6273072196153755`*^9, 3.627307278357479*^9}, {3.627307394889085*^9, 
   3.627307417698325*^9}, 3.6273079680732126`*^9, {3.686835675084648*^9, 
   3.686835697436103*^9}},ExpressionUUID->"bc52cc27-17ad-4949-93b1-\
196da26fecc2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tplane0", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "x"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.686835787489636*^9, 
  3.686835857642974*^9}},ExpressionUUID->"4055c74b-5ad4-4d96-93e9-\
a7e5dbc1cc52"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coline", " ", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "t"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
     RowBox[{"PlotStyle", " ", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", " ", "Thick"}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6868363281908073`*^9, 3.686836423294489*^9}, {
  3.686836525440834*^9, 
  3.6868365316011143`*^9}},ExpressionUUID->"fc109346-6629-4367-bd5c-\
50ff93df5d48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tpl0", " ", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "x"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Opacity", "[", ".4", "]"}]}], "}"}]}], ",", 
     RowBox[{"Mesh", "\[Rule]", " ", "None"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.686835876012898*^9, 3.6868359985863543`*^9}, {
   3.6868362305903397`*^9, 3.686836267079569*^9}, 
   3.686836561698398*^9},ExpressionUUID->"91a63e3c-4b57-4272-83d4-\
d8bc8ea5d585"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"figcon", ",", "tpl0", ",", "coline"}], "}"}], ",", 
   RowBox[{"Boxed", "\[Rule]", " ", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686836044402121*^9, 3.6868361175207243`*^9}, {
  3.686836576785565*^9, 
  3.686836585357031*^9}},ExpressionUUID->"3797a332-957e-4485-be3b-\
bc4639b3d3b6"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6868368669361153`*^9, 
  3.686836866938018*^9}},ExpressionUUID->"626b85cf-5ae1-4777-82cf-\
455e3dca410d"],

Cell[TextData[{
 StyleBox["Example 2",
  FontColor->RGBColor[0, 0, 1]],
 ". A Plane"
}], "Text",
 CellChangeTimes->{{3.587272440743189*^9, 3.5872724436063533`*^9}, 
   3.588661276850272*^9, 3.5995529828209066`*^9, 3.599566093190103*^9, 
   3.6176185715049677`*^9, 3.6176250871982107`*^9, 3.62730822193326*^9, 
   3.627308449269261*^9, {3.6868380978967876`*^9, 3.686838103720685*^9}, {
   3.686987814440392*^9, 
   3.68698783994416*^9}},ExpressionUUID->"316c137e-e381-4fba-a271-\
ac94c32c3c41"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fpl", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{"{", 
   RowBox[{"u", ",", "v", ",", 
    RowBox[{"u", "+", 
     RowBox[{"2", "*", "v"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.553947791570472*^9, 3.5539477933488746`*^9}, {
  3.586001848219719*^9, 3.586001869981757*^9}, {3.5860020467612677`*^9, 
  3.586002150158249*^9}},ExpressionUUID->"9b9cfae2-4a61-4719-ae7d-\
d38ce9e407fb"],

Cell["\<\
For a plane the vectors of the moving frame can be chosen to be constant:\
\>", "Text",
 CellChangeTimes->{{3.572176177272483*^9, 3.5721762037599983`*^9}, {
   3.572176239688053*^9, 3.572176260632251*^9}, 
   3.572255951175156*^9},ExpressionUUID->"12bde49e-5fe9-4e50-a980-\
fc3011486af6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "1", "]"}], "[", "fpl", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.553948967562937*^9, 3.5539502761680355`*^9, {3.586002788948171*^9, 
   3.586002790726574*^9}, 3.6148618491295214`*^9, 3.6149178248366194`*^9, 
   3.6149181005671034`*^9},ExpressionUUID->"e404c699-de30-4192-92b9-\
5ce66b89dd35"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "2", "]"}], "[", "fpl", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.553950304404085*^9, 3.586002826544237*^9, 
  3.6148618491295214`*^9, 3.6149178248366194`*^9, 
  3.6149181022207065`*^9},ExpressionUUID->"0fd3b9e3-a0b1-40e7-98d5-\
9ab2b9389934"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "3", "]"}], "[", "fpl", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.5539489906821775`*^9, 3.5539503233269186`*^9, 
  3.58600282829144*^9, 3.614861849145121*^9, 3.614917824852219*^9, 
  3.614918103531109*^9},ExpressionUUID->"04aa2b10-cebc-4ae8-aae7-\
9acf59254559"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "fpl", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "j", "]"}], "[", "fpl", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.553947825625331*^9, 3.5539478262649326`*^9}, {
   3.5539479129386845`*^9, 3.5539479129386845`*^9}, {3.5539480114528575`*^9, 
   3.5539480249468813`*^9}, {3.5539490104630127`*^9, 
   3.5539490713811197`*^9}, {3.5539503233425183`*^9, 
   3.5539503233425183`*^9}, {3.5721759831323786`*^9, 3.5721760687492757`*^9}, 
   3.5721761324919214`*^9, {3.5860028308186445`*^9, 3.5860028329246483`*^9}, {
   3.6148618491607213`*^9, 3.614861849176321*^9}, 3.614863501344023*^9, {
   3.6149178248678193`*^9, 3.6149178248678193`*^9}, {3.6149181080083165`*^9, 
   3.614918109693119*^9}},ExpressionUUID->"d2f306e6-c044-4a39-9c82-\
f5a9691b93e5"],

Cell["As we see, the vectors of this moving frame are constant:", "Text",
 CellChangeTimes->{{3.586003209961711*^9, 3.5860032385721607`*^9}, {
  3.5995601670382357`*^9, 
  3.599560167205245*^9}},ExpressionUUID->"d4038b37-7f83-416b-8f0e-\
dd9919297e9b"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"amf", "[", "i", "]"}], "[", "fpl", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5860029528576593`*^9, 3.5860030749746733`*^9}, {
   3.6148618492075214`*^9, 3.6148618492075214`*^9}, 3.614863501375223*^9, 
   3.6149178248990192`*^9, 3.6149181233275433`*^9, {3.686987948207975*^9, 
   3.6869879933033333`*^9}},ExpressionUUID->"0b338dec-aec2-425f-9577-\
2ad3d4b48da7"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6869880519376287`*^9, 
  3.686988051938691*^9}},ExpressionUUID->"d0dc9e32-5f90-4056-a145-\
987c9215dc73"],

Cell[TextData[{
 "It is useful to add the point sf[u,v] of the surface to form a moving frame \
consisting of the point of the surface and the adapted vector frame \
{amf[i][sf][u,v]}., i 0 1,...,dim. The advantage one gets comes from the fact \
that the set of all possible such frames can be identified with the Euclidean \
group, see example 1.2.4 in the notebook ",
 ButtonBox["Affine Geometry.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{"."}, "AffineGeom.nb", CharacterEncoding -> "UTF-8"], 
    None}],
 "   In this notebook we presented H. Weyl\[CloseCurlyQuote]s point- vector \
axiomatic in terms of Mathematica. To distinguish points and vectors we \
introduced in tensalgv3.m the objects"
}], "Text",
 CellChangeTimes->{{3.692629007376865*^9, 3.6926290871524143`*^9}, {
   3.692629202967578*^9, 3.692629300830575*^9}, {3.6926293340946093`*^9, 
   3.692629787843944*^9}, {3.69262989989895*^9, 3.692629922914315*^9}, 
   3.692629979833675*^9, {3.692630098196447*^9, 3.692630098199472*^9}, {
   3.69263013244977*^9, 3.69263023071305*^9}, {3.692682986152541*^9, 
   3.6926830600855618`*^9}, 3.69268311746836*^9, {3.692683174555771*^9, 
   3.692683181460497*^9}},ExpressionUUID->"988ae949-adf5-4a17-ac52-\
95a4ebf1e6d8"],

Cell[BoxData[
 RowBox[{"?", "point"}]], "Input",
 CellChangeTimes->{{3.692630246372423*^9, 
  3.692630250327774*^9}},ExpressionUUID->"1ed95d27-f706-409f-8c00-\
ab67651bcd8a"],

Cell[BoxData[
 RowBox[{"?", "vector"}]], "Input",
 CellChangeTimes->{{3.690377536572606*^9, 3.690377545890882*^9}, {
  3.690377673454241*^9, 
  3.690377677865142*^9}},ExpressionUUID->"4a34dd24-99f4-4e8b-b715-\
877b378250c4"],

Cell[BoxData[
 RowBox[{"Context", "[", "vector", "]"}]], "Input",
 CellChangeTimes->{{3.690377791700899*^9, 
  3.690377805432325*^9}},ExpressionUUID->"1ad7dae9-a892-4ee5-bef9-\
66f61d5e2935"],

Cell[BoxData["\"\<tensalgv3`\>\""], "Input",
 CellChangeTimes->{{3.692595118507934*^9, 
  3.692595118515523*^9}},ExpressionUUID->"de03e2b1-af0c-4ee6-aedc-\
1d5dbedae514"],

Cell[TextData[{
 "The following construction joins the point sf[u,v] of the surface with its \
orthonormal moving frame amf to the ",
 StyleBox[" adapted moving frame",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface."
}], "Text",
 CellChangeTimes->{{3.5995682124053154`*^9, 3.599568327117876*^9}, {
  3.6903588783590393`*^9, 
  3.690358904534911*^9}},ExpressionUUID->"e33c9d5c-3cd1-4fc3-9591-\
d35c4113d257"],

Cell["Here is the point:", "Text",
 CellChangeTimes->{{3.692631187487176*^9, 3.6926311897188263`*^9}, {
  3.692683233602495*^9, 
  3.6926832491707373`*^9}},ExpressionUUID->"a2f57f94-ca63-4797-806f-\
3a38618001c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fr", "[", "0", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Prepend", "[", 
   RowBox[{
    RowBox[{"sf", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", "1"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5860610379176807`*^9, 3.5860610410532866`*^9}, {
   3.586061137071455*^9, 3.5860612128251877`*^9}, {3.692630465614196*^9, 
   3.6926304963255253`*^9}, 3.692630538525861*^9, 3.692631292608345*^9, {
   3.696081723972372*^9, 3.696081740052397*^9}, {3.696172927114043*^9, 
   3.6961729333702374`*^9}},ExpressionUUID->"f3814e36-fdd2-49a7-b9bc-\
966c8ad36ca2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fr", "[", "0", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5860612266468124`*^9, 3.5860612409208374`*^9}, {
   3.692631220455703*^9, 3.692631271351253*^9}, 
   3.692631313847259*^9},ExpressionUUID->"d04be8bd-aafd-46ae-ae25-\
2ff836dc37b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fr", "[", "i_Integer", "]"}], "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "i", "]"}], "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "0"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"i", ">", "0"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"i", "\[LessEqual]", "3"}], ")"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586061255272863*^9, 3.5860614152199435`*^9}, 
   3.6148618493947215`*^9, 3.614917824961419*^9, 3.6149182629633884`*^9, {
   3.62279638766888*^9, 3.6227963919120874`*^9}, {3.692631406342917*^9, 
   3.692631415390092*^9}, {3.696172969058009*^9, 3.696172970033243*^9}, 
   3.696173050273346*^9},ExpressionUUID->"7e8c18cf-e699-494c-a2b4-\
7bc7de96246f"],

Cell[BoxData[
 RowBox[{"?", "fr"}]], "Input",
 CellChangeTimes->{{3.6150305135993085`*^9, 3.6150306235171013`*^9}, 
   3.6150306611755676`*^9, {3.615030842853463*^9, 3.6150309915679693`*^9}, 
   3.615031036574544*^9, {3.6150310837622423`*^9, 3.6150310923837357`*^9}, 
   3.615031205239191*^9, {3.622794881439434*^9, 3.622794884013439*^9}, {
   3.622795296946164*^9, 
   3.622795308958185*^9}},ExpressionUUID->"1b81bac7-6f07-4cf3-96b8-\
c1744fe102d5"],

Cell[BoxData[
 RowBox[{"Context", "[", "fr", "]"}]], "Input",
 CellChangeTimes->{{3.622795315572597*^9, 
  3.622795327381818*^9}},ExpressionUUID->"f33263d7-cd30-445b-bf91-\
ebaf4e42c666"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fr", "[", "3", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5860614258279624`*^9, 3.5860614510376062`*^9}, {
   3.617705834811267*^9, 3.617705859882701*^9}, {3.6227958443511257`*^9, 
   3.622795846394729*^9}, {3.692631507925536*^9, 3.692631521645362*^9}, 
   3.6961730900164747`*^9},ExpressionUUID->"50062220-221a-4520-8751-\
a56d2486307a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"frame", "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fr", "[", "j", "]"}], "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "3"}], "}"}]}], "]"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586059709294547*^9, 3.58605971650176*^9}, {
   3.5860602525343018`*^9, 3.5860604795147*^9}, {3.5860605311039906`*^9, 
   3.5860605475620193`*^9}, {3.5860605822876806`*^9, 3.586060606249323*^9}, {
   3.586060813090086*^9, 3.586060828939714*^9}, {3.586061476996052*^9, 
   3.586061557772994*^9}, {3.6148618494103217`*^9, 3.614861849425922*^9}, 
   3.6148635014844236`*^9, {3.6149178249770193`*^9, 
   3.6149178249926195`*^9}},ExpressionUUID->"bd05643f-9183-41ec-babb-\
f25987828308"],

Cell[BoxData[
 RowBox[{"?", "frame"}]], "Input",
 CellChangeTimes->{{3.6150311612106724`*^9, 3.6150311927404757`*^9}, {
   3.615031307772055*^9, 3.615031452198316*^9}, {3.6150316663265634`*^9, 
   3.6150318326870785`*^9}, 3.615031877439638*^9, {3.6227955599938264`*^9, 
   3.6227955710698457`*^9}},ExpressionUUID->"a93d0c55-e17f-47ab-859c-\
2df8383aedc8"],

Cell[BoxData[
 RowBox[{"Context", "[", "frame", "]"}]], "Input",
 CellChangeTimes->{{3.622795578807459*^9, 
  3.62279559044508*^9}},ExpressionUUID->"06548a82-be90-43b4-bce3-\
ac54a711512a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"frame", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.586060615328539*^9, 3.586060640460183*^9}, 
   3.6148618494415216`*^9, 3.6149178250082197`*^9, 3.6177059560121994`*^9, 
   3.6177060146115513`*^9, {3.6227962126989727`*^9, 
   3.6227962374874163`*^9}},ExpressionUUID->"4b3f8593-fcb8-4a70-85b0-\
1f733e9b54a6"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Det", "[", "%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.586061756330143*^9, 
  3.5860617723357706`*^9}},ExpressionUUID->"afcbb548-348f-4cc7-bade-\
832e4799b3b6"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"frame", "[", 
    RowBox[{"circularcone", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5860619918437567`*^9, 3.586062006351782*^9}, {
   3.5862321451928434`*^9, 3.586232152712056*^9}, 3.614861849457122*^9, 
   3.6149178250082197`*^9, {3.6149183005126543`*^9, 3.6149183068774652`*^9}, {
   3.614918369090375*^9, 
   3.6149183730995817`*^9}},ExpressionUUID->"8454d938-5a3c-4d06-bdab-\
4cedc261aec7"],

Cell[BoxData[
 RowBox[{"%", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.586062026491417*^9, 3.586062042746646*^9}, 
   3.586232171447689*^9},ExpressionUUID->"afef3cfa-914f-4957-932a-\
aa1605f34f28"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", "%", "]"}], ",", 
   RowBox[{"v", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586062079671911*^9, 3.586062115817174*^9}, {
  3.6960819964844217`*^9, 
  3.696082000385953*^9}},ExpressionUUID->"da3719c0-c308-4397-b8fd-\
19e833e2f46f"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.2.  First Fundamental Form. Inner Geometry", "Subsubsection",
 CellChangeTimes->{{3.5860653550319138`*^9, 3.586065364922331*^9}, {
   3.5872724489986615`*^9, 3.587272452765877*^9}, {3.5886612605950437`*^9, 
   3.588661268863058*^9}, 3.5886740069241586`*^9, {3.5902137324227285`*^9, 
   3.590213746431553*^9}, 3.6176250938625917`*^9, 3.617693466379898*^9, 
   3.6273084563692737`*^9, 3.627309886928396*^9, 3.68698806662964*^9, 
   3.6871818884961967`*^9, 3.687181922009631*^9, 3.696173314703136*^9, 
   3.696224599334243*^9},ExpressionUUID->"b76b761a-1280-4ac5-a383-\
7ed591d40012"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", "2"}], ";", 
  RowBox[{"spdim", " ", "=", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.6962196188163548`*^9, 
  3.696219659042901*^9}},ExpressionUUID->"0201dcb4-7ee3-4fb9-b529-\
f8369358e10b"],

Cell["Let a smooth curve in the parameter space be given:", "Text",
 CellChangeTimes->{{3.5860654539672875`*^9, 
  3.5860654965397625`*^9}},ExpressionUUID->"82ea5204-9524-4a64-8eef-\
525fcde7b165"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[Gamma]", "]"}], ";", " ", 
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5860655187074013`*^9, 3.586065549002654*^9}, {
   3.5860657022885237`*^9, 3.5860657414289923`*^9}, {3.5860658041255026`*^9, 
   3.5860658268391423`*^9}, 3.5890873523715672`*^9, 3.589088281233695*^9, {
   3.687176599609446*^9, 3.6871766104931726`*^9}, {3.693486818961433*^9, 
   3.693486828876281*^9}, 
   3.693487001313575*^9},ExpressionUUID->"45ca94d3-9cc5-4fdf-9770-\
74118431c9b3"],

Cell["The corresponding curve  on the surface is", "Text",
 CellChangeTimes->{{3.586066192568585*^9, 3.586066201913001*^9}, {
  3.589006059047471*^9, 
  3.5890060703111153`*^9}},ExpressionUUID->"2c77312b-877c-43c6-9fc6-\
2cb4dfa1f580"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sf\[Gamma]", "[", "t_", "]"}], " ", ":=", 
  RowBox[{"sf", "[", 
   RowBox[{
    RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
    RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.58606588789765*^9, 3.586065894434061*^9}, {
   3.586066107280835*^9, 3.5860661590597258`*^9}, {3.5860670057980137`*^9, 
   3.586067018200035*^9}, {3.589087429064954*^9, 3.589087468249195*^9}, {
   3.617625177320366*^9, 3.6176251841517563`*^9}, {3.693486878591151*^9, 
   3.6934868785966*^9}, 
   3.696082154854063*^9},ExpressionUUID->"cf13afab-7d91-4b2a-81bd-\
61ef29c7563f"],

Cell["Here is its tangent vector of the curve:", "Text",
 CellChangeTimes->{{3.5860662109454174`*^9, 3.586066227918247*^9}, 
   3.687153172258504*^9, {3.687153651207342*^9, 
   3.687153659342918*^9}},ExpressionUUID->"8e3bc724-282e-4d1c-9e4a-\
9546a5ce88cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sf\[Gamma]", "'"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.687152730239546*^9, 3.687152750262936*^9}, 
   3.687152789387711*^9, {3.687152840067884*^9, 3.687152845286014*^9}, 
   3.693486878613226*^9},ExpressionUUID->"b6a7b5be-f65e-4f39-80d6-\
638fb6e0ec0d"],

Cell["By the chain rule this equals ", "Text",
 CellChangeTimes->{{3.6869888778218107`*^9, 3.6869888935574408`*^9}, 
   3.6871532995218153`*^9},ExpressionUUID->"a79592de-d389-4759-bb67-\
03c012e3fc48"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sf\[Gamma]", "'"}], "[", "t", "]"}], "==", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{
     RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}], ".", 
   RowBox[{
    RowBox[{"d", "[", "\[Gamma]", "]"}], "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5860662523010902`*^9, 3.586066287057951*^9}, 
   3.5890874822809973`*^9, {3.686988322333063*^9, 3.686988328795423*^9}, {
   3.686988359019589*^9, 3.686988388003014*^9}, {3.686988502498396*^9, 
   3.686988541481502*^9}, 3.686988591858343*^9, {3.687152951005146*^9, 
   3.6871529543885736`*^9}, 3.687153218497163*^9, {3.693486878701687*^9, 
   3.693486878707261*^9}},ExpressionUUID->"092571b5-c2f0-4983-9039-\
2db12188b1bd"],

Cell["or", "Text",
 CellChangeTimes->{{3.687153328191731*^9, 
  3.687153338787924*^9}},ExpressionUUID->"07119f27-fff5-4f11-b9ca-\
c35f18485b92"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sf\[Gamma]", "'"}], "[", "t", "]"}], "==", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{
     RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}], ".", 
   RowBox[{
    RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5860662523010902`*^9, 3.586066287057951*^9}, 
   3.5890874822809973`*^9, {3.686988322333063*^9, 3.686988328795423*^9}, {
   3.686988359019589*^9, 3.686988388003014*^9}, {3.686988502498396*^9, 
   3.686988541481502*^9}, 3.686988591858343*^9, {3.687152951005146*^9, 
   3.6871529543885736`*^9}, 3.687153218497163*^9, {3.6871533462996607`*^9, 
   3.6871533701300707`*^9}, {3.693486878719036*^9, 
   3.693486878725355*^9}},ExpressionUUID->"3c958c1a-4c7a-4d15-bc28-\
8617f23448cc"],

Cell[TextData[{
 StyleBox["The tangent vector ",
  FontSlant->"Italic"],
 "sf\[Gamma]\[CloseCurlyQuote][t] ",
 StyleBox[" of the curve",
  FontSlant->"Italic"],
 " sf\[Gamma][t] ",
 StyleBox["on the surface ",
  FontSlant->"Italic"],
 "sf ",
 StyleBox["is the image of the tangent vector \[Gamma]",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote][t] ",
 StyleBox["of the parameter curve  \[Gamma]",
  FontSlant->"Italic"],
 "[t] \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]],
  FontSlant->"Plain",ExpressionUUID->"6b6bafd3-f394-4c62-8e59-6ebabf0012bf"],
 StyleBox[" under the linear map ",
  FontSlant->"Italic"],
 "d[sf][\[Gamma]1[t],\[Gamma]2[t]]."
}], "Text",
 CellChangeTimes->{{3.687153706762546*^9, 3.687153750510541*^9}, {
  3.687153802038887*^9, 3.687153962653026*^9}, {3.687153993110272*^9, 
  3.6871541039319677`*^9}, {3.687154138790085*^9, 3.687154143179824*^9}, {
  3.693486878738029*^9, 
  3.693486878956539*^9}},ExpressionUUID->"91250002-2ffb-40fa-b157-\
57d8bef13b6b"],

Cell["\<\
Its representation as a linear combination of the tangent basis vectors is\
\>", "Text",
 CellChangeTimes->{{3.686988918493421*^9, 3.686989004580632*^9}, {
  3.6871544452253532`*^9, 
  3.687154472785116*^9}},ExpressionUUID->"58443493-e153-4b1a-b3e9-\
1ef526ec513b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sf\[Gamma]", "'"}], "[", "t", "]"}], "==", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}], "*", 
     RowBox[{
      SuperscriptBox["\[Gamma]1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
       RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}], "*", 
     RowBox[{
      SuperscriptBox["\[Gamma]2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5860663716724997`*^9, 3.586066533226383*^9}, {
   3.5860665822728696`*^9, 3.586066582912471*^9}, {3.586066701659879*^9, 
   3.5860667132038994`*^9}, {3.58606687879819*^9, 3.5860669453011074`*^9}, {
   3.589087499328973*^9, 3.589087507184422*^9}, 3.589087578555504*^9, 
   3.589087612347437*^9, {3.614163211576773*^9, 3.614163233042411*^9}, 
   3.6141642723006363`*^9, 3.6176000240258875`*^9, 3.617600085739596*^9, {
   3.6869882953390007`*^9, 3.6869882955965023`*^9}, 3.6869886848781977`*^9, 
   3.687152979141797*^9, 3.6871544895682898`*^9, {3.693486878971025*^9, 
   3.693486878986022*^9}},ExpressionUUID->"46c36673-1706-461a-93f1-\
70dcbd9ab116"],

Cell["or", "Text",
 CellChangeTimes->{{3.6871545168723097`*^9, 
  3.687154517480281*^9}},ExpressionUUID->"33ff7074-c65f-47ef-aa65-\
d0bf45e18b5a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sf\[Gamma]", "'"}], "[", "t", "]"}], "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"tangsp", "[", "sf", "]"}], "[", 
    RowBox[{
     RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
     RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}], "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]1", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], ",", 
    RowBox[{
     SuperscriptBox["\[Gamma]2", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5860679659785004`*^9, 3.5860680404842315`*^9}, 
   3.5890875161849365`*^9, 3.5890875882410583`*^9, 3.5890876187208014`*^9, 
   3.6227808564211283`*^9, 3.687153030116816*^9, 3.6871545296072807`*^9, {
   3.693486878997271*^9, 3.693486879004904*^9}, 3.693579311583015*^9, 
   3.693579348775467*^9},ExpressionUUID->"ca2a3088-140e-49a2-85ae-\
4b79201896a9"],

Cell[BoxData[
 RowBox[{"?", "tangsp"}]], "Input",
 CellChangeTimes->{{3.627308563288262*^9, 
  3.6273085679838705`*^9}},ExpressionUUID->"876cb72f-5209-492d-b4d5-\
949df960bcca"],

Cell["\<\
The metric properties: the arc length of the curve, intersection angles, the \
area  etc. are defined by the scalar products of  tangent vectors at the \
variable point {u,v} of the surface, e.g.\
\>", "Text",
 CellChangeTimes->{{3.586068142992011*^9, 3.586068177561672*^9}, {
   3.5860682279341607`*^9, 3.586068343514764*^9}, 3.586151985007841*^9, 
   3.5995528399297333`*^9, 3.61416242396259*^9, {3.614949815192522*^9, 
   3.6149498664854116`*^9}, 3.61762524523025*^9, {3.687152668974971*^9, 
   3.687152673047009*^9}, 3.6871531473714733`*^9, {3.6871545830961*^9, 
   3.687154589352193*^9}, {3.68715465989574*^9, 
   3.687154663815583*^9}},ExpressionUUID->"50bf57ca-3035-45d5-91d3-\
9eeb9bf08f4a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"s", "[", "t_", "]"}], ":=", 
  RowBox[{
   RowBox[{"arclength", "[", "sf\[Gamma]", "]"}], "[", "t", "]"}], 
  StyleBox[" ",
   FontSlant->"Italic"]}]], "Input",
 CellChangeTimes->{{3.6871546714077272`*^9, 3.687154680886219*^9}, {
   3.6871547157456207`*^9, 3.687154724415225*^9}, {3.687154763515485*^9, 
   3.6871548322791758`*^9}, {3.687154934492044*^9, 3.687154936774392*^9}, {
   3.687175357899935*^9, 3.687175372007761*^9}, {3.687175411229026*^9, 
   3.6871754265372972`*^9}, 
   3.693486879014379*^9},ExpressionUUID->"aa396baa-fbef-40a5-9191-\
7bd3e2fd10ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"s", "[", "t", "]"}], 
  StyleBox["\[Equal]",
   FontSlant->"Italic"], " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"norm", "[", 
     RowBox[{
      RowBox[{"sf\[Gamma]", "'"}], "[", "t", "]"}], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox["]",
      FontSlant->"Italic"]}], 
    StyleBox[",",
     FontSlant->"Italic"], 
    StyleBox["t",
     FontSlant->"Italic"]}], 
   StyleBox["]",
    FontSlant->"Italic"]}]}]], "Input",
 CellChangeTimes->{{3.6871754411915293`*^9, 3.687175449198433*^9}, 
   3.693486879025519*^9},ExpressionUUID->"5faf315f-38a6-4c40-9e7e-\
860b54315821"],

Cell["\<\
Any tangent vector with standard coordinates x,y at the point sf[u,v],\
\>", "Text",
 CellChangeTimes->{{3.687155198707108*^9, 
  3.687155295946041*^9}},ExpressionUUID->"e1911cb5-8c14-4d6e-9c27-\
d81967eed684"],

Cell[BoxData[
 RowBox[{"vxy", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", "x"}], " ", "+", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", "y"}]}]}]], "Input",
 CellChangeTimes->{{3.687155309311401*^9, 3.6871553926828337`*^9}, {
  3.6871554307369432`*^9, 3.687155431578148*^9}, {3.6871569325360928`*^9, 
  3.687156935245682*^9}},ExpressionUUID->"7ce095b5-d94d-4bc6-acf6-\
f7c837b71ae9"],

Cell["\<\
can be represented as a tangent vector of a curve  through the point, e.g.\
\>", "Text",
 CellChangeTimes->{{3.687155461485694*^9, 3.687155575328165*^9}, {
  3.687155635695881*^9, 
  3.6871556513193913`*^9}},ExpressionUUID->"6ddfe3e4-d995-41f6-9bcd-\
b81d6afdbf53"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{
        RowBox[{"u", "+", 
         RowBox[{"t", "*", "x"}]}], ",", " ", 
        RowBox[{"v", "+", 
         RowBox[{"t", "*", "y"}]}]}], "]"}], ",", "t"}], "]"}], "/.", 
    RowBox[{"t", "\[Rule]", "0"}]}], " ", "]"}], "\[Equal]", " ", 
  "vxy"}]], "Input",
 CellChangeTimes->{{3.6871556698597603`*^9, 3.687155722623555*^9}, {
  3.687155757927064*^9, 3.687155810726795*^9}, {3.687156179307616*^9, 
  3.687156202435305*^9}, {3.6871562430110617`*^9, 3.6871563003604593`*^9}, {
  3.687156601820294*^9, 3.6871566129042797`*^9}, {3.6871567652731247`*^9, 
  3.687156770350627*^9}, {3.6871569637226686`*^9, 
  3.687157002437088*^9}},ExpressionUUID->"009efc67-9322-4104-a73f-\
31c8e3357618"],

Cell[TextData[{
 "Therefore we will first study the scalar products on the tangent planes \
obtained as the restriction of the Euclidean scalar product Dot of the space \
to these planes; this field of scalar products is named the ",
 ButtonBox["first fundamental form",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/FirstFundamentalForm.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/FirstFundamentalForm.html"],
 StyleBox[" of the surface",
  FontColor->RGBColor[0, 0, 1]],
 ", calculated by the function"
}], "Text",
 CellChangeTimes->{{3.687157177042428*^9, 3.687157269913898*^9}, {
  3.6871573872009068`*^9, 3.6871574730482492`*^9}, {3.687157570447486*^9, 
  3.687157587231271*^9}, {3.6871586259433937`*^9, 3.687158768797303*^9}, {
  3.6871589976055593`*^9, 
  3.687158997608374*^9}},ExpressionUUID->"74377d56-b14c-4af1-91a3-\
abafc635b03a"],

Cell[BoxData[
 RowBox[{"?", "fund1"}]], "Input",
 CellChangeTimes->{{3.6871582847571898`*^9, 
  3.687158286866828*^9}},ExpressionUUID->"6b0f5dbe-56b5-45de-8deb-\
cd099ce6ad22"],

Cell["defined by", "Text",
 CellChangeTimes->{{3.687162969989112*^9, 
  3.687162974180972*^9}},ExpressionUUID->"ef51e68c-ef59-4eec-9305-\
456e6e266d2e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox["fund1",
      TraditionalForm], "[", "f_", "]"}], "[", "u__", "]"}], "[", 
   RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "x", "]"}], " ", "\[Equal]", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"{", "u", "}"}], "]"}]}], "&&", 
     RowBox[{
      RowBox[{"Length", "[", "y", "]"}], " ", "\[Equal]", "  ", 
      RowBox[{"Length", "[", 
       RowBox[{"{", "u", "}"}], "]"}]}]}], ",", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "f", "]"}], "[", "u", "]"}], 
       "*", 
       RowBox[{"x", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "*", 
       RowBox[{"y", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "u", "}"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "u", "}"}], "]"}]}], "}"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", "\"\<Wrong arguments!\>\"", "]"}], ";", 
     RowBox[{"Return", "[", "]"}]}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5861529045544357`*^9, 3.5861530716929955`*^9}, 
   3.5861532850852013`*^9, {3.5861533247654705`*^9, 3.586153326756584*^9}, 
   3.586153440461088*^9, 3.5861536097777724`*^9, {3.5890012608770313`*^9, 
   3.5890012796371045`*^9}, 3.590495710406209*^9, 3.6176259155025873`*^9, {
   3.618028607001949*^9, 3.6180286476868205`*^9}, 3.6180288206443243`*^9, {
   3.618029334727627*^9, 3.6180293682988863`*^9}, {3.618029401433344*^9, 
   3.6180294186401744`*^9}, 3.6180295739228473`*^9, {3.6180296220645313`*^9, 
   3.6180296248413363`*^9}, {3.618029689940251*^9, 3.618029832680502*^9}, {
   3.618030383548669*^9, 3.6180303996322975`*^9}, {3.6180311010875297`*^9, 
   3.61803112412877*^9}, {3.6180313060562897`*^9, 3.618031380031619*^9}, {
   3.618031423196895*^9, 3.6180314644277678`*^9}, {3.618031496064623*^9, 
   3.61803157401796*^9}},ExpressionUUID->"1291b375-a591-4b65-8b87-\
b89a9d3c8ad3"],

Cell[BoxData[
 RowBox[{"Context", "[", "fund1", "]"}]], "Input",
 CellChangeTimes->{{3.68699091011992*^9, 
  3.686990975757555*^9}},ExpressionUUID->"7ab71b9b-a5fc-4e48-8001-\
9fb673b97a68"],

Cell["\<\
The definition of rgT is given in the proof of the next proposition. The \
bilinear form fund1 is induced by the Euclidean scalar product:\
\>", "Text",
 CellChangeTimes->{{3.687163060220366*^9, 3.6871631906115637`*^9}, {
  3.6934834196075287`*^9, 
  3.693483422894981*^9}},ExpressionUUID->"35412170-d5b0-4da6-962a-\
7cd0f97d085f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x1", ",", "x2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", "y2"}], "}"}]}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tangsp", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{"x1", ",", "x2"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"tangsp", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{"y1", ",", "y2"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5860683560727854`*^9, 3.5860684322165194`*^9}, {
   3.5860685573443394`*^9, 3.5860685599183435`*^9}, 3.5886615418167377`*^9, {
   3.589001060562574*^9, 3.5890010784986*^9}, 3.599565556008378*^9, 
   3.599565651376833*^9, 3.6149498906498547`*^9, {3.617683238320698*^9, 
   3.61768324505991*^9}, {3.6227808658279448`*^9, 3.622780867075947*^9}, 
   3.687154633073059*^9, 3.687158066000938*^9, {3.6871581451635723`*^9, 
   3.687158235338622*^9}, {3.687158496518427*^9, 3.687158503225524*^9}},
 CellTags->"fund1",ExpressionUUID->"6d0b18c6-1dcc-4a02-84e4-34ce8c69bcd7"],

Cell["The properties of the Euclidean scalar product imply", "Text",
 CellChangeTimes->{{3.687157817661111*^9, 3.68715784715711*^9}, 
   3.687158121267125*^9},ExpressionUUID->"5af2a714-0073-4dcd-8d26-\
e6ad0cf5a4fa"],

Cell[TextData[{
 StyleBox["Proposition 1",
  FontColor->RGBColor[0, 0, 1]],
 ". For any regular point of the surface the first  fundamental form  is a \
symmetric positive definite bilinear form whose coefficient matrix is the \
matrix of the scalar products of the standard tangent basis vectors depending \
on the points {u,v}. In general, they are neither normed nor orthogonal."
}], "Text",
 CellChangeTimes->{{3.617684210639206*^9, 3.617684599111088*^9}, {
   3.686989357506459*^9, 3.686989396801725*^9}, 3.6871576448629932`*^9, {
   3.6871576900709057`*^9, 3.6871576985904408`*^9}, {3.687157790293861*^9, 
   3.687157798229843*^9}, {3.687157882565*^9, 3.687157915492981*^9}, 
   3.687157976348723*^9, {3.6871590594205437`*^9, 3.687159076428146*^9}, {
   3.687159581232711*^9, 
   3.6871595855919113`*^9}},ExpressionUUID->"b36f9b4c-a357-4e74-b545-\
83e9e7d3a4aa"],

Cell[TextData[{
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " The coefficients of the first fundamental form are functions of the \
parameters u,v:"
}], "Text",
 CellChangeTimes->{{3.687159550179737*^9, 3.6871595612980947`*^9}, {
  3.687159612263362*^9, 
  3.687159681734707*^9}},ExpressionUUID->"e033a15f-0e3e-49d6-be66-\
15f883a9e55a"],

Cell[BoxData[
 RowBox[{"?", "rgT"}]], "Input",
 CellChangeTimes->{{3.6176846574395905`*^9, 3.6176847979646373`*^9}, {
   3.617684835311103*^9, 3.6176851458296485`*^9}, {3.61768518668612*^9, 
   3.6176852141889687`*^9}, 3.617685283999091*^9, {3.622721531670311*^9, 
   3.6227215418883286`*^9}, 3.693484112428256*^9, {3.6934841658003693`*^9, 
   3.693484168274267*^9}},ExpressionUUID->"5fceb009-99be-4791-999a-\
0f0437b70df3"],

Cell[BoxData[
 RowBox[{"Context", "[", "rgT", "]"}]], "Input",
 CellChangeTimes->{{3.693483670638887*^9, 
  3.69348368306209*^9}},ExpressionUUID->"895a5121-b708-44a4-b635-\
2bc6e5a9d51c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"i_", ",", "j_"}], "]"}], "[", "f_", "]"}], "[", "u__", "]"}], 
   " ", ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"IntegerQ", "[", "i", "]"}], "&&", 
        RowBox[{"i", ">", "0"}], "&&", 
        RowBox[{"i", "\[LessEqual]", 
         RowBox[{"Length", "[", 
          RowBox[{"{", "u", "}"}], "]"}]}]}], ")"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"IntegerQ", "[", "j", "]"}], "&&", 
        RowBox[{"j", ">", "0"}], "&&", 
        RowBox[{"j", "\[LessEqual]", 
         RowBox[{"Length", "[", 
          RowBox[{"{", "u", "}"}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], "\[Equal]", " ", "List"}], "&&",
         " ", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], ">", "1"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"tv", "[", "i", "]"}], "[", "f", "]"}], "[", "u", "]"}], 
        ".", 
        RowBox[{
         RowBox[{
          RowBox[{"tv", "[", "j", "]"}], "[", "f", "]"}], "[", "u", "]"}]}]}],
       "]"}], ",", " ", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Wrong {i,j} = \>\"", ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], "]"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586068574332769*^9, 3.5860686078104277`*^9}, {
   3.5860686390572824`*^9, 3.5860687084618044`*^9}, 3.6149501405622935`*^9, 
   3.6149504057159595`*^9, {3.6176000240414877`*^9, 3.6176000240414877`*^9}, 
   3.617625895736457*^9, {3.617683366818124*^9, 3.617683440606253*^9}, {
   3.617692768223966*^9, 3.6176927691900215`*^9}, {3.618028941934537*^9, 
   3.618028984023411*^9}, {3.6180299968551903`*^9, 3.6180300191164293`*^9}, {
   3.61803007644653*^9, 3.6180301031225767`*^9}, 3.6227214881774344`*^9},
 CellTags->"rgT",ExpressionUUID->"a2d8ecd2-fd87-4a23-ac18-e316cb4b914f"],

Cell["For the general surface sf[u,v] we have", "Text",
 CellChangeTimes->{{3.686989590599444*^9, 
  3.686989644263212*^9}},ExpressionUUID->"c853c20c-5897-4edf-9d22-\
228a14258d81"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.6176835523960495`*^9},ExpressionUUID->"6f70ffe7-8edb-4044-86ad-\
10be4270b455"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.6176835523960495`*^9, {3.617684097336207*^9, 
   3.617684111657032*^9}},ExpressionUUID->"590f0c99-0132-4069-b2eb-\
b74193dec64f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{
  3.6176835523960495`*^9, {3.617684097336207*^9, 3.617684111657032*^9}, {
   3.6869904192665997`*^9, 
   3.686990425785736*^9}},ExpressionUUID->"8b352578-7755-49d0-a074-\
8dc47c217e3b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.586068574332769*^9, 3.5860686078104277`*^9}, {
   3.5860686390572824`*^9, 3.5860687337962494`*^9}, 3.6149501434326982`*^9, 
   3.6149504087735643`*^9, 3.6176000240414877`*^9, 3.617600085739596*^9, 
   3.617625897056532*^9, {3.617683457079882*^9, 3.6176834844579306`*^9}, 
   3.6176840514253263`*^9},ExpressionUUID->"7b225e6b-5bd5-494e-a460-\
563a0f13cfe8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "[", "f", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.586068574332769*^9, 3.5860686078104277`*^9}, {
   3.5860686390572824`*^9, 3.5860687337962494`*^9}, 3.6149501434326982`*^9, 
   3.6149504087735643`*^9, 3.6176000240414877`*^9, 3.617600085739596*^9, 
   3.617625897056532*^9, {3.617683457079882*^9, 3.6176834844579306`*^9}, 
   3.6176840514253263`*^9, {3.6273091347082696`*^9, 3.6273091545057044`*^9}, 
   3.686990260997732*^9, {3.686990297487562*^9, 3.6869902988188543`*^9}, 
   3.686990331872575*^9, {3.686990398695031*^9, 
   3.686990400657876*^9}},ExpressionUUID->"071003f6-42f2-4c58-a475-\
2cc0187f69bc"],

Cell["\<\
The symmetry follows from the symmetry of the Euclidean scalar product:\
\>", "Text",
 CellChangeTimes->{{3.686990618519651*^9, 
  3.686990678543309*^9}},ExpressionUUID->"fc0fdbe2-7ffb-4624-8852-\
64ee2b99e6cf"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5886613827276583`*^9, 3.5886614689802094`*^9}, {
  3.588661500523465*^9, 3.588661516326293*^9}, {3.61762590209282*^9, 
  3.6176259031958833`*^9}},ExpressionUUID->"25fb8b27-77de-46a4-867b-\
3853abc01936"],

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x1", ",", "x2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", "y2"}], "}"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", "x1", "*", "y1"}], " ", "+", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x1", "*", "y2"}], " ", "+", 
       RowBox[{"x2", "*", "y1"}]}], ")"}]}], " ", "+", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", "x2", "*", "y2"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5860688561316643`*^9, 3.5860690418811903`*^9}, {
  3.5860690841260643`*^9, 3.586069106621304*^9}, {3.5890011430442915`*^9, 
  3.5890011879328594`*^9}, {3.617625905967042*^9, 3.617625909573248*^9}, {
  3.687159354212344*^9, 
  3.687159359954605*^9}},ExpressionUUID->"0f02c906-264e-4146-ae04-\
290762505a00"],

Cell["\<\
That the scalar square is non-negative isn\[CloseCurlyQuote]t confirmed by \
Mathematica:\
\>", "Text",
 CellChangeTimes->{{3.687161990956203*^9, 
  3.687162060715868*^9}},ExpressionUUID->"0c2487d5-5e47-45f8-9b9c-\
db0a4c10e9db"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{
      RowBox[{"x", "|", "y", "|", 
       RowBox[{
        RowBox[{"f", "[", "1", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "|", 
       RowBox[{
        RowBox[{"f", "[", "2", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "|", 
       RowBox[{
        RowBox[{"f", "[", "3", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ",", "Reals"}], "]"}], "&&", 
    RowBox[{"(", 
     RowBox[{"x", ">", "0"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Det", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"rgT", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ">", "0"}], ")"}]}],
    ",", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tangsp", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"x", ",", "y"}], "]"}], ".", 
      RowBox[{
       RowBox[{
        RowBox[{"tangsp", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.687161035533032*^9, 3.687161101476042*^9}, {
   3.687161140364435*^9, 3.6871612331796827`*^9}, {3.687161338031764*^9, 
   3.687161366362537*^9}, {3.687161499529595*^9, 3.687161521082965*^9}, {
   3.68716158216199*^9, 3.687161640215788*^9}, 3.687161677145582*^9, {
   3.687161757756835*^9, 3.6871617699836187`*^9}, {3.687161868387856*^9, 
   3.687161902406981*^9}, {3.6962202206142893`*^9, 3.696220262109315*^9}, 
   3.696220294169346*^9, {3.696220361374035*^9, 3.696220390388345*^9}, {
   3.69622043104487*^9, 3.696220546793518*^9}, {3.69622058832168*^9, 
   3.696220638288903*^9}},ExpressionUUID->"c0cc65e1-ce30-4e63-8113-\
9ba63ed9a159"],

Cell["\<\
Obviously, this is true as a sum of three real squares. The definiteness at \
regular points is confirmed immediately:\
\>", "Text",
 CellChangeTimes->{{3.687162075822625*^9, 
  3.6871621826887207`*^9}},ExpressionUUID->"16b10e2d-bc4c-4598-8c64-\
c02dfea816e7"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"MatrixRank", "[", 
     RowBox[{
      RowBox[{"d", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", "2"}], ",", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], ",", "Reals"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.687160215001017*^9, 3.68716023733356*^9}, {
  3.687160273930642*^9, 3.687160514405118*^9}, {3.6871606012292957`*^9, 
  3.687160606681178*^9}, {3.687160658501683*^9, 3.6871606636245337`*^9}, {
  3.687160729104368*^9, 3.68716074339121*^9}, {3.6871608046549377`*^9, 
  3.687160891326516*^9}},ExpressionUUID->"98b683a1-dfff-472b-a793-\
d738952e8ec8"],

Cell["\<\
Of course, these properties don\[CloseCurlyQuote]t need a proof since the \
restriction of a positively definite, symmetric scalar product of an \
Euclidean vector space to a subspace has these properties. The calculations \
show some possibilities to use Mathematica to symbolic calculations. \
\[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.693484600782158*^9, 3.693484742045014*^9}, {
  3.693484780036891*^9, 3.693484844620206*^9}, {3.693484907507885*^9, 
  3.693484959091405*^9}, {3.6934853823037653`*^9, 3.69348545367128*^9}, {
  3.693485507695321*^9, 
  3.693485529890764*^9}},ExpressionUUID->"e9283cac-f694-4ecd-b97b-\
6e94f35a8903"],

Cell[TextData[{
 "The",
 StyleBox[" first",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 StyleBox["fundamental form ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox["fund1", TraditionalForm]],
  CellChangeTimes->{{3.5861529045544357`*^9, 3.5861530716929955`*^9}, 
    3.5861532850852013`*^9, {3.5861533247654705`*^9, 3.586153326756584*^9}, 
    3.586153440461088*^9, 3.5861536097777724`*^9},ExpressionUUID->
  "43380e60-b8e9-485b-bb94-112d4788fdff"],
 " defines the",
 StyleBox[" inner geometry",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface: a geometric property of the surface belongs to the inner \
geometry if it may be expressed by the first form only, not using its \
embedding into the space. "
}], "Text",
 CellChangeTimes->{{3.586152357579151*^9, 3.586152604679284*^9}, {
   3.5861526839358172`*^9, 3.5861527425681705`*^9}, {3.586152808759957*^9, 
   3.5861528462721024`*^9}, 3.5861533692320137`*^9, {3.586153400847822*^9, 
   3.586153548808285*^9}, 3.58615358683146*^9, {3.5861541794643564`*^9, 
   3.586154180671426*^9}, {3.586154312279953*^9, 3.5861543492690687`*^9}, {
   3.5885676557649*^9, 3.5885677678883133`*^9}, {3.5885680164035273`*^9, 
   3.5885680453391824`*^9}, {3.588661586308016*^9, 3.588661586822817*^9}, {
   3.588661624746483*^9, 3.5886616346525006`*^9}, {3.5886618514772816`*^9, 
   3.588661868418911*^9}, 3.589191183132166*^9, {3.5904957103906093`*^9, 
   3.590495710406209*^9}, 3.5995529202423267`*^9, 3.614950556365424*^9, 
   3.6176259128434353`*^9, 3.6176854156633224`*^9, {3.6176854904342537`*^9, 
   3.6176854977662663`*^9}, {3.687162290643009*^9, 3.687162307331168*^9}, {
   3.687162341835083*^9, 3.6871623567546167`*^9}, 3.687162554457034*^9, {
   3.687162606024452*^9, 3.687162787735655*^9}, 3.6871628206785917`*^9, 
   3.687163236572022*^9, {3.687163276027032*^9, 3.687163296338965*^9}},
 CellTags->"g(i",ExpressionUUID->"15b49bd8-af68-42dc-94ff-bbe33ba5bc59"],

Cell[TextData[{
 "The classical notation is ",
 Cell[BoxData[
  FormBox["fund1", TraditionalForm]],ExpressionUUID->
  "c40ba566-5a9e-4871-8d50-1d3d36e641b3"],
 " = ",
 Cell[BoxData[
  SuperscriptBox["ds", "2"]],ExpressionUUID->
  "75aaa90f-5fea-46e9-b5da-d23d3bfbea98"],
 " can\[CloseCurlyQuote]t be reproduced in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " formulas, since such an expression  is always interpreted as a power. The \
cause of this notation: for the curve in the parameter plane"
}], "Text",
 CellChangeTimes->{{3.586152357579151*^9, 3.586152604679284*^9}, {
   3.5861526839358172`*^9, 3.5861527425681705`*^9}, {3.586152808759957*^9, 
   3.5861528462721024`*^9}, 3.5861533692320137`*^9, {3.586153400847822*^9, 
   3.586153548808285*^9}, 3.58615358683146*^9, {3.5861541794643564`*^9, 
   3.586154180671426*^9}, {3.586154312279953*^9, 3.5861543492690687`*^9}, {
   3.5885676557649*^9, 3.5885677678883133`*^9}, {3.5885680164035273`*^9, 
   3.5885680453391824`*^9}, {3.588661586308016*^9, 3.588661586822817*^9}, {
   3.588661624746483*^9, 3.5886616346525006`*^9}, {3.5886618514772816`*^9, 
   3.588661868418911*^9}, 3.589191183132166*^9, {3.5904957103906093`*^9, 
   3.590495710406209*^9}, 3.5995529202423267`*^9, 3.614950556365424*^9, 
   3.6176259128434353`*^9, 3.6176854156633224`*^9, {3.6176854904342537`*^9, 
   3.6176854977662663`*^9}, {3.687162290643009*^9, 3.687162307331168*^9}, {
   3.687162341835083*^9, 3.6871623567546167`*^9}, 3.687162554457034*^9, {
   3.687162606024452*^9, 3.687162787735655*^9}, 3.6871628285663347`*^9, 
   3.6871752469359694`*^9, {3.687177823595038*^9, 3.68717787876226*^9}, {
   3.6934856098464947`*^9, 3.693485614661923*^9}, {3.6962241052028646`*^9, 
   3.696224117770523*^9}},
 CellTags->"g(i",ExpressionUUID->"7d57fac0-f7a8-4248-b16e-a41a8aca77a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
    RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{
  3.6871765293502893`*^9, {3.687176638945053*^9, 3.687176641453456*^9}, {
   3.6871767896795473`*^9, 3.6871768298276*^9}, {3.693486879028726*^9, 
   3.693486879030472*^9}},ExpressionUUID->"6448d268-ab37-4667-ae04-\
455886e0e87d"],

Cell["\<\
 the arc length parameter s[t] of the corresponding curve on the surface has \
been defined at the beginning of this subsection; it suffices\
\>", "Text",
 CellChangeTimes->{{3.6871779097538548`*^9, 3.687177969033412*^9}, {
  3.687178168311659*^9, 
  3.6871782097595367`*^9}},ExpressionUUID->"b5350403-91f7-469f-b69d-\
e5242f113e1d"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"s", "[", "t", "]"}], " ", "==", " ", 
   RowBox[{
    RowBox[{"arclength", "[", "sf\[Gamma]", "]"}], "[", "t", "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.687177990393332*^9, 3.687178026233788*^9}, {
   3.687178075529932*^9, 3.687178131624297*^9}, {3.6934857598563213`*^9, 
   3.693485775196836*^9}, 
   3.693486879036458*^9},ExpressionUUID->"d0b8b223-663b-4185-8dbf-\
66069efbbf51"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "s", "]"}], "[", "t", "]"}], "\[Equal]", 
  RowBox[{"norm", "[", 
   RowBox[{
    RowBox[{"sf\[Gamma]", "'"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.687175486159669*^9, 3.6871755603813753`*^9}, 
   3.687176910510364*^9, {3.687176953626582*^9, 3.687176962522277*^9}, {
   3.687177031830062*^9, 3.687177104172017*^9}, {3.687177745628291*^9, 
   3.687177749780198*^9}, 
   3.6934868790443907`*^9},ExpressionUUID->"0eb1bba5-a302-4690-b03d-\
f07f39ee7fec"],

Cell["and it follows", "Text",
 CellChangeTimes->{{3.687178254807117*^9, 
  3.687178260870738*^9}},ExpressionUUID->"790cf409-4b01-4975-b17e-\
fd8a4ab274e4"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "s", "]"}], "[", "t", "]"}], "^", "2"}], " ", 
   "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
      RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.687175606181246*^9, 3.687175656572839*^9}, {
   3.687175692028418*^9, 3.687175784467548*^9}, 3.687176477219262*^9, {
   3.6871768661474743`*^9, 3.687176879603505*^9}, 3.68717827303378*^9, {
   3.693486007907962*^9, 3.693486010250008*^9}, {3.693486879051407*^9, 
   3.693486879053792*^9}},ExpressionUUID->"14a76b67-5663-4b9b-99f4-\
7ee2b3a55306"],

Cell[TextData[{
 "This explains the traditional, a bit sloppy notation ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["ds", "2"], TraditionalForm]],ExpressionUUID->
  "11ed2e59-45aa-4aea-a8ec-226c5581923a"],
 " of the first fundamental form."
}], "Text",
 CellChangeTimes->{{3.687178299326529*^9, 
  3.687178397846015*^9}},ExpressionUUID->"d4936a14-5ec0-4519-b2e6-\
d8a21bfbf43b"],

Cell[TextData[{
 StyleBox["Example.3 .",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["The spheres",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.5861531338965535`*^9, 3.586153139327864*^9}, {
   3.5886616891901965`*^9, 3.5886617024658194`*^9}, 3.686991084212322*^9, {
   3.686991497921322*^9, 
   3.686991535120764*^9}},ExpressionUUID->"47c2b9cb-76ec-48a8-8340-\
eb25639e0d8a"],

Cell[BoxData[
 RowBox[{"?", "sphero"}]], "Input",
 CellChangeTimes->{{3.6273093145643864`*^9, 
  3.627309318869994*^9}},ExpressionUUID->"c11a4fe0-2d30-4a87-a692-\
e2b842d0e55d"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox["fund1",
      TraditionalForm], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x1", ",", "x2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y1", ",", "y2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5861531444481573`*^9, 3.5861532434508195`*^9}, {
   3.586153274283583*^9, 3.5861532782268085`*^9}, {3.5861536173652067`*^9, 
   3.586153627083762*^9}, {3.586153777276353*^9, 3.5861537821146297`*^9}, 
   3.5861545793562293`*^9, 3.590495710406209*^9, {3.6176856123328676`*^9, 
   3.617685662018955*^9}},ExpressionUUID->"c2cfb174-268c-4c08-a0a9-\
80b489ecf04d"],

Cell["Another commonly used simplification is", "Text",
 CellChangeTimes->{{3.5861541213060303`*^9, 3.586154139401065*^9}, 
   3.5861543977998447`*^9},ExpressionUUID->"2d12816f-2a91-4106-b11a-\
480abf8e730f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FormBox["fund1",
       TraditionalForm], "[", 
      RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x1", ",", "x2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y1", ",", "y2"}], "}"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "^", "2"}], ")"}], "*", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Cos", "[", "v", "]"}], ")"}], "^", "2"}], "*", "x1", "*", 
       "y1"}], "+", 
      RowBox[{"x2", "*", "y2"}]}], " ", ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5861537211471424`*^9, 3.5861537348419256`*^9}, {
   3.5861539275459476`*^9, 3.586154063466722*^9}, {3.586154468125867*^9, 
   3.5861544917242165`*^9}, {3.586154603805628*^9, 3.58615467517371*^9}, 
   3.590495710406209*^9, {3.61768585274489*^9, 
   3.6176859259714184`*^9}},ExpressionUUID->"d387df20-89b6-42ce-a1e1-\
530c06f46661"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.617685983083119*^9, 
  3.617686136446988*^9}},ExpressionUUID->"4046bba3-991d-4594-8251-\
cb8d5d30a819"],

Cell[TextData[{
 "\[FilledSquare]\nTo define the",
 StyleBox[" area of a surface",
  FontColor->RGBColor[0, 0, 1]],
 " we consider the ",
 StyleBox["Gram determinant ",
  FontColor->RGBColor[0, 0, 1]],
 "of two vectors:"
}], "Text",
 CellChangeTimes->{{3.5722510364627957`*^9, 3.5722510654008465`*^9}, {
  3.586154782192831*^9, 3.586154814847698*^9}, {3.6871793323260307`*^9, 
  3.68717934060505*^9}},ExpressionUUID->"cd02ca80-c591-4537-91bb-\
c3a014c130fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"x1", ",", "x2", ",", " ", "gram"}], "]"}], ";", 
  RowBox[{
   RowBox[{"gram", "[", 
    RowBox[{"x1_List", ",", "x2_List"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x1", ".", "x1"}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{"x2", ".", "x2"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x1", ".", "x2"}], ")"}], "^", "2"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.586069943593974*^9, 3.586069984809246*^9}, {
  3.7073711912137136`*^9, 3.707371194930902*^9}, {3.7073712958384657`*^9, 
  3.707371309639789*^9}},ExpressionUUID->"a2169651-ea3e-4605-87ad-\
61fb48cfc89b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gram", "::", "usage"}], " ", "=", " ", 
   "\"\<gram[vx,vy] is the Gram determinant of two vectors vx,vy  in the \
n-dimensional Euclidean Space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6149507206961126`*^9, 3.6149508409411235`*^9}, 
   3.61495087285878*^9},ExpressionUUID->"e4707856-fcda-463f-970d-\
92b95dc70d25"],

Cell["\<\
In Euclidean geometry this is the square of the area of the parallelogram \
spanned by the vectors x1,  x2:\
\>", "Text",
 CellChangeTimes->{{3.572251109876525*^9, 3.57225117556824*^9}, 
   3.586069358592946*^9, {3.5861548724479933`*^9, 3.5861549045198274`*^9}, 
   3.586156372890814*^9, {3.5890885163591433`*^9, 
   3.589088550846116*^9}},ExpressionUUID->"de180a98-c5fa-4406-9d34-\
967edb0d575b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"vec", "[", 
         RowBox[{"x", ",", "2"}], "]"}], ",", 
        RowBox[{"vec", "[", 
         RowBox[{"y", ",", "2"}], "]"}]}], "}"}], "]"}], ")"}], "^", "2"}], 
   " ", "\[Equal]", " ", 
   RowBox[{"gram", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"x", ",", "2"}], "]"}], ",", 
     RowBox[{"vec", "[", 
      RowBox[{"y", ",", "2"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.572087475918888*^9, 3.5720876163876476`*^9}, {
  3.5720876693809404`*^9, 
  3.5720877258266935`*^9}},ExpressionUUID->"2a1b0c58-a2cd-4097-b9e5-\
0f3bebc7cf34"],

Cell["\<\
   Thus the square of  the area of a parallelogram in the tangent plane of \
the surface is defined by\
\>", "Text",
 CellChangeTimes->{{3.572251109876525*^9, 3.57225117556824*^9}, 
   3.586069358592946*^9, {3.5861548724479933`*^9, 3.5861549045198274`*^9}, 
   3.586156372890814*^9, {3.586156413240121*^9, 
   3.5861564361274304`*^9}},ExpressionUUID->"7772f007-4e72-4ed2-b2df-\
8b7cb5eaaa4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tangsp", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{"s1", ",", "s2"}], "]"}]], "Input",ExpressionUUID->"3f8c3be6-4bdf-\
457e-be9f-2d3f01a0a1df"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "dst", "]"}], ";", 
  RowBox[{"dst", "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"gram", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tangsp", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"s1", ",", "s2"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"tangsp", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"t1", ",", "t2"}], "]"}]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.586069422007058*^9, 3.58606947440755*^9}, {
   3.622780870398752*^9, 3.6227808730039573`*^9}, {3.707371363773264*^9, 
   3.70737137478428*^9}, 3.707371616653741*^9, 
   3.707371751201191*^9},ExpressionUUID->"c62f40b8-f447-40ea-9695-\
bf83eb4d743b"],

Cell[BoxData["dst"], "Input",
 CellChangeTimes->{{3.707371623323045*^9, 
  3.707371625091146*^9}},ExpressionUUID->"52ccda34-8a47-4eb3-8040-\
04c82eaa6a34"],

Cell["and this equals the product of two determinants:", "Text",
 CellChangeTimes->{{3.6871797092989397`*^9, 
  3.687179730330514*^9}},ExpressionUUID->"16dbceb0-7a41-4a2c-a78a-\
40e131688f20"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"dst", "\[Equal]", "  ", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "*", 
    RowBox[{
     RowBox[{"Det", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s1", ",", "s2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t1", ",", "t2"}], "}"}]}], "}"}], "]"}], "^", "2"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5860694992583933`*^9, 3.586069705116355*^9}, {
   3.5860697555356436`*^9, 3.586069761260854*^9}, 3.586070236627984*^9, {
   3.5860702801554737`*^9, 3.586070319856745*^9}, {3.586070594851474*^9, 
   3.5860706219870253`*^9}, 3.5860707138922825`*^9, 3.5860709654996734`*^9, {
   3.586071217676097*^9, 3.5860712227553873`*^9}, 3.6148618492387214`*^9, 
   3.6148635013908234`*^9, 
   3.6176259295093884`*^9},ExpressionUUID->"d3496e42-88cb-4af5-887a-\
f896fb6424a8"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "\[Equal]", " ", 
   RowBox[{"gram", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5860694992583933`*^9, 3.586069705116355*^9}, {
   3.5860697555356436`*^9, 3.586069761260854*^9}, 3.586070236627984*^9, {
   3.5860702801554737`*^9, 3.586070319856745*^9}, {3.586070594851474*^9, 
   3.5860706219870253`*^9}, 3.5860707138922825`*^9, 3.5860709654996734`*^9, {
   3.586071217676097*^9, 3.5860712227553873`*^9}, {3.5860748660092196`*^9, 
   3.5860749408935027`*^9}, 3.6148618492543216`*^9, 3.6148635014220233`*^9, 
   3.617600024057088*^9, 3.617600085755196*^9, 
   3.617625931341493*^9},ExpressionUUID->"b6f88685-bbc2-4321-831c-\
c5e75aa6f692"],

Cell[TextData[{
 "We define in eudiffgeov3.m  the ",
 StyleBox["area element",
  FontColor->RGBColor[0, 0, 1]],
 " as  the  ",
 StyleBox["integrand of the",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 StyleBox["area integral",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.586074957018425*^9, 3.5860749831289186`*^9}, {
   3.6149511390512924`*^9, 3.614951164738762*^9}, 3.6176862785320377`*^9, {
   3.6226170862645617`*^9, 3.6226171006789875`*^9}, 3.686289008235034*^9, {
   3.687179777938871*^9, 
   3.687179787035832*^9}},ExpressionUUID->"f78e2baf-2f9e-4750-a942-\
9bbd295e8481"],

Cell[BoxData[
 RowBox[{"?", "dA"}]], "Input",
 CellChangeTimes->{{3.6149512007068186`*^9, 3.6149512315495825`*^9}, {
   3.6149512646054735`*^9, 3.6149513092050247`*^9}, 3.6149513572857747`*^9, {
   3.6226169727119627`*^9, 
   3.6226169860343857`*^9}},ExpressionUUID->"3d30dcbe-d93e-4595-9011-\
4fd52afe0bfa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dA", "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{"Sqrt", "[", " ", 
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5721028398629103`*^9, 3.5721030771549273`*^9}, 
   3.5721031379326334`*^9, {3.586074746853404*^9, 3.5860747605491877`*^9}, {
   3.5860748158453503`*^9, 3.586074825492902*^9}, {3.5861549510774903`*^9, 
   3.586154964603264*^9}, {3.5862629631854534`*^9, 3.586262985017702*^9}, {
   3.5862630295142474`*^9, 3.5862630744648185`*^9}, {3.586604010786734*^9, 
   3.5866040355439777`*^9}, 3.6176000240726876`*^9, 3.617600085755196*^9, 
   3.617687181505224*^9, 3.6176873242766747`*^9, {3.617687380748774*^9, 
   3.6176874075964212`*^9}, 3.6226169373623004`*^9, {3.686996998891444*^9, 
   3.6869970039999437`*^9}, {3.693492895666019*^9, 
   3.69349291041782*^9}},ExpressionUUID->"e72e6916-087c-4522-84df-\
7f3b4c7f9f68"],

Cell[TextData[{
 StyleBox["Remark.",
  FontColor->RGBColor[0, 0, 1]],
 " Since the first fundamental form is positive  definite its determinant is \
always positive. Therefore its non oriented integral is positive too. "
}], "Text",
 CellChangeTimes->{{3.617952911137521*^9, 3.6179529253933363`*^9}, {
   3.617953007017005*^9, 3.617953011633269*^9}, {3.6179530458652267`*^9, 
   3.6179531287369666`*^9}, {3.6180305569429736`*^9, 3.6180305659909897`*^9}, 
   3.627308098271442*^9, {3.627309524432357*^9, 3.6273095252747583`*^9}, {
   3.69622447504723*^9, 
   3.6962244752628098`*^9}},ExpressionUUID->"e23220c9-f219-45e9-99b0-\
3f74010d4a56"],

Cell[TextData[{
 StyleBox["Example 4.",
  FontColor->RGBColor[0, 0, 1]],
 " Circular cone. (See also Example 1.1.4)"
}], "Text",
 CellChangeTimes->{{3.6176877651178493`*^9, 3.617687777675871*^9}, {
  3.686997108734058*^9, 3.686997111318013*^9}, {3.687180314397572*^9, 
  3.6871803670533037`*^9}},ExpressionUUID->"a2babf2d-6e03-4086-8fd4-\
977964b552e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.687180444165143*^9},ExpressionUUID->"2c84e9f8-9b89-4125-bd53-\
f3e33c164852"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"dA", "[", 
    RowBox[{"circularcone", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5866039382466063`*^9, 3.5866039759206724`*^9}, {
  3.5866041540105853`*^9, 3.5866041641662035`*^9}, {3.6148653631292934`*^9, 
  3.6148653750945144`*^9}},ExpressionUUID->"8b83e8a0-eb67-46c0-a180-\
e5866bb5c78d"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"h", ">", "0"}], ",", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dA", "[", 
       RowBox[{"circularcone", "[", 
        RowBox[{"a", ",", "b"}], "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", "0", ",", "h"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.589088773152831*^9, 3.589088850954281*^9}, {
   3.5890888926896687`*^9, 3.5890889221143513`*^9}, 3.6148618492855215`*^9, 
   3.614865446090239*^9, {3.614865726531932*^9, 3.614865741539158*^9}, {
   3.614866292275104*^9, 3.614866301169613*^9}, 3.6176875207278194`*^9, 
   3.686997179100081*^9, 3.6869972179472103`*^9, 3.686997250867572*^9, 
   3.6869972866221313`*^9, {3.68699736763062*^9, 3.6869973823299828`*^9}, {
   3.6869974355699244`*^9, 3.6869974753403587`*^9}, {3.686997512648988*^9, 
   3.686997515059486*^9}, {3.6871804153952312`*^9, 
   3.687180419926106*^9}},ExpressionUUID->"6e15a345-b87e-44d2-84f9-\
3a719d4832e3"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6176878245383534`*^9, 
  3.6176878245383534`*^9}},ExpressionUUID->"7ef300ac-562b-49dc-9e56-\
02778f08dfaf"],

Cell[TextData[{
 "The integral over dA[sf][u,v] yields the ",
 StyleBox["area",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface. Since a parameter transformation for the surface amounts \
to the multiplication of the integrand with the Jacobian determinant of the \
parameter transformation, the integral is independent of the choice of the \
parameter representation."
}], "Text",
 CellChangeTimes->{{3.5720898734695654`*^9, 3.572089907259225*^9}, {
  3.572105272437583*^9, 3.5721052835448027`*^9}, {3.572173734631772*^9, 
  3.5721738456001186`*^9}, {3.586074789744858*^9, 3.586074792722028*^9}, {
  3.586155042023692*^9, 3.5861551192241077`*^9}, {3.5861562113125715`*^9, 
  3.5861562665757327`*^9}, {3.5861563043758945`*^9, 3.5861563220399046`*^9}, {
  3.61769233645127*^9, 
  3.617692342075592*^9}},ExpressionUUID->"756034e0-4f89-4cdb-a3b4-\
c93181d02281"],

Cell[TextData[{
 StyleBox["Example 5",
  FontColor->RGBColor[0, 0, 1]],
 ". Spheres"
}], "Text",
 CellChangeTimes->{{3.6176878338827696`*^9, 3.6176878428683853`*^9}, {
  3.6869975733866787`*^9, 
  3.686997574170723*^9}},ExpressionUUID->"f611733d-c667-4744-bab8-\
3cdee57dbb77"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6176878844580584`*^9, 
  3.617687952458578*^9}},ExpressionUUID->"eebe1045-4d28-4380-be3c-\
5d3b65e6032d"],

Cell["The area of the hemisphere of radius r is", "Text",
 CellChangeTimes->{{3.617691530792863*^9, 3.617691555612507*^9}, {
   3.6176918647894497`*^9, 3.617691867831455*^9}, 3.6176921682166476`*^9, {
   3.6934929923280888`*^9, 
   3.69349302337554*^9}},ExpressionUUID->"3813f614-b444-4ffa-9222-\
48c6d1cb744f"],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617687965328601*^9, 3.617688027135909*^9}, 
   3.617691877129071*^9},ExpressionUUID->"2fcc5255-a6fb-4a41-a0ed-\
4a04768d1caf"],

Cell["\<\
Here is another parameter representation of the hemisphere of radius r:\
\>", "Text",
 CellChangeTimes->{{3.61769158015135*^9, 3.6176916295254364`*^9}, 
   3.6176921682456493`*^9},ExpressionUUID->"0b2065d0-0231-402d-a1df-\
9ed727cdccbf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sphf", "[", "r_", "]"}], "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], " ", ":=", "  ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "*", 
     RowBox[{"Cos", "[", "y", "]"}]}], ",", 
    RowBox[{"x", "*", 
     RowBox[{"Sin", "[", "y", "]"}]}], ",", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"r", "^", "2"}], "-", 
      RowBox[{"x", "^", "2"}]}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6176881577081385`*^9, 3.6176882004366136`*^9}, {
  3.617688240637884*^9, 3.617688321227626*^9}, {3.617688750072379*^9, 
  3.6176888089000826`*^9}, {3.61769068046657*^9, 
  3.6176907256286488`*^9}},ExpressionUUID->"85e289e6-54d1-48c9-b891-\
035f6af7178f"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphf", "[", "2", "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61768835777849*^9, 3.617688479614704*^9}, {
   3.6176888188216996`*^9, 3.617688849678554*^9}, {3.617688879942607*^9, 
   3.61768888749302*^9}, 3.617690751774295*^9, {3.617690789963162*^9, 
   3.617690805313589*^9}},ExpressionUUID->"e563fa4e-c61d-405c-aabe-\
93af47d172a3"],

Cell["The area element is", "Text",
 CellChangeTimes->{{3.617691660475891*^9, 
  3.617691667573903*^9}},ExpressionUUID->"bb416247-75c6-468c-bebb-\
8b38e3a46707"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", 
     RowBox[{"sphf", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", " ", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6176890442264957`*^9, 
  3.6176890872513714`*^9}},ExpressionUUID->"338140cd-631f-414f-8d88-\
ea022c652b1c"],

Cell["The area of the  hemisphere is", "Text",
 CellChangeTimes->{{3.617691697073555*^9, 3.617691713562784*^9}, 
   3.6176921682676506`*^9},ExpressionUUID->"7067df43-f4ca-42a2-aedd-\
c9c1de10967f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "r"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6176891033193994`*^9, 3.6176891346130543`*^9}, {
   3.617689172599121*^9, 3.6176892293676205`*^9}, {3.617690863954092*^9, 
   3.617690886776932*^9}, {3.6176911210581436`*^9, 3.6176911442397842`*^9}, {
   3.6176913540913525`*^9, 3.617691383903005*^9}, 3.617691444025511*^9, {
   3.6176917597700653`*^9, 
   3.6176917974753313`*^9}},ExpressionUUID->"70691998-fb92-4d10-9ec3-\
79166fc35360"],

Cell[TextData[{
 "This equals the preceding result and illustrates the ",
 StyleBox["invariance of the area of a surface under parameter \
transformations",
  FontSlant->"Italic"],
 ", or the ",
 StyleBox["independence of the area from the parameter representation",
  FontSlant->"Italic"],
 ". \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.617691919342746*^9, 3.617691938468379*^9}, {
   3.6176922194665794`*^9, 3.6176922237468243`*^9}, {3.6176922937228265`*^9, 
   3.617692296446982*^9}, 3.6176925683365335`*^9, {3.6871812619497013`*^9, 
   3.687181411596387*^9}, {3.68718144934051*^9, 
   3.687181530139585*^9}},ExpressionUUID->"7f49e6a2-399c-4473-9b22-\
5dbeebd1d035"],

Cell[TextData[{
 "Also the ",
 StyleBox["angle",
  FontColor->RGBColor[0, 0, 1]],
 " between two vectors lying in the tangent plane of sf at the same point \
sf[u,v] can be expressed with the first fundamental form. The cosinus of the \
angle \[Alpha] of the vectors "
}], "Text",
 CellChangeTimes->{{3.687182566233488*^9, 3.68718266740195*^9}, {
  3.687183284020514*^9, 3.687183304516694*^9}, {3.68718337993202*^9, 
  3.687183451211337*^9}, {3.687183511794798*^9, 3.687183565642557*^9}, {
  3.687183706778448*^9, 
  3.68718374632104*^9}},ExpressionUUID->"ca61e132-2458-4333-bfdb-\
7b1e4a6ce415"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vx", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tangsp", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"x1", ",", "x2"}], "]"}]}], ";", "  ", 
  RowBox[{"vy", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tangsp", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"y1", ",", "y2"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6871837534605103`*^9, 
  3.687183811656879*^9}},ExpressionUUID->"e5cc2a44-75ef-4c39-9c96-\
d26aa6c90650"],

Cell[TextData[{
 "is (use the ",
 ButtonBox["identity",
  BaseStyle->"Hyperlink",
  ButtonData->"fund1"],
 " before the definition of fund1)"
}], "Text",
 CellChangeTimes->{{3.687183822798848*^9, 3.6871838235921917`*^9}, 
   3.68718389933807*^9, {3.68718405000632*^9, 3.6871841485014153`*^9}, {
   3.687184181363324*^9, 
   3.6871841813656588`*^9}},ExpressionUUID->"2db4ddab-cd18-4b7c-8b53-\
e061f6dcc005"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"vx", ".", "vy"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"vx", ".", "vx"}], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{"vy", ".", "vy"}], ")"}]}], "]"}]}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x1", ",", "x2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y1", ",", "y2"}], "}"}]}], "]"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x1", ",", "x2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x1", ",", "x2"}], "}"}]}], "]"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"y1", ",", "y2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y1", ",", "y2"}], "}"}]}], "]"}]}], "]"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.687183926383564*^9, 3.687184033375304*^9}, {
  3.687184251142941*^9, 3.6871843232227497`*^9}, {3.687184368509027*^9, 
  3.6871843868363543`*^9}, {3.687184430965068*^9, 
  3.6871844463887444`*^9}},ExpressionUUID->"d9a33a25-09f2-4ce8-a1fd-\
6ceadff91c32"],

Cell["where", "Text",
 CellChangeTimes->{{3.687186029876725*^9, 
  3.687186049118897*^9}},ExpressionUUID->"1a2b8852-b4b3-4017-9f38-\
3de3605c23e2"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"norm", "[", "vx", "]"}], " ", "\[Equal]", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x1", ",", "x2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x1", ",", "x2"}], "}"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6871860639204073`*^9, 3.6871860762136993`*^9}, {
  3.687186112342507*^9, 
  3.687186144454274*^9}},ExpressionUUID->"a6ca2df2-7e93-4d5a-8dd9-\
e0a409cf71b1"],

Cell["\<\
coincides with the length of the vector vx. Thus the basic concepts of \
Euclidean geometry, the metric concepts length,angle, area,  are expressed in \
terms of the first fundamental form. In particular, the angle between the \
standard basis vectors has the cosinus\
\>", "Text",
 CellChangeTimes->{{3.687186218126296*^9, 
  3.687186460026771*^9}},ExpressionUUID->"b4fd9c52-5d32-464c-8dd3-\
b2e77c4df993"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"fund1", "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"fund1", "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "]"}], ")"}]}], 
   "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"rgT", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.687184576827136*^9, 3.687184716626564*^9}, {
   3.6871847744821243`*^9, 3.687184845650091*^9}, 3.6871849584207373`*^9, 
   3.687184991664506*^9, {3.687185470006343*^9, 3.6871854803327837`*^9}, {
   3.687185530255351*^9, 3.687185541724531*^9}, {3.687185574301775*^9, 
   3.687185586916109*^9}, {3.687185666232842*^9, 
   3.687185757025632*^9}},ExpressionUUID->"62e77eb5-f931-4a0c-98c5-\
4e69bcb1fc56"],

Cell["\<\
The parameter representation is orthogonal, if the parameter lines cut \
themselves orthogonally at each point of the surface, and this the case iff \
rgT[1,2][sf][u,v]== 0.\
\>", "Text",
 CellChangeTimes->{{3.687186595929023*^9, 3.687186682728725*^9}, {
  3.687186714104452*^9, 
  3.6871868082720222`*^9}},ExpressionUUID->"0d22035d-994d-4e04-a221-\
1f04b7c7a9ca"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.3. Isometries", "Subsubsection",
 CellChangeTimes->{{3.586059663992068*^9, 3.586059674943287*^9}, {
   3.5860750543689933`*^9, 3.58607505605709*^9}, {3.5866611656056275`*^9, 
   3.586661191821127*^9}, {3.5872724573591394`*^9, 3.5872724609903474`*^9}, {
   3.588661830058444*^9, 3.588661834145651*^9}, {3.5889467393286066`*^9, 
   3.58894674141901*^9}, 3.589200965451682*^9, {3.5892029279099283`*^9, 
   3.58920294017163*^9}, 3.5995661030936694`*^9, 3.5995680459337935`*^9, 
   3.614951511699607*^9, 3.615021851745468*^9, 3.6176934720992255`*^9, 
   3.617705065201067*^9, {3.6273099762505536`*^9, 3.6273099853609695`*^9}, 
   3.627372246455145*^9, 3.686988070693749*^9, {3.687181933176096*^9, 
   3.687181945655674*^9}, 3.6872611666127377`*^9, {3.693493296501141*^9, 
   3.693493303181026*^9}, 3.693581428382351*^9, 3.696224611966826*^9, 
   3.6962357591073713`*^9},ExpressionUUID->"b2175e24-507e-43c3-b111-\
059b2379de01"],

Cell["Let sf[u, v] and sh[uu,vv] be two regular surfaces:", "Text",
 CellChangeTimes->{{3.58867436634879*^9, 3.588674446798131*^9}, {
  3.588674735336238*^9, 
  3.588674760608282*^9}},ExpressionUUID->"e89db75f-40f8-45f4-8e78-\
79b8de3b2fe7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "2"}], ";", 
  RowBox[{"spdim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.617701255839184*^9, 3.6177012716340876`*^9}, 
   3.687064885433197*^9, {3.696082351568009*^9, 3.696082352535955*^9}, {
   3.696229254058276*^9, 
   3.6962292590021553`*^9}},ExpressionUUID->"dcf5519b-713e-45c1-b6b3-\
ac9502b00169"],

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5886741949824886`*^9, 
  3.5886742022053013`*^9}},ExpressionUUID->"44cd7295-a5cf-40bb-837b-\
89c9b5c6ff37"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sh", "[", 
    RowBox[{"uu_", ",", "vv_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", "i", "]"}], "[", 
      RowBox[{"uu", ",", "vv"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"sh", "[", 
   RowBox[{"uu", ",", "vv"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.588674462132958*^9, 3.588674468450969*^9}, {
   3.5886746092880163`*^9, 3.588674654886897*^9}, 3.614861849316722*^9, 
   3.6148635014220233`*^9, {3.687064957443266*^9, 
   3.687064959286564*^9}},ExpressionUUID->"25930684-f1fb-4e78-98d4-\
f7da6962e776"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "[", "1", "]"}], "[", 
    RowBox[{"uu", ",", "vv"}], "]"}], ",", 
   RowBox[{
    RowBox[{"h", "[", "2", "]"}], "[", 
    RowBox[{"uu", ",", "vv"}], "]"}], ",", 
   RowBox[{
    RowBox[{"h", "[", "3", "]"}], "[", 
    RowBox[{"uu", ",", "vv"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.708321848150147*^9},ExpressionUUID->"da070c0a-974a-4fc6-9cc3-\
e580bb0576cf"]
}, Open  ]],

Cell[TextData[{
 "The parameter vary in open subsets of the real plane: U,UU\[Subset] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]],ExpressionUUID->
  "7cec9bee-f3c4-4079-a0af-2bd8550ba2b8"],
 ".  A map  "
}], "Text",
 CellChangeTimes->{{3.588674970288251*^9, 3.588675107786892*^9}, 
   3.5890024944555883`*^9, 3.6176267756617856`*^9, {3.687065359771167*^9, 
   3.687065535497964*^9}, {3.687065668018014*^9, 3.6870656953687487`*^9}, 
   3.6935453839572077`*^9},ExpressionUUID->"de3e93dc-8786-4303-970b-\
a5ae5df22da9"],

Cell[BoxData[
 RowBox[{"F", ":", " ", 
  RowBox[{
   RowBox[{"sf", "[", "U", "]"}], " ", "\[RightArrow]", " ", 
   RowBox[{"sh", " ", "[", "UU", "]"}], " "}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6870657002128057`*^9, 
  3.687065750976832*^9}},ExpressionUUID->"32d2d0f1-5239-4b7d-99c7-\
b6f4e8f6d896"],

Cell["can be defined by the map f between the parameter regions:", "Text",
 CellChangeTimes->{{3.588674970288251*^9, 3.588675107786892*^9}, 
   3.5890024944555883`*^9, 3.6176267756617856`*^9, {3.687065359771167*^9, 
   3.687065535497964*^9}, {3.687065779760125*^9, 
   3.68706579149586*^9}},ExpressionUUID->"564f165b-1620-4580-842a-\
588ea4eaffe7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", ":", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}], " ", "\[Element]", " ", 
    RowBox[{"U", " ", "\[RightArrow]", " ", 
     RowBox[{"f", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], " ", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "  ", "\[Element]", " ", 
   RowBox[{"U", " ", "U", "         ", 
    RowBox[{"(", "1", ")"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5886751171313086`*^9, 3.5886752965160236`*^9}, {
   3.5887663043718996`*^9, 3.5887663441987696`*^9}, 3.5887664615265756`*^9, {
   3.617701328276327*^9, 3.6177013359237647`*^9}, {3.687068639307858*^9, 
   3.687068648771859*^9}},ExpressionUUID->"a30c99a7-3722-45c0-919c-\
a7c075a8fb8a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f1", ",", "f2", ",", "f"}], "]"}], ";", " ", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.588766400343268*^9, 3.588766437346533*^9}, 
   3.588766471978594*^9, {3.589198575767*^9, 
   3.5891985917029114`*^9}},ExpressionUUID->"96a5fa49-8bd9-40fd-9380-\
c3b5e84c0383"],

Cell[BoxData[
 RowBox[{GridBox[{
    {
     RowBox[{"F", ":"}], 
     RowBox[{"sf", "[", "U", "]"}], "\[LongRightArrow]", 
     RowBox[{"sh", "[", "UU", "]"}]},
    {"\[Placeholder]", 
     RowBox[{"sf", "\[UpArrow]"}], "\[Placeholder]", 
     RowBox[{"sh", "\[UpArrow]"}]},
    {
     RowBox[{"f", ":"}], "U", "\[LongRightArrow]", "UU"}
   }], "                                                           ", 
  RowBox[{"(", "2", ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.688711639854274*^9, 3.688711648437992*^9}, 
   3.688711685056102*^9, {3.6887117894546347`*^9, 3.688711810109971*^9}, {
   3.690025991090109*^9, 3.690026019634101*^9}, 3.690026109553459*^9, {
   3.6900908631970253`*^9, 3.690090948443631*^9}, {3.693545897578624*^9, 
   3.6935460445366983`*^9}, {3.693546079000332*^9, 
   3.6935460953760843`*^9}},ExpressionUUID->"6490ae30-0a51-4c9f-81f6-\
ae9f8762d187"],

Cell["\<\
The functions f1,f2, like all functions and maps in differential geometry, \
are assumed to be smooth, that means continuously differentiable as often as \
necessary.  The map F is defined by\
\>", "Text",
 CellChangeTimes->{{3.5886753470913124`*^9, 3.588675451190295*^9}, {
   3.5886754866335573`*^9, 3.5886755497668686`*^9}, 3.588675617580188*^9, {
   3.5886756774218926`*^9, 3.5886756818055005`*^9}, 3.5887661518192315`*^9, 
   3.588917638220236*^9, 3.5995674356568875`*^9, {3.687065088877676*^9, 
   3.687065100693088*^9}, {3.687066843584601*^9, 3.6870668634084053`*^9}, {
   3.687067047183182*^9, 3.687067048070627*^9}, 3.688712043682767*^9, 
   3.688712171578203*^9},ExpressionUUID->"bbe2ada9-72b5-4cc0-8edc-\
2ae5b72468cc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F", ":", " ", 
   RowBox[{"x", "\[Element]", " ", 
    RowBox[{
     RowBox[{"sf", "[", "U", "]"}], " ", "\[RightTeeArrow]", " ", 
     RowBox[{"F", "[", "x", "]"}]}]}]}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"sh", "\[SmallCircle]", "f", "\[SmallCircle]", 
    RowBox[{
     SuperscriptBox["sf", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]], "[", "x", "]"}]}], " ", "\[Element]", " ", 
   RowBox[{"sh", "[", "UU", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.687066519532153*^9, 3.687066625466715*^9}, {
  3.687066657431443*^9, 
  3.687066779129833*^9}},ExpressionUUID->"0a979e5c-da2f-4298-abde-\
0da9d394f97a"],

Cell[TextData[{
 "under the assumption that also the parameter representation sf: U -> sf[U] \
is bijective. This is the case  at least locally, in a neighborhood of  a \
regular point, as can be proved by the",
 ButtonBox[" implicit function theorem",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ImplicitFunctionTheorem.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ImplicitFunctionTheorem.html"],
 ".  Globally, or if singular points of the parameter representations exist, \
the definition of the map F using a map f between the parameter regions must \
be done in each special situation particularly. Clearly, the properties of F \
are completely defined by the map f between the parameter regions: the map f \
is named a ",
 StyleBox["parameter representation",
  FontColor->RGBColor[0, 0, 1]],
 " of the map F. Thus we will speak  a bit sloppily about the map f between \
the surfaces having in mind the described relation between F and f. \
Sometimes, if the map sf is injective, it is simpler to consider the point \
{u,v} of the parameter region instead of the surface point sf[u,v] as the \
argument of F. In this case the relation between F and f is"
}], "Text",
 CellChangeTimes->{{3.687066924263392*^9, 3.6870670647264347`*^9}, {
   3.687067108597992*^9, 3.6870671991096354`*^9}, {3.687067242965447*^9, 
   3.6870672576131496`*^9}, {3.6870674770516644`*^9, 3.687067506403289*^9}, 
   3.687067537387185*^9, {3.68706756854673*^9, 3.687067610178938*^9}, {
   3.68706767736241*^9, 3.687067898593587*^9}, {3.687068083896092*^9, 
   3.687068100808187*^9}, {3.687068153519404*^9, 3.687068265151273*^9}, {
   3.68706834215873*^9, 3.6870684225510263`*^9}, {3.6870685103007298`*^9, 
   3.6870685143580933`*^9}, {3.688712742839923*^9, 3.6887128080316963`*^9}, {
   3.693546707776*^9, 3.693546709975443*^9}, {3.693546751535204*^9, 
   3.693547027999487*^9}},ExpressionUUID->"ddde1d89-7da1-42b0-b3a5-\
731a07823633"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"F", ",", "f"}], "]"}], ";", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}], ";", " ", 
  RowBox[{
   RowBox[{"F", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
   RowBox[{"sh", "[", 
    RowBox[{"lts", "[", 
     RowBox[{"f", "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}], 
   "                                          "}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.588675689121913*^9, 3.5886758305517616`*^9}, {
  3.687068992361431*^9, 3.687069000553358*^9}, {3.687069050752048*^9, 
  3.687069059601143*^9}, {3.690026303048397*^9, 3.6900263229763727`*^9}, {
  3.6900263656558332`*^9, 3.6900263820315*^9}, {3.690026470770081*^9, 
  3.690026482266757*^9}, {3.690026924739543*^9, 3.690026966795692*^9}, {
  3.690027015765272*^9, 3.6900270190352783`*^9}, {3.696139102212089*^9, 
  3.696139121425585*^9}},ExpressionUUID->"b8fa3496-54da-4946-ab86-\
7218d3336830"],

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.690013024494219*^9, 3.690013041318087*^9}, {
  3.6900270722636633`*^9, 
  3.6900270927061377`*^9}},ExpressionUUID->"44c63143-9da5-4530-9566-\
6042418278aa"],

Cell[TextData[{
 "   The map f is said to be a ",
 StyleBox["diffeomorphism",
  FontColor->RGBColor[0, 0, 1]],
 " if it is smooth, bijective, and its inverse ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["f", 
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}]], TraditionalForm]],ExpressionUUID->
  "b7408c60-dd3f-4e1a-9645-0ca9a050d091"],
 " is smooth too; the map F is said to be a diffeomorphism if it is bijective \
and all its parameter representations are diffeomorphisms.  Obviously, these \
definitions may be applied also for higher dimensional immersions."
}], "Text",
 CellChangeTimes->{{3.688713032046961*^9, 3.688713046188828*^9}, {
  3.688713079555187*^9, 3.688713149306736*^9}, {3.688713184626669*^9, 
  3.688713251753664*^9}, {3.6887133045378017`*^9, 3.6887134317124443`*^9}, {
  3.688713488296549*^9, 3.688713580535857*^9}, {3.688713610704042*^9, 
  3.6887136193917427`*^9}},ExpressionUUID->"715aac1e-4332-4f8e-be3c-\
411e1e67be46"],

Cell[TextData[{
 "On the other hand, a diffeomorphism f  given by (1) can be interpreted as a \
",
 StyleBox["parameter transformation",
  FontColor->RGBColor[0, 0, 1]],
 " for the surface defined by sf:"
}], "Text",
 CellChangeTimes->{{3.6870691052643147`*^9, 3.687069119159842*^9}, {
   3.687069151355236*^9, 3.687069238926867*^9}, {3.6870693708942432`*^9, 
   3.687069388421954*^9}, 
   3.688713640519127*^9},ExpressionUUID->"d2941a41-c3cf-4e00-ad91-\
dcf4530001b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"uu", " ", ":=", " ", 
   RowBox[{"f1", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], ";", "  ", 
  RowBox[{"vv", "  ", ":=", " ", 
   RowBox[{"f2", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.687069253783224*^9, 
  3.6870693546306877`*^9}},ExpressionUUID->"8d529bd2-998b-4330-bbfe-\
9da8719c6140"],

Cell["such that ", "Text",
 CellChangeTimes->{{3.687069424821456*^9, 3.687069438637445*^9}, {
   3.6870695039329453`*^9, 3.687069569476668*^9}, {3.6870696055820312`*^9, 
   3.68706966965993*^9}, 3.6870697327240963`*^9, 
   3.687069819066579*^9},ExpressionUUID->"93344a6d-6781-4811-9bc1-\
89a965ded4d2"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox[
      OverscriptBox["sf", "^"],
      TraditionalForm], "[", 
     RowBox[{"uu", ",", "vv"}], "]"}], " ", "==", " ", 
    RowBox[{
     FormBox["sf",
      TraditionalForm], "[", 
     RowBox[{
      SuperscriptBox["f", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]], "[", 
      RowBox[{"uu", ",", "vv"}], "]"}], "]"}]}], "\n", 
   FormBox[
    RowBox[{
     OverscriptBox["sf", "^"], " ", ":=", " ", 
     RowBox[{
      RowBox[{"sf", "\[SmallCircle]", 
       RowBox[{
        SuperscriptBox["f", 
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}]], ":", " ", "UU"}]}], " ", "->", " ", 
      RowBox[{
       RowBox[{
        OverscriptBox["sf", "^"], "[", "UU", "]"}], " ", "==", " ", 
       RowBox[{"sf", "[", "U", "]"}]}]}]}],
    TraditionalForm]}]}]], "Text",
 CellChangeTimes->{{3.68706973723442*^9, 3.687069737235414*^9}, {
   3.6870701715136137`*^9, 3.687070183111093*^9}, 3.6872433356455812`*^9, {
   3.688713871950101*^9, 3.6887138726858664`*^9}, 3.6887139312135143`*^9, {
   3.6887139706677513`*^9, 3.688714026316854*^9}, {3.690027177202133*^9, 
   3.6900271777692327`*^9}},
 CellTags->"ptr",ExpressionUUID->"5f9e9458-8c19-42dc-a97b-adfdb87b7562"],

Cell[TextData[{
 "If this parameter representation is carried out The functions F, f in \
equation (2) becomes a ",
 StyleBox["map of equal parameters",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.6870714422607327`*^9, 3.68707149663594*^9}, {
  3.687071738562398*^9, 3.687071756314487*^9}, {3.687073721034051*^9, 
  3.687073721641765*^9}, {3.690027391511518*^9, 
  3.69002742899957*^9}},ExpressionUUID->"7e64db05-88b9-414a-8c84-\
71866e523e10"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    OverscriptBox["sf", "^"], " ", "[", 
    RowBox[{"uu", ",", "vv"}], "]"}], "\[RightTeeArrow]", 
   RowBox[{"F", "[", 
    RowBox[{"uu", ",", "vv"}], "]"}]}], ":=", 
  RowBox[{
   RowBox[{"sh", "[", 
    RowBox[{"uu", ",", "vv"}], "]"}], "                                   ", 
   RowBox[{"(", "3", ")"}], "          "}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.687071511657872*^9, 3.687071590092448*^9}, {
   3.687071623499724*^9, 3.687071636219993*^9}, 3.687243486192151*^9, {
   3.690027263017414*^9, 3.690027284825039*^9}, {3.690027460823496*^9, 
   3.6900275196244287`*^9}},ExpressionUUID->"42e78552-7a3b-4f7e-b605-\
2361a14be1da"],

Cell[TextData[{
 "points with the same parameter values are mapped onto each other. With \
respect to these common parameters the map F is representd by the identity ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["f", "^"], TraditionalForm]],ExpressionUUID->
  "94961fea-c8bf-42aa-904a-dbc586cd6096"],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["id", "UU"], TraditionalForm]],ExpressionUUID->
  "1cf5c4e5-546a-4034-82f8-406e4e272e3f"],
 " of UU:"
}], "Text",
 CellChangeTimes->{{3.68707180271388*^9, 3.6870718535374928`*^9}, {
   3.68707189137718*^9, 3.687072137439787*^9}, 3.6870722755904818`*^9, {
   3.6870723247819853`*^9, 3.687072402965551*^9}, {3.687072563820356*^9, 
   3.6870725977316303`*^9}, {3.687243514194064*^9, 
   3.6872435150502777`*^9}},ExpressionUUID->"2cc35a51-6d30-4665-a4b4-\
858c923a01da"],

Cell[BoxData[
 RowBox[{
  RowBox[{"identity", "[", 
   RowBox[{"uu", ",", "vv"}], "]"}], "==", 
  RowBox[{"{", 
   RowBox[{"uu", ",", "vv"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.68707242291187*^9, 3.6870724280851707`*^9}, 
   3.687072469423877*^9, {3.687072505006514*^9, 
   3.687072544417225*^9}},ExpressionUUID->"6ff57a55-dd94-4f34-b4d6-\
bb3faf272e14"],

Cell["\<\
Using the implicit function theorem to obtain appropriate parameter \
representations one can prove\
\>", "Text",
 CellChangeTimes->{{3.687072699106333*^9, 3.687072754049814*^9}, {
  3.687073575659287*^9, 
  3.6870736665222797`*^9}},ExpressionUUID->"647f8631-14fb-4d39-9fca-\
009ed911e5a0"],

Cell[TextData[{
 StyleBox["Lemma 1",
  FontColor->RGBColor[0, 0, 1]],
 ". Each diffeomorphism F between surfaces (or more generally, differentiable \
manifolds) may locally be represented as a map of equal parameters. \
\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.687072766729744*^9, 3.687072777041704*^9}, {
   3.6870728907926693`*^9, 3.687072940816382*^9}, {3.687072972087994*^9, 
   3.6870730786474257`*^9}, {3.68707310973508*^9, 3.6870731180947104`*^9}, {
   3.687073556059165*^9, 3.687073564358392*^9}, {3.6870737072744503`*^9, 
   3.68707370793814*^9}, 3.687157766038405*^9, 
   3.6871791378641453`*^9},ExpressionUUID->"c511aabe-04a0-4bf7-946e-\
1da200680eb2"],

Cell[TextData[{
 StyleBox["Definition",
  FontColor->RGBColor[0, 0, 1]],
 ". A bijective map F: sf[U] \[RightArrow] sh [UU] generated by a \
diffeomorphism f, see formulas (1), (2), is said to be an",
 StyleBox[" isometry",
  FontColor->RGBColor[0, 0, 1]],
 " if for any smooth curve\nsf[ \[Gamma][t]] in  sf[U]  "
}], "Text",
 CellChangeTimes->{{3.5886761540027294`*^9, 3.5886763175846167`*^9}, 
   3.588766216465745*^9, {3.58900491683214*^9, 3.58900496927914*^9}, {
   3.687073978783595*^9, 3.687074007935691*^9}, {3.687074058224078*^9, 
   3.6870741278625917`*^9}, {3.687098085964526*^9, 3.687098178443804*^9}, {
   3.6870982139558077`*^9, 3.687098247699435*^9}, 3.693486879225854*^9, {
   3.696229888628737*^9, 
   3.696229899668517*^9}},ExpressionUUID->"c062ea32-d5f1-4cc4-9c71-\
612b1898c416"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"sf\[Gamma]", "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.58867632485423*^9, 3.588676377051922*^9}, 
   3.5886764129163847`*^9, {3.5890048989381166`*^9, 3.589004906552552*^9}, {
   3.5890912050399275`*^9, 3.5890912313764334`*^9}, 
   3.6934868792395353`*^9},ExpressionUUID->"363a5d65-b0d2-49ce-b35e-\
38739b9f097a"],

Cell["its image under F,   namely", "Text",
 CellChangeTimes->{{3.5886764221204004`*^9, 3.5886764349436235`*^9}, {
   3.588676585171887*^9, 3.588676593330701*^9}, {3.588676743387365*^9, 
   3.588676793073452*^9}, {3.588676830435518*^9, 3.588676858265967*^9}, 
   3.6870741466223087`*^9},ExpressionUUID->"47eaae74-86f3-4802-947b-\
8203f092f152"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F\[Gamma]", "[", "t_", "]"}], "=", 
  RowBox[{"F", "[", 
   RowBox[{"lts", "[", 
    RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5886764432116375`*^9, 3.588676487172515*^9}, {
   3.588676519776572*^9, 3.5886765561246357`*^9}, {3.6900277117534027`*^9, 
   3.690027789877187*^9}, {3.6900278332246513`*^9, 3.6900278387963943`*^9}, {
   3.690027886773343*^9, 3.690027910971924*^9}, {3.690027951978155*^9, 
   3.690028002443124*^9}, 3.690036216221366*^9, {3.693486879250502*^9, 
   3.6934868792523403`*^9}, {3.696139195744589*^9, 
   3.6961392232085257`*^9}},ExpressionUUID->"498273af-2371-4342-b1fd-\
c6943c5094a0"],

Cell["has the same arc length.  \[FilledSquare]", "Text",
 CellChangeTimes->{{3.588676867469983*^9, 3.5886768700439873`*^9}, 
   3.5886770860263667`*^9, {3.5890026335835457`*^9, 3.5890026564708548`*^9}, 
   3.5995674706898913`*^9, {3.687076018794739*^9, 
   3.687076027597039*^9}},ExpressionUUID->"caba955a-ecd4-4dca-8d9b-\
44fee86d1d03"],

Cell[TextData[{
 "An immediate consequence of this definition is\n",
 StyleBox["Proposition 2",
  FontColor->RGBColor[0, 0, 1]],
 ". The Inverse map ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["F", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], " "}]], TraditionalForm]],ExpressionUUID->
  "567f3cd7-1a96-4fc4-bc0d-607ae2209691"],
 "of an isometry is an isometry too. The composition F1\[SmallCircle]F2  of \
two isometries F1, F2, if it exists, is an isometry again. The set of all \
isometries of a surface sf onto itself with the composition \[SmallCircle] as \
operation is a group, called the ",
 StyleBox["isometry group",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface. The unity of this group is the identity map. \
\[FilledSquare]\nA generally curved surface may have only the trivial \
isometry group consisting of the trivial isometry, the identity map"
}], "Text",
 CellChangeTimes->{{3.68709828631015*^9, 3.687098341850225*^9}, {
  3.687098415609889*^9, 3.687098630728312*^9}, {3.6870986793442717`*^9, 
  3.687098849127426*^9}, {3.687098985126466*^9, 3.687099062838168*^9}, {
  3.687099105381782*^9, 3.6870991922291327`*^9}, {3.687243914159383*^9, 
  3.6872439153597803`*^9}, {3.69035662596419*^9, 3.690356625966838*^9}, {
  3.693547509825671*^9, 
  3.693547517721629*^9}},ExpressionUUID->"fc49d812-24d9-47b8-ba11-\
30aca4080185"],

Cell[BoxData[
 RowBox[{"?", "identity"}]], "Input",
 CellChangeTimes->{{3.687099212516328*^9, 
  3.6870992167241096`*^9}},ExpressionUUID->"52b062dd-559d-4495-b2fc-\
b1f52476c26f"],

Cell[BoxData[
 RowBox[{"identity", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellChangeTimes->{{3.6870992481687613`*^9, 
  3.6870992597883472`*^9}},ExpressionUUID->"d1e24684-bdbf-44d5-91c5-\
1317964a0f23"],

Cell[TextData[{
 "On the other hand, the isometry group E(n) of the n-dimensional Euclidean \
space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "07931407-b1e9-4aa1-9db7-f3348d206a87"],
 " contains all ",
 StyleBox["Euclidean transformations",
  FontColor->RGBColor[0, 0, 1]],
 " of this space,named the ",
 StyleBox["Euclidean group of  ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "a40d80d7-2d14-41d5-bede-d3075c7c7f32"],
 StyleBox[".",
  FontColor->GrayLevel[0]],
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["This is the subgroup of the affine group represented by the square \
 matrices of degree n+1, ",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.687099281869266*^9, 3.687099614193124*^9}, {
   3.6872446470977373`*^9, 3.687244673753395*^9}, {3.687244908895718*^9, 
   3.687244962351573*^9}, {3.687245008343237*^9, 3.687245021383099*^9}, 
   3.687245119278777*^9, {3.687245159822274*^9, 3.6872451698134403`*^9}, {
   3.6935538102081013`*^9, 3.693553818118943*^9}, 3.6935538791990843`*^9, {
   3.693553940350543*^9, 3.693553965221569*^9}, {3.693577844663247*^9, 
   3.693577922340497*^9}, {3.6935779621969833`*^9, 3.693577969412073*^9}, {
   3.693578070212143*^9, 3.693578107171715*^9}, 3.693578194403042*^9, {
   3.693578226810614*^9, 3.693578284122217*^9}, {3.693633406583632*^9, 
   3.6936334432388697`*^9}, {3.6936335290463657`*^9, 3.693633586197598*^9}, {
   3.6936336176297913`*^9, 3.693633647877419*^9}, {3.693633685197215*^9, 
   3.693633687133316*^9}, {3.693640605181938*^9, 3.69364061508573*^9}, {
   3.6936408837002707`*^9, 3.69364089100333*^9}, 
   3.693640939571253*^9},ExpressionUUID->"8a01e5e3-aa35-4fd7-99cc-\
921fbb4460ba"],

Cell[BoxData[
 RowBox[{"?", "afftr"}]], "Input",
 CellChangeTimes->{{3.6936338049319983`*^9, 3.693633807379776*^9}, {
  3.696230196535532*^9, 
  3.6962302078225*^9}},ExpressionUUID->"e00b0ad0-69a9-4634-8e9a-d530f30a6e22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"afftr", "[", 
   RowBox[{
    RowBox[{"matrix", "[", 
     RowBox[{"a", ",", "3"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"b", ",", "3"}], "]"}], ",", "3"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.6962323261846857`*^9, 3.6962323500646*^9}, {
  3.696232420425932*^9, 3.696232439087834*^9}, {3.696233930339656*^9, 
  3.696233947670526*^9}, {3.6962344893139687`*^9, 
  3.696234502358103*^9}},ExpressionUUID->"4a6bcf54-12f5-46cb-b77d-\
7d0b35651909"],

Cell["\<\
with n = dim, where matrix[a] is orthogonal. One can show that it is a \
manifold of dimension n(n+1)/2, the number of independent parameters defining \
an Euclidean transformation.\
\>", "Text",
 CellChangeTimes->{{3.693640215640519*^9, 3.693640277399775*^9}, {
   3.693640694180922*^9, 3.6936408226356564`*^9}, {3.693642583013586*^9, 
   3.69364259304573*^9}, {3.696082437943523*^9, 3.696082439295164*^9}, 
   3.6962339116467323`*^9},ExpressionUUID->"3c5961e9-3e0a-4bc3-b6db-\
85ce65790d24"],

Cell[TextData[{
 StyleBox["Example 6",
  FontColor->RGBColor[0, 0, 1]],
 ". We prove that the group of isometries of an Euclidean plane is the  \
Euclidean group E(2) of the plane .  This group,  can be represented as the \
group of all matrices of the form"
}], "Text",
 CellChangeTimes->{{3.687101250965632*^9, 3.6871012653187523`*^9}, {
   3.687101301364588*^9, 3.6871013063405027`*^9}, {3.687101417059936*^9, 
   3.687101452931395*^9}, {3.687245194013048*^9, 3.6872451948141108`*^9}, {
   3.687245840759904*^9, 3.6872458483599167`*^9}, {3.690286625121811*^9, 
   3.690286661034597*^9}, 3.693554443377411*^9, {3.693578204466263*^9, 
   3.6935782059069767`*^9}, 3.693578309521627*^9, {3.6936330492338877`*^9, 
   3.6936331674566727`*^9}, {3.693633210912768*^9, 
   3.693633211968483*^9}},ExpressionUUID->"de92fb83-858e-41f8-bcef-\
209fbddd714d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eu2", "[", 
   RowBox[{"\[Phi]_", ",", "a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "a", ",", "b"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], ",", 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", "\[Phi]", "]"}]}], ",", " ", 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "}"}]}], "}"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6870996329573183`*^9, 3.687099684481101*^9}, {
  3.6870997218089437`*^9, 3.687099759163515*^9}, {3.687099838436434*^9, 
  3.68709989666393*^9}, {3.687099948815503*^9, 3.687100000967444*^9}, {
  3.687100038518621*^9, 3.6871000490465813`*^9}, {3.6871000790947733`*^9, 
  3.687100114134955*^9}},ExpressionUUID->"3f492188-353c-4039-b39e-\
52ce526005f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eu2", "[", 
   RowBox[{"\[Phi]", ",", "a", ",", "b"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.6935542623475323`*^9, 
  3.69355430929141*^9}},ExpressionUUID->"a5be5376-187f-4bcf-8031-\
8f41a24531af"],

Cell[TextData[{
 "with determinant 1, the ",
 StyleBox["motions",
  FontColor->RGBColor[0, 0, 1]],
 " which preserve the orientation, joined with the set of the ",
 StyleBox["reflections",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.693554904309619*^9, 3.693554994572929*^9}, {
  3.693578351257374*^9, 
  3.693578404521006*^9}},ExpressionUUID->"30ba7a60-128c-4c35-a80c-\
b786e3c0d834"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], "}"}], ".", 
    RowBox[{"eu2", "[", 
     RowBox[{"\[Phi]", ",", "a", ",", "b"}], "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.693555037381239*^9, 
  3.693555285359321*^9}},ExpressionUUID->"d8393130-b9c3-42fd-9d2f-\
f54abb467ff0"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", "%", "]"}], "\[Equal]", " ", 
   RowBox[{"-", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.693555391515334*^9, 3.693555402434278*^9}, {
  3.693555452950488*^9, 3.693555456529603*^9}, {3.693555495757257*^9, 
  3.693555509169407*^9}},ExpressionUUID->"a57c58a9-b244-4817-bf77-\
010bc1c2600a"],

Cell[TextData[{
 "We embed the Euclidean plane ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "2"], TraditionalForm]],ExpressionUUID->
  "cc190e61-7865-4634-9b2a-365ca5f225df"],
 " into the Euclidean space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]],ExpressionUUID->
  "53871e45-9c86-4b3b-8ebc-ecd2be8b4835"],
 " as the set of all points with first coordinate 1. A parameter \
representation of this plane is"
}], "Text",
 CellChangeTimes->{{3.6872441288292418`*^9, 3.6872442165407887`*^9}, {
   3.687244269076599*^9, 3.687244308236062*^9}, {3.687244450882556*^9, 
   3.687244511618607*^9}, 3.687245209924985*^9, {3.68724540785951*^9, 
   3.6872454670390577`*^9}, {3.687245519794935*^9, 3.6872455473543158`*^9}, {
   3.6872457078013353`*^9, 3.6872457149076757`*^9}, {3.693555858774741*^9, 
   3.693555862413929*^9}, {3.6935559383257923`*^9, 3.693555941245434*^9}, {
   3.693578686111944*^9, 3.693578712015627*^9}, 
   3.69357876722386*^9},ExpressionUUID->"5e2ca991-057a-4556-b640-\
022b18433a86"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fpl", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", "u", ",", "v"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.693578779570139*^9, 3.69357880871908*^9}, {
  3.6935788564385023`*^9, 
  3.693578894063137*^9}},ExpressionUUID->"b6d1fa77-573f-44e3-a88a-\
fd99035225c6"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"fpl", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6935789010256853`*^9, 
  3.6935789671578836`*^9}},ExpressionUUID->"c63a0cb0-46f4-450e-a64b-\
7160b59c450e"],

Cell[BoxData[
 RowBox[{"?", "fund1"}]], "Input",
 CellChangeTimes->{{3.693579618801859*^9, 
  3.693579623954295*^9}},ExpressionUUID->"ed812b89-c9d1-4a60-9576-\
e0afd5640b07"],

Cell["\<\
The first fundamental form of the plane is the Dot product of the tangent \
vectors.\
\>", "Text",
 CellChangeTimes->{{3.693579537562193*^9, 3.693579572001767*^9}, {
  3.693579806024629*^9, 
  3.693579834568535*^9}},ExpressionUUID->"d68bb581-21b7-4cab-841a-\
bd1099903db8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund1", "[", "fpl", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], ",", 
   RowBox[{"vec", "[", "b", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.693579588681478*^9, 3.69357961004218*^9}, {
  3.693579645034438*^9, 3.693579668441786*^9}, {3.696234873867364*^9, 
  3.69623488497104*^9}},ExpressionUUID->"67da134c-25e2-4365-9263-\
0731d94e2334"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], ".", 
   RowBox[{"vec", "[", "b", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.693579698579259*^9, 3.693579759041357*^9}, {
  3.696234908027055*^9, 
  3.696234936282022*^9}},ExpressionUUID->"6d374882-d088-41f4-9056-\
81bd0f6d4b11"],

Cell["\<\
Clearly, each Euclidean transformation of the plane preserves the Dot product \
of the tangent vectors; therefore it preserves the arc length of plane curves\
\>", "Text",
 CellChangeTimes->{{3.693579963588553*^9, 3.693580108735016*^9}, {
  3.693580161502586*^9, 
  3.6935802687823343`*^9}},ExpressionUUID->"b46f75e6-4fe0-41bd-824e-\
4990e09469eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cu", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"fpl", "[", 
   RowBox[{
    RowBox[{"h1", "[", "t", "]"}], ",", 
    RowBox[{"h2", "[", "t", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.693580272234838*^9, 
  3.693580313702116*^9}},ExpressionUUID->"6309df72-5691-421d-a68f-\
5b71aaf85b27"],

Cell[BoxData[
 RowBox[{"?", "arc"}]], "Input",
 CellChangeTimes->{{3.693580842279551*^9, 
  3.6935808451708508`*^9}},ExpressionUUID->"b35486ca-320e-4a49-9247-\
4b839f05de26"],

Cell[BoxData[
 RowBox[{"arc", "[", 
  RowBox[{"cu", ",", "t", ",", "0", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6935808590240507`*^9, 
  3.693580880986486*^9}},ExpressionUUID->"4396a36a-98f8-4d87-8f9f-\
7d1860696877"],

Cell["The image curve is", "Text",
 CellChangeTimes->{{3.693581009825033*^9, 
  3.693581017889194*^9}},ExpressionUUID->"7bacae35-826c-4761-9c6c-\
37862c5d4486"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cuu", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"eu2", "[", 
     RowBox[{"\[Phi]", ",", "a", ",", "b"}], "]"}], ".", 
    RowBox[{"cu", "[", "t", "]"}]}]}], ";", 
  RowBox[{"cuu", "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.693580410058384*^9, 
  3.69358055638859*^9}},ExpressionUUID->"63d5d134-114c-4131-b3f1-\
fda45f238f82"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"arc", "[", 
    RowBox[{"cu", ",", "t", ",", "0", ",", "t"}], "]"}], "==", 
   RowBox[{"arc", "[", 
    RowBox[{"cuu", ",", "t", ",", "0", ",", "t"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.693581032665616*^9, 
  3.693581073889572*^9}},ExpressionUUID->"d33b4b6f-e017-4c17-94e4-\
7b933834ba0a"],

Cell["Also the indefinite integrals coincide:", "Text",
 CellChangeTimes->{{3.693581107752501*^9, 
  3.693581124896269*^9}},ExpressionUUID->"45d8248c-72e6-4bcb-8659-\
f1366f548eaa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"arclength", "[", "cu", "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.693580327667753*^9, 
  3.6935803444381113`*^9}},ExpressionUUID->"ac9bf885-897c-42f4-bf87-\
c00b5d8961a8"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"arclength", "[", "cu", "]"}], "[", "t", "]"}], "==", 
   RowBox[{
    RowBox[{"arclength", "[", "cuu", "]"}], "[", "t", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.693580579624147*^9, 3.693580588173553*^9}, {
  3.693580706868601*^9, 
  3.693580774907188*^9}},ExpressionUUID->"b5fd850e-f6cb-4333-bf3a-\
3f2058ceff94"],

Cell["\<\
Thus any Euclidean motion is an isometry. The same calculation is valid  also \
for the reflections. Thus the Euclidean group consists of isometries of the \
plane. Conversely, let F be an isometry of the plane. Since lines are the \
uniquely defined shortest connections of any pair of their points,  F must \
transform lines into lines. Since F is bijective, parallel lines must be \
transformed into parallel lines; thus F must be an affine transformation of \
the plane. Consider the line spanned by the vector \
\>", "Text",
 CellChangeTimes->{{3.6872441288292418`*^9, 3.6872442165407887`*^9}, {
   3.687244269076599*^9, 3.687244308236062*^9}, {3.687244450882556*^9, 
   3.687244511618607*^9}, 3.687245209924985*^9, {3.68724540785951*^9, 
   3.6872454670390577`*^9}, {3.687245519794935*^9, 3.6872455473543158`*^9}, {
   3.6872457078013353`*^9, 3.6872457149076757`*^9}, {3.693555858774741*^9, 
   3.693555862413929*^9}, {3.6935559383257923`*^9, 3.693555941245434*^9}, {
   3.693578686111944*^9, 3.693578712015627*^9}, {3.693581159096168*^9, 
   3.693581253488079*^9}, {3.693581284751439*^9, 3.69358139789495*^9}, 
   3.6936275286944532`*^9, {3.693627607029619*^9, 3.693627658700883*^9}, {
   3.6936276955171537`*^9, 3.6936277848845577`*^9}, {3.693627816916176*^9, 
   3.693627848643887*^9}, {3.693628040626354*^9, 3.6936281373856497`*^9}, {
   3.6936281711778507`*^9, 3.693628173281962*^9}, {3.693628229936335*^9, 
   3.693628281616034*^9}, 
   3.6936427211249228`*^9},ExpressionUUID->"ec708b96-9871-40fc-be84-\
a3e44ed36bd1"],

Cell[BoxData[
 RowBox[{"va", " ", "=", " ", 
  RowBox[{"vector", "[", "a", "]"}]}]], "Input",
 CellChangeTimes->{{3.693628300624956*^9, 3.6936283262323008`*^9}, 
   3.696235152672426*^9},ExpressionUUID->"63c3831a-8dbb-439e-a079-\
f3942d384026"],

Cell["through the origin", "Text",
 CellChangeTimes->{{3.693628332724409*^9, 3.693628342543981*^9}, {
  3.693628379977441*^9, 
  3.693628396334839*^9}},ExpressionUUID->"b073b776-31e5-4811-b20a-\
635634942684"],

Cell[BoxData[
 RowBox[{"o", "=", 
  RowBox[{"stb", "[", 
   RowBox[{"1", ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.693628406235289*^9, {3.6936284402230883`*^9, 3.6936284513109627`*^9}, {
   3.696235233891899*^9, 
   3.696235235767673*^9}},ExpressionUUID->"a557014b-a7b2-4ec1-9a77-\
43d0d52fb399"],

Cell["with parameter representation", "Text",
 CellChangeTimes->{{3.693628501517742*^9, 
  3.693628515757687*^9}},ExpressionUUID->"5b330d4c-ee92-4d13-b28c-\
7ff33f92dd2f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"px", "[", "t_", "]"}], " ", "=", " ", 
  RowBox[{"o", "+", 
   RowBox[{"va", "*", "t", " "}]}]}]], "Input",
 CellChangeTimes->{{3.693628526973352*^9, 3.693628587821788*^9}, 
   3.693631597414006*^9},ExpressionUUID->"453a076f-e898-4832-a9f3-\
499bcf70f47f"],

Cell["Then the image of this line by the affine isometry is", "Text",
 CellChangeTimes->{{3.6936285967782183`*^9, 3.6936286536845207`*^9}, {
  3.69363138684015*^9, 
  3.6936313978228703`*^9}},ExpressionUUID->"58c0b79e-052f-4b57-9b5d-\
f2d3ef7731c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"py", "[", " ", "t_", "]"}], "=", 
  RowBox[{"po", " ", "+", " ", 
   RowBox[{
    RowBox[{"F", "[", "va", "]"}], "*", " ", "t"}]}]}]], "Input",
 CellChangeTimes->{{3.693631447864655*^9, 3.693631540926189*^9}, 
   3.6936317243829937`*^9},ExpressionUUID->"f2e8eb1a-f3d9-4034-9731-\
4f70c88c56f4"],

Cell["For the arc length we have, since F is an isometry", "Text",
 CellChangeTimes->{{3.693631632288312*^9, 
  3.6936317012301493`*^9}},ExpressionUUID->"374e7e28-7530-49dd-a263-\
5814076b74cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"arc", "[", 
   RowBox[{"px", ",", "t", ",", "0", ",", "t"}], "]"}], "\[Equal]", " ", 
  RowBox[{"arc", "[", 
   RowBox[{"py", ",", "t", ",", "0", ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.693631735466196*^9, 
  3.693631779492559*^9}},ExpressionUUID->"89572722-33e3-4b94-90b9-\
19a9e60269b5"],

Cell["\<\
and it follows for the arbitrary vector va the invariance of the scalar square\
\>", "Text",
 CellChangeTimes->{{3.693631966170416*^9, 3.6936319987300777`*^9}, 
   3.693632053817849*^9, {3.693632145041089*^9, 3.6936321630246267`*^9}, {
   3.6936321983845577`*^9, 3.69363221565646*^9}, 
   3.693632850843218*^9},ExpressionUUID->"7f405db4-c5af-401b-8e32-\
aa6155c75ae4"],

Cell[BoxData["va"], "Input",
 CellChangeTimes->{{3.707372167607802*^9, 
  3.70737216848131*^9}},ExpressionUUID->"5e3683e7-137f-48f2-a7a6-\
57c2499b00d9"],

Cell[BoxData[
 RowBox[{"F", "[", "va", "]"}]], "Input",
 CellChangeTimes->{{3.707372182600792*^9, 
  3.707372189063599*^9}},ExpressionUUID->"2726d666-ab84-4a36-8bff-\
a8201fc3d554"],

Cell[BoxData[
 RowBox[{
  RowBox[{"va", ".", "va"}], " ", "==", " ", 
  RowBox[{
   RowBox[{"F", "[", "va", "]"}], ".", 
   RowBox[{"F", "[", "va", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.69363210659453*^9, 3.69363213252943*^9}, 
   3.707372265916554*^9},ExpressionUUID->"e8ec50a4-a598-4b96-945c-\
b914337f43a6"],

Cell["Using the identity", "Text",
 CellChangeTimes->{{3.693632265943941*^9, 
  3.6936322747840014`*^9}},ExpressionUUID->"84927f7f-7835-4aba-9954-\
a592c37ca36a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"va", " ", ".", "vb"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"va", "+", "vb"}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{"va", "+", "vb"}], ")"}]}], " ", "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"va", "-", "vb"}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{"va", "-", "vb"}], ")"}]}]}], ")"}], "/", "4"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6936323127463703`*^9, 3.6936323988956633`*^9}, {
  3.693632445248023*^9, 
  3.6936324803263807`*^9}},ExpressionUUID->"e2c90dbf-892e-44af-b51a-\
8fbf81ef3afc"],

Cell["\<\
and the linearity  of F we conclude, that the action of the affine map F on \
the vector space of the plane is orthogonal, thus the matrix  mc defining \
this action must be orthogonal too, and F is an Euclidean transformation. \
\[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.6936324921744556`*^9, 3.6936326208287067`*^9}, {
  3.693632654413175*^9, 3.693632813737513*^9}, {3.693632892707397*^9, 
  3.693632899939232*^9}},ExpressionUUID->"20aa9d42-0df8-4fcc-a460-\
e0382cfd0a22"],

Cell[TextData[{
 "Analogously one proves for n\[GreaterEqual]2\n",
 StyleBox["Proposition 3",
  FontColor->RGBColor[0, 0, 1]],
 ". The isometry group of the Euclidean Space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "5e3aa7ef-ed08-43dd-917b-76a97f17f959"],
 " is the group of Euclidean Transformations E(n) defined above. \
\[FilledSmallSquare]\nThe case n=1 can be shown directly: The group consists \
of all translations combine wit reflections  at points: f[x] = \[PlusMinus]x \
+a.  \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.6936429939062033`*^9, 3.693643016889735*^9}, {
   3.693643083345634*^9, 3.693643302095913*^9}, {3.6936433376316833`*^9, 
   3.6936435443744707`*^9}, {3.693643647405777*^9, 3.693643649461787*^9}, {
   3.693654871920143*^9, 3.693654902600464*^9}, 
   3.693654938161001*^9},ExpressionUUID->"e55dfd8d-1baa-466a-85b8-\
1afb1f228e12"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2.4. Transformations. Tangent Bundle", "Subsubsection",
 CellChangeTimes->{{3.6870760717190933`*^9, 3.687076074486999*^9}, {
   3.6872617212004147`*^9, 3.687261728016395*^9}, {3.687261859527289*^9, 
   3.687261885783373*^9}, {3.689837531491288*^9, 3.689837562778967*^9}, 
   3.690356504153872*^9, 3.696235768427848*^9, 
   3.696256610107397*^9},ExpressionUUID->"3c41b8fd-833c-462d-8b54-\
7d335841ceb3"],

Cell["\<\
Again we consider as in Subsection 1.2.3 a map F: sf[U]\[RightArrow]sh[UU] \
constructed with the local diffeomorphism f:U\[RightArrow]UU.  We use the \
same definitions of F and f as there, see formulas (1)-(3);  therefore \
evaluate now Subsection 1.2.3 if not yet done.
The tangent vector of the image curve \
\>", "Text",
 CellChangeTimes->{{3.588676867469983*^9, 3.5886768700439873`*^9}, 
   3.5886770860263667`*^9, {3.5890026335835457`*^9, 3.5890026564708548`*^9}, 
   3.5995674706898913`*^9, {3.687076018794739*^9, 3.687076018797014*^9}, {
   3.6872622543004*^9, 3.6872624580350018`*^9}, {3.687262648625778*^9, 
   3.687262783664727*^9}, {3.6872628171366253`*^9, 3.687262873360362*^9}, {
   3.687262932593424*^9, 3.6872629431599503`*^9}, {3.687263004655457*^9, 
   3.687263014927423*^9}, {3.6872630453519363`*^9, 3.687263078470894*^9}, {
   3.689310658146212*^9, 
   3.689310672962015*^9}},ExpressionUUID->"2fd01094-027d-4e72-8ba2-\
8e4b484a83a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F\[Gamma]", "[", "t", "]"}], " ", "=", "  ", 
  RowBox[{
   RowBox[{"F", "[", 
    RowBox[{"sf", "[", 
     RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "]"}], "\[Equal]", " ", 
   RowBox[{"sh", "[", 
    RowBox[{"f", "[", 
     RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.687263085124465*^9, 3.687263173590769*^9}, {
  3.6893107348342543`*^9, 3.689310741874151*^9}, {3.69348687926295*^9, 
  3.693486879266675*^9}, {3.696235835739541*^9, 
  3.6962358439471684`*^9}},ExpressionUUID->"9fdb2383-8c96-4fc4-aa33-\
62051fe24650"],

Cell[BoxData[
 RowBox[{"F\[Gamma]", "[", "t", "]"}]], "Input",
 CellChangeTimes->{
  3.6934868792763844`*^9},ExpressionUUID->"692eec10-7916-49c0-a507-\
9cbf0eed1b9a"],

Cell["is", "Text",
 CellChangeTimes->{{3.687263220205207*^9, 
  3.6872632206530457`*^9}},ExpressionUUID->"90b45682-8c4a-4603-8181-\
a18c9c1a70b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F\[Gamma]", "'"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.5886768793416033`*^9, 3.5886769396825094`*^9}, {
   3.5890062311063128`*^9, 3.5890062466492014`*^9}, {3.617703363419731*^9, 
   3.6177033783065825`*^9}, {3.687262509302026*^9, 3.687262511051553*^9}, 
   3.693486879286243*^9},ExpressionUUID->"65d5d34b-fdff-4185-b849-\
a952e7c5561b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"F\[Gamma]", "'"}], "[", "t", "]"}], " ", "==", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sh", "]"}], "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{
        RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
        RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}], ",", 
      RowBox[{"f2", "[", 
       RowBox[{
        RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
        RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}]}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"f1", "[", 
         RowBox[{
          RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}], ",", "t"}], "]"}], 
      ",", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"f2", "[", 
         RowBox[{
          RowBox[{"\[Gamma]1", "[", "t", "]"}], ",", 
          RowBox[{"\[Gamma]2", "[", "t", "]"}]}], "]"}], ",", "t"}], "]"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5886777739251747`*^9, 3.5886777838623924`*^9}, 
   3.588677815093647*^9, 3.58867788471657*^9, 3.588678039718442*^9, {
   3.5886784767844095`*^9, 3.5886784915264354`*^9}, 3.588678564362963*^9, 
   3.5886786037374325`*^9, {3.5886786817843695`*^9, 3.588678690676385*^9}, {
   3.588678745182881*^9, 3.5886787995021763`*^9}, {3.5886788985935507`*^9, 
   3.588678939902423*^9}, {3.588947001143866*^9, 3.5889470423591385`*^9}, {
   3.687262556888351*^9, 3.687262557123844*^9}, 3.68726747046024*^9, {
   3.693486879298315*^9, 
   3.693486879314486*^9}},ExpressionUUID->"b18349f8-8aa4-4e4c-b235-\
8bcc049c1a29"],

Cell[TextData[{
 "Thus we get\n",
 StyleBox["Lemma 2",
  FontColor->RGBColor[0, 0, 1]],
 ". The tangent vector of the image curve is obtained composing the \
differential d[sh] with the differential d[f] applied to the tangent vector \
of the preimage.   \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.5889473808953333`*^9, 3.588947383016937*^9}, {
   3.589002927767372*^9, 3.5890030386547146`*^9}, {3.5890034142311964`*^9, 
   3.58900342374374*^9}, {3.5890036758001575`*^9, 3.5890036774552517`*^9}, {
   3.5891127612773533`*^9, 3.589112761698554*^9}, {3.687268405709424*^9, 
   3.687268421669221*^9}, {3.687268526020619*^9, 3.6872686022598763`*^9}, {
   3.6873347614433603`*^9, 3.6873347626149483`*^9}, 3.687334807018393*^9, {
   3.68931089680767*^9, 
   3.6893108968091097`*^9}},ExpressionUUID->"4196591e-c9ab-45e2-8fca-\
83b9282c77fb"],

Cell[TextData[{
 "Denote the surfaces SF = sf[U], SH =sh[UU]. We remark that every tangent \
vector ",
 Cell[BoxData[
  RowBox[{"\[GothicT]", "\[Element]", " ", 
   RowBox[{
    SubscriptBox["T", "u"], " ", "SF"}]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.687326906661622*^9, 3.6873270652063427`*^9}, {
   3.687327096136034*^9, 3.6873271035987387`*^9}, {3.6873275789789257`*^9, 
   3.6873275806343937`*^9}, {3.687332025589939*^9, 3.687332030645768*^9}},
  ExpressionUUID->"fb0c8205-eb85-4f2f-95fd-8ea5767fb2db"],
 " with coordinates ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["th", "U"], "[", "\[GothicT]", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"u1", ",", "u2", ",", "\[Xi]1", ",", "\[Xi]2"}], "}"}]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.68732443676053*^9, 3.68732447979003*^9}, {
    3.68732451134757*^9, 3.687324606322544*^9}, {3.687324648384639*^9, 
    3.6873246549782352`*^9}, {3.687324689530624*^9, 3.687324699329584*^9}, {
    3.6873247312126904`*^9, 3.687324759201103*^9}, {3.6873248081772614`*^9, 
    3.687324814171988*^9}, 3.687324892425655*^9, 3.687325004568611*^9, {
    3.687325063446603*^9, 3.687325071070591*^9}, {3.68732513787784*^9, 
    3.687325146782296*^9}, {3.687325189427127*^9, 3.687325204957716*^9}, {
    3.687325542194747*^9, 3.687325592290525*^9}, {3.687325625466267*^9, 
    3.687325640218268*^9}, {3.6873256964022627`*^9, 3.687325721194049*^9}},
  ExpressionUUID->"8d801317-04be-4222-a5f9-1b9ddf98d6cb"],
 " is the tangent vector of certain curves through the point sf[u], e.g."
}], "Text",
 CellChangeTimes->{{3.687330199499147*^9, 3.687330232210848*^9}, 
   3.687331750615272*^9, {3.687331913182273*^9, 3.687331934328946*^9}, {
   3.6873319692380953`*^9, 3.687332007790091*^9}, {3.6873320651873093`*^9, 
   3.687332131260971*^9}, {3.68733218410071*^9, 3.687332186068684*^9}, {
   3.690037599889701*^9, 
   3.690037605269782*^9}},ExpressionUUID->"1a61c890-2b01-4772-8f70-\
89babbc362eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cu", "[", "t_", "]"}], " ", "=", " ", 
   RowBox[{"sf", "[", 
    RowBox[{
     RowBox[{"u1", "+", 
      RowBox[{"t", "*", "\[Xi]1"}]}], ",", 
     RowBox[{"u2", "+", 
      RowBox[{"t", "*", "\[Xi]2"}]}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"cu", "'"}], "[", "t", "]"}], "/.", 
   RowBox[{"t", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.687332189893588*^9, 
  3.68733236645999*^9}},ExpressionUUID->"1f344dea-9282-4e31-a173-\
624d424798f9"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "==", 
   RowBox[{
    RowBox[{
     RowBox[{"tangsp", "[", "sf", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], "[", 
    RowBox[{"\[Xi]1", ",", "\[Xi]2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.687332415063002*^9, 3.687332418138968*^9}, 
   3.687332467620081*^9, {3.687332499232113*^9, 3.68733250789146*^9}, {
   3.687332584919332*^9, 
   3.687332666162277*^9}},ExpressionUUID->"e74c2cf4-5f51-4b65-92ce-\
07aed201fe81"],

Cell["\<\
Thus the differential d[F][u1,u2] is well defined as a linear map ( with u = \
{u1,u2})\
\>", "Text",
 CellChangeTimes->{{3.690038198640726*^9, 3.6900383283680964`*^9}, {
   3.690038494438685*^9, 3.690038513518796*^9}, 
   3.690038692900939*^9},ExpressionUUID->"f9336e3b-79bd-4e94-841e-\
d413214cbe8f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "F", "]"}], "[", "u", "]"}], ":", " ", 
  RowBox[{
   RowBox[{
    SubscriptBox["T", "u"], " ", "SF"}], " ", "\[RightArrow]", 
   RowBox[{
    SubscriptBox["T", 
     RowBox[{"f", "[", "u", "]"}]], " ", "SH", "                                                                ", 
    RowBox[{"(", "4", ")"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.690038333230863*^9, 3.690038359160365*^9}, {
   3.6900384005436983`*^9, 3.6900384840556183`*^9}, 3.690038703982098*^9, {
   3.690038755693036*^9, 
   3.690038764237092*^9}},ExpressionUUID->"1db6763a-aedc-46f6-bfe9-\
37a76d2492e0"],

Cell[TextData[{
 StyleBox["Lemma 3. ",
  FontColor->RGBColor[0, 0, 1]],
 "Let f: U\[RightArrow]UU be a smooth map, f and F as defined above. Then (4) \
defines a family of linear maps smoothly depending on u=  {u1,u2}.The map \
d[F] is the composition of the differentials "
}], "Text",
 CellChangeTimes->{{3.690038574843845*^9, 3.690038660917066*^9}, {
  3.690038770388524*^9, 3.690038817572057*^9}, {3.6900388519962*^9, 
  3.690038914514903*^9}},ExpressionUUID->"0853b47b-0bf4-4b66-8fbc-\
e70a113cdb52"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "F", "]"}], "[", "u", "]"}], " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sh", "]"}], "[", 
    RowBox[{"f", "[", "u", "]"}], "]"}], ".", 
   RowBox[{"df", "[", "u", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.690038933254972*^9, 
  3.6900390722185717`*^9}},ExpressionUUID->"db4e7881-5b42-4d67-a49f-\
363c1260f8b5"],

Cell[TextData[{
 StyleBox["Proof. ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["The  statement is a consequence of the chain rule:",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.690039119597662*^9, 3.6900391255935583`*^9}, 
   3.6900392292351227`*^9, {3.690085532140306*^9, 3.690085548188066*^9}, {
   3.690085583475952*^9, 
   3.690085629755418*^9}},ExpressionUUID->"5b32d196-fea6-4d7a-8f73-\
f426bb7fa4e5"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "F", "]"}], "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sh", "]"}], "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{"u1", ",", "u2"}], "]"}], ",", 
      RowBox[{"f2", "[", 
       RowBox[{"u1", ",", "u2"}], "]"}]}], "]"}], ".", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.690036525845875*^9, 3.690036537357874*^9}, 
   3.690036581704365*^9, 3.690036639734949*^9, 3.6900366727740707`*^9, 
   3.6900367104458513`*^9, {3.6900367664684353`*^9, 3.690036813268526*^9}, {
   3.690036845123787*^9, 3.6900368499874773`*^9}, {3.690036880676485*^9, 
   3.690036886451427*^9}, {3.6900369672572002`*^9, 3.6900369988749237`*^9}, {
   3.6900370292391357`*^9, 3.6900370538828917`*^9}, 3.6900370885145617`*^9, {
   3.69003915965734*^9, 
   3.690039209825864*^9}},ExpressionUUID->"47ba33d2-f97f-4e31-b507-\
d3faf7a9e898"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6900392660430393`*^9, 
  3.6900392660452843`*^9}},ExpressionUUID->"2348e1c3-86ed-4113-9026-\
b35804152d2d"],

Cell[TextData[{
 "The ",
 StyleBox["tangent bundle",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"TSF", "  "}], TraditionalForm]],ExpressionUUID->
  "0bb53c41-5de5-420c-b93c-92849918cf7a"],
 "of the surface SF is the set of all pairs {u, \[GothicT]}, \[GothicT] a \
tangent vector of SF at the point sf[u]:"
}], "Text",
 CellChangeTimes->{{3.687269459442853*^9, 3.687269581444014*^9}, {
   3.687269620643612*^9, 3.687269671227234*^9}, {3.687269732186614*^9, 
   3.687269734570643*^9}, 3.6872697979941483`*^9, 3.687269834065729*^9, {
   3.687269878624425*^9, 3.687269913387372*^9}, {3.6872699544333277`*^9, 
   3.687269992304908*^9}, {3.687270032528637*^9, 3.687270054984274*^9}, {
   3.687270491860989*^9, 3.687270497412898*^9}, {3.687272745565853*^9, 
   3.687272781955392*^9}, 3.689311041504472*^9, {3.6900858403142776`*^9, 
   3.6900859408812647`*^9}, {3.690086206767211*^9, 
   3.690086218735133*^9}},ExpressionUUID->"7cb662b2-ff8e-4170-b194-\
89ede5163b5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["T", "u"], " ", "SF"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[GothicT]", "|", 
     RowBox[{"\[GothicT]", "\[Equal]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"tangsp", "[", "sf", "]"}], "[", 
        RowBox[{"u1", ",", "u2"}], "]"}], "[", 
       RowBox[{"t1", ",", "t2"}], "]"}]}]}], ";", "  ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t1", ",", "t2"}], "}"}], "\[Element]", " ", 
     SuperscriptBox["R", "2"]}]}], "}"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.687270069498892*^9, 3.687270105616124*^9}, {
  3.687270253904826*^9, 3.687270330970984*^9}, {3.6872703661586437`*^9, 
  3.687270431669716*^9}, {3.6872705716629543`*^9, 3.687270583029397*^9}, {
  3.687270624973009*^9, 
  3.6872706676997967`*^9}},ExpressionUUID->"844271ca-ac92-4eed-bf92-\
ce31bb37fb01"],

Cell[BoxData[
 RowBox[{"?", "tangsp"}]], "Input",
 CellChangeTimes->{{3.6872707531454353`*^9, 
  3.687270757443637*^9}},ExpressionUUID->"6703e91f-6b8a-4d2e-a715-\
17e1d8e8963c"],

Cell[BoxData[
 RowBox[{"?", "tv"}]], "Input",
 CellChangeTimes->{{3.6900864849912567`*^9, 
  3.690086490621046*^9}},ExpressionUUID->"7cce37f9-52ae-43aa-ba21-\
57e6a2ebc32c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tangsp", "[", "sf", "]"}], "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], "[", 
   RowBox[{"t1", ",", "t2"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], "*", "t1"}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], "*", "t2"}]}]}]], "Input",
 CellChangeTimes->{{3.6900863511986732`*^9, 3.690086371701914*^9}, {
  3.690086426870432*^9, 3.690086466653391*^9}, {3.690086505788978*^9, 
  3.690086556420747*^9}},ExpressionUUID->"ec89b802-f5ed-49a4-afa5-\
d3a3e7179f3f"],

Cell[TextData[{
 "This is the vector subspace  of the Euclidean space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]],ExpressionUUID->
  "e7f22194-2034-462b-845f-07d46c342742"],
 " spanned by the tangent basis at the regular point sf[u1,u2] \[Element] SF, \
indexed by the point u={u1,u2} \[Element] U. This indexing is necessary: if \
the surface has self-intersections, sf[[u1,u2] ==sf[w1,w2] for {u1,u2}\
\[NotEqual][w1,w2}, then, at any rate, the tangent planes for these parameter \
values considered as subsets of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]],ExpressionUUID->
  "da94e2a9-4880-477d-888c-1cbad90bd1a7"],
 "  will have a non-trivial intersection.  But it is useful to distinguish \
the tangent planes of the intersecting leaves of the surface, each being \
locally a regular part of SF. By using the indexes always the intersection  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "u"], " ", "SF"}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.687270069498892*^9, 3.687270105616124*^9}, {
   3.687270253904826*^9, 3.687270330970984*^9}, {3.6872703661586437`*^9, 
   3.687270431669716*^9}, {3.6872705716629543`*^9, 3.687270583029397*^9}, {
   3.687270624973009*^9, 3.6872706676997967`*^9}},ExpressionUUID->
  "0c685012-8251-47a5-99de-148885ec6fc1"],
 "\[Intersection]",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "w"], " ", "SF"}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.687270069498892*^9, 3.687270105616124*^9}, {
   3.687270253904826*^9, 3.687270330970984*^9}, {3.6872703661586437`*^9, 
   3.687270431669716*^9}, {3.6872705716629543`*^9, 3.687270583029397*^9}, {
   3.687270624973009*^9, 3.6872706676997967`*^9}},ExpressionUUID->
  "eef5de32-3c4e-4348-b85c-625f7e551dfa"],
 " is empty for u\[NotEqual]w. Often one speaks about building a ",
 StyleBox["disjoint union",
  FontColor->RGBColor[0, 0, 1]],
 " if the indexing method is used, as now defining the ",
 StyleBox["tangent bundle of",
  FontColor->RGBColor[0, 0, 1]],
 " SF:"
}], "Text",
 CellChangeTimes->{{3.68727082429902*^9, 3.6872710157793217`*^9}, {
  3.687271118584054*^9, 3.6872711639358397`*^9}, {3.687271210319599*^9, 
  3.6872712215351133`*^9}, {3.687271352742494*^9, 3.68727164817264*^9}, {
  3.687271681396336*^9, 3.687271760436193*^9}, {3.68727181323558*^9, 
  3.687271823659741*^9}, {3.687271930106838*^9, 3.687271969946353*^9}, {
  3.687272000314253*^9, 3.687272375448516*^9}, {3.6872724342222548`*^9, 
  3.687272487368251*^9}, {3.687272796407674*^9, 
  3.687272844491087*^9}},ExpressionUUID->"1b788730-99ef-4b16-a168-\
cdcb15df0cde"],

Cell[BoxData[
 RowBox[{"TSF", " ", "=", 
  RowBox[{
   UnderscriptBox[
    RowBox[{" ", "\[Union]"}], 
    RowBox[{"u", "\[Element]", "U"}]], " ", 
   SubscriptBox["T", "u"], " ", "SF"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.687272492376625*^9, 
  3.687272579246892*^9}},ExpressionUUID->"d7f5776d-0e01-4a99-a6b0-\
ea356a21ead4"],

Cell[TextData[{
 "On  the tangent bundle TSF using the parameter representation of the \
surface the standard coordinates ",
 Cell[BoxData[
  SubscriptBox["th", "U"]], "Input",
  CellChangeTimes->{{3.68732443676053*^9, 3.68732447979003*^9}, {
    3.68732451134757*^9, 3.687324606322544*^9}, {3.687324648384639*^9, 
    3.6873246549782352`*^9}, {3.687324689530624*^9, 3.687324699329584*^9}, {
    3.6873247312126904`*^9, 3.687324759201103*^9}, {3.6873248081772614`*^9, 
    3.687324814171988*^9}, 3.687324892425655*^9, 3.687325004568611*^9, {
    3.687325063446603*^9, 3.687325071070591*^9}, {3.68732513787784*^9, 
    3.687325146782296*^9}, {3.687325189427127*^9, 3.687325204957716*^9}, {
    3.687325542194747*^9, 3.687325592290525*^9}, {3.687325625466267*^9, 
    3.687325640218268*^9}, {3.6873256964022627`*^9, 3.687325721194049*^9}},
  ExpressionUUID->"568b4553-46ea-4eea-80a9-6900aa664d79"],
 "[\[GothicT]] are defined:"
}], "Text",
 CellChangeTimes->{{3.68732391960074*^9, 3.6873239342650623`*^9}, {
  3.687324012911963*^9, 3.687324097310547*^9}, {3.68732419894965*^9, 
  3.6873242369574833`*^9}, {3.687324270349382*^9, 3.687324339340291*^9}, {
  3.687326407769034*^9, 
  3.687326420139146*^9}},ExpressionUUID->"29d5b716-a82c-4e84-9118-\
70c2e17a56c0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["th", "U"], ":", " ", 
    RowBox[{"\[GothicT]", "\[Element]", " ", 
     RowBox[{"TSF", " ", "\[RightTeeArrow]", " ", 
      RowBox[{
       SubscriptBox["th", "U"], "[", "\[GothicT]", "]"}]}]}]}], " ", ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u1", ",", "u2", ",", "\[Xi]1", ",", "\[Xi]2"}], "}"}], 
    "\[Element]", " ", 
    RowBox[{"U", "\[Times]", 
     SuperscriptBox["R", "2"], " ", "if"}]}]}], "  "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[GothicT]", "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"tangsp", "[", "sf", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], "[", 
    RowBox[{"\[Xi]1", ",", "\[Xi]2"}], "]"}]}], " ", "\[Element]", " ", 
  RowBox[{
   SubscriptBox["T", "u"], "sf"}]}]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.68732443676053*^9, 3.68732447979003*^9}, {
   3.68732451134757*^9, 3.687324606322544*^9}, {3.687324648384639*^9, 
   3.6873246549782352`*^9}, {3.687324689530624*^9, 3.687324699329584*^9}, {
   3.6873247312126904`*^9, 3.687324759201103*^9}, {3.6873248081772614`*^9, 
   3.687324814171988*^9}, 3.687324892425655*^9, 3.687325004568611*^9, {
   3.687325063446603*^9, 3.687325071070591*^9}, {3.68732513787784*^9, 
   3.687325146782296*^9}, {3.687325189427127*^9, 3.687325204957716*^9}, {
   3.687325542194747*^9, 3.687325592290525*^9}, {3.687325625466267*^9, 
   3.687325640218268*^9}, {3.6873256964022627`*^9, 
   3.687325721194049*^9}},ExpressionUUID->"dae48903-8840-4856-8353-\
b682bd9db8f3"],

Cell[TextData[{
 "The map ",
 Cell[BoxData[
  SubscriptBox["th", "U"]], "Input",
  CellChangeTimes->{{3.68732443676053*^9, 3.68732447979003*^9}, {
    3.68732451134757*^9, 3.687324606322544*^9}, {3.687324648384639*^9, 
    3.6873246549782352`*^9}, {3.687324689530624*^9, 3.687324699329584*^9}, {
    3.6873247312126904`*^9, 3.687324759201103*^9}, {3.6873248081772614`*^9, 
    3.687324814171988*^9}, 3.687324892425655*^9, 3.687325004568611*^9, {
    3.687325063446603*^9, 3.687325071070591*^9}, {3.68732513787784*^9, 
    3.687325146782296*^9}, {3.687325189427127*^9, 3.687325204957716*^9}, {
    3.687325542194747*^9, 3.687325592290525*^9}, {3.687325625466267*^9, 
    3.687325640218268*^9}, {3.6873256964022627`*^9, 3.687325721194049*^9}},
  ExpressionUUID->"5e0c19bb-c7e4-4642-b8e6-5d297a0e4d73"],
 " is bijective, its inverse is ",
 Cell[BoxData[
  SuperscriptBox[
   SubscriptBox["th", "U"], 
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}]]], "Input",
  CellChangeTimes->{{3.68732443676053*^9, 3.68732447979003*^9}, {
    3.68732451134757*^9, 3.687324606322544*^9}, {3.687324648384639*^9, 
    3.6873246549782352`*^9}, {3.687324689530624*^9, 3.687324699329584*^9}, {
    3.6873247312126904`*^9, 3.687324759201103*^9}, {3.6873248081772614`*^9, 
    3.687324814171988*^9}, 3.687324892425655*^9, 3.687325004568611*^9, {
    3.687325063446603*^9, 3.687325071070591*^9}, {3.68732513787784*^9, 
    3.687325146782296*^9}, {3.687325189427127*^9, 3.687325204957716*^9}, {
    3.687325542194747*^9, 3.687325592290525*^9}, {3.687325625466267*^9, 
    3.687325640218268*^9}, {3.6873256964022627`*^9, 3.687325721194049*^9}},
  ExpressionUUID->"ae286b6f-0ceb-46a6-860a-a4a5cc60d1c4"],
 "= tangsp[sf]. We take ",
 Cell[BoxData[
  SubscriptBox["th", "U"]], "Input",
  CellChangeTimes->{{3.68732443676053*^9, 3.68732447979003*^9}, {
    3.68732451134757*^9, 3.687324606322544*^9}, {3.687324648384639*^9, 
    3.6873246549782352`*^9}, {3.687324689530624*^9, 3.687324699329584*^9}, {
    3.6873247312126904`*^9, 3.687324759201103*^9}, {3.6873248081772614`*^9, 
    3.687324814171988*^9}, 3.687324892425655*^9, 3.687325004568611*^9, {
    3.687325063446603*^9, 3.687325071070591*^9}, {3.68732513787784*^9, 
    3.687325146782296*^9}, {3.687325189427127*^9, 3.687325204957716*^9}, {
    3.687325542194747*^9, 3.687325592290525*^9}, {3.687325625466267*^9, 
    3.687325640218268*^9}, {3.6873256964022627`*^9, 3.687325721194049*^9}},
  ExpressionUUID->"0c564eda-a279-4e06-9062-862d5fe38f18"],
 " as an diffeomorphism transferring the differentiable structure of ",
 Cell[BoxData[
  RowBox[{"U", "\[Times]", 
   SuperscriptBox["R", "2"]}]], "Input",
  CellChangeTimes->{{3.68732443676053*^9, 3.68732447979003*^9}, {
    3.68732451134757*^9, 3.687324606322544*^9}, {3.687324648384639*^9, 
    3.6873246549782352`*^9}, {3.687324689530624*^9, 3.687324699329584*^9}, {
    3.6873247312126904`*^9, 3.687324759201103*^9}, {3.6873248081772614`*^9, 
    3.687324814171988*^9}, 3.687324892425655*^9, 3.687325004568611*^9, {
    3.687325063446603*^9, 3.687325071070591*^9}, {3.68732513787784*^9, 
    3.687325146782296*^9}, {3.687325189427127*^9, 3.687325204957716*^9}, {
    3.687325542194747*^9, 3.687325592290525*^9}, {3.687325625466267*^9, 
    3.687325640218268*^9}, {3.6873256964022627`*^9, 3.687325721194049*^9}},
  ExpressionUUID->"33720282-e2b3-4ae9-98da-9b36e55cd3d3"],
 " to TSF. The ",
 StyleBox["projection",
  FontColor->RGBColor[0, 0, 1]],
 " p of the tangent bundle is defined as"
}], "Text",
 CellChangeTimes->{{3.68732605772586*^9, 3.687326222828265*^9}, {
   3.68732646400277*^9, 3.6873264937546167`*^9}, {3.687326699137046*^9, 
   3.6873267154648848`*^9}, {3.687326756923218*^9, 3.687326896599566*^9}, 
   3.687327230669116*^9},ExpressionUUID->"b65527f9-20e6-4e1d-a063-\
f96f2093a94b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"p", ":", " ", 
    RowBox[{"\[GothicT]", " ", "\[Element]", " ", 
     RowBox[{"TSF", " ", "\[RightTeeArrow]", " ", 
      RowBox[{"p", "[", "\[GothicT]", "]"}]}]}]}], " ", ":=", 
   RowBox[{"u", "\[Element]", " ", "U"}]}], ",", "  ", 
  RowBox[{
   RowBox[{"if", "  ", "\[GothicT]"}], "\[Element]", " ", 
   RowBox[{
    SubscriptBox["T", "u"], " ", 
    RowBox[{"SF", "."}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.687326906661622*^9, 3.6873270652063427`*^9}, {
  3.687327096136034*^9, 3.6873271035987387`*^9}, {3.6873275789789257`*^9, 
  3.6873275806343937`*^9}, {3.687332025589939*^9, 
  3.687332030645768*^9}},ExpressionUUID->"389c0dd9-778e-446f-a2e2-\
1d2c37fb269e"],

Cell[TextData[{
 "The preimages ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["p", 
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}]], TraditionalForm]],ExpressionUUID->
  "b60db825-00e1-4cc0-acfe-15bf8c94629d"],
 "[u] == ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "u"], " ", "SF"}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.687326906661622*^9, 3.6873270652063427`*^9}, {
   3.687327096136034*^9, 3.6873271035987387`*^9}},ExpressionUUID->
  "1cd3b192-3028-429e-87af-7a646cea873d"],
 " are the ",
 StyleBox["fibers",
  FontColor->RGBColor[0, 0, 1]],
 " of the bundle; the fibers are  two-dimensional Euclidean vector spaces as \
subspaces of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]],ExpressionUUID->
  "aef0fec1-0820-4f5b-b233-ca4502881987"],
 " such that \n tangsp[sf][u]: \[GothicT]",
 Cell[BoxData[
  RowBox[{"\[Element]", 
   RowBox[{
    SuperscriptBox["R", "2"], "\[RightTeeArrow]"}]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.68732443676053*^9, 3.68732447979003*^9}, {
    3.68732451134757*^9, 3.687324606322544*^9}, {3.687324648384639*^9, 
    3.6873246549782352`*^9}, {3.687324689530624*^9, 3.687324699329584*^9}, {
    3.6873247312126904`*^9, 3.687324759201103*^9}, {3.6873248081772614`*^9, 
    3.687324814171988*^9}, 3.687324892425655*^9, 3.687325004568611*^9, {
    3.687325063446603*^9, 3.687325071070591*^9}, {3.68732513787784*^9, 
    3.687325146782296*^9}, {3.687325189427127*^9, 3.687325204957716*^9}, {
    3.687325542194747*^9, 3.687325592290525*^9}, {3.687325625466267*^9, 
    3.687325640218268*^9}, {3.6873256964022627`*^9, 3.687325721194049*^9}},
  ExpressionUUID->"50528b07-e615-4d95-9f21-e1d1595c2bbf"],
 " tangsp[sf][u][\[GothicT]]\[Element]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["p", 
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}]], TraditionalForm]],ExpressionUUID->
  "1c9fb9f2-6739-447f-b06f-5c7848f252de"],
 "[u]  are linear isomorphisms:"
}], "Text",
 CellChangeTimes->{{3.687327307739547*^9, 3.6873273644836807`*^9}, {
   3.6873274523228817`*^9, 3.687327555786201*^9}, {3.687327590610176*^9, 
   3.687327704641395*^9}, {3.687327739464861*^9, 3.6873278088006277`*^9}, {
   3.687327840691766*^9, 3.687327864808181*^9}, {3.687327898544033*^9, 
   3.687327925295743*^9}, {3.687327958038332*^9, 3.687327958041122*^9}, 
   3.687328006302129*^9, {3.687328041676355*^9, 3.68732804167651*^9}, {
   3.687328073312778*^9, 3.68732810877073*^9}, {3.687328142294456*^9, 
   3.687328185925646*^9}, {3.687328238991867*^9, 3.687328238994739*^9}, {
   3.687328352384758*^9, 3.68732839885198*^9}, {3.689311489517516*^9, 
   3.6893115468288603`*^9}, {3.6900868374025803`*^9, 3.690086856770191*^9}, {
   3.6901249027713737`*^9, 
   3.690124914761018*^9}},ExpressionUUID->"7e3ee5ca-d782-4e67-8abe-\
80c4c9b83729"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"tangsp", "[", "sf", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], "[", 
    RowBox[{"lts", "[", 
     RowBox[{
      RowBox[{"a", "*", 
       RowBox[{"vec", "[", 
        RowBox[{"\[Xi]", ",", "2"}], "]"}]}], "+", 
      RowBox[{"b", "*", 
       RowBox[{"vec", "[", 
        RowBox[{"\[Eta]", ",", "2"}], "]"}]}]}], "]"}], "]"}], "\[Equal]", 
   " ", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"tangsp", "[", "sf", "]"}], "[", 
       RowBox[{"u1", ",", "u2"}], "]"}], "[", 
      RowBox[{"lts", "[", 
       RowBox[{"vec", "[", 
        RowBox[{"\[Xi]", ",", "2"}], "]"}], "]"}], "]"}]}], "+", " ", 
    RowBox[{"b", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"tangsp", "[", "sf", "]"}], "[", 
       RowBox[{"u1", ",", "u2"}], "]"}], "[", 
      RowBox[{"lts", "[", 
       RowBox[{"vec", "[", 
        RowBox[{"\[Eta]", ",", "2"}], "]"}], "]"}], "]"}]}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.687328528471493*^9, 3.6873285439546328`*^9}, {
   3.687328630337579*^9, 3.687328821184127*^9}, {3.6873288583811493`*^9, 
   3.68732898265561*^9}, {3.687329013446404*^9, 3.687329140070517*^9}, 
   3.687329173548992*^9, {3.687329257164385*^9, 3.687329293764282*^9}, {
   3.687329339566725*^9, 3.687329357307384*^9}, {3.696139302777287*^9, 
   3.696139309633669*^9}, 3.696139389576284*^9, {3.6961394247842627`*^9, 
   3.696139429304566*^9}, {3.696139617854274*^9, 3.6961396692296143`*^9}, 
   3.696139709862125*^9},ExpressionUUID->"d7c0a974-d8c4-4433-9701-\
d604ff74ee3f"],

Cell["\<\
The tangent bundles are a important class of vector bundles, a basic concept \
of differential geometry and topology.\
\>", "Text",
 CellChangeTimes->{{3.687330305381165*^9, 3.687330357537744*^9}, {
   3.6873303957378798`*^9, 3.687330427929162*^9}, {3.68733168764014*^9, 
   3.68733174095931*^9}, 
   3.690086950113284*^9},ExpressionUUID->"3d2d2437-62ac-4d4b-be86-\
7a363b15362c"],

Cell[TextData[{
 "We apply the construction of the tangent bundle also to the parameter \
neighborhoods U\[Subset]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]],ExpressionUUID->
  "97f7d338-1739-4ea4-a6de-77e2b8ecbdb5"],
 "; the map corresponding to sf now is the embedding \[Iota]:U\[RightArrow]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]],ExpressionUUID->
  "10e6e89f-688e-495d-8774-2ab71e67987d"],
 ", the tangent bundle TU = U\[Times]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]],ExpressionUUID->
  "33bbfa97-3fd1-41f1-b1f7-36ebb9d5d103"],
 " with projection ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"p", ":", 
    RowBox[{"t", "\[Element]", "TU"}]}], "=", " ", 
   RowBox[{
    RowBox[{"\[RightTeeArrow]", "u"}], "=", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u1", ",", "u2"}], "}"}], "\[Element]", 
     RowBox[{"U", "  ", "and", " ", "fibers", " ", 
      SuperscriptBox["p", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]]}]}]}]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.68732443676053*^9, 3.68732447979003*^9}, {
    3.68732451134757*^9, 3.687324606322544*^9}, {3.687324648384639*^9, 
    3.6873246549782352`*^9}, {3.687324689530624*^9, 3.687324699329584*^9}, {
    3.6873247312126904`*^9, 3.687324759201103*^9}, {3.6873248081772614`*^9, 
    3.687324814171988*^9}, 3.687324892425655*^9, 3.687325004568611*^9, {
    3.687325063446603*^9, 3.687325071070591*^9}, {3.68732513787784*^9, 
    3.687325146782296*^9}, {3.687325189427127*^9, 3.687325204957716*^9}, {
    3.687325542194747*^9, 3.687325592290525*^9}, {3.687325625466267*^9, 
    3.687325640218268*^9}, {3.6873256964022627`*^9, 3.687325721194049*^9}},
  ExpressionUUID->"b72b8abe-9b3b-49a1-bea7-b5e71c2904fe"],
 "[u] = u\[Times]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]],ExpressionUUID->
  "2d7acb6f-c12f-4d29-a0ad-6a54c1b9a523"],
 ".\nThe tuple {u1,u2,t1,t2} consists of the standard coordinates of the \
vector {u, \[GothicT]}\[Element]TU\[Subset] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "4"], TraditionalForm]],ExpressionUUID->
  "1d9ace9e-dc25-4189-8ea9-34912a8e387b"],
 ". This open set of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "4"], TraditionalForm]],ExpressionUUID->
  "7cb72019-6b45-4b6f-afec-633eb4528812"],
 " is also the set of coordinates for the tangent bundle TSF: the map"
}], "Text",
 CellChangeTimes->{{3.689316756877956*^9, 3.689316829397497*^9}, {
   3.6893168742613173`*^9, 3.689317118683939*^9}, {3.68931716061578*^9, 
   3.689317190403748*^9}, {3.689317240227229*^9, 3.689317511057743*^9}, {
   3.6893180550855703`*^9, 3.689318066404744*^9}, {3.689318169994813*^9, 
   3.6893181821120872`*^9}, {3.689318214386958*^9, 3.689318230364233*^9}, {
   3.6893182869832478`*^9, 3.689318301279293*^9}, {3.689318347938295*^9, 
   3.6893183479386806`*^9}, {3.689318388829973*^9, 3.689318416058276*^9}, {
   3.689318475179236*^9, 3.689318475179412*^9}, {3.689318537009821*^9, 
   3.68931856123349*^9}, {3.689318595745512*^9, 3.689318625857171*^9}, {
   3.689482304138789*^9, 3.6894823041391907`*^9}, {3.689482347850712*^9, 
   3.689482364650537*^9}, {3.6900877624476137`*^9, 3.690087809067967*^9}, {
   3.690087907714787*^9, 3.6900879077172728`*^9}, {3.690087945186571*^9, 
   3.6900879579900103`*^9}, {3.69008800873809*^9, 3.690088077333178*^9}, 
   3.6900881099452267`*^9, {3.6900881456170883`*^9, 3.690088185944755*^9}, {
   3.6900882776883173`*^9, 3.6900882848959837`*^9}, {3.69008844923809*^9, 
   3.690088473744123*^9}},ExpressionUUID->"272a1d1c-acb3-4c58-ac80-\
07f6cfd224e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", "\[Element]", 
   RowBox[{"TSF", " ", "\[RightTeeArrow]", " ", 
    RowBox[{"{", 
     RowBox[{"u1", ",", "u2", ",", "t1", ",", "t2"}], "}"}]}], "\[Element]", 
   " ", "TU"}], ",", " ", 
  RowBox[{
   RowBox[{"if", " ", 
    RowBox[{"p", "[", "t", "]"}]}], "\[Equal]", 
   RowBox[{"{", 
    RowBox[{"u1", ",", "u2"}], "}"}]}]}]], "Input",
 Evaluatable->False,ExpressionUUID->"4314c209-0028-41ff-99b0-0e018636e0fe"],

Cell[TextData[{
 "t1, t2 the standard coordinates of t ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "u"], TraditionalForm]],ExpressionUUID->
  "a726c41c-6412-4443-8587-c168e655c9db"],
 "SF, is a diffeomorphism. With these definitions we formulate the simple but \
important\n",
 StyleBox["Proposition 4",
  FontColor->RGBColor[0, 0, 1]],
 ". For any smooth map  f: U\[RightArrow]UU there exists the uniquely defined \
differential df:TU\[LongRightArrow]TUU,"
}], "Text",
 CellChangeTimes->{{3.689317760963933*^9, 3.689317868750517*^9}, {
   3.6893179337338142`*^9, 3.689317942717737*^9}, {3.689317987469542*^9, 
   3.689318006525544*^9}, 3.689318643592309*^9, {3.6893187000880213`*^9, 
   3.689318714271957*^9}, {3.689318754210393*^9, 3.689318859710964*^9}, {
   3.690088789044017*^9, 3.690088896466893*^9}, 
   3.693643700909521*^9},ExpressionUUID->"204f8d96-1de8-4cc9-b2bf-\
a0db9f7b2c9f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"df", "[", 
   RowBox[{"u", ",", "t"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], ",", 
    RowBox[{
     RowBox[{"df", "[", "u", "]"}], ".", "t"}]}], "}"}], " "}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.689318910674317*^9, 3.6893190178309298`*^9}, {
   3.689319063854597*^9, 3.689319070341898*^9}, {3.68931910575851*^9, 
   3.68931912707793*^9}, 3.689319189357644*^9, {3.6900889512927227`*^9, 
   3.690088968827569*^9}},ExpressionUUID->"87df5540-502d-4234-89fa-\
5dfc2b5be615"],

Cell["\<\
1. This differential is the family of linear maps of the fibers:\
\>", "Text",
 CellChangeTimes->{{3.5890036977964153`*^9, 3.589003791990803*^9}, {
  3.689319257084168*^9, 3.6893192614121227`*^9}, {3.689485021255581*^9, 
  3.689485082026742*^9}, {3.6894855178747168`*^9, 3.68948551885851*^9}, {
  3.689486384895811*^9, 
  3.68948638717575*^9}},ExpressionUUID->"cc6a9380-a86c-4df9-8345-\
1b7650b587c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "\[SmallCircle]", "p"}], " ", "\[Equal]", " ", 
   RowBox[{"q", "\[SmallCircle]", "df"}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.689485359570395*^9, 
  3.6894853932362347`*^9}},ExpressionUUID->"3719605b-5cda-4b5c-8d77-\
6622b4e04feb"],

Cell[TextData[{
 "q the projection of the bundle TUU,  represented by the ",
 StyleBox["Jacobian matrix",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5890036977964153`*^9, 3.589003791990803*^9}, {
  3.689319257084168*^9, 3.6893192614121227`*^9}, {3.689485021255581*^9, 
  3.689485064831007*^9}, {3.689485661641035*^9, 
  3.689485696320459*^9}},ExpressionUUID->"9ba080d5-1b1f-43a0-97cd-\
1f2e884ae6b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{"u1", ",", "u2"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.5890038068086505`*^9, 3.5890038232325897`*^9}, {
  3.689319224492743*^9, 
  3.6893192322196712`*^9}},ExpressionUUID->"ea65de98-31eb-423f-b8de-\
73644e9fb725"],

Cell[TextData[{
 "For any diffeomorphism f the determinant of the Jacobian matrix isn\
\[CloseCurlyQuote]t zero, and the fiber maps d[f][u] ",
 Cell[BoxData[
  FormBox[":", TraditionalForm]],ExpressionUUID->
  "f1a96148-e54d-4d6a-b872-805469eba948"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "u"], TraditionalForm]],ExpressionUUID->
  "265be56d-a2f9-4778-89c1-c50a8fce7f03"],
 "U \[LongRightArrow] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"f", "[", "u", "]"}]], TraditionalForm]],ExpressionUUID->
  "697be2a1-2821-4a75-94cd-f5d15910335c"],
 "UU  are linear isomorphisms."
}], "Text",
 CellChangeTimes->{{3.5890040970872536`*^9, 3.5890041462870674`*^9}, 
   3.68940421688302*^9, {3.68948555676225*^9, 3.689485614011714*^9}, {
   3.68948573119982*^9, 3.6894857584422293`*^9}, 3.689485827738707*^9, {
   3.689486089379156*^9, 3.6894861524296103`*^9}, {3.689486219484761*^9, 
   3.689486229417428*^9}, {3.689486266876086*^9, 3.68948626687632*^9}, {
   3.689486309888702*^9, 3.689486354952304*^9}, {3.6894864206474457`*^9, 
   3.689486421031364*^9}},ExpressionUUID->"32aaf051-360b-463b-bb9c-\
3b3d21539108"],

Cell["\<\
2. Is h: W\[RightArrow]U also a smooth map, then the differential of the \
composition
f\[SmallCircle]h: W\[LongRightArrow]UU  is the composition of the \
differentials: \
\>", "Text",
 CellChangeTimes->{{3.689404584800016*^9, 3.689404719166862*^9}, {
   3.689404757158698*^9, 3.689404926077897*^9}, {3.689405227795286*^9, 
   3.689405250051317*^9}, {3.689486458159215*^9, 3.689486459743144*^9}, {
   3.689486499206841*^9, 3.689486548674934*^9}, {3.689486712508955*^9, 
   3.689486766068758*^9}, 3.68948701395571*^9, {3.689660792271817*^9, 
   3.689660793847952*^9}},ExpressionUUID->"9b7869c6-f70a-4da4-a3fe-\
6c3a91361217"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"f", "\[SmallCircle]", "h"}], "]"}], "[", "w", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"h", "[", "w", "]"}], "]"}], "\[SmallCircle]", 
    RowBox[{
     RowBox[{"d", "[", "h", "]"}], "[", "w", "]"}]}], "."}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.689486835557622*^9, {3.6894870265819883`*^9, 
   3.6894871086030912`*^9}},ExpressionUUID->"5765e49b-6939-4e40-830d-\
e20ec5a14f14"],

Cell[TextData[{
 " 3. Is the image space of the maps f, h a real vector space, here for \
example  \nf, h: U\[LongRightArrow]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "3"], TraditionalForm]],ExpressionUUID->
  "ad9023e8-ae1b-4986-a1e7-ee433c824816"],
 ", then the sum of the functions f, h  "
}], "Text",
 CellChangeTimes->{{3.689487216254855*^9, 3.689487261025423*^9}, {
   3.689487334674274*^9, 3.6894874513196707`*^9}, {3.6894874889064093`*^9, 
   3.6894877442132196`*^9}, 
   3.689660905935418*^9},ExpressionUUID->"3406f4cd-59a0-4831-866f-\
8224d874191c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"u1_", ",", "u2_"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"u1", ",", "u2"}], "]"}], ",", 
     RowBox[{"h2", "[", 
      RowBox[{"u1", ",", "u2"}], "]"}]}], "}"}]}], ";", " ", 
  RowBox[{
   RowBox[{"plus", "[", 
    RowBox[{"f", ",", "h"}], "]"}], "[", 
   RowBox[{"u1", ",", "u2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.689487749859762*^9, 3.689487749861782*^9}, {
  3.689487802170865*^9, 3.6894878169571037`*^9}, {3.68948790451651*^9, 
  3.6894879549318943`*^9}},ExpressionUUID->"5805d173-a1c7-4fa1-b453-\
08df792e485d"],

Cell["\<\
has the differential d[plus[f,h][u] == d[f][u] + d[h][u].
4. Let now w: U\[LongRightArrow]R be a smooth real function and f like in 3. \
Then the product function times[w,f][u] = f[u]*w[u] has the differential\
\>", "Text",
 CellChangeTimes->{{3.68948801724275*^9, 3.689488089529687*^9}, {
   3.6894882378884773`*^9, 3.6894885791255608`*^9}, {3.689488762371974*^9, 
   3.6894887826197166`*^9}, 3.6894912853876867`*^9, {3.689491423330655*^9, 
   3.6894914360423517`*^9}, {3.689660955311325*^9, 3.689660986438609*^9}, {
   3.689661025161275*^9, 3.689661040950302*^9}, 3.6896633988772182`*^9, {
   3.689663428884699*^9, 3.689663431716474*^9}, {3.689663473787808*^9, 
   3.689663519267932*^9}},ExpressionUUID->"d31b3a24-e906-4225-bcb0-\
4d943795f81a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"times", "[", 
     RowBox[{"w", ",", "f"}], "]"}], "]"}], "[", "u", "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", "w", "]"}], "[", "u", "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"w", "[", "u", "]"}], "*", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.689488795428286*^9, 3.6894888746995564`*^9}, {
   3.689488906587344*^9, 3.689489005826309*^9}, {3.689489143081411*^9, 
   3.6894891548677673`*^9}, {3.689661065495309*^9, 3.689661095078499*^9}, 
   3.689662040392375*^9, {3.6896635350206213`*^9, 
   3.6896635588199663`*^9}},ExpressionUUID->"c1211edf-f3aa-4310-910d-\
cea517056cb0"],

Cell[TextData[{
 " ",
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " Statement 1. follows immediately from the definitions.  Statement 2 is the \
",
 ButtonBox["chain rule ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/ChainRule.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/ChainRule.html"],
 "of the differential. We verify 2.:"
}], "Text",
 CellChangeTimes->{{3.68949186332904*^9, 3.6894919010553417`*^9}, {
  3.6896613879236813`*^9, 3.689661471619298*^9}, {3.6896616149783163`*^9, 
  3.6896616553540382`*^9}, {3.6896617465028343`*^9, 3.689661746504367*^9}, {
  3.689661790177561*^9, 
  3.6896618327612133`*^9}},ExpressionUUID->"a8cf378f-666e-416b-a77f-\
0cb02ee0d9f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "h", "]"}], ";", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"w1_", ",", "w2_"}], "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"w1", ",", "w2"}], "]"}], ",", 
     RowBox[{"h2", "[", 
      RowBox[{"w1", ",", "w2"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6894082024848633`*^9, 3.6894083081872883`*^9}, {
   3.689408346290826*^9, 3.6894083549948483`*^9}, {3.6894906526874723`*^9, 
   3.689490654171957*^9}, 3.689491338659741*^9, 
   3.6894915321752043`*^9},ExpressionUUID->"73c7c4bb-4559-47c7-a1cb-\
ef0697fa9830"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "f", "]"}], ";", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"u1_", ",", "u2_"}], "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u1", ",", "u2"}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{"u1", ",", "u2"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6894084479624453`*^9, 
  3.6894085133623247`*^9}},ExpressionUUID->"6752d97b-2bbd-4c90-8a37-\
644acf5babe4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "fh", "]"}], ";", 
  RowBox[{
   RowBox[{"fh", "[", 
    RowBox[{"w1_", ",", "w2_"}], "]"}], " ", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"h1", "[", 
      RowBox[{"w1", ",", "w2"}], "]"}], ",", 
     RowBox[{"h2", "[", 
      RowBox[{"w1", ",", "w2"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6894085743620358`*^9, 3.6894086186244783`*^9}, {
  3.689408655064314*^9, 3.689408657448819*^9}, {3.689408694840493*^9, 
  3.689408700647814*^9}, {3.6894087327531357`*^9, 3.689408738007841*^9}, {
  3.689408769155924*^9, 3.6894088048795013`*^9}, {3.690089239816553*^9, 
  3.69008924077604*^9}, {3.690089562889323*^9, 
  3.690089572077577*^9}},ExpressionUUID->"4b212208-ba4d-4e98-a418-\
eb752042c685"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "fh", "]"}], "[", 
  RowBox[{"w1", ",", "w2"}], "]"}]], "Input",
 CellChangeTimes->{{3.689408838557857*^9, 3.689408882638256*^9}, {
  3.69008925075255*^9, 
  3.690089251792762*^9}},ExpressionUUID->"38c205b0-8605-4a2d-b1bd-\
a1bab437842e"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{
      RowBox[{"h1", "[", 
       RowBox[{"w1", ",", "w2"}], "]"}], ",", 
      RowBox[{"h2", "[", 
       RowBox[{"w1", ",", "w2"}], "]"}]}], "]"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", "h", "]"}], "[", 
     RowBox[{"w1", ",", "w2"}], "]"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.689408924250729*^9, 3.6894089952695*^9}, {
  3.689409034166277*^9, 
  3.689409038277432*^9}},ExpressionUUID->"d1445ed3-a433-4f5e-bddd-\
7c40124f0e96"],

Cell[TextData[{
 "Using concepts of the theory of ",
 ButtonBox["categories",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Category.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/Category.html"],
 ", properties 1. and 2. say that  \nf\[RightArrow]d[f] is a ",
 ButtonBox["covariant functor",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/CovariantFunctor.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/CovariantFunctor.html"],
 " of the category of smooth manifolds and maps into the category of smooth \
vector bundles. Statements 3.is a consequences of the additivity of the \
differential: "
}], "Text",
 CellChangeTimes->{{3.689662097457481*^9, 3.689662411568717*^9}, {
   3.6896625261464033`*^9, 3.6896625261480703`*^9}, {3.689662659038906*^9, 
   3.689662659040843*^9}, {3.689662848081847*^9, 3.6896629625289793`*^9}, {
   3.690089360168462*^9, 3.690089372191785*^9}, 
   3.690089409071911*^9},ExpressionUUID->"a0edc508-e5d1-4f51-b8ce-\
1ef5ae77c4fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"plus", "[", 
     RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
   RowBox[{"u1", ",", "u2"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], "+", " ", 
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u1", ",", "u2"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6896629724971724`*^9, 3.6896631157518873`*^9}, {
  3.689663162231332*^9, 
  3.689663170927197*^9}},ExpressionUUID->"01071464-0d88-4308-a7e8-\
47ad04892745"],

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "=", 
   RowBox[{"y", "[", 
    RowBox[{"u1", ",", "u2"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"times", "[", 
    RowBox[{"w", ",", "f"}], "]"}], "[", 
   RowBox[{"u1", ",", "u2"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.689663880201178*^9, {3.689663957098969*^9, 3.6896639707447357`*^9}, {
   3.689664009506423*^9, 
   3.68966404707242*^9}},ExpressionUUID->"c866bb69-f3b0-4af7-8393-\
641c003dd566"],

Cell["\<\
Statement 4. follows from the product rule of the differential:\
\>", "Text",
 CellChangeTimes->{{3.6896649742728662`*^9, 3.689665014840551*^9}, 
   3.690089438814342*^9},ExpressionUUID->"8594be5c-e0c3-49f5-b6af-\
1e7795980b99"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fy", "[", 
   RowBox[{"u1_", ",", "u2_"}], "]"}], " ", "=", 
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], "*", 
   RowBox[{"f", "[", 
    RowBox[{"u1", ",", "u2"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.689663607963311*^9, 3.689663697603286*^9}, {
   3.689663786662643*^9, 3.689663819631762*^9}, {3.689664146438343*^9, 
   3.689664175951933*^9}, {3.6896642119762506`*^9, 3.689664230776141*^9}, 
   3.68966426451504*^9, {3.6896643541801357`*^9, 3.689664380742622*^9}, {
   3.689664440945619*^9, 3.689664480995216*^9}, {3.68966458753726*^9, 
   3.6896645980527554`*^9}, {3.6896646301968727`*^9, 3.689664637348751*^9}, {
   3.689664763719305*^9, 3.6896648701443*^9}, {3.690089484156324*^9, 
   3.690089485110952*^9}},ExpressionUUID->"950130ec-b144-447b-8edb-\
643b52bd11de"],

Cell["For any tangent vector with coordinates {s1,s2} we obtain", "Text",
 CellChangeTimes->{{3.689665296437896*^9, 
  3.6896653778302813`*^9}},ExpressionUUID->"e3cd5df2-df30-42a1-b94e-\
bcb579dcb11d"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "fy", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], "\[Equal]", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"u1", ",", "u2"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "y", "]"}], "[", 
        RowBox[{"u1", ",", "u2"}], "]"}], ".", 
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}]}], " ", ")"}]}], "+", 
    RowBox[{
     RowBox[{"y", "[", 
      RowBox[{"u1", ",", "u2"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", 
        RowBox[{"u1", ",", "u2"}], "]"}], ".", 
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}]}], ")"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.689663607963311*^9, 3.689663697603286*^9}, {
   3.689663786662643*^9, 3.689663819631762*^9}, {3.689664146438343*^9, 
   3.689664175951933*^9}, {3.6896642119762506`*^9, 3.689664230776141*^9}, 
   3.68966426451504*^9, {3.6896643541801357`*^9, 3.689664380742622*^9}, {
   3.689664440945619*^9, 3.689664480995216*^9}, {3.68966458753726*^9, 
   3.6896645980527554`*^9}, {3.6896646301968727`*^9, 3.689664637348751*^9}, {
   3.689664763719305*^9, 3.6896648701443*^9}, 3.689664910579273*^9, {
   3.689665051359507*^9, 3.689665087345681*^9}, 3.68966512768561*^9, {
   3.689665228173421*^9, 3.689665257009884*^9}, {3.690089510055101*^9, 
   3.6900895107589397`*^9}},ExpressionUUID->"b5bf5a70-ec3d-4387-981c-\
d0ecf7b3dd10"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.689665396549061*^9, 
  3.6896653965507193`*^9}},ExpressionUUID->"bf8634ac-9f9f-4738-8ba9-\
e2ba10b591fd"],

Cell["\<\
The functor property of f\[RightTeeArrow]d[f] permits to conclude from the \
validity of the commutative diagram\
\>", "Text",
 CellChangeTimes->{{3.690090042721347*^9, 
  3.690090141633*^9}},ExpressionUUID->"27044026-afa9-4488-86e7-fa67fc46ee97"],

Cell[BoxData[
 RowBox[{GridBox[{
    {"\[Placeholder]", 
     RowBox[{"sf", "[", "U", "]"}], "\[LongRightArrow]", 
     RowBox[{"sh", "[", "UU", "]"}]},
    {"\[Placeholder]", 
     RowBox[{"sf", "\[UpArrow]"}], 
     RowBox[{"F", "\[UpperRightArrow]"}], 
     RowBox[{"sh", "\[UpArrow]"}]},
    {"f", "U", "\[LongRightArrow]", "UU"}
   }], "                                                                            ", 
  RowBox[{"(", "2", ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.688711639854274*^9, 3.688711648437992*^9}, 
   3.688711685056102*^9, {3.6887117894546347`*^9, 3.688711810109971*^9}, {
   3.690025991090109*^9, 3.690026019634101*^9}, 3.690026109553459*^9, {
   3.6900908631970253`*^9, 
   3.690090948443631*^9}},ExpressionUUID->"9a71b3e8-f823-4cfb-b126-\
29040623b615"],

Cell["\<\
of  Subsection 1.2.3 to conclude the commutative diagram of the differentials \
and the tangent bundles\
\>", "Text",
 CellChangeTimes->{{3.690090154592291*^9, 
  3.6900902568963118`*^9}},ExpressionUUID->"93d52932-64b6-4a5a-a73d-\
885ce94570af"],

Cell[BoxData[
 RowBox[{GridBox[{
    {"\[Placeholder]", 
     RowBox[{"     ", "TSF"}], "\[LongRightArrow]", 
     RowBox[{"         ", "TSH"}]},
    {"\[Placeholder]", 
     RowBox[{
      RowBox[{"d", "[", "sf", "]"}], "\[UpArrow]"}], 
     RowBox[{
      RowBox[{"d", "[", "F", "]"}], "\[UpperRightArrow]"}], 
     RowBox[{
      RowBox[{"d", "[", "sh", "]"}], "\[UpArrow]"}]},
    {
     RowBox[{"d", "[", "f", "]"}], "TU", "\[LongRightArrow]", 
     RowBox[{"        ", "TUU"}]}
   }], "                                               ", 
  RowBox[{"(", "5", ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.688711639854274*^9, 3.688711648437992*^9}, 
   3.688711685056102*^9, {3.6887117894546347`*^9, 3.688711810109971*^9}, {
   3.690025991090109*^9, 3.690026019634101*^9}, 3.690026109553459*^9, {
   3.690090274008176*^9, 3.69009033412784*^9}, {3.6900903674646883`*^9, 
   3.69009056413484*^9}, {3.690090595605679*^9, 3.690090635614043*^9}, {
   3.690090720901318*^9, 3.690090752493005*^9}, {3.690091049788377*^9, 
   3.690091090585828*^9}, {3.690091135994562*^9, 3.690091208649727*^9}, {
   3.6900912462249813`*^9, 
   3.690091250480871*^9}},ExpressionUUID->"82cf669f-085e-4ca2-9928-\
98f94640bdf8"],

Cell["\<\
The image of a tangent vector of sf with the coordinates {t1,t2} under the \
map f is\
\>", "Text",
 CellChangeTimes->{{3.5891791270655837`*^9, 3.5891791611685343`*^9}, 
   3.690091527126541*^9, 3.6900916373026543`*^9, {3.690179037161993*^9, 
   3.690179049249897*^9}, 
   3.690194938626758*^9},ExpressionUUID->"13d63717-5373-4225-af3a-\
74d38a084bcc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"u1_", ",", "u2_"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f1", "[", 
      RowBox[{"u1", ",", "u2"}], "]"}], ",", 
     RowBox[{"f2", "[", 
      RowBox[{"u1", ",", "u2"}], "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.689840843413109*^9, 3.6898409588542233`*^9}, 
   3.690178904259544*^9, {3.6901789426847057`*^9, 
   3.690178958243352*^9}},ExpressionUUID->"66d93224-5014-4109-8eb5-\
c9b415373d76"],

Cell["\<\
This implies the image of this vector under the map F as a tangent vector of \
SH\
\>", "Text",
 CellChangeTimes->{{3.690179085057431*^9, 
  3.690179149081079*^9}},ExpressionUUID->"73029cfd-d266-483e-bfe6-\
e8f4e15e578e"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"imF", " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "F", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"t1", ",", "t2"}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5891788967184086`*^9, 3.5891789940119734`*^9}, 
   3.5891790666921306`*^9, {3.689840452437813*^9, 3.689840654712349*^9}, 
   3.690091692057876*^9, {3.690096408575344*^9, 3.690096442390139*^9}, {
   3.6901961158146133`*^9, 
   3.690196167799192*^9}},ExpressionUUID->"b930615c-3a39-4d1d-bb4e-\
630bd97e2f21"],

Cell["The norm square of this vector is ", "Text",
 CellChangeTimes->{{3.5891792418171473`*^9, 3.589179256528989*^9}, 
   3.5995675589289384`*^9},ExpressionUUID->"ac2e95c0-7938-4a03-838c-\
3f6f5cdf2922"],

Cell[BoxData[
 RowBox[{"imfdot", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"imF", ".", "imF"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5890961486185813`*^9, 3.5890961630174046`*^9}, {
  3.589173102998705*^9, 
  3.5891731114071198`*^9}},ExpressionUUID->"493b08db-cd5a-45f2-886e-\
067a219a411d"],

Cell[TextData[{
 "This symmetric, positive definite quadratic form on the tangent space  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "u"], TraditionalForm]],ExpressionUUID->
  "ba7db2ae-b3b8-4a04-b9b4-86329b573cd2"],
 "SF at the point sf[u1,u2], which can be expressed as the",
 ButtonBox[" pullback",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/PullbackMap.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/PullbackMap.html"],
 " of the first fundamental form of the surface SH: "
}], "Text",
 CellChangeTimes->{{3.589179351104398*^9, 3.5891794335371127`*^9}, {
   3.589179471897307*^9, 3.5891794926004915`*^9}, {3.589179532632781*^9, 
   3.589179597400485*^9}, {3.589179633257536*^9, 3.589179648616415*^9}, {
   3.5891796791211596`*^9, 3.5891796974572086`*^9}, 3.589191183175168*^9, {
   3.690096965916626*^9, 3.690097061171833*^9}, {3.690097111187277*^9, 
   3.69009714172302*^9}, {3.6901792160166492`*^9, 3.690179304984659*^9}, {
   3.690201259052651*^9, 3.690201323819956*^9}, {3.6902836763701468`*^9, 
   3.690283677570056*^9}, {3.690294489968027*^9, 
   3.6902944899706984`*^9}},ExpressionUUID->"b25a452a-73fc-4a43-a6eb-\
47d63db7cec2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pullback", "::", "usage"}], " ", "=", 
   "\"\<Let f: U\[RightArrow]Y be a smooth map of a manifold U with  \
coordinates u,..., into a manifold Y and \[Phi][y][s1,...,sp]a function of p\
\[GreaterTilde]0 tangent vectors si\[Element]TY, i=1,...,p. Then \n\
pullback[f,\[Phi]][u...][t,...] = \n\[Phi][f[u]][d[f][u][t1],..., \
d[f][u][tp]] \nis the pullback of \[Phi] being a function of p tangent \
vectors ti \[Element] TU.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.690283765792776*^9, 3.690283825744747*^9}, 
   3.6902838559457417`*^9, {3.69028388712129*^9, 3.690284013584609*^9}, {
   3.690284057783841*^9, 3.690284074687726*^9}, {3.690284108255466*^9, 
   3.69028420419845*^9}, {3.690284273614396*^9, 3.690284783907267*^9}, {
   3.6902848348186073`*^9, 3.690284950066084*^9}, 3.69028524034066*^9, {
   3.690285339567439*^9, 3.690285346390917*^9}, 3.6902853920493383`*^9, {
   3.6962482941696777`*^9, 
   3.696248299998931*^9}},ExpressionUUID->"56d20ade-3c05-4c7e-a96d-\
76644ab5fc55"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "pullback", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"pullback", "[", 
      RowBox[{"f_", ",", "\[Phi]_"}], "]"}], "[", "u__", "]"}], "[", 
    "t___List", "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"pp", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "t", "}"}], "]"}]}], ",", ",", "i", ",", "qq", ",", "s",
        ",", "ss"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"pp", "\[Equal]", "0"}], ",", 
        RowBox[{"Return", "[", 
         RowBox[{"\[Phi]", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"qq", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}], ".", 
          RowBox[{
           RowBox[{"{", "t", "}"}], "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "pp"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ss", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"s", "[", "i", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "pp"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "[", 
         RowBox[{"lts", "[", 
          RowBox[{"f", "[", 
           RowBox[{"u1", ",", "u2"}], "]"}], "]"}], "]"}], "[", 
        RowBox[{"lts", "[", "ss", "]"}], "]"}], "/.", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"s", "[", "i", "]"}], "->", 
          RowBox[{"qq", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "pp"}], "}"}]}], "]"}]}]}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.69020171678872*^9, 3.690201857176386*^9}, {
   3.6902019112324047`*^9, 3.6902019913997097`*^9}, {3.690202324741007*^9, 
   3.690202341213303*^9}, {3.690202375189332*^9, 3.690202394932822*^9}, 
   3.690202461092967*^9, {3.6902025080122643`*^9, 3.690202636147746*^9}, 
   3.690203651627779*^9, {3.690203699715612*^9, 3.6902038824585943`*^9}, 
   3.6902039850977097`*^9, {3.690204050295128*^9, 3.690204104928643*^9}, 
   3.690204329314828*^9, {3.690204914692965*^9, 3.6902049443877697`*^9}, 
   3.690204976887052*^9, {3.690205201989319*^9, 3.690205213698127*^9}, 
   3.690205428485504*^9, 3.69020582168155*^9, {3.6902058643342447`*^9, 
   3.690205995341649*^9}, {3.690206087253605*^9, 3.690206094828724*^9}, 
   3.6902063864598093`*^9, {3.690206418387186*^9, 3.690206442595039*^9}, {
   3.696139773482065*^9, 3.696139850285893*^9}, {3.6962475951131487`*^9, 
   3.696247597748128*^9}, {3.6962490509609423`*^9, 
   3.696249076098514*^9}},ExpressionUUID->"5ef49606-5fc6-4144-a728-\
352998bd255e"],

Cell["We consider the first fundamental form of the surface SF", "Text",
 CellChangeTimes->{{3.690286446516199*^9, 
  3.690286475323923*^9}},ExpressionUUID->"ddab80ba-72da-470c-a862-\
6eedd88aed48"],

Cell[BoxData[
 RowBox[{"?", "fund1"}]], "Input",
 CellChangeTimes->{{3.6901796126531878`*^9, 
  3.69017961796628*^9}},ExpressionUUID->"378b8d35-7cbf-46a1-9ad2-\
8e7f86e6b40b"],

Cell[TextData[{
 StyleBox["Example 7",
  FontColor->RGBColor[0, 0, 1]],
 ". The first fundamental form of the surface sf[u1,u2] is the pullback of \
the Euclidean scalar product "
}], "Text",
 CellChangeTimes->{{3.6902855338642197`*^9, 3.690285649210472*^9}, {
   3.690285684858345*^9, 3.690285749585743*^9}, 3.690285842065486*^9, {
   3.690286688090672*^9, 
   3.690286689474308*^9}},ExpressionUUID->"d57ae63f-b88a-403f-90e7-\
49ea85b94303"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"sv", "[", 
     RowBox[{"x1_", ",", "x2_", ",", "x3_"}], "]"}], "[", 
    RowBox[{"t_", ",", "s_"}], "]"}], " ", ":=", 
   RowBox[{"t", ".", "s"}]}], ";", 
  RowBox[{
   RowBox[{"sv", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2", ",", "s3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6902108696240473`*^9, 3.69021097242566*^9}, {
  3.6902110907249613`*^9, 3.6902111072007523`*^9}, {3.690285868137281*^9, 
  3.6902858848349037`*^9}},ExpressionUUID->"7ff44af9-38ab-49f8-9d39-\
78c9c3cb99ed"],

Cell["to  the tangent bundle TSF of the surface:", "Text",
 CellChangeTimes->{{3.690285985959894*^9, 3.690285987287723*^9}, {
  3.690286024407465*^9, 
  3.690286066583323*^9}},ExpressionUUID->"b103261a-0488-4a73-ae86-\
de848da5266f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pullback", "[", 
    RowBox[{"sf", ",", "sv"}], "]"}], "[", 
   RowBox[{"u1", ",", "u2"}], "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6902112112239637`*^9, 
  3.690211290326848*^9}},ExpressionUUID->"0c937568-e576-4358-8c1d-\
db73bd13a674"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t1", ",", "t2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.690211303658886*^9, 3.690211331870797*^9}, 
   3.69021154662864*^9, 3.69021158436585*^9, {3.6902860901674013`*^9, 
   3.6902861258237877`*^9}},ExpressionUUID->"a7a1ec32-c512-4ddf-8503-\
f67d33d51b09"],

Cell[TextData[{
 "This function pulls back the scalar product sv to the immersion sf: U\
\[RightArrow]",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["E", "3"], ";"}], TraditionalForm]],ExpressionUUID->
  "7a915272-27a5-4a45-a46e-22889cdf90ae"],
 "\n speaking exactly, we obtain a pullback to TU, being a coordinate \
representation of TSF, see (5). \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.690286218923181*^9, 3.690286218925645*^9}, {
  3.6902868385052032`*^9, 3.6902870138474627`*^9}, {3.6902870554635773`*^9, 
  3.690287131327182*^9}, {3.6902872514461184`*^9, 3.690287333101451*^9}, {
  3.696248063896405*^9, 3.696248097055937*^9}, {3.69624812767144*^9, 
  3.6962481328156767`*^9}, {3.696248167842256*^9, 
  3.696248187999045*^9}},ExpressionUUID->"53f5890d-c159-44c4-8e81-\
4b6b383f95d8"],

Cell["Now we return to the scalar square imfdot:", "Text",
 CellChangeTimes->{{3.690287370988779*^9, 
  3.6902874257405*^9}},ExpressionUUID->"b8196eef-b223-4550-8274-cf91e4a7b4ba"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"imfdot", "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sh", "]"}], "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{"u1", ",", "u2"}], "]"}], ",", 
      RowBox[{"f2", "[", 
       RowBox[{"u1", ",", "u2"}], "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", 
        RowBox[{"u1", ",", "u2"}], "]"}], ".", 
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2"}], "}"}]}], ")"}], ",", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", 
        RowBox[{"u1", ",", "u2"}], "]"}], ".", 
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2"}], "}"}]}], ")"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.589006516431632*^9, 3.5890065543608017`*^9}, {
   3.58900660888992*^9, 3.5890066480421596`*^9}, {3.5890066985860505`*^9, 
   3.589006759490534*^9}, 3.589007352939478*^9, {3.589007550179759*^9, 
   3.5890075695968695`*^9}, {3.589007613876402*^9, 3.589007622562899*^9}, {
   3.5890076612551117`*^9, 3.589007699765315*^9}, {3.589007746557991*^9, 
   3.589007825304495*^9}, 3.5890079005778008`*^9, 3.5890079866817255`*^9, {
   3.5890081122659082`*^9, 3.5890081411845627`*^9}, {3.589111668230233*^9, 
   3.5891117338439484`*^9}, {3.5891117660736055`*^9, 
   3.5891117712528143`*^9}, {3.5891118153228917`*^9, 3.589111820658101*^9}, {
   3.589111873354994*^9, 3.589111932385497*^9}, {3.5891121139386163`*^9, 
   3.5891121239538336`*^9}, 3.6176259331745977`*^9, {3.690091697918755*^9, 
   3.690091699440052*^9}, {3.690096606255603*^9, 3.690096611366665*^9}, {
   3.690096800276102*^9, 3.690096870814621*^9}, {3.690179318594244*^9, 
   3.690179318810082*^9}, {3.690179682817968*^9, 3.690179742030574*^9}, {
   3.690179791053903*^9, 3.690179832533057*^9}, {3.690180055098991*^9, 
   3.690180062268786*^9}},ExpressionUUID->"d27e0d56-38f6-4d4e-b7a5-\
85096dc42b37"],

Cell["\<\
Indeed, it is the pullback of fund1[sh] of SH to the surface SF generated by \
the map f defining F:\
\>", "Text",
 CellChangeTimes->{{3.690287534083558*^9, 
  3.690287655610825*^9}},ExpressionUUID->"23e881e5-7f6d-4b91-981c-\
da4620574886"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pullback", "[", 
    RowBox[{"f", ",", 
     RowBox[{"fund1", "[", "sh", "]"}]}], "]"}], "[", 
   RowBox[{"u1", ",", "u2"}], "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b1", ",", "b2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.690204129760255*^9, 3.69020429443836*^9}, {
  3.6902046731088657`*^9, 3.690204680173107*^9}, {3.690205473899666*^9, 
  3.6902054804231253`*^9}},ExpressionUUID->"ae5c5dcf-2198-4fb9-85a0-\
2ab24d05c8fb"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"imfdot", "==", 
   RowBox[{
    RowBox[{
     RowBox[{"pullback", "[", 
      RowBox[{"f", ",", 
       RowBox[{"fund1", "[", "sh", "]"}]}], "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t1", ",", "t2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t1", ",", "t2"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.690206542633129*^9, 3.69020658449608*^9}, {
  3.690206641616811*^9, 
  3.690206726415728*^9}},ExpressionUUID->"6c66cbbc-3ef3-4216-b45c-\
e12c0e3c638c"],

Cell[TextData[{
 "Summarizing we obtain\n",
 StyleBox["Proposition 5",
  FontColor->RGBColor[0, 0, 1]],
 ". Let SF, SH be two surfaces in the Euclidean space and F[sf[u1,u2]] = \
sh[f[u1,u2]] a diffeomorphism as defined above. Then the differential \
dF[u1,u2] is a family of linear isomorphisms between the tangent planes of \
the surfaces "
}], "Text",
 CellChangeTimes->{{3.5891810884887705`*^9, 3.589181246160789*^9}, {
   3.5891813391141057`*^9, 3.589181539624574*^9}, {3.5891816073614483`*^9, 
   3.5891816585633774`*^9}, 3.589182385073931*^9, {3.5891909517719326`*^9, 
   3.589190958603323*^9}, 3.687152189805739*^9, {3.69018612894355*^9, 
   3.690186130409254*^9}, {3.690295668885523*^9, 3.690295670157485*^9}, {
   3.690295706789666*^9, 3.69029571298131*^9}, {3.690295755581031*^9, 
   3.690295757452787*^9}, {3.6936437220291433`*^9, 3.693643724077087*^9}, 
   3.707373074632045*^9, {3.707373819323167*^9, 
   3.707373826289866*^9}},ExpressionUUID->"6ffc45e8-be15-4ad9-aadc-\
1859ace4b588"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tangsp", "[", "sf", "]"}], "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], "[", 
   RowBox[{"t1", ",", "t2"}], "]"}], " ", "\[RightTeeArrow]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "F", "]"}], "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5891816839978323`*^9, 3.589181696219531*^9}, {
   3.5891817267402763`*^9, 3.589181730315481*^9}, {3.58918179322808*^9, 
   3.5891818181395044`*^9}, {3.5891818644271517`*^9, 3.5891818810271015`*^9}, 
   3.6227808742831593`*^9, 3.690091704167704*^9, {3.6901861325426273`*^9, 
   3.690186134045349*^9}, {3.690287824321988*^9, 3.6902878413620787`*^9}, {
   3.6902878941776543`*^9, 
   3.690287898761498*^9}},ExpressionUUID->"28c9d089-55b8-4f23-b2a8-\
7dd8705cfaa9"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "F", "]"}], "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"t1", ",", "t2"}], "}"}]}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sh", "]"}], "[", 
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{"u1", ",", "u2"}], "]"}], ",", " ", 
      RowBox[{"f2", "[", 
       RowBox[{"u1", ",", "u2"}], "]"}]}], "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u1", ",", "u2"}], "]"}], ".", 
      RowBox[{"{", 
       RowBox[{"t1", ",", "t2"}], "}"}]}], ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5891819634118137`*^9, 3.5891820500607696`*^9}, {
  3.5891821021567492`*^9, 3.5891822003973684`*^9}, {3.690091705467079*^9, 
  3.6900917069404488`*^9}, {3.690186135760251*^9, 3.6901861409299383`*^9}, {
  3.690287781294938*^9, 3.690287783234357*^9}, {3.6902879163394814`*^9, 
  3.690287956441412*^9}},ExpressionUUID->"9ae52333-6fe0-4210-821c-\
32a13cbf7300"],

Cell[TextData[{
 "where the Jacobian matrix d[f][u1,u2] of f is invertible.  The scalar \
product of two image vectors under the map dF[u1,u2] can be calculated  \
evaluating the \n",
 StyleBox["pullback of the first fundamental form",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"fund1", "[", "sh", "]"}], " ", "of", " ", "SH", " ", "to", " ", 
    "the", " ", "surface", " ", "SF"}], TraditionalForm]],ExpressionUUID->
  "07563fb4-013a-4445-b05a-735ca8e3607e"],
 " which is a field of symmetric, positive definite bilinear forms on the \
preimage surface SF. The map F is an isometry iff this pullback coincides \
with the first fundamental form of sf."
}], "Text",
 CellChangeTimes->{{3.5891822714574327`*^9, 3.58918234099341*^9}, 
   3.5891823920413294`*^9, {3.589182424977214*^9, 3.5891825574487906`*^9}, {
   3.5891826145780582`*^9, 3.5891828892247667`*^9}, {3.589182955201541*^9, 
   3.5891830094166417`*^9}, 3.5891911831031637`*^9, {3.590495710453009*^9, 
   3.590495710453009*^9}, 3.5995676203694525`*^9, 3.6141620282522945`*^9, 
   3.6176274924947863`*^9, {3.6901861424094143`*^9, 3.690186143727558*^9}, {
   3.690288000449213*^9, 3.6902880094409237`*^9}, {3.690288041957138*^9, 
   3.6902880428353786`*^9}, {3.690288090026116*^9, 3.6902880952747793`*^9}, {
   3.690288137191999*^9, 3.690288166383279*^9}, {3.6902882216711884`*^9, 
   3.690288235526683*^9}},ExpressionUUID->"2196169a-21c3-4c92-8a3a-\
72e0ccb11665"],

Cell[TextData[{
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " It remains to show the last statement about the isometry. By Lemma 1 we \
may assume that the map F is a map of equal coordinates: points corresponding \
by F have the same coordinates; f:U\[RightArrow]UU==U is the identity.  Curve \
and image curve have the same coordinate representation. If the mentioned \
first fundamental forms coincide, the arc length integrals over the norm of \
its tangent vectors coincide for any curve. and F is an isometry. To prove \
the converse, assume that uo = {uo1,uo2} is a point with fund1[sf][uo]\
\[NotEqual]fund1[sh][uo]. Then there exists a vector \[GothicT]o\[Element] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "uo"], TraditionalForm]],ExpressionUUID->
  "7f64450e-a2f8-46e5-b924-6de0d0d69f9a"],
 "U such that the norms with respect to the both forms differ; this follows \
since each value of the bilinear form may be expressed as a difference of two \
squares, e.g. for the Dot product:"
}], "Text",
 CellChangeTimes->{{3.589191329142517*^9, 3.589191399947567*^9}, {
   3.5891914342835307`*^9, 3.589191466123352*^9}, {3.5891915146831293`*^9, 
   3.5891915159472017`*^9}, {3.5891916046032724`*^9, 3.589191819059539*^9}, {
   3.5891918549235897`*^9, 3.589191867915333*^9}, {3.5891921228519144`*^9, 
   3.5891922318111467`*^9}, {3.5891923724761925`*^9, 3.589192558955858*^9}, {
   3.5995669673581023`*^9, 3.59956699126147*^9}, {3.5995676328671675`*^9, 
   3.5995676404746027`*^9}, {3.627371918604969*^9, 3.6273719225361757`*^9}, {
   3.6900917084907084`*^9, 3.690091709803751*^9}, {3.690186208203342*^9, 
   3.6901862099165173`*^9}, 3.6902961778971243`*^9, {3.690296572286092*^9, 
   3.6902970013714037`*^9}, 3.690297056731139*^9, {3.690297155066368*^9, 
   3.690297309585473*^9}, {3.690297375724442*^9, 3.690297678200019*^9}, {
   3.6902982715156097`*^9, 3.690298293499255*^9}, {3.6902983333217697`*^9, 
   3.69029845053004*^9}, 
   3.69625627063328*^9},ExpressionUUID->"8e58ff47-e582-4634-a552-\
205af7562e59"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", "a", "]"}], ".", 
    RowBox[{"vec", "[", "b", "]"}]}], "\[Equal]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "a", "]"}], "+", 
         RowBox[{"vec", "[", "b", "]"}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "a", "]"}], "+", 
         RowBox[{"vec", "[", "b", "]"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "a", "]"}], "-", 
         RowBox[{"vec", "[", "b", "]"}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "a", "]"}], "-", 
         RowBox[{"vec", "[", "b", "]"}]}], ")"}]}]}], ")"}], "/", "4"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.690297702859993*^9, 3.690297901204679*^9}, 
   3.690297961409391*^9, 3.690298013385194*^9, {3.690298059035646*^9, 
   3.690298085027297*^9}, {3.6902981835349693`*^9, 
   3.6902981913147163`*^9}},ExpressionUUID->"ea93bfcc-6d2f-451f-a521-\
5dc708989c19"],

Cell[TextData[{
 "Now let \[GothicT]o={to1,to2}\[Element] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "uo"], TraditionalForm]],ExpressionUUID->
  "f227350d-2359-4f61-b630-5b864b9ca090"],
 "U be a tangent vector with "
}], "Text",
 CellChangeTimes->{{3.690353085964579*^9, 3.690353254245122*^9}, {
  3.690353593378645*^9, 
  3.690353620546769*^9}},ExpressionUUID->"27c46263-5548-4368-bf07-\
5583c354349e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"norm", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], "[", "uo", "]"}], "[", "\[GothicT]o", 
    "]"}], "]"}], " ", "<", " ", 
  RowBox[{"norm", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sh", "]"}], "[", "uo", "]"}], "[", "\[GothicT]o", 
    "]"}], "]"}], "                     ", 
  RowBox[{"(*", ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6903533005492773`*^9, 3.690353411348666*^9}, {
  3.6903550287515087`*^9, 
  3.690355037744178*^9}},ExpressionUUID->"fd05df74-ec97-4fcb-8cb7-\
2ba8f74994aa"],

Cell["Consider the curve", "Text",
 CellChangeTimes->{{3.690353463723566*^9, 
  3.69035347352346*^9}},ExpressionUUID->"8a42ec1c-dc0d-427a-b88e-\
4940a84dfda9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cu", "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"uo1", "+", 
     RowBox[{"x", "*", "to1"}]}], ",", 
    RowBox[{"uo2", "+", 
     RowBox[{"x", "*", "to2"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.690353481718978*^9, 3.6903534865810423`*^9}, {
   3.6903535196041107`*^9, 3.690353544195867*^9}, 3.690353574259481*^9, {
   3.69035364809088*^9, 
   3.690353738562331*^9}},ExpressionUUID->"3e7c1fcf-ef53-4c1d-8dfe-\
58ccdc4327f4"],

Cell["\<\
Clearly, there exists an interval |x| <\[Epsilon], \[Epsilon]>0, such that \
cu[x] \[Element]U. The map F maps the curve sf[cu[x]] onto sh[cu[x]], and for \
the differential we have\
\>", "Text",
 CellChangeTimes->{{3.690353801696149*^9, 3.6903538693368177`*^9}, {
  3.690353903688622*^9, 3.690354112255249*^9}, {3.690354160255292*^9, 
  3.690354167584446*^9}, {3.696256447069077*^9, 
  3.6962564473325787`*^9}},ExpressionUUID->"71c54008-86a2-43a4-a529-\
5b64e0b0d96b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "cu", "]"}], "[", "x", "]"}], "\[Equal]", " ", 
  RowBox[{"{", 
   RowBox[{"to1", ",", "to2"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6903542111028337`*^9, 3.690354227278675*^9}, {
  3.690354266415659*^9, 3.690354268702856*^9}, {3.6903543317518387`*^9, 
  3.690354333974127*^9}},ExpressionUUID->"1c05afed-a9b7-4569-aa7f-\
7e3876952f59"],

Cell["consider the function", "Text",
 CellChangeTimes->{{3.690354423101178*^9, 
  3.6903544338129*^9}},ExpressionUUID->"9104ca34-3450-413b-9639-8e3495787fb6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nd", "[", "x_", "]"}], " ", ":=", "  ", 
  RowBox[{
   RowBox[{"norm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "sh", "]"}], "[", 
      RowBox[{"lts", "[", 
       RowBox[{"cu", "[", "x", "]"}], "]"}], "]"}], "[", 
     RowBox[{"to1", ",", "to2"}], "]"}], "]"}], "-", 
   RowBox[{"norm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "sf", "]"}], "[", 
      RowBox[{"lts", "[", 
       RowBox[{"cu", "[", "x", "]"}], "]"}], "]"}], "[", 
     RowBox[{"to1", ",", "to2"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6903544757265167`*^9, 3.690354491268978*^9}, {
  3.690354524877323*^9, 3.690354553508441*^9}, {3.690354586652701*^9, 
  3.69035459467654*^9}, {3.690354724620263*^9, 3.69035473220436*^9}, {
  3.6903548134210033`*^9, 3.6903548517783613`*^9}, {3.696139972730996*^9, 
  3.6961399804763803`*^9}, {3.696140024315159*^9, 
  3.6961400655628357`*^9}},ExpressionUUID->"939cab85-fc9f-467a-b10e-\
d50b3d5b710d"],

Cell["Since by assumption (*)", "Text",
 CellChangeTimes->{{3.690355045598077*^9, 
  3.690355091070496*^9}},ExpressionUUID->"f56ffd7d-6fe5-4d06-b2bf-\
1c757abb3305"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nd", "[", "0", "]"}], ">", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.690354654350194*^9, 3.690354659490651*^9}, {
  3.6903548829495897`*^9, 3.6903548899930687`*^9}, {3.690354977189587*^9, 
  3.6903549953837976`*^9}},ExpressionUUID->"b1ac3afa-7c1b-4442-b4eb-\
72caf6c3a1f9"],

Cell["\<\
by continuity of nd[x] the interval |x| < \[Epsilon] can be chosen so small \
that for all x in this interval we have\
\>", "Text",
 CellChangeTimes->{{3.690355205279889*^9, 3.690355280108877*^9}, {
  3.690355310308879*^9, 
  3.690355352436208*^9}},ExpressionUUID->"08aa03bd-b30c-4717-a156-\
eedda5f011b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nd", "[", "x", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"norm", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "sh", "]"}], "[", 
       RowBox[{"cu", "[", "x", "]"}], "]"}], "[", "\[GothicT]o", "]"}], "]"}],
     " ", "-", " ", 
    RowBox[{"norm", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "sf", "]"}], "[", 
       RowBox[{"cu", "[", "x", "]"}], "]"}], "[", "\[GothicT]o", "]"}], 
     "]"}]}], ">", "0"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.690355361703031*^9, 3.690355377428672*^9}, {
  3.6903554585734453`*^9, 
  3.69035552578785*^9}},ExpressionUUID->"c3b043cb-e13a-4fdf-bdc9-\
3076295ef453"],

Cell["Integrating we obtain for the arc length of the curves", "Text",
 CellChangeTimes->{{3.6903555849541063`*^9, 
  3.690355653257517*^9}},ExpressionUUID->"45cac05a-c115-4716-93a1-\
99d745f04e21"],

Cell[BoxData[
 RowBox[{"?", "arc"}]], "Input",
 CellChangeTimes->{{3.690355671522057*^9, 3.69035570323343*^9}, {
  3.6903557892704077`*^9, 
  3.690355789952456*^9}},ExpressionUUID->"164f4e05-abf4-4b16-b9ba-\
c603063d9eb8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"arc", "[", 
    RowBox[{
     RowBox[{"sh", "[", 
      RowBox[{"cu", "[", "x", "]"}], "]"}], ",", "x", ",", 
     RowBox[{"-", "\[Epsilon]"}], ",", "\[Epsilon]"}], "]"}], " ", ">", 
   RowBox[{"arc", "[", 
    RowBox[{
     RowBox[{"sf", "[", 
      RowBox[{"cu", "[", "x", "]"}], "]"}], ",", "x", ",", 
     RowBox[{"-", "\[Epsilon]"}], ",", "\[Epsilon]"}], "]"}]}], 
  ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.690355671522057*^9, 3.6903557818968897`*^9}, {
  3.690355829512019*^9, 3.690355920863494*^9}, {3.690355972647027*^9, 
  3.690356023854643*^9}},ExpressionUUID->"c950cd5c-399e-4b97-8011-\
40b15fa2a914"],

Cell["and since", "Text",
 CellChangeTimes->{{3.690356078213685*^9, 
  3.690356083485632*^9}},ExpressionUUID->"2f3deade-031d-4458-bcd7-\
f2fc15895484"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", 
   RowBox[{"sf", "[", 
    RowBox[{"cu", "[", "x", "]"}], "]"}], "]"}], "\[Equal]", " ", 
  RowBox[{"sh", "[", 
   RowBox[{"cu", "[", "x", "]"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.690356089933443*^9, 
  3.690356194901045*^9}},ExpressionUUID->"a08b9f0c-ceaa-4768-96be-\
0fdfc9ed1a39"],

Cell["F is not an isometry. \[FilledSquare]", "Text",
 CellChangeTimes->{{3.690356203500619*^9, 
  3.690356232375355*^9}},ExpressionUUID->"80803a17-a9d3-457c-82a2-\
1c11cdf72789"],

Cell[TextData[{
 "We conclude:\n",
 StyleBox["Corollary 1",
  FontColor->RGBColor[0, 0, 1]],
 ". A map F[sf[u1,u2]] := sh[u1,u2]    defined by the equality of the \
parameters u1,u2 is an isometry iff the coefficients of the first fundamental \
forms coincide:"
}], "Text",
 CellChangeTimes->{{3.5892004162202682`*^9, 3.589200431100119*^9}, {
  3.5892004646920404`*^9, 3.5892005485078344`*^9}, {3.5892006375559278`*^9, 
  3.589200690859977*^9}, {3.690186235237114*^9, 3.6901862377320433`*^9}, {
  3.690356404843238*^9, 
  3.690356406155099*^9}},ExpressionUUID->"13115773-f716-44c3-a222-\
de275e556dec"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u1", ",", "u2"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "[", "sh", "]"}], "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], "."}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5892007019866133`*^9, 3.58920071259722*^9}, {
  3.589200746462157*^9, 3.589200819790351*^9}, {3.617626032620286*^9, 
  3.617626033843356*^9}, {3.690186239726737*^9, 
  3.6901862408370857`*^9}},ExpressionUUID->"b68f0473-ce4a-4511-8597-\
abc2b1f3252c"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3. Differential Forms", "Subsection",
 CellChangeTimes->{{3.5725953757423115`*^9, 3.572595385461128*^9}, {
   3.58666439764649*^9, 3.5866644089011335`*^9}, {3.5872724756311846`*^9, 
   3.58727247921439*^9}, 3.599568542111173*^9, 3.599804993627187*^9, 
   3.6176277747189283`*^9, 3.617632840802114*^9, 3.627372710290759*^9, 
   3.6273740816423683`*^9},ExpressionUUID->"4d4535c2-ac88-42cd-820e-\
1a8e07592390"],

Cell[TextData[{
 "In the following we will use E. Cartan\[CloseCurlyQuote]s method of moving \
frames. We apply the calculus of differential forms on the parameter manifold \
U in an elementary form in dimension 2, as it is presented in the \
Introduction of W. Blaschke and H. Reichardt [",
 ButtonBox["B-R",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 "],  avoiding tensor algebra. The general calculus of differential forms on \
manifolds is presented in the notebook ",
 ButtonBox["Pseudo-Riemannian Geometry and Tensor Analysis.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www-irm.mathematik.hu-berlin.de/~sulanke/diffgeo.html#\
IntroDG"], None},
  ButtonNote->
   "http://www-irm.mathematik.hu-berlin.de/~sulanke/diffgeo.html#IntroDG"]
}], "Text",
 CellChangeTimes->{{3.5866617389574213`*^9, 3.586661854765045*^9}, {
   3.5866619107972503`*^9, 3.5866619417650213`*^9}, {3.586662052197338*^9, 
   3.5866621045253305`*^9}, 3.5866624506461277`*^9, {3.586663494477832*^9, 
   3.586663633164764*^9}, 3.586664441966025*^9, 3.5867576531566353`*^9, {
   3.5998034928760347`*^9, 3.5998035298325*^9}, {3.5998035685049677`*^9, 
   3.599803644882702*^9}, {3.692683488681673*^9, 3.692683490873301*^9}, {
   3.692683549089242*^9, 3.692683615344736*^9}, {3.692683780511355*^9, 
   3.692683813767358*^9}, {3.692685400158326*^9, 3.692685437239564*^9}, {
   3.692685723028304*^9, 3.692685723030352*^9}, 
   3.692972545575938*^9},ExpressionUUID->"756af610-cd4c-408b-931f-\
6af47a75b4af"],

Cell[CellGroupData[{

Cell["1.3.1. The Differential of a 0-Form (= Function)", "Subsubsection",
 CellChangeTimes->{{3.572611276502635*^9, 3.572611281323043*^9}, {
   3.586174321969679*^9, 3.5861743363685026`*^9}, {3.5866646931983943`*^9, 
   3.586664749405609*^9}, {3.587272484902715*^9, 3.5872724953183107`*^9}, 
   3.6092316085437975`*^9, 3.609308006813593*^9, 3.6177061733856325`*^9, 
   3.6177065148971663`*^9, {3.692691995634706*^9, 3.692691998370565*^9}, 
   3.69332022788186*^9, {3.693656078468349*^9, 3.693656081908203*^9}, 
   3.6937498788052464`*^9, 3.694702845718586*^9, 3.696256617292922*^9, 
   3.696345327114135*^9, {3.699773107638053*^9, 
   3.69977311091791*^9}},ExpressionUUID->"d54393ec-92b6-4a4d-b665-\
556e7b19c02a"],

Cell["\<\
The differential of a function was defined in Section 1.1; it is a \
differential form, more exactly, the coordinate tuple of a covector field. \
The evaluation of the forms for tangent vectors or tangent vector fields is \
obtained by the Dot product with the coordinate vectors\
\>", "Text",
 CellChangeTimes->{{3.586174802937189*^9, 3.586174919432852*^9}, 
   3.5862322201509748`*^9, {3.586609483759947*^9, 3.58660954266565*^9}, {
   3.59021230392822*^9, 3.5902123231630535`*^9}, 3.595484014179422*^9, {
   3.5998037540204935`*^9, 3.599803787295352*^9}, {3.6963435066111298`*^9, 
   3.696343528066391*^9}},ExpressionUUID->"67d9e2df-b0c3-499c-8a2d-\
789005f127ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.696257372782627*^9, 
  3.696257376901731*^9}},ExpressionUUID->"fd7fc8c1-62e2-45f6-9f63-\
f7fa4fef7515"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "h", "]"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "h", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696258699433877*^9, 3.696258708548069*^9}, 
   3.696258823181409*^9},ExpressionUUID->"c6a2fb78-07d8-42f3-b472-\
832dd693e430"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "h", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{"vec", "[", "a", "]"}]}]], "Input",
 CellChangeTimes->{{3.590212361710721*^9, 3.590212380820755*^9}, 
   3.6271054821943345`*^9, {3.6926859131508007`*^9, 3.692685921801564*^9}, {
   3.696257387090865*^9, 3.696257392549939*^9}, 
   3.69625880904797*^9},ExpressionUUID->"807933f1-bde4-426f-a85d-\
0cfe4a4a4461"],

Cell["In traditional notation the differential is written as", "Text",
 CellChangeTimes->{{3.696258078064068*^9, 
  3.696258121223833*^9}},ExpressionUUID->"3ff5a9ad-f875-412a-905f-\
93bb61819ffe"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "h", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "u"], 
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], " ", "du"}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "v"], 
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], " ", "dv"}]}]}]], "Input",
 CellChangeTimes->{{3.6962581355842333`*^9, 3.696258158887925*^9}, {
  3.696258201837515*^9, 
  3.696258273655408*^9}},ExpressionUUID->"19cb7579-59ad-473f-b46f-\
3e21e7e4bad0"],

Cell[BoxData[
 RowBox[{"?", "du"}]], "Input",
 CellChangeTimes->{{3.6962574440816927`*^9, 
  3.696257445341185*^9}},ExpressionUUID->"77625ef2-bd71-4630-8b08-\
0ec29b1cccb3"],

Cell["\<\
In this expression the symbols du, dv are pure symbols; they don\
\[CloseCurlyQuote]t have neither definitions nor values:\
\>", "Text",
 CellChangeTimes->{{3.693055911547058*^9, 3.6930561791687717`*^9}, 
   3.693319828527966*^9, {3.6937496369515877`*^9, 3.69374964383136*^9}, 
   3.696257566180237*^9, 3.696257613171917*^9, {3.6963436212650127`*^9, 
   3.696343635248769*^9}},ExpressionUUID->"0ad40cb4-3b24-461e-a40d-\
5d71de5a5490"],

Cell[BoxData[
 RowBox[{"ValueQ", "[", "dv", "]"}]], "Input",
 CellChangeTimes->{{3.693056190129706*^9, 3.6930562020576477`*^9}, 
   3.693056248302834*^9},ExpressionUUID->"301f23ba-8be1-4572-b12c-\
10a217af0f37"],

Cell[BoxData[
 RowBox[{"Definition", "[", "du", "]"}]], "Input",
 CellChangeTimes->{{3.693056212378481*^9, 
  3.69305626508105*^9}},ExpressionUUID->"7a501258-e10b-40db-9044-\
2442cf613e5e"],

Cell[BoxData[
 RowBox[{"Head", "[", "du", "]"}]], "Input",
 CellChangeTimes->{{3.693056332235083*^9, 3.693056347344201*^9}, {
  3.6930571407372*^9, 
  3.693057206640229*^9}},ExpressionUUID->"c7934590-baa9-4239-a0ee-\
5f9dfa3a454b"],

Cell["In traditional notation the identity", "Text",
 CellChangeTimes->{{3.696258078064068*^9, 3.696258121223833*^9}, 
   3.696258894754039*^9, {3.6963437837995253`*^9, 
   3.696343786974824*^9}},ExpressionUUID->"94a90e1b-f3eb-4b2c-9d3c-\
5b1db1b1ccd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "u"], 
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], " ", "du"}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "v"], 
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], " ", "dv"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6962581355842333`*^9, 3.696258158887925*^9}, {
   3.696258201837515*^9, 3.696258273655408*^9}, 
   3.696258902535078*^9},ExpressionUUID->"687866df-3742-422e-b348-\
21c40602e1aa"],

Cell["\<\
is evaluated asTrue if the symbols du, dv are replaced by the corresponding \
cobasis covectors:\
\>", "Text",
 CellChangeTimes->{{3.696258427149444*^9, 3.696258522933071*^9}, {
  3.69634382307119*^9, 
  3.696343860839274*^9}},ExpressionUUID->"140eaf65-9197-4e73-a39d-\
619fe8f7a18d"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"du", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"d", "[", "u", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ",", 
    RowBox[{"dv", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"d", "[", "v", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{3.6962583158543377`*^9, 
  3.6962583573124037`*^9},ExpressionUUID->"f0f81e41-e2ec-4242-8550-\
031230790e1c"],

Cell["The short form of these covectors are ", "Text",
 CellChangeTimes->{{3.696343909373968*^9, 3.696343962669691*^9}, {
  3.696344655999831*^9, 
  3.6963446857514067`*^9}},ExpressionUUID->"fe53e24c-f9ca-4ba1-9fcc-\
fb28c6ad10e8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"du", "=", 
  RowBox[{
   RowBox[{"d", "[", "u", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.6962585330754833`*^9, {3.696258574109909*^9, 3.696258592004774*^9}, {
   3.696344694335762*^9, 
   3.696344697664311*^9}},ExpressionUUID->"c7ddd504-dc0d-42c1-afda-\
872b4bb008d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.708321848497007*^9},ExpressionUUID->"f5b1b4b9-5a7e-4b49-896c-\
1728cd47ae72"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dv", "=", 
  RowBox[{
   RowBox[{"d", "[", "v", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.696258615309144*^9, {3.69634470551229*^9, 
   3.696344710248323*^9}},ExpressionUUID->"cfaf23ee-c631-42f6-a400-\
232166e8206d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7083218485262823`*^9},ExpressionUUID->"45b21dd6-d271-431f-b3cc-\
5b7268a3b3c9"]
}, Open  ]],

Cell["\<\
Here is a simple notation for the basis 1-forms in any dimension:\
\>", "Text",
 CellChangeTimes->{{3.695620384243918*^9, 3.695620440795226*^9}, {
  3.696260069361161*^9, 
  3.696260082376829*^9}},ExpressionUUID->"d53b4dee-bd04-4bdf-8421-\
8429226ebdce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"dim", ",", "dx"}], "]"}], ";", 
  RowBox[{
   RowBox[{"dx", "[", 
    RowBox[{"i_", ",", 
     RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"x", "[", "i", "]"}], "]"}], "[", 
    RowBox[{"lts", "[", 
     RowBox[{"vec", "[", 
      RowBox[{"x", ",", "n"}], "]"}], "]"}], "]"}]}], ";", 
  RowBox[{"dim", "=", " ", "2"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694354120125146*^9, 3.6943541469447536`*^9}, {
   3.694354306893662*^9, 3.6943543957111673`*^9}, {3.69435446903512*^9, 
   3.6943545269268713`*^9}, 3.69554179535201*^9, {3.695541884131007*^9, 
   3.6955419275189533`*^9}, {3.695541964101838*^9, 3.695542006397696*^9}, {
   3.69554211947031*^9, 3.6955421579330463`*^9}, {3.69562610651618*^9, 
   3.695626203487417*^9}, {3.696140461379093*^9, 3.696140483422941*^9}, 
   3.696260217554976*^9},ExpressionUUID->"e43cb534-c730-46e5-8e55-\
a3d13a384d61"],

Cell["In the case dim =2 one has", "Text",
 CellChangeTimes->{{3.696260280887217*^9, 
  3.696260324559166*^9}},ExpressionUUID->"90986892-075e-4e43-b8f6-\
788fd22fcef4"],

Cell[BoxData[
 RowBox[{"dx", "[", "1", "]"}]], "Input",ExpressionUUID->"e2fdb70e-3fcd-4509-8d9d-1f8a9fcca2bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"du", "\[Equal]", 
   RowBox[{"dx", "[", "1", "]"}]}], "&&", " ", 
  RowBox[{"dv", "\[Equal]", " ", 
   RowBox[{"dx", "[", "2", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.696260162399474*^9, 3.6962601934087267`*^9}, {
   3.696260229824136*^9, 3.696260244119935*^9}, 3.696344794413104*^9, {
   3.696344836464473*^9, 
   3.696344863926165*^9}},ExpressionUUID->"7f76d65f-f2d9-4855-9ba5-\
fee54270a9f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "5"}], ";", " ", 
  RowBox[{"dx", "[", "5", "]"}]}]], "Input",
 CellChangeTimes->{{3.695626034346772*^9, 
  3.6956260539287777`*^9}},ExpressionUUID->"e26a43a3-0a22-4f63-94e7-\
3408cb6459f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.696260122043179*^9, 
  3.6962601256571217`*^9}},ExpressionUUID->"8b9ae88d-403c-4f4b-a749-\
6d3416d2966e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}]}], "]"}], ".", 
  RowBox[{"vec", "[", "dx", "]"}]}]], "Input",
 CellChangeTimes->{{3.6930366299152803`*^9, 3.6930367631795387`*^9}, {
   3.69625692620536*^9, 3.696256928145835*^9}, 3.696256981477386*^9, 
   3.6962594728587112`*^9},ExpressionUUID->"3b43ef42-9e01-4fa1-8caa-\
dc753da90c18"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{
   RowBox[{"d", "[", "f", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.696344285462213*^9, 3.6963442928517847`*^9}, 
   3.696344323204466*^9},ExpressionUUID->"95356add-e4dc-4121-9617-\
5ee94db748c8"],

Cell[BoxData[
 RowBox[{"dx", "[", "2", "]"}]], "Input",
 CellChangeTimes->{
  3.696344185945878*^9},ExpressionUUID->"7bbed2e1-0717-4546-bd5b-\
b4764ce80697"],

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"dx", "[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.693056332235083*^9, 3.693056347344201*^9}, {
  3.6930571407372*^9, 
  3.693057182217705*^9}},ExpressionUUID->"31f2bb3f-3447-4103-a643-\
8ef129c22fa5"],

Cell[BoxData[
 RowBox[{"ValueQ", "[", 
  RowBox[{"dx", "[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.693056332235083*^9, 3.693056347344201*^9}, {
   3.6930571407372*^9, 3.693057182217705*^9}, 3.693057248168352*^9, {
   3.693057283719982*^9, 
   3.693057287407494*^9}},ExpressionUUID->"6e08a3bb-615f-4e9c-9ed9-\
c482ba59003e"],

Cell["\<\
The differential of a vector function is the vector of the differentials of \
its components:\
\>", "Text",
 CellChangeTimes->{{3.586664784821635*^9, 3.586664824405899*^9}, {
   3.586672145190624*^9, 3.5866721496778803`*^9}, 3.5998049367289324`*^9, {
   3.693058139655883*^9, 
   3.69305814555965*^9}},ExpressionUUID->"64bff028-3fba-462a-a382-\
568174705f12"],

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5867577346292953`*^9, 
  3.5867577393255634`*^9}},ExpressionUUID->"860f5781-a67d-461c-9a54-\
bd9ed1122337"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586608541643092*^9, 3.586608570113142*^9}, {
  3.696344916505396*^9, 
  3.696344922071712*^9}},ExpressionUUID->"e9b51be6-f3a5-45c9-8f80-\
aa4ad8b9c971"],

Cell["This is a vector of differential forms:", "Text",
 CellChangeTimes->{{3.5861755001530676`*^9, 3.586175567096896*^9}, 
   3.586175620051925*^9, {3.586175719948639*^9, 3.586175730684253*^9}, {
   3.586665765597732*^9, 
   3.5866657669328084`*^9}},ExpressionUUID->"91760962-7f25-40f0-a3a4-\
cf4195093f68"],

Cell[BoxData[
 RowBox[{"%", "==", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"du", ",", "dv"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.58617394101589*^9, 3.5861739511384687`*^9}, {
   3.586175358458963*^9, 3.586175475179639*^9}, {3.58617562555624*^9, 
   3.586175682092474*^9}, {3.5862639673368874`*^9, 3.5862639758653755`*^9}, 
   3.6148618495195217`*^9, 3.614863501500024*^9, {3.693037972802931*^9, 
   3.693037997466877*^9}, 3.6930381945590773`*^9, {3.696344982710898*^9, 
   3.696344990629681*^9}, 
   3.696345036533124*^9},ExpressionUUID->"032332a8-eb0e-4cec-8ca1-\
d25a51e0d8b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"du", ",", "dv"}], "}"}]}], "\[Equal]", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"f", "[", "i", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"du", ",", "dv"}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]], "Input",ExpressionUUID->\
"a0114adb-0b7a-47ae-ade7-cafeba37a919"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"sf", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", " ", "u"}], "]"}], ",", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"sf", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", " ", "v"}], "]"}]}], "}"}], 
    "]"}], ".", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "u", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "v", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6092308865074997`*^9, 3.609231047065683*^9}, {
   3.6092310939473643`*^9, 3.6092311331686077`*^9}, {3.692780525938285*^9, 
   3.692780648703126*^9}, {3.6927808758186274`*^9, 3.692780896238304*^9}, {
   3.6927809374470053`*^9, 3.692780957824445*^9}, {3.6927810362151423`*^9, 
   3.692781112410828*^9}, 3.693058468997448*^9, {3.693058504085647*^9, 
   3.69305853425334*^9}, {3.693058591778377*^9, 3.693058596492669*^9}, {
   3.693058682985548*^9, 3.69305871817187*^9}, 3.69305882269096*^9, {
   3.693058854787471*^9, 3.693058944114307*^9}, 3.6930590412093353`*^9, {
   3.693059081449355*^9, 3.6930591503526897`*^9}, {3.6930591866087713`*^9, 
   3.693059213728507*^9}, 3.693059249064006*^9, 
   3.693059282526655*^9},ExpressionUUID->"a56e506c-b3d8-4e24-af7d-\
108bb30f1019"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t"}], "}"}], " "}]], "Input",
 CellChangeTimes->{{3.586232907051381*^9, 3.586232990511528*^9}, {
  3.586233084673293*^9, 3.586233102675725*^9}, {3.5862332045595036`*^9, 
  3.586233306552483*^9}, {3.586693207585164*^9, 3.586693231078806*^9}, {
  3.5866932664596677`*^9, 3.5866933097341437`*^9}, {3.69278215355367*^9, 
  3.692782159553932*^9}},ExpressionUUID->"0b61b578-41f1-409c-8302-\
b120837447bd"],

Cell["Remember also  the TensorProduct:", "Text",
 CellChangeTimes->{{3.6092267184271193`*^9, 3.609226736707165*^9}, {
  3.6092315366386847`*^9, 
  3.609231550774493*^9}},ExpressionUUID->"a22ec0e6-c33e-484b-9f59-\
e155027d357a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"sf", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "\[TensorProduct]", 
   "du"}], "+", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"sf", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}], "\[TensorProduct]", 
   "dv"}]}]], "Input",
 CellChangeTimes->{{3.6092255700064335`*^9, 3.6092255957509055`*^9}, {
  3.6092256366472445`*^9, 3.6092256596085577`*^9}, {3.6092257240252423`*^9, 
  3.6092257378640337`*^9}, {3.6092259323801594`*^9, 3.6092259767666984`*^9}, {
  3.696345113028173*^9, 
  3.6963451247001257`*^9}},ExpressionUUID->"641f7efa-8ea0-484f-a04e-\
249dae3d7361"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6092256755794716`*^9, 
  3.609225686205079*^9}},ExpressionUUID->"3ff3f038-0bee-4118-bd2d-\
1d9e397169f4"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.2. Multilinear Functions. p- Forms", "Subsubsection",
 CellChangeTimes->{{3.693656305930441*^9, 3.6936563313300037`*^9}, {
   3.693661454571966*^9, 3.693661459419652*^9}, {3.6937499043096313`*^9, 
   3.69374993241271*^9}, {3.693750302993585*^9, 3.693750310249486*^9}, 
   3.694002564915666*^9, {3.6940026887703543`*^9, 3.694002723498115*^9}, 
   3.696345339722332*^9, 3.696345502688787*^9, 
   3.696389095167131*^9},ExpressionUUID->"9cb85930-d995-42ff-8034-\
a40b701ae762"],

Cell[TextData[{
 "In this subsection we consider multilinear functions on tangent bundles of \
manifolds ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", 
    RowBox[{"n", " "}]], TraditionalForm]],ExpressionUUID->
  "a63aaa50-dc24-4739-8068-2707be2d0cce"],
 ", mainly surfaces n=2, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["M", 
     RowBox[{"n", " "}]], "=", "SF"}], TraditionalForm]],ExpressionUUID->
  "f2fa5be0-def6-49a5-9166-1cef008b0587"],
 "  (see subsection 1.2.4):"
}], "Text",
 CellChangeTimes->{{3.6937506643585377`*^9, 3.693750787925602*^9}, {
  3.693750958876197*^9, 3.693750989059917*^9}, {3.693751098643107*^9, 
  3.693751132778926*^9}, {3.694358078372623*^9, 3.6943583032859163`*^9}, {
  3.694407846976388*^9, 
  3.6944078583649883`*^9}},ExpressionUUID->"7c12ea26-d9af-49d4-9234-\
bad8a3afe486"],

Cell[BoxData[
 RowBox[{"TSF", " ", "=", 
  RowBox[{
   UnderscriptBox[
    RowBox[{" ", "\[Union]"}], 
    RowBox[{"u", "\[Element]", "U"}]], " ", 
   SubscriptBox["T", "u"], " ", "SF"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.687272492376625*^9, 
  3.687272579246892*^9}},ExpressionUUID->"8f9775af-e4c3-4fae-8782-\
e9d4c784a526"],

Cell[TextData[{
 "A",
 StyleBox[" multilinear function of degree p",
  FontColor->RGBColor[0, 0, 1]],
 " is a field of maps"
}], "Text",
 CellChangeTimes->{{3.693751354009303*^9, 
  3.693751404064958*^9}},ExpressionUUID->"b0cb5030-342a-41bb-ae0f-\
7275e75125d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"w", "[", "u", "]"}], ":", " ", "v1"}], ",", "...", ",", 
  RowBox[{"vp", "\[Element]", 
   RowBox[{
    RowBox[{
     SubscriptBox["T", "u"], " ", "SF"}], "\[RightTeeArrow]", " ", 
    RowBox[{
     RowBox[{"w", "[", "u", "]"}], "[", 
     RowBox[{"v1", ",", "...", ",", "vp"}], "]"}]}], "\[Element]", " ", 
   "R"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.693751427321993*^9, 3.6937514924883623`*^9}, {
  3.693751537128004*^9, 3.693751537888113*^9}, {3.6937515686891537`*^9, 
  3.693751601943386*^9}, {3.6937516477793922`*^9, 3.6937516505750732`*^9}, {
  3.693751713718862*^9, 
  3.693751760198419*^9}},ExpressionUUID->"59da13cd-e46e-4655-9fd5-\
c7516100884a"],

Cell["\<\
being linear in each vector argument vi, i=1,...,p, and depending smoothly on \
u. As an example we know the bilinear first fundamental form of the surface, \
see Subsection 1.2.2.  The coordinates of the multilinear form are its values \
on all tuples of basis vector fields. For example :\
\>", "Text",
 CellChangeTimes->{{3.693751833679224*^9, 3.693751949660561*^9}, {
   3.6937520238361588`*^9, 3.6937520378759604`*^9}, {3.693752114179384*^9, 
   3.693752257114418*^9}, {3.693752682391115*^9, 3.693752772118235*^9}, {
   3.694357798476843*^9, 3.694357808230576*^9}, 3.694357882174383*^9, {
   3.694357912541995*^9, 3.694357954669654*^9}, {3.694357997373414*^9, 
   3.69435801375695*^9}, {3.694417016368166*^9, 3.694417117574988*^9}, 
   3.694417574603421*^9, {3.6947595228976793`*^9, 3.694759527753152*^9}, 
   3.696345555416809*^9},ExpressionUUID->"6ebcd6c5-5392-4958-94b6-\
9fe8d3ba776b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{"stb", "[", 
       RowBox[{"i", ",", "2"}], "]"}], ",", 
      RowBox[{"stb", "[", 
       RowBox[{"j", ",", "2"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "\[Equal]", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"rgT", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694417333513115*^9, 3.6944175422380037`*^9}, 
   3.694417582720097*^9},ExpressionUUID->"aed97f5a-47d8-4254-9278-\
1e8c1a05b72b"],

Cell["\<\
the functions rgT[i,j][sf][u,v] are the coordinates of the first fundamental \
form with respect to the standard basis of the tangent planes. Obviously, the \
coordinates define the form:\
\>", "Text",
 CellChangeTimes->{{3.694417674714266*^9, 3.6944178363291388`*^9}, 
   3.696345714846681*^9},ExpressionUUID->"31e778f8-ac61-4b62-ad38-\
9333d6f660d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fund1", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"s", ",", "2"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"t", ",", "2"}], "]"}]}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{"s", "[", "i", "]"}], "*", 
     RowBox[{"t", "[", "j", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694417908505231*^9, 
  3.694418116319725*^9}},ExpressionUUID->"23afcc0e-777f-42ac-8808-\
bceb11cfb915"],

Cell["\<\
The usual way to define a multilinear function is to give the Array of its \
coordinates. Let us assume that n=dim and in case n=3:\
\>", "Text",
 CellChangeTimes->{{3.693751833679224*^9, 3.693751949660561*^9}, {
   3.6937520238361588`*^9, 3.6937520378759604`*^9}, {3.693752114179384*^9, 
   3.693752257114418*^9}, {3.693752682391115*^9, 3.693752772118235*^9}, {
   3.694357798476843*^9, 3.694357808230576*^9}, 3.694357882174383*^9, {
   3.694357912541995*^9, 3.694357954669654*^9}, {3.694357997373414*^9, 
   3.69435801375695*^9}, {3.694417016368166*^9, 3.694417148086772*^9}, {
   3.694417180198279*^9, 3.694417187054386*^9}, {3.69441722671809*^9, 
   3.694417266789906*^9}, 3.694417328173805*^9, {3.6944182785014553`*^9, 
   3.694418290868824*^9}, {3.694418322988647*^9, 3.694418386076145*^9}, {
   3.69444499492725*^9, 
   3.6944450068948936`*^9}},ExpressionUUID->"684cff35-3bc3-4519-8eef-\
8205f22eac97"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "3"}], ";", 
  RowBox[{"u", "\[Element]", " ", 
   SuperscriptBox["M", 
    RowBox[{"3", " "}]]}], ";", " ", 
  RowBox[{
   RowBox[{"u", " ", "\[RightTeeArrow]", " ", 
    RowBox[{"vec", "[", "u", "]"}]}], " ", "\[Element]", " ", 
   SuperscriptBox["R", "3"]}]}]], "Input",
 CellChangeTimes->{{3.6943580298931417`*^9, 3.694358035969597*^9}, {
  3.694358372954813*^9, 3.6943584559943447`*^9}, {3.696345773422647*^9, 
  3.696345778366481*^9}, {3.69634582916956*^9, 3.696345851421402*^9}, {
  3.696345921714446*^9, 
  3.696345959277123*^9}},ExpressionUUID->"b2479cde-d66a-457e-8604-\
348b234ffc09"],

Cell[TextData[{
 "is a coordinate system, a",
 StyleBox[" chart",
  FontColor->RGBColor[0, 0, 1]],
 " on ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", 
    RowBox[{"n", " "}]], TraditionalForm]],ExpressionUUID->
  "8a7fcaab-a591-4e77-b069-68df36b7f068"],
 ". Then a multilinear function on ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", 
    RowBox[{"n", " "}]], TraditionalForm]],ExpressionUUID->
  "57864ce5-1033-4d20-b320-f642342f916a"],
 "in p variables is defined by its Array  of ",
 StyleBox["coordinate functions",
  FontColor->RGBColor[0, 0, 1]],
 " with respect to the basis fields ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "j"], TraditionalForm]],ExpressionUUID->
  "60473853-0aae-4f29-8b31-f0a0bbe35f77"],
 "= b[u1,...,un][i], i = 1,...,n:"
}], "Text",
 CellChangeTimes->{{3.694358483929208*^9, 3.694358538337081*^9}, {
  3.694358647584063*^9, 3.6943587762793417`*^9}, {3.694358810359085*^9, 
  3.694358823126945*^9}, {3.6944448994640627`*^9, 3.694444968703525*^9}, {
  3.694445033735433*^9, 
  3.694445096454873*^9}},ExpressionUUID->"c32c2a3e-79fa-4d06-8976-\
5e98ccc04b03"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ca", "[", 
    RowBox[{"u", ",", "..."}], "]"}], "[", 
   RowBox[{"i1", ",", "...", ",", "ip"}], "]"}], " ", "=", 
  RowBox[{
   RowBox[{"w", "[", 
    RowBox[{"u", "..."}], "]"}], "[", 
   RowBox[{
    SubscriptBox["b", "i1"], ",", "...", ",", 
    SubscriptBox["b", "ip"]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.694416908180756*^9, 3.6944169317603827`*^9}, {
   3.6944184935961657`*^9, 3.694418717394562*^9}, 
   3.69470268130378*^9},ExpressionUUID->"fdf6bdda-8786-4d0b-ba2c-\
deb138a6bcf7"],

Cell[TextData[{
 "The Array ww  of the coordinates of the multilinear function w over the \
tangent bundle T",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "ccac353b-a6c9-4ad7-8fc5-4ae47b36a2cd"],
 " is of a special type: The dimension of the arguments equal the dimension n \
of the manifold. Thus it has the dimensions"
}], "Text",
 CellChangeTimes->{{3.694418793133697*^9, 3.6944188335043087`*^9}, {
   3.694418878888053*^9, 3.694418974591164*^9}, {3.6944190118789177`*^9, 
   3.6944192596053343`*^9}, 3.694763505299395*^9, 
   3.696346076451874*^9},ExpressionUUID->"48dec4a5-0917-4c1b-8446-\
6c81cd45bb04"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Dimensions", "[", "ww", "]"}], " ", "\[Equal]", " ", 
  RowBox[{"Table", "[", 
   RowBox[{"n", ",", 
    RowBox[{"{", "p", "}"}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.694419269056101*^9, 
  3.694419317917357*^9}},ExpressionUUID->"7e848b8e-a9cf-4636-b180-\
12fcf97a46ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"w", ",", "ww"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"ww", "[", 
     RowBox[{"a_", ",", "p_"}], "]"}], "[", "u__", " ", "]"}], ":=", " ", 
   RowBox[{"Array", "[", " ", 
    RowBox[{
     RowBox[{"a", "[", "u", "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Length", "[", 
        RowBox[{"{", "u", "}"}], "]"}], ",", 
       RowBox[{"{", "p", "}"}]}], "]"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694358850421303*^9, 3.6943588660790052`*^9}, {
   3.694358900006742*^9, 3.694358958406794*^9}, {3.694359028717327*^9, 
   3.694359130401012*^9}, {3.6943591957052937`*^9, 3.694359209212645*^9}, {
   3.694359705689712*^9, 3.694359717568577*^9}, {3.694419344072442*^9, 
   3.694419364428403*^9}, 
   3.694419410988138*^9},ExpressionUUID->"19fb769d-aab8-4672-94a4-\
6b07808b4112"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ww", "::", "usage"}], " ", "=", " ", 
   "\"\<ww[a,p][u1,...,un]defines an Array field of elements a[i1,...,ip], \
depending on u1,..,un, with Dimensions Table[n,{p}]which may be used as the \
coordinate Array of a multilinear function of p vector variabes.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694762823936363*^9, 3.6947628420056973`*^9}, {
   3.694762875910056*^9, 3.694762973605102*^9}, {3.6947630108852*^9, 
   3.6947630631884623`*^9}, {3.694763164651731*^9, 3.694763165195709*^9}, {
   3.694763209499551*^9, 3.694763275883258*^9}, {3.694763322538971*^9, 
   3.694763372786172*^9}, {3.6947634039064283`*^9, 3.694763486545493*^9}, 
   3.694763553061111*^9},ExpressionUUID->"72f483e1-4df4-488e-bd18-\
3432688cecf8"],

Cell["For example, if p=3 and", "Text",
 CellChangeTimes->{{3.694359914541367*^9, 3.694359964100976*^9}, {
   3.694408012267386*^9, 3.69440804873904*^9}, {3.694419461819045*^9, 
   3.694419523754744*^9}, 3.694445233069199*^9, 3.694760009605442*^9, 
   3.694760041132847*^9, {3.696346325105044*^9, 
   3.696346327448954*^9}},ExpressionUUID->"d064fdb7-e548-4f64-a34b-\
1044e75cb2fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.696346272871789*^9, 3.696346274521687*^9}, {
  3.69634633321073*^9, 
  3.6963463370814867`*^9}},ExpressionUUID->"7fe0af69-ada4-4bfe-8f83-\
86cd3710f3ec"],

Cell[BoxData[
 RowBox[{"wa", "=", 
  RowBox[{
   RowBox[{"ww", "[", 
    RowBox[{
     RowBox[{"a", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "3"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694759851931691*^9, 3.694759908414548*^9}, {
  3.694759938474683*^9, 
  3.694759944870719*^9}},ExpressionUUID->"19a4c6d9-e707-46c0-8feb-\
2dfefc20826a"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "wa", "]"}]], "Input",
 CellChangeTimes->{{3.69441959523587*^9, 
  3.694419617090547*^9}},ExpressionUUID->"2b05612a-56dd-46cd-8561-\
c1e2988c6e15"],

Cell["The corresponding multilinear function then is", "Text",
 CellChangeTimes->{{3.694419717680773*^9, 3.694419745112514*^9}, 
   3.694420158684895*^9},ExpressionUUID->"c374d821-30c6-4b74-8a5c-\
4c32817d7552"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fwa", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], "[", 
   RowBox[{"v1_", ",", "v2_", ",", "v3_"}], "]"}], ":=", " ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"wa", "[", 
      RowBox[{"[", 
       RowBox[{"i1", ",", "i2", ",", "i3"}], "]"}], "]"}], "*", 
     RowBox[{"v1", "[", 
      RowBox[{"[", "i1", "]"}], "]"}], "*", 
     RowBox[{"v2", "[", 
      RowBox[{"[", "i2", "]"}], "]"}], "*", 
     RowBox[{"v3", "[", 
      RowBox[{"[", "i3", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i2", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i3", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694419754094748*^9, 3.694420035343277*^9}, {
  3.6944201990975533`*^9, 
  3.6944202049016457`*^9}},ExpressionUUID->"a551b11a-4c90-40f8-8464-\
26a9a6900d7f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fwa", "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", "x", "]"}], ",", 
   RowBox[{"vec", "[", "y", "]"}], ",", 
   RowBox[{"vec", "[", "z", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694420046056281*^9, 3.694420116550179*^9}, {
  3.6963464005062733`*^9, 
  3.696346429472928*^9}},ExpressionUUID->"f959657e-8b81-4614-bd77-\
32e73b422e06"],

Cell["\<\
The general definition of a multilinear function by its Array w of  \
coordinates is\
\>", "Text",
 CellChangeTimes->{{3.6944204152583323`*^9, 
  3.694420474945999*^9}},ExpressionUUID->"0a99cdaf-958e-47e0-9bff-\
2adcd7b47583"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"w", ",", "val"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"val", "[", "w_", "]"}], "[", "u__", "]"}], "[", "v__", "]"}], 
   " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"pp", "=", 
        RowBox[{"{", "}"}]}], ",", " ", 
       RowBox[{"dp", " ", "=", " ", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "u", "}"}], "]"}]}], ",", 
       RowBox[{"np", "=", "0"}], ",", "i", ",", 
       RowBox[{"nv", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "v", "}"}], "]"}]}], ",", "jj"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "w", "]"}], "===", " ", "List"}], ",", 
        RowBox[{
         RowBox[{"pp", "=", 
          RowBox[{"Dimensions", "[", "w", "]"}]}], ";", 
         RowBox[{"np", "=", 
          RowBox[{"Length", "[", "pp", "]"}]}]}], ",", " ", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Invalid argument \>\"", ",", " ", "w", ",", "\"\<!\>\""}], 
          "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{"pp", " ", "\[Equal]", 
          RowBox[{"Table", "[", 
           RowBox[{"dp", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "np"}], "}"}]}], "]"}]}], "]"}], ",", " ", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Invalid argument \>\"", ",", " ", "w", ",", "\"\<!\>\""}], 
          "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", " ", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", " ", 
        RowBox[{"i", "\[LessEqual]", "nv"}], ",", 
        RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"Not", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Head", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "v", "}"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "===", " ", "List"}], "]"}], 
             ")"}], "&&", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Length", "[", 
               RowBox[{
                RowBox[{"{", "v", "}"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[Equal]", " ", 
              "dp"}], ")"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<Argument \>\"", ",", 
             RowBox[{
              RowBox[{"{", "v", "}"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", "\"\< invalid!\>\""}], 
            "]"}], ";", 
           RowBox[{"Return", "[", "]"}]}]}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"jj", " ", "=", 
       RowBox[{"Tuples", "[", 
        RowBox[{
         RowBox[{"Range", "[", "dp", "]"}], ",", "nv"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"w", "[", 
          RowBox[{"[", 
           RowBox[{"lts", "[", 
            RowBox[{"jj", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "]"}], "*", 
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"{", "v", "}"}], "[", 
             RowBox[{"[", "k", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"jj", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "nv"}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"dp", "^", "nv"}]}], "}"}]}], "]"}]}]}], "]"}]}]}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.694359994145073*^9, 3.694360028500808*^9}, {
   3.694360082404924*^9, 3.694360176196384*^9}, {3.6943602063477297`*^9, 
   3.694360226003807*^9}, {3.6943602571716223`*^9, 3.694360292745573*^9}, {
   3.694360413090001*^9, 3.694360413465519*^9}, 3.694408182923888*^9, {
   3.694408233698605*^9, 3.694408269666717*^9}, {3.694408303593569*^9, 
   3.6944083141942663`*^9}, {3.694408378073564*^9, 3.6944084416807823`*^9}, {
   3.694408776141704*^9, 3.694408822197476*^9}, {3.694408961204042*^9, 
   3.69440905846738*^9}, {3.6944090917801857`*^9, 3.694409174522627*^9}, {
   3.694409215394433*^9, 3.694409391680705*^9}, {3.694409433975556*^9, 
   3.694409445159487*^9}, 3.694409477496471*^9, {3.6944097224061832`*^9, 
   3.694409806675989*^9}, 3.69440985268608*^9, {3.694409944131505*^9, 
   3.694409958692175*^9}, {3.694409989691217*^9, 3.6944099986606083`*^9}, {
   3.694410075443997*^9, 3.694410076025577*^9}, {3.6944102308579063`*^9, 
   3.694410231528661*^9}, {3.694410285150093*^9, 3.694410299479342*^9}, 
   3.69441042254078*^9, 3.6944104830302134`*^9, {3.694410531323791*^9, 
   3.6944105384071493`*^9}, {3.694410574855517*^9, 3.694410583407029*^9}, {
   3.694410673540824*^9, 3.694410701325795*^9}, 3.694410918792918*^9, 
   3.694411111999198*^9, {3.694411208213234*^9, 3.694411224169442*^9}, {
   3.6944112953340178`*^9, 3.6944113158562*^9}, {3.6944114713155003`*^9, 
   3.694411482135517*^9}, {3.6944116239932327`*^9, 3.6944116252216043`*^9}, 
   3.694411762030542*^9, 3.6944118009194117`*^9, 3.694411832440154*^9, 
   3.694411871219738*^9, {3.6944119449434233`*^9, 3.694411947683618*^9}, {
   3.694412133930592*^9, 3.694412153401095*^9}, {3.6944122165292873`*^9, 
   3.694412224901614*^9}, {3.694412264625074*^9, 3.694412330716341*^9}, {
   3.694412463595096*^9, 3.694412468082416*^9}, {3.694412565254222*^9, 
   3.6944125774933357`*^9}, {3.6944126076461353`*^9, 3.694412697757371*^9}, {
   3.694413396327321*^9, 3.694413482833023*^9}, {3.694413523160513*^9, 
   3.694413523535996*^9}, {3.694413563888132*^9, 3.69441363160765*^9}, {
   3.694413662584303*^9, 3.694413747319141*^9}, {3.694413822870976*^9, 
   3.694413849078458*^9}, 3.694413904174274*^9, {3.694414009797668*^9, 
   3.694414088524703*^9}, {3.69441432888702*^9, 3.694414360610578*^9}, 
   3.69441465898552*^9, {3.694414689720132*^9, 3.694414739543906*^9}, {
   3.694414773447377*^9, 3.694414939720921*^9}, {3.6944149768006268`*^9, 
   3.694415122477685*^9}, {3.694415183669004*^9, 3.694415184421383*^9}, {
   3.6961402894146013`*^9, 
   3.696140309971816*^9}},ExpressionUUID->"9b33321e-3ed0-4c9d-92a3-\
642b2bef97bb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"val", "::", "usage"}], " ", "=", " ", 
   "\"\<val[a][u1,...,un][v1,...,vp] calculates the value of a field of \
multilinear functions with coordinate Array a for the tangent vectors \
v1,..,vp.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694763572302384*^9, 3.694763818926468*^9}, {
  3.694763877273231*^9, 
  3.694763906265829*^9}},ExpressionUUID->"e0c4c360-b62c-4f1f-94e1-\
2d7024f6ecbb"],

Cell[BoxData["dim"], "Input",
 CellChangeTimes->{{3.69638673621898*^9, 
  3.696386739925219*^9}},ExpressionUUID->"d2d1f869-ad80-47bc-b994-\
41fc6db236db"],

Cell[TextData[{
 StyleBox["Example 1",
  FontColor->RGBColor[0, 0, 1]],
 ". We consider bilinear functions. The defining Array may depend on some \
additional parameters, here e.g. vec[x]:"
}], "Text",
 CellChangeTimes->{{3.694433001437958*^9, 3.694433080933504*^9}, {
   3.694445320252532*^9, 3.6944453555799217`*^9}, 3.694445421291333*^9, {
   3.694445519114778*^9, 
   3.6944455574505777`*^9}},ExpressionUUID->"c05043df-6709-415f-a8bf-\
6f8293ea7479"],

Cell[BoxData[
 RowBox[{"wb", "=", 
  RowBox[{"Array", "[", 
   RowBox[{
    RowBox[{"b", "[", 
     RowBox[{"u", ",", "v", ",", 
      RowBox[{"vec", "[", "x", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6944084934827347`*^9, 3.6944085199435*^9}, 
   3.6944153247580442`*^9, {3.6944154306337557`*^9, 3.694415436800091*^9}, {
   3.6944156427367887`*^9, 3.694415664345463*^9}, 3.694415774745653*^9, 
   3.69442083782119*^9, {3.6944209341905823`*^9, 3.694420992174296*^9}, {
   3.694432914055294*^9, 
   3.6944329260470257`*^9}},ExpressionUUID->"d76ee3de-0378-4840-9c69-\
1c02246c996b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"val", "[", "wb", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"s", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"t", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694415543048897*^9, 3.694415551006918*^9}, {
  3.694415703187451*^9, 3.6944157033648787`*^9}, {3.6944210086432467`*^9, 
  3.694421056501792*^9}, {3.696386876928433*^9, 
  3.6963868965838337`*^9}},ExpressionUUID->"6aa58c04-dabb-40fa-8e54-\
f3eca42ff24b"],

Cell["or it may have constant coordinate functions:", "Text",
 CellChangeTimes->{{3.69443310839719*^9, 
  3.694433143989169*^9}},ExpressionUUID->"86c82e72-c360-46ec-99e5-\
36ae81178192"],

Cell[BoxData[
 RowBox[{"wc", "=", 
  RowBox[{"Array", "[", 
   RowBox[{"c", ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694433186133119*^9, 3.694433207788973*^9}, {
   3.6963870306023617`*^9, 3.6963870334058657`*^9}, 
   3.696387097898342*^9},ExpressionUUID->"464e0b50-d762-48b3-85f4-\
26b8d27f72fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"val", "[", "wc", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"s", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"t", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694415543048897*^9, 3.694415551006918*^9}, {
   3.694415703187451*^9, 3.6944157033648787`*^9}, {3.6944210086432467`*^9, 
   3.694421056501792*^9}, 3.6944332802877007`*^9, {3.6963869517009563`*^9, 
   3.6963869688790092`*^9}, {3.6963871130485086`*^9, 
   3.69638713111712*^9}},ExpressionUUID->"9576f4d5-4db9-4de1-862b-\
94d547e63645"],

Cell["\<\
We consider the first fundamental form of the general surface sf:\
\>", "Text",
 CellChangeTimes->{{3.694445615945932*^9, 
  3.694445705049183*^9}},ExpressionUUID->"96a522c9-9894-4411-a667-\
b0fab7f99edf"],

Cell[BoxData[
 RowBox[{"wfund1", " ", "=", " ", 
  RowBox[{"Table", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"rgT", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694433424637136*^9, 3.6944334517867002`*^9}, 
   3.694433497060726*^9, {3.694433549120246*^9, 3.6944335556581573`*^9}, {
   3.6944338883645277`*^9, 3.694433930440723*^9}, {3.694434013891144*^9, 
   3.694434113974379*^9}, {3.694434151554281*^9, 3.6944342976287413`*^9}, {
   3.694434354160693*^9, 3.694434355268466*^9}, {3.694434397178422*^9, 
   3.6944344225475893`*^9}, {3.694434620309999*^9, 3.6944346233536167`*^9}, 
   3.6944346579536457`*^9},ExpressionUUID->"f570f6e5-6ca1-4eae-9ef9-\
96cdbf16ef5f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"val", "[", "wfund1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"s", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "2"}], "]"}], ",", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"t", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "2"}], "]"}]}], "]"}], 
   "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"s", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
     RowBox[{"vec", "[", 
      RowBox[{"t", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694433583216446*^9, 3.694433616737383*^9}, {
  3.6944336626349688`*^9, 3.694433723162238*^9}, {3.694434460620668*^9, 
  3.694434475795609*^9}, {3.694434515941876*^9, 3.694434532512504*^9}, {
  3.694434679423143*^9, 3.694434685633938*^9}, {3.69638715566963*^9, 
  3.696387165261372*^9}},ExpressionUUID->"bd6cff70-cc84-4837-b705-\
190eee5b6bc9"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.694445738294469*^9, 
  3.694445738296352*^9}},ExpressionUUID->"51c53d3e-470f-4c86-8621-\
955e2bf6cdf4"],

Cell[TextData[{
 StyleBox["Example 2",
  FontColor->RGBColor[0, 0, 1]],
 ". The differential w[u] = d[f][u] of a function is an examples for p=1:"
}], "Text",
 CellChangeTimes->{{3.693751833679224*^9, 3.693751949660561*^9}, {
  3.6937520238361588`*^9, 3.6937520378759604`*^9}, {3.693752114179384*^9, 
  3.693752257114418*^9}, {3.693752682391115*^9, 3.693752772118235*^9}, {
  3.694445782064502*^9, 
  3.6944458326641273`*^9}},ExpressionUUID->"2cdcf7b9-27ec-4db6-9d02-\
55fbf72fd5d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "df", "]"}], ";", 
  RowBox[{"df", " ", "=", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u1", ",", "u2"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.693752292826668*^9, 3.6937523899133177`*^9}, {
  3.693752543770214*^9, 3.6937525578089733`*^9}, {3.694443875024822*^9, 
  3.694443877600718*^9}, {3.694444404057128*^9, 
  3.6944444480678062`*^9}},ExpressionUUID->"19378761-7d2b-4092-91bf-\
44aa4cbd0269"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"val", "[", "df", "]"}], "[", 
   RowBox[{"u1", ",", "u2"}], "]"}], "[", 
  RowBox[{"vec", "[", 
   RowBox[{"t", "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6944438887803917`*^9, 3.6944439350184317`*^9}, {
   3.694444531392078*^9, 3.694444538347302*^9}, 
   3.696387219268058*^9},ExpressionUUID->"bfc9c506-f959-49c5-952c-\
1ff224fa9b2a"],

Cell[BoxData[
 RowBox[{"vec", "[", 
  RowBox[{"t", "[", 
   RowBox[{"u1", ",", "u2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.694444502236834*^9, 3.694444513139366*^9}, {
   3.694444560898926*^9, 3.694444567899157*^9}, 
   3.696387248243764*^9},ExpressionUUID->"dfa1cb9a-745c-4a8b-bcbe-\
b014db2ba81e"],

Cell[TextData[{
 "t[u1,u2][i] are the coordinates of the vector field vec[t[u1,u2],2] \
\[Element]",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "u"], " ", "SF"}]], "Input",
  CellChangeTimes->{{3.693751427321993*^9, 3.6937514924883623`*^9}, {
   3.693751537128004*^9, 3.693751537888113*^9}, {3.6937515686891537`*^9, 
   3.693751601943386*^9}, {3.6937516477793922`*^9, 3.6937516505750732`*^9}, {
   3.693751713718862*^9, 3.693751760198419*^9}},ExpressionUUID->
  "b9f5e9ce-07b5-4afb-a058-dc7bd7b26fe7"],
 ", u1, u2 the coordinates of the point u of the parameter manifold. \
\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.69375241365628*^9, 3.693752530840128*^9}, {
   3.693752568496141*^9, 3.693752619631555*^9}, {3.693752826501966*^9, 
   3.693752938269075*^9}, {3.693753013476487*^9, 3.693753033244207*^9}, {
   3.694444590082674*^9, 3.6944447455534763`*^9}, 3.6944448196709623`*^9, {
   3.6944457662579947`*^9, 
   3.694445766260064*^9}},ExpressionUUID->"5de08588-ee75-4258-ac28-\
f6474918cbcf"],

Cell[TextData[{
 StyleBox["Example 3",
  FontColor->RGBColor[0, 0, 1]],
 ". Tensor product of multilinear forms.\nThe built-in function"
}], "Text",
 CellChangeTimes->{{3.6955638050521803`*^9, 3.695563865834631*^9}, {
  3.695563984161469*^9, 
  3.695563996361367*^9}},ExpressionUUID->"ce291a75-a595-4dc2-9f02-\
4a90f9f30a53"],

Cell[BoxData[
 RowBox[{"?", "TensorProduct"}]], "Input",
 CellChangeTimes->{{3.69556400490889*^9, 
  3.6955640129298573`*^9}},ExpressionUUID->"364519ec-ff18-42b5-bf64-\
49b380380d6f"],

Cell["\<\
can be used to define a product of multilinear forms, in traditional notation:
let f[u,...][v1,..,  vp] be a field of degree p and h[u,...][w1,...,wq] a \
field of degree q, then\
\>", "Text",
 CellChangeTimes->{{3.695564102368449*^9, 3.695564187047839*^9}, {
  3.6955643197986803`*^9, 3.695564723171267*^9}, {3.695564756723322*^9, 
  3.695564774794908*^9}, {3.695564806290554*^9, 3.695564923367819*^9}, {
  3.6963873358262444`*^9, 
  3.696387341930056*^9}},ExpressionUUID->"b7395d7f-379c-4586-bda7-\
4a49036883bc"],

Cell["\<\
 tprod[f,h][u,...][v1,...,v(p+q)]:= f[u,...][v1,..,  \
vp]*h[u,...][v(p+1)...,v(p+q)] \
\>", "Text",
 CellChangeTimes->{{3.695564102368449*^9, 3.695564187047839*^9}, {
  3.6955643197986803`*^9, 3.695564723171267*^9}, {3.695564756723322*^9, 
  3.695564774794908*^9}, {3.695564806290554*^9, 3.695564893825982*^9}, {
  3.69556493787331*^9, 
  3.6955649491773*^9}},ExpressionUUID->"791ea374-a4ab-4c8f-91aa-f22333552187"],

Cell[TextData[{
 "is a field of multilinear functions of degree p+q, naturally called the ",
 StyleBox["tensor product of the multilinear functions",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.6955649845817823`*^9, 
  3.695565086376031*^9}},ExpressionUUID->"423f591f-07c8-4988-9159-\
3651199765ef"],

Cell["\<\
Consider an example with p =2, q=1. We omit the field variables u...\
\>", "Text",
 CellChangeTimes->{{3.695565161014933*^9, 3.695565173271158*^9}, {
  3.6955652106072807`*^9, 
  3.6955653066300097`*^9}},ExpressionUUID->"2bac922b-50c0-4a3a-8e62-\
da1a8412f472"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", " ", 
  RowBox[{"wa", " ", "=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"a", ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"wb", " ", "=", " ", 
   RowBox[{"vec", "[", "b", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695565182062119*^9, 3.695565192199198*^9}, {
  3.6955653699018583`*^9, 
  3.695565436637395*^9}},ExpressionUUID->"bc3ef6c7-42c1-4bbe-84f9-\
f7907b7da7ca"],

Cell[BoxData[
 RowBox[{"tprodab", " ", "=", " ", 
  RowBox[{"TensorProduct", "[", 
   RowBox[{"wa", ",", "wb"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695565461053184*^9, 3.695565498988969*^9}, {
  3.695565630246961*^9, 
  3.695565631979895*^9}},ExpressionUUID->"4c574c54-73a7-40d7-a684-\
5ac28fc6a39c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"val", "[", "tprodab", "]"}], "[", 
   RowBox[{"u1", ",", "u2", ",", "u3"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", "x1", "]"}], ",", 
   RowBox[{"vec", "[", "x2", "]"}], ",", 
   RowBox[{"vec", "[", "x3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6955655979903717`*^9, 3.6955657652991867`*^9}, {
  3.695566235250277*^9, 
  3.6955662700702467`*^9}},ExpressionUUID->"d49738fa-7eea-43cf-801a-\
87bf5d47fa00"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"val", "[", "wa", "]"}], "[", 
      RowBox[{"u1", ",", "u2", ",", "u3"}], "]"}], "[", 
     RowBox[{
      RowBox[{"vec", "[", "x1", "]"}], ",", 
      RowBox[{"vec", "[", "x2", "]"}]}], "]"}], "*", 
    RowBox[{
     RowBox[{
      RowBox[{"val", "[", "wb", "]"}], "[", 
      RowBox[{"u1", ",", "u2", ",", "u3"}], "]"}], "[", 
     RowBox[{"vec", "[", "x3", "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.695565800619402*^9, 3.695565843393906*^9}, {
  3.695565898115532*^9, 
  3.6955659712493877`*^9}},ExpressionUUID->"461f2998-5296-4133-b256-\
4756a33f9f32"],

Cell["\<\
One  sees that the TensorProduct of the defining Arrays corresponds to the \
product of multilinear functions mentioned above. This product is associative \
(flat) but not commutative:\
\>", "Text",
 CellChangeTimes->{{3.695566374182734*^9, 3.695566379038704*^9}, {
  3.695566946586568*^9, 3.695567034530067*^9}, {3.695567101721135*^9, 
  3.69556714412108*^9}},ExpressionUUID->"38bc6f76-017b-46c0-a007-\
f8a1d7dc3459"],

Cell[BoxData[
 RowBox[{"Attributes", " ", "[", "TensorProduct", "]"}]], "Input",
 CellChangeTimes->{{3.695567159916992*^9, 
  3.695567199513253*^9}},ExpressionUUID->"97eb703e-a8f9-4a6c-a4a1-\
55df773398c9"],

Cell["In our example:", "Text",
 CellChangeTimes->{{3.695567364055256*^9, 
  3.69556738359927*^9}},ExpressionUUID->"fa34d0a0-9ad0-48dc-b14a-\
8505d08cbf81"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"TensorProduct", "[", 
    RowBox[{"wb", ",", "wa"}], "]"}], "-", " ", "tprodab"}], "]"}]], "Input",
 CellChangeTimes->{{3.695567388720354*^9, 
  3.695567478247332*^9}},ExpressionUUID->"1ec5035e-90c4-4aea-a384-\
7aeec188f112"],

Cell[BoxData[
 RowBox[{"wc", "=", " ", 
  RowBox[{"vec", "[", "c", "]"}]}]], "Input",
 CellChangeTimes->{{3.6955675035469313`*^9, 
  3.695567535014544*^9}},ExpressionUUID->"de5234e5-d4db-42dd-8a11-\
388f3a1015dd"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"TensorProduct", "[", 
    RowBox[{"wa", ",", "wb", ",", "wc"}], "]"}], " ", "\[Equal]", 
   RowBox[{"TensorProduct", "[", 
    RowBox[{"wa", ",", 
     RowBox[{"TensorProduct", "[", 
      RowBox[{"wb", ",", "wc"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.695567544176784*^9, 
  3.695567627749848*^9}},ExpressionUUID->"0926f2f2-2ac6-48ed-b24c-\
db7620984b44"],

Cell["Test other appropriate Arrays! \[FilledSquare]", "Text",
 CellChangeTimes->{{3.695567649077299*^9, 
  3.695567741700363*^9}},ExpressionUUID->"b8e929f9-7686-4b3f-a5cf-\
a4b80d20d1ce"],

Cell[TextData[{
 "A multilinear function of p vector variables is named a ",
 StyleBox["p-form",
  FontColor->RGBColor[0, 0, 1]],
 ", if it is antisymmetric  in the vector variables vi:"
}], "Text",
 CellChangeTimes->{{3.69375241365628*^9, 3.693752530840128*^9}, {
  3.693752568496141*^9, 3.693752619631555*^9}, {3.693752826501966*^9, 
  3.693752938269075*^9}, {3.693753013476487*^9, 3.693753033244207*^9}, {
  3.694444590082674*^9, 3.6944447455534763`*^9}, {3.694614819029409*^9, 
  3.694614863572953*^9}},ExpressionUUID->"17cac3c6-cc5e-4d8d-b090-\
70138d56c8d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"w", "[", "u", "]"}], "[", 
   RowBox[{"..", ",", "vi", ",", "...", ",", "vj", ",", "..."}], "]"}], 
  "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"w", "[", "u", "]"}], "[", 
     RowBox[{"..", ",", "vj", ",", "...", ",", "vi", ",", ".."}], "]"}]}], "  ", 
   RowBox[{"(", "1", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.693753112947774*^9, 3.693753176451406*^9}, {
  3.693753211171115*^9, 3.693753336857914*^9}, {3.6938067432032413`*^9, 
  3.693806761027424*^9}},ExpressionUUID->"18b05be4-8a6b-4481-b768-\
2228932a38fb"],

Cell["\<\
An equivalent condition is: For all pairs (i,j), i\[NotEqual]j, i,j =1,...,p: \
If vv=vi== vj, then\
\>", "Text",
 CellChangeTimes->{{3.6938064112912073`*^9, 3.693806591171081*^9}, 
   3.693806677402996*^9},ExpressionUUID->"b3d2ae08-0726-4254-b2b1-\
62153a03016f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"w", "[", "u", "]"}], "[", 
   RowBox[{"..", ",", "vv", ",", "...", ",", "vv", ",", "..."}], "]"}], 
  "\[Equal]", " ", 
  RowBox[{"0", "              ", 
   RowBox[{"(", "2", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6938066871319523`*^9, 3.6938067238754263`*^9}, {
  3.693806768475565*^9, 
  3.693806783763524*^9}},ExpressionUUID->"95117a21-59a7-4272-bd29-\
a135f2bd1642"],

Cell["\<\
Since the coordinate functions are defined evaluating the form for all \
p-tuples of basis vectors the antisymmetry of the p-form is equivalent to the \
antisymmetry of its coordinate Array:\
\>", "Text",
 CellChangeTimes->{{3.694614948715822*^9, 
  3.694615171018197*^9}},ExpressionUUID->"598447f4-5716-4376-911a-\
2428d012b1ea"],

Cell[TextData[StyleBox["If {i1, .., ip} is a permutation of {j1, .., jp}, \
then  \nSignature[{i1, .., ip}]*ca[u ...][i1, .. ip] ==          (3) \n\
Signature[{j1, .., jp}]*ca[u ...][j1, ..., jp] ",
 FontWeight->"Plain"]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.694615271885585*^9, 3.694615394769059*^9}, {
   3.694615468816437*^9, 3.694615520391967*^9}, {3.6946155650960903`*^9, 
   3.6946156203754187`*^9}, {3.694615699566584*^9, 3.694615761942359*^9}, 
   3.694615794766713*^9, {3.6946158493661413`*^9, 3.694615881829412*^9}, {
   3.694615964610417*^9, 3.694616063539093*^9}, {3.694699939031164*^9, 
   3.694699942950728*^9}, {3.6947002022528973`*^9, 3.6947002500123577`*^9}, 
   3.694700663976956*^9, {3.694764173803001*^9, 
   3.694764180195084*^9}},ExpressionUUID->"b7064e36-266a-49bc-b5d1-\
1f0ab4c7a8b5"],

Cell["\<\
By (2) a coordinate function with two equal indices ik == il for \
k\[NotEqual]l is zero;  decomposing the permutations into transpositions, see\
\>", "Text",
 CellChangeTimes->{{3.694616173399934*^9, 3.694616278819586*^9}, {
  3.694616323382045*^9, 3.694616346944628*^9}, {3.694616437119998*^9, 
  3.69461643948792*^9}, {3.694616511374892*^9, 3.694616546518745*^9}, {
  3.694616717173541*^9, 
  3.69461672782104*^9}},ExpressionUUID->"67b5a841-4bda-4d24-97ec-\
84c6037cf64d"],

Cell[BoxData[
 RowBox[{"?", "Signature"}]], "Input",
 CellChangeTimes->{{3.694616734186075*^9, 3.694616740900839*^9}, {
  3.6946167729150457`*^9, 3.69461679304525*^9}, {3.694616830138803*^9, 
  3.694616832453287*^9}},ExpressionUUID->"6ea241ef-341b-492d-8aba-\
7e1e4de3754a"],

Cell["\<\
one easily proves (3) as a consequence of (1).
In particular, if the index sequence j1<j2<...<jp is in natural order, its \
signature is 1, e.g.\
\>", "Text",
 CellChangeTimes->{{3.694699977653843*^9, 3.694700126604876*^9}, {
  3.694700267027404*^9, 3.694700270379228*^9}, {3.694700389882443*^9, 
  3.694700423266191*^9}, {3.694764289049715*^9, 
  3.6947643344493093`*^9}},ExpressionUUID->"740cc6eb-21d1-4c65-899b-\
a8ebff9cfe85"],

Cell[BoxData[
 RowBox[{"Signature", " ", "[", 
  RowBox[{"{", 
   RowBox[{"2", ",", "3", ",", "5", ",", "7"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.6947001321677113`*^9, 
  3.694700175036824*^9}},ExpressionUUID->"d202c5fb-b5f5-44de-8993-\
0eec805008d8"],

Cell["then formula (3) becomes", "Text",
 CellChangeTimes->{{3.694700459921278*^9, 
  3.6947004822035913`*^9}},ExpressionUUID->"4c52cfdc-9204-4e8f-bf18-\
8e7641908d00"],

Cell[TextData[StyleBox["If {i1, .., ip} is a permutation of {j1, .., jp}, \
j1<j2< ..,<jp, then\nca[u ...][i1, .. ip] ==                                  \
                                                                      (4)\n \
Signature[{i1, .., ip}]*ca[u ...][j1, ..., jp] ",
 FontWeight->"Plain"]], "Input",
 CellChangeTimes->{{3.6947005543843193`*^9, 3.694700621752996*^9}, {
   3.6947007442248*^9, 3.69470074747569*^9}, 3.694700790704545*^9, {
   3.6947008423992558`*^9, 3.694700878038022*^9}, {3.694701009013331*^9, 
   3.6947010314054213`*^9}},ExpressionUUID->"fac5c1c2-23fc-47e4-8239-\
b3ad67ee3a04"],

Cell[TextData[{
 "It follows: \n",
 StyleBox["Lemma 1",
  FontColor->RGBColor[0, 0, 1]],
 ".The coordinates of a p-form are uniquely defined by its ",
 StyleBox["strict coordinates",
  FontColor->RGBColor[0, 0, 1]],
 ", these are the ",
 StyleBox[" ca[j1, .., jp] with j1<j2< ..,<jp. \[FilledSquare]\nIndeed, for \
the permuted indices the coordinate is defined by (4), and if two indices are \
equal the coordinate is zero.",
  FontWeight->"Plain"]
}], "Text",
 CellChangeTimes->{{3.694701047068363*^9, 3.6947010623405046`*^9}, {
  3.694701098828185*^9, 3.6947012452513733`*^9}, {3.694701277515586*^9, 
  3.694701419633851*^9}, {3.694701450705473*^9, 
  3.694701562136619*^9}},ExpressionUUID->"272e62f5-2557-4a50-b695-\
46835202aad3"],

Cell[BoxData[
 RowBox[{"?", "strictcoords"}]], "Input",
 CellChangeTimes->{{3.694701597832281*^9, 
  3.6947016048881683`*^9}},ExpressionUUID->"2837d704-f1bf-4346-b750-\
2ca2a0a3136e"],

Cell["\<\
Problem: Construct a p-form coordinate  Array with given strict coordinates. \
The strict coordinates correspond to all subsets of p elements of Range[n], n \
the dimension of the tangent vector spaces. Using the built-in function\
\>", "Text",
 CellChangeTimes->{{3.6946900911663857`*^9, 3.6946901850999126`*^9}, {
  3.694690325482839*^9, 3.694690333715035*^9}, {3.6947023170336523`*^9, 
  3.6947024157692547`*^9}, {3.694702456080957*^9, 3.6947024588648577`*^9}, {
  3.6947024978722773`*^9, 
  3.6947025170883293`*^9}},ExpressionUUID->"87c6f407-3e86-4e5b-a2fb-\
523fcf7ebbed"],

Cell[BoxData[
 RowBox[{"?", "Subsets"}]], "Input",
 CellChangeTimes->{{3.694690383003344*^9, 3.694690394314807*^9}, 
   3.694702487150099*^9},ExpressionUUID->"82c212a4-de1d-4186-aa6c-\
36aac3bbb4b9"],

Cell["We define", "Text",
 CellChangeTimes->{{3.694703009779513*^9, 
  3.694703016739633*^9}},ExpressionUUID->"288797b3-8c5c-4b72-bf89-\
8bf70f2b8f36"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subs", "[", 
   RowBox[{"n_", ",", "p_"}], "]"}], ":=", " ", 
  RowBox[{"Subsets", "[", 
   RowBox[{
    RowBox[{"Range", "[", "n", "]"}], ",", 
    RowBox[{"{", "p", "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694690570340641*^9, 
  3.694690625617071*^9}},ExpressionUUID->"09025624-a68d-491f-a680-\
3b2a827f3a98"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"subs", "::", "usage"}], " ", "=", " ", 
   "\"\<subs[n,p] is the family of subsets of p numbers of Range[n].\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.694764447268218*^9, 3.694764559000093*^9}, 
   3.694764626389089*^9},ExpressionUUID->"6639871d-5bfd-4fc8-ac1e-\
7f459e7c48cb"],

Cell[BoxData[
 RowBox[{"subs", "[", 
  RowBox[{"5", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.694690629058174*^9, 3.694690668453197*^9}, {
  3.694703050056807*^9, 
  3.694703094292183*^9}},ExpressionUUID->"db9ca36b-ae77-4d81-a80d-\
10de90c5ced1"],

Cell["The number of such subsets is Binomial[n,p]:", "Text",
 CellChangeTimes->{{3.694703125306595*^9, 
  3.694703171962476*^9}},ExpressionUUID->"fa31875c-03c2-427c-b1ae-\
6f5ccb23f36d"],

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.694703187598247*^9, 
  3.694703200186932*^9}},ExpressionUUID->"ab49536a-e43b-4a3d-96c7-\
d4edc4cff387"],

Cell["\<\
If the strict coordinates f[i1,...,ip] of a p-form are given, then the Array \
of all coordinates of the p-form is given by\
\>", "Text",
 CellChangeTimes->{{3.6947034725277653`*^9, 
  3.694703590558811*^9}},ExpressionUUID->"d8c56bed-981c-4531-a377-\
1525efe8f586"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nn", "=", "dim"}], ";", 
  RowBox[{"Clear", "[", 
   RowBox[{"dim", ",", "extform"}], "]"}], ";", 
  RowBox[{
   RowBox[{"extform", "[", 
    RowBox[{"f_", ",", "p_", ",", 
     RowBox[{"n_:", "dim"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"p", "\[Equal]", "0"}], ",", "f", ",", 
     RowBox[{"Normal", "[", 
      RowBox[{"SymmetrizedArray", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"subs", "[", 
             RowBox[{"n", ",", "p"}], "]"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
           RowBox[{"f", "[", 
            RowBox[{"lts", "[", 
             RowBox[{
              RowBox[{"subs", "[", 
               RowBox[{"n", ",", "p"}], "]"}], "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Binomial", "[", 
             RowBox[{"n", ",", "p"}], "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{"n", ",", 
          RowBox[{"{", "p", "}"}]}], "]"}], ",", 
        RowBox[{"Antisymmetric", "[", 
         RowBox[{"Range", "[", "p", "]"}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
  ";", 
  RowBox[{"dim", "=", "nn"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.69461782146107*^9, 3.694617826645046*^9}, {
   3.6946918502785788`*^9, 3.69469185492097*^9}, {3.694691941766007*^9, 
   3.694691993709361*^9}, 3.6946920261014853`*^9, 3.694692083405427*^9, {
   3.694692133628324*^9, 3.6946921623161163`*^9}, {3.6946922029476213`*^9, 
   3.694692211795311*^9}, {3.694692248547454*^9, 3.6946923069149733`*^9}, {
   3.694692391983219*^9, 3.6946923932577333`*^9}, {3.694692671043663*^9, 
   3.6946926891111717`*^9}, {3.6946927697185993`*^9, 3.694692773318281*^9}, {
   3.694692820750873*^9, 3.69469283038274*^9}, {3.694693013409646*^9, 
   3.6946930202050962`*^9}, {3.694693138789893*^9, 3.6946931686080303`*^9}, {
   3.694694229988452*^9, 3.694694266458255*^9}, {3.6946943048022337`*^9, 
   3.694694314146253*^9}, {3.69469435657078*^9, 3.694694369121921*^9}, {
   3.694703605627874*^9, 3.69470362053589*^9}, {3.694765192887146*^9, 
   3.6947652172677193`*^9}, {3.6957989160281467`*^9, 3.695798988730131*^9}, {
   3.696140393561529*^9, 3.6961404180808067`*^9}, {3.696147425981717*^9, 
   3.696147449779726*^9}},ExpressionUUID->"3321563e-b1aa-4b87-85ca-\
0b6c1acce930"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"extform", "::", "usage"}], " ", "=", " ", 
   "\"\<extform[f,p,n:dim] is the coordinate Array of the p-form with strict \
coordinates f[i1,...,ip], i1<...<ip.\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.69476471602728*^9, 3.6947648913333597`*^9}, {
  3.694764926086978*^9, 
  3.6947649302862043`*^9}},ExpressionUUID->"c20aa21a-22aa-406d-ab01-\
24aac1b65a7a"],

Cell[BoxData[
 RowBox[{"?", "altform"}]], "Input",
 CellChangeTimes->{{3.696000479092596*^9, 
  3.696000483750203*^9}},ExpressionUUID->"5c684fe4-1eca-4b42-ba9a-\
5ee904bc6aa2"],

Cell[BoxData[
 RowBox[{"Context", "[", "altform", "]"}]], "Input",
 CellChangeTimes->{{3.696000533431984*^9, 
  3.6960005485893183`*^9}},ExpressionUUID->"86474d06-ee4e-4a29-a71c-\
ae4b8f86ea53"],

Cell["\<\
Here is the coordinate matrix of a 2-form on the 3-space with coordinates \
{x,y,z}:\
\>", "Text",
 CellChangeTimes->{{3.694704174561633*^9, 
  3.694704232185499*^9}},ExpressionUUID->"340e387b-ef5f-4559-8805-\
26064fb95e9e"],

Cell[BoxData[
 RowBox[{"extform", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.694692840555313*^9, 3.694692852197979*^9}, {
  3.69470410454312*^9, 
  3.694704110795437*^9}},ExpressionUUID->"eef55a3c-939e-4039-aeb1-\
f788f883834b"],

Cell[BoxData[
 RowBox[{"%", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.694694400346448*^9, 3.694694419143827*^9}, 
   3.694704148064773*^9},ExpressionUUID->"e8955ba3-c5a4-437c-aa10-\
c2893d3bf5c4"],

Cell[BoxData[
 RowBox[{"extform", "[", 
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.694765010384033*^9, 
  3.694765052052538*^9}},ExpressionUUID->"ea3bbb3f-0ed7-4520-b7ee-\
a4216d9949a9"],

Cell[BoxData[
 RowBox[{"extform", "[", 
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.694765010384033*^9, 3.694765052052538*^9}, {
  3.694765108918713*^9, 
  3.694765120767057*^9}},ExpressionUUID->"42deb759-07e5-410e-a48d-\
d1240a991c9a"],

Cell[TextData[{
 StyleBox["Example 4",
  FontColor->RGBColor[0, 0, 1]],
 ". n-forms on ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["M", "n"], ".", "  ", "We"}], " ", "consider", " ", 
     "the", " ", "case", " ", "n"}], "=", " ", 
    RowBox[{"3.", ":"}]}], TraditionalForm]],ExpressionUUID->
  "c53f3bc3-c49a-4a87-90c3-d72b6d2d64f0"]
}], "Text",
 CellChangeTimes->{{3.695447780824535*^9, 3.695447784608355*^9}, {
  3.6954478172802973`*^9, 3.6954479311937647`*^9}, {3.69556359634136*^9, 
  3.695563598996763*^9}},ExpressionUUID->"4d35908c-5029-4c5b-805d-\
d2de7b7e437b"],

Cell[BoxData[
 RowBox[{"w3", " ", "=", 
  RowBox[{"extform", "[", 
   RowBox[{
    RowBox[{"a", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694765010384033*^9, 3.694765052052538*^9}, {
  3.694765108918713*^9, 3.694765120767057*^9}, {3.694765247429164*^9, 
  3.6947652564823637`*^9}, {3.694765488725416*^9, 
  3.694765491344203*^9}},ExpressionUUID->"3a363ea1-2591-4051-908b-\
89a99c73bf24"],

Cell[BoxData[
 RowBox[{"?", "val"}]], "Input",
 CellChangeTimes->{{3.6947654155127068`*^9, 
  3.694765417193075*^9}},ExpressionUUID->"2283ff24-3e80-442b-8df8-\
f7a6f2103d3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"val", "[", "w3", "]"}], "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", "x", "]"}], ",", 
   RowBox[{"vec", "[", "y", "]"}], ",", 
   RowBox[{"vec", "[", "z", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6947653347701607`*^9, 3.694765436322784*^9}, {
  3.694765503517784*^9, 
  3.694765504463566*^9}},ExpressionUUID->"7fa6a3d7-ee00-42c5-87ba-\
c0a2d92a2e4b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "[", 
     RowBox[{"1", ",", "2", ",", "3"}], "]"}], "*", 
    RowBox[{"Det", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"vec", "[", "x", "]"}], ",", 
       RowBox[{"vec", "[", "y", "]"}], ",", 
       RowBox[{"vec", "[", "z", "]"}]}], "}"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694765529125779*^9, 3.694765554199964*^9}, {
  3.694765602168523*^9, 3.6947656504390383`*^9}, {3.694765697667622*^9, 
  3.694765758006816*^9}},ExpressionUUID->"52407b54-a617-4f6d-ba2f-\
53c7fafc5a76"],

Cell[TextData[{
 "n-forms with on ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "d0d91f0e-4765-4ea1-9685-355272114cb2"],
 " have only 1 strict coordinate; they are called ",
 StyleBox["densities",
  FontColor->RGBColor[0, 0, 1]],
 ". The last formula shows that its value is the product of this coordinate \
with the determinant of its arguments. \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.694765829636846*^9, 3.694765895644537*^9}, {
  3.694765929539851*^9, 3.6947660031235523`*^9}, {3.695447984935587*^9, 
  3.695448035258643*^9}},ExpressionUUID->"dfaa8862-cc42-431a-8774-\
157f3b800438"],

Cell[TextData[{
 StyleBox["We summarize proving",
  FontColor->GrayLevel[0]],
 StyleBox["\nProposition 1",
  FontColor->RGBColor[0, 0, 1]],
 ".  a)The set of all multilinear functions of the same degree p on a \
manifold ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "ea715d6f-1e5a-4eb7-a40d-4eb5ad39f026"],
 " is an infinite dimensional  real vector space with addition"
}], "Text",
 CellChangeTimes->{{3.6939869900260563`*^9, 3.693987067849349*^9}, {
   3.693987100792982*^9, 3.693987241447968*^9}, {3.693987271871748*^9, 
   3.693987278783598*^9}, 3.693987782907199*^9, {3.694000663651024*^9, 
   3.69400066785069*^9}, {3.6946148922927303`*^9, 3.69461489743683*^9}, {
   3.6947040418195744`*^9, 
   3.694704058547132*^9}},ExpressionUUID->"bcde572a-1cc0-4af5-a03f-\
09da10ccd17c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plus", "[", 
   RowBox[{
    RowBox[{"w1", "[", "u__", "]"}], ",", 
    RowBox[{"w2", "[", "u__", "]"}]}], "]"}], "[", "v__List", "]"}]], "Input",
 CellChangeTimes->{{3.693987284250766*^9, 3.693987371694845*^9}, 
   3.69398745588615*^9},ExpressionUUID->"254d3e18-669e-4e4d-8ba5-\
84d6a4148781"],

Cell[TextData[{
 "and multiplication with real numbers; it is a module over the Ring of \
smooth functions on ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "4bad0f82-52df-41e7-a666-7856ce9c4c99"],
 ". The multiplication with the function f[u] is defined pointwise:"
}], "Text",
 CellChangeTimes->{{3.6939877972266693`*^9, 3.693987833442457*^9}, {
  3.6939878989862947`*^9, 3.693988052096974*^9}, {3.693999877562406*^9, 
  3.693999902593082*^9}},ExpressionUUID->"098c6194-800c-4ade-8801-\
0bf71d2b1757"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f", ",", "w"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"fw", "[", "u__", "]"}], "[", "v__List", "]"}], " ", ":=", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "*", 
    RowBox[{
     RowBox[{"w", "[", "u", "]"}], "[", "v", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.693988083066033*^9, 3.693988166192059*^9}, {
  3.693988269727962*^9, 3.6939882832235813`*^9}, {3.693988315495494*^9, 
  3.693988328102847*^9}, {3.693988497010193*^9, 
  3.693988541862033*^9}},ExpressionUUID->"0e31c670-0da7-4cad-878e-\
cb15a630416b"],

Cell[TextData[{
 "b)The set of p-forms are subspaces of the vector space and submodules of \
the module of multilinear functions of degree p.\nc)The only p-form on a \
manifold ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "6a0d30ff-edae-4947-a646-251051c790cb"],
 " with p>n is the zero-form.\n",
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". Clearly the sum of multilinear forms of degree p"
}], "Text",
 CellChangeTimes->{{3.6940007021288223`*^9, 3.69400072278695*^9}, {
  3.694000768281702*^9, 3.694000942616577*^9}, {3.69400112227107*^9, 
  3.694001134878875*^9}, {3.694001306117511*^9, 
  3.69400150461205*^9}},ExpressionUUID->"c2866379-38ae-4d7e-80eb-\
4051d677960f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plus", "[", 
   RowBox[{
    RowBox[{"w1", "[", 
     RowBox[{"u1", ",", "u2"}], "]"}], ",", 
    RowBox[{"w2", "[", 
     RowBox[{"u1", ",", "u2"}], "]"}]}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"x", ",", "2"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"y", ",", "2"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"z", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6939874376625643`*^9, 3.693987503565645*^9}, {
  3.69398767110539*^9, 
  3.693987698524939*^9}},ExpressionUUID->"ec86d0ae-f308-41ec-b36d-\
60032047767d"],

Cell["\<\
and its multiple with a number or function are multilinear again, and the \
same is true for p-forms. The module properties are simple consequences of \
the operations with numbers. This shows statements a) and b). Statement c) \
follows from (2) and the definition of the coordinates: in any p-tuple of \
basis vectors  in dimension n<p there are two equal vectors. Thus all \
coordinate functions are \
\>", "Text",
 CellChangeTimes->{{3.694001515791252*^9, 3.694001644274705*^9}, {
  3.6940016991304092`*^9, 3.694001818193535*^9}, {3.694001886697145*^9, 
  3.694001895712945*^9}, {3.6940020788316402`*^9, 3.694002309366425*^9}, {
  3.694774750181758*^9, 3.694774770284886*^9}, {3.69544809593484*^9, 
  3.695448099078985*^9}},ExpressionUUID->"8cde407b-e664-42b8-ae40-\
1655b992fa57"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ca", "[", 
    RowBox[{"u1", ",", "u2", ",", "...", ",", "un"}], "]"}], "[", 
   RowBox[{"i1", ",", "i2", ",", "...", ",", "ip"}], "]"}], "\[Equal]", " ", 
  RowBox[{"0", " ", "for", "  ", "p"}], ">", 
  RowBox[{"n", ".", "     ", "\[FilledSquare]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.694002417756966*^9, 
  3.694002537935196*^9}},ExpressionUUID->"9dc39d9c-b8b9-49a8-bfc9-\
7e534ca7f474"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.3. Exterior Product", "Subsubsection",
 CellChangeTimes->{{3.586665161894202*^9, 3.586665168125559*^9}, {
   3.5872725143584003`*^9, 3.587272520677761*^9}, {3.60913869538486*^9, 
   3.6091387007281656`*^9}, 3.6092316026384597`*^9, {3.6093094046875467`*^9, 
   3.6093094080137367`*^9}, 3.609309574326249*^9, {3.6095608566429873`*^9, 
   3.6095608600281935`*^9}, 3.6177078269291887`*^9, 3.6177190550258956`*^9, 
   3.62744137111684*^9, 3.627442434835908*^9, 3.694002820010169*^9, 
   3.69554074259089*^9, 3.69638910177381*^9, {3.696405361314867*^9, 
   3.696405362746777*^9}, {3.6966053248975563`*^9, 3.696605327265338*^9}, 
   3.696681236712038*^9},ExpressionUUID->"82d751a9-1510-4af7-b728-\
850890746469"],

Cell[TextData[{
 "We consider the direct sum of the spaces of all antisymmetric forms on a \
manifold ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "58e935a5-d6fe-4b80-ac57-e6e5a3d5eab3"]
}], "Text",
 CellChangeTimes->{{3.694070900525688*^9, 
  3.69407103306145*^9}},ExpressionUUID->"92145af7-cae6-40d3-aa83-\
d8b268ce0e74"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[And]", 
   SuperscriptBox["M", "n"]}], " ", "=", 
  RowBox[{
   UnderoverscriptBox["\[CirclePlus]", 
    RowBox[{"p", "=", "0"}], "\[Infinity]"], " ", 
   RowBox[{
    SuperscriptBox["\[Wedge]", "p"], 
    SuperscriptBox["M", "n"]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.694071129092206*^9, {3.694071176993775*^9, 3.694071186876473*^9}, {
   3.6940712729007797`*^9, 3.694071401731885*^9}, 
   3.6963925248154383`*^9},ExpressionUUID->"7c2a9db5-f729-4c29-a14f-\
2362f2796780"],

Cell[TextData[{
 "Here ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Wedge]", "p"], 
   SuperscriptBox["M", "n"]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{
   3.694071129092206*^9, {3.694071176993775*^9, 3.694071186876473*^9}, {
    3.6940712729007797`*^9, 3.694071401731885*^9}},ExpressionUUID->
  "c5c255be-5998-4611-97c7-82122c8c25d0"],
 " denotes the space of p-forms on ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "ceaa646c-d0a6-4bc7-be3a-ebe120a42d57"],
 ", ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Wedge]", "0"], 
   SuperscriptBox["M", "n"]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{
   3.694071129092206*^9, {3.694071176993775*^9, 3.694071186876473*^9}, {
    3.6940712729007797`*^9, 3.694071401731885*^9}},ExpressionUUID->
  "0c0e7beb-fcd6-4877-b2ec-b200991b058b"],
 " the space of smooth functions; remember that ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Wedge]", "p"], 
   SuperscriptBox["M", "n"]}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{
   3.694071129092206*^9, {3.694071176993775*^9, 3.694071186876473*^9}, {
    3.6940712729007797`*^9, 3.694071401731885*^9}},ExpressionUUID->
  "9ee06d18-a845-44b6-b60a-323727cf0df3"],
 " is zero for p>n. Now we will define an operation, the exterior product, in \
the space  ",
 Cell[BoxData[
  RowBox[{"\[And]", 
   SuperscriptBox["M", "n"], " "}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{
   3.694071129092206*^9, {3.694071176993775*^9, 3.694071186876473*^9}, {
    3.6940712729007797`*^9, 3.694071401731885*^9}},ExpressionUUID->
  "82936c9b-1ac9-42cc-815e-5743646c9e11"],
 " such that it becomes an associative, anti-commutative algebra over R. The \
exterior product is obtained by the built-in Function"
}], "Text",
 CellChangeTimes->{{3.694072433233466*^9, 3.694072436049468*^9}, {
  3.694072475719043*^9, 3.694072644656418*^9}, {3.694072710535058*^9, 
  3.694072805855197*^9}, {3.694072855510895*^9, 
  3.694073009261961*^9}},ExpressionUUID->"420a33ff-c578-4b8a-8b51-\
95f0a24b60b4"],

Cell[BoxData[
 RowBox[{"?", "TensorWedge"}]], "Input",
 CellChangeTimes->{{3.586614301966012*^9, 3.5866143148672347`*^9}, {
  3.6089625997735806`*^9, 3.608962603891988*^9}, {3.608963615959365*^9, 
  3.6089636229637775`*^9}},ExpressionUUID->"f3549d67-dcc9-4b12-a997-\
083997995aa9"],

Cell[BoxData[
 RowBox[{"Context", "[", "TensorWedge", "]"}]], "Input",
 CellChangeTimes->{{3.586614326286455*^9, 3.5866143340708685`*^9}, {
   3.6089625399630756`*^9, 3.6089625472170877`*^9}, 
   3.609139331541246*^9},ExpressionUUID->"ee087ae7-c4b7-4e5e-b76f-\
7eca2fa29e80"],

Cell["For example:", "Text",
 CellChangeTimes->{{3.694073047249896*^9, 
  3.6940730997400723`*^9}},ExpressionUUID->"56fe933b-a22b-46e9-b4ea-\
710fb931f3d4"],

Cell[BoxData[
 RowBox[{"TensorWedge", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5866075367049265`*^9, {3.5866078946943555`*^9, 3.586607923382806*^9}, {
   3.586609053713991*^9, 3.586609060437603*^9}, {3.5866091609953794`*^9, 
   3.586609167874992*^9}, 3.5866142301590858`*^9, {3.6089625185130377`*^9, 
   3.6089625203070407`*^9}, {3.6089637807424545`*^9, 
   3.6089637866548653`*^9}, {3.608963958769967*^9, 3.608964000765241*^9}, 
   3.609139366379239*^9, 3.6148618495663223`*^9, 
   3.6149177823421445`*^9},ExpressionUUID->"f2cc3409-c415-46e3-b3f2-\
dfd044ab0e0a"],

Cell["\<\
To get the coordinate expression of the result one has to apply\
\>", "Text",
 CellChangeTimes->{{3.6940731396917458`*^9, 
  3.6940731947553062`*^9}},ExpressionUUID->"4d9bf912-9f04-48aa-a62f-\
c9ffe5fc2982"],

Cell[BoxData[
 RowBox[{"Normal", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6089638230497293`*^9, 
  3.608963830865343*^9}},ExpressionUUID->"630298cc-5cbc-480d-b1c1-\
0a653c5e3855"],

Cell[BoxData[
 RowBox[{"?", "Normal"}]], "Input",
 CellChangeTimes->{{3.609139383471216*^9, 
  3.6091393864273853`*^9}},ExpressionUUID->"d78fe741-24ce-4e04-8601-\
f29e5ab973f4"],

Cell[TextData[{
 "The result is a 2-form in dimension two with  the only ",
 StyleBox["strict coordinate",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.5867611712118564`*^9, 3.586761221964759*^9}, {
  3.6092151598757515`*^9, 3.609215169273289*^9}, {3.6940733000508833`*^9, 
  3.694073307106524*^9}, {3.694150371479233*^9, 
  3.694150373406879*^9}},ExpressionUUID->"668dac78-46ef-48de-9436-\
16623f1701a0"],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "h", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5866075367049265`*^9, {3.5866078946943555`*^9, 3.586607923382806*^9}, {
   3.586609053713991*^9, 3.586609060437603*^9}, {3.5866091609953794`*^9, 
   3.586609167874992*^9}, 3.5866142301590858`*^9, {3.5867609939407167`*^9, 
   3.586761018799139*^9}},ExpressionUUID->"0e282497-eac3-410a-ae18-\
e1242f2c2e77"],

Cell["We defined in tensalgv3.m", "Text",
 CellChangeTimes->{{3.6091400809761114`*^9, 3.6091400842482986`*^9}, {
  3.6095608806670294`*^9, 3.609560890167446*^9}, {3.694094302379421*^9, 
  3.694094303179009*^9}},ExpressionUUID->"76fb74f2-4ee7-401b-890c-\
78016c50efeb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"extprod", "[", "w___", "]"}], " ", ":=", " ", 
   RowBox[{"Normal", "[", 
    RowBox[{"TensorWedge", "[", "w", "]"}], "]"}]}], 
  "\[LineSeparator]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.609140140859536*^9, 3.6091402137787075`*^9}, 
   3.609140254443033*^9, {3.609142536672043*^9, 3.6091425573932285`*^9}, {
   3.609143273953213*^9, 3.609143278689484*^9}, 3.6095608991218615`*^9, 
   3.614861849581922*^9, 3.614917782357744*^9, 
   3.696392707391447*^9},ExpressionUUID->"86de071b-ee49-4987-b6b8-\
2a331582aee2"],

Cell[BoxData[
 RowBox[{"?", "extprod"}]], "Input",
 CellChangeTimes->{{3.609561048024123*^9, 
  3.6095610523765306`*^9}},ExpressionUUID->"80d7c779-08a6-4c50-9e29-\
608f4ff81af6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"strictcoords", "[", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "h", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", " ", 
  RowBox[{"Det", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694150572893877*^9, 3.694150582914633*^9}, {
   3.694150617494062*^9, 3.694150648685343*^9}, {3.694150702030167*^9, 
   3.694150717700494*^9}, 3.694150757853167*^9, {3.694150794313675*^9, 
   3.694150796867219*^9}},ExpressionUUID->"fdbff668-273e-4ed0-80ff-\
22eafae7c55f"],

Cell[BoxData[
 RowBox[{"extprod", "[", "]"}]], "Input",
 CellChangeTimes->{
  3.609143301679799*^9},ExpressionUUID->"bbd862a7-9400-4e1b-b437-\
7304b293c9e3"],

Cell[TextData[{
 StyleBox["Warning.",
  FontColor->RGBColor[1, 0, 0]],
 " Unfortunately, a symbolic function isn\[CloseCurlyQuote]t recognized as a \
0-form, extprod is not evaluated:"
}], "Text",
 CellChangeTimes->{{3.609215433394396*^9, 3.6092155061055546`*^9}, {
  3.6150338443951416`*^9, 3.6150338459312296`*^9}, {3.694150837811027*^9, 
  3.694150855546921*^9}, {3.6941569806871157`*^9, 
  3.694156988143577*^9}},ExpressionUUID->"bf96451f-7463-4366-b971-\
8fd7eaab5830"],

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{"f", "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.6092153726999245`*^9, 
  3.6150338561808157`*^9},ExpressionUUID->"089e1d48-ea1c-41cc-a57b-\
8988e19d2fc6"],

Cell["A concrete function is returned as a 0-form:", "Text",
 CellChangeTimes->{{3.60921561144158*^9, 3.609215640329232*^9}, {
   3.694150921010562*^9, 3.694150925218317*^9}, {3.695480620374836*^9, 
   3.6954806609263*^9}, {3.695480759589621*^9, 3.695480761013359*^9}, 
   3.6963928393017683`*^9},ExpressionUUID->"98e025d2-6d7e-461c-8975-\
6e0b2df467b3"],

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{"Cos", "[", 
   RowBox[{"u", "*", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6092153726999245`*^9, {3.6092155294898925`*^9, 
   3.609215560515667*^9}},ExpressionUUID->"6b83112f-ba99-4fe2-a220-\
b6bcea6f6829"],

Cell["Entered as a List of Length 1 one gets:", "Text",
 CellChangeTimes->{{3.695448947439568*^9, 3.6954489781674*^9}, {
  3.6954806015269337`*^9, 
  3.695480604486967*^9}},ExpressionUUID->"97528756-baa0-4cd5-8577-\
bfd2ad6c8e7a"],

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{"{", 
   RowBox[{"f", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6092153726999245`*^9, 3.6150338561808157`*^9, 3.695448705858448*^9, {
   3.695448777330044*^9, 
   3.695448790825933*^9}},ExpressionUUID->"7179baf0-eb69-4a6f-af7c-\
5a7519eab663"],

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{"{", 
   RowBox[{"Cos", "[", 
    RowBox[{"u", "*", "v"}], "]"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6092153726999245`*^9, 3.6150338561808157`*^9, 3.695448705858448*^9, {
   3.695448777330044*^9, 3.695448790825933*^9}, {3.69548069318649*^9, 
   3.695480720726349*^9}},ExpressionUUID->"41bf3301-c762-4956-959f-\
1fc16fad0466"],

Cell["Here the argument is considered as a 1-form in dimension 1. ", "Text",
 CellChangeTimes->{{3.60921561144158*^9, 3.609215640329232*^9}, {
   3.694150921010562*^9, 3.694150925218317*^9}, {3.695480620374836*^9, 
   3.6954806609263*^9}, {3.695480759589621*^9, 3.695480761013359*^9}, 
   3.696392829126099*^9},ExpressionUUID->"933ea6c7-24fe-4c09-8729-\
e96c5f503933"],

Cell["Again", "Text",
 CellChangeTimes->{{3.6092156749692135`*^9, 
  3.609215677897381*^9}},ExpressionUUID->"7bd6333c-f967-4bdf-a07d-\
dc7c2b52847c"],

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6091402188970003`*^9, 3.609140224441317*^9}, {
   3.609142821985362*^9, 3.6091428627446938`*^9}, 3.609142910601431*^9, 
   3.615033913997123*^9},ExpressionUUID->"cc2c6f9c-b819-4290-870b-\
a5f2f864eb60"],

Cell["\<\
isn\[CloseCurlyQuote]t evaluated. The assumption that h  has real values \
doesn\[CloseCurlyQuote]t help:\
\>", "Text",
 CellChangeTimes->{{3.694150975565217*^9, 3.694151035426373*^9}, {
  3.696392953076646*^9, 
  3.696392972036124*^9}},ExpressionUUID->"e1813add-e660-40a7-bf3c-\
2878f733de0a"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Element", "[", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "Reals"}], "]"}], "==", "True"}], 
   ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6091402188970003`*^9, 3.609140224441317*^9}, {
   3.609142821985362*^9, 3.6091428627446938`*^9}, 3.609142910601431*^9, 
   3.615033913997123*^9, {3.694098807751157*^9, 3.694098864329377*^9}, {
   3.6940988979668493`*^9, 3.694098966174712*^9}, {3.6940991210339403`*^9, 
   3.694099224076968*^9}, {3.694099329058506*^9, 3.694099372155814*^9}, 
   3.694099423633038*^9, {3.696392999581089*^9, 
   3.696393001332575*^9}},ExpressionUUID->"2035008e-19aa-4f4b-a0ea-\
71e70eb3bfc9"],

Cell["Setting", "Text",
 CellChangeTimes->{{3.6966614556518183`*^9, 3.696661459021841*^9}, 
   3.69666149246336*^9},ExpressionUUID->"de0a64cf-32ad-4e1a-9d10-\
25a4b14f9cc2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Attributes", "[", "h", "]"}], "=", 
  RowBox[{"{", "NumericFunction", "}"}]}]], "Input",ExpressionUUID->"8da51dad-\
8c8c-4834-b1cb-499ec02b6038"],

Cell["gives the correct result:", "Text",
 CellChangeTimes->{{3.696661560461396*^9, 3.696661570756708*^9}, {
  3.6966616018544407`*^9, 
  3.696661609636125*^9}},ExpressionUUID->"2b9f9676-2e46-4f60-841c-\
d92cc78f38d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "h", "]"}], ";", 
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"u", "*", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694155471813333*^9, 
  3.6941555288846292`*^9}},ExpressionUUID->"3b9e9c0b-b12b-44e2-b966-\
20dcf22e5ae7"],

Cell["The clearing of h doesn\[CloseCurlyQuote]t change the Attributes:", \
"Text",
 CellChangeTimes->{{3.6966616224841413`*^9, 
  3.696661660659737*^9}},ExpressionUUID->"c2fc159d-d336-4ff8-a399-\
bf0b292b8e9b"],

Cell[BoxData[
 RowBox[{"Attributes", "[", "h", "]"}]], "Input",
 CellChangeTimes->{{3.6966614248094263`*^9, 
  3.696661438165889*^9}},ExpressionUUID->"b6431340-2fab-445c-a327-\
39ddf7c193ef"],

Cell["Concrete functions are evaluated correctly:", "Text",
 CellChangeTimes->{{3.694151057890089*^9, 3.694151082458219*^9}, 
   3.694151133433838*^9},ExpressionUUID->"c78b3aa7-6d83-4169-9cdc-\
788fe4892791"],

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"u", "*", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6091402188970003`*^9, 3.609140224441317*^9}, {
   3.609142821985362*^9, 3.6091428627446938`*^9}, 3.609142910601431*^9, {
   3.609143190727453*^9, 3.609143205793315*^9}, {3.609215712988388*^9, 
   3.609215713740431*^9}},ExpressionUUID->"5e3c0f75-4cc9-4adc-bb7c-\
a59704af14b8"],

Cell["\<\
For 1-forms the function strict coords returns the 1-form itself:\
\>", "Text",
 CellChangeTimes->{{3.69415153524765*^9, 3.694151592543614*^9}, {
   3.695480965045849*^9, 3.695480968067698*^9}, 3.6954812213729773`*^9, 
   3.69554081768607*^9},ExpressionUUID->"8d2b5312-7c95-4e92-a9b6-\
a7804eb08077"],

Cell[BoxData[
 RowBox[{
  RowBox[{"strictcoords", "[", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"u", "*", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}], "\[Equal]", " ", 
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"u", "*", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694099447907859*^9, 3.694099458267118*^9}, {
  3.694100269821662*^9, 3.694100290755899*^9}, {3.694151463304949*^9, 
  3.694151482770006*^9}},ExpressionUUID->"1dd18216-7242-4305-a0de-\
d81ecf4475aa"],

Cell[TextData[{
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 "This is not confirmed for general symbolic g[u, v] :"
}], "Text",
 CellChangeTimes->{{3.6941568307404203`*^9, 3.694156879192918*^9}, 
   3.69415691483631*^9, 3.695450076295423*^9, 
   3.6966617106516047`*^9},ExpressionUUID->"3ccde001-77bf-481a-a5f0-\
95f2e96d2930"],

Cell[BoxData[
 RowBox[{
  RowBox[{"strictcoords", "[", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"u", "*", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}], "\[Equal]", " ", 
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{"g", "[", 
     RowBox[{"u", "*", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694099447907859*^9, 3.694099458267118*^9}, {
  3.694100269821662*^9, 3.694100290755899*^9}, {3.694151463304949*^9, 
  3.694151482770006*^9}, {3.694156735942844*^9, 3.6941567731621037`*^9}, {
  3.696661720345098*^9, 
  3.696661728379901*^9}},ExpressionUUID->"fe27ff59-e1c1-46eb-8e07-\
dae6b83e942d"],

Cell["and confirmed for h:", "Text",
 CellChangeTimes->{{3.696661806320745*^9, 
  3.6966618352423162`*^9}},ExpressionUUID->"3a8132da-79eb-4802-bcd7-\
775902160537"],

Cell[BoxData[
 RowBox[{
  RowBox[{"strictcoords", "[", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"u", "*", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}], "\[Equal]", " ", 
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"u", "*", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694099447907859*^9, 3.694099458267118*^9}, {
  3.694100269821662*^9, 3.694100290755899*^9}, {3.694151463304949*^9, 
  3.694151482770006*^9}, {3.694156735942844*^9, 3.6941567731621037`*^9}, {
  3.696661720345098*^9, 
  3.696661781476021*^9}},ExpressionUUID->"be35319f-4bc6-4887-bd01-\
6f61295d2f51"],

Cell[TextData[{
 StyleBox["Attention.",
  FontColor->RGBColor[1, 0, 0]],
 " If a symbolic, not explicitly defined function like h[u,v] is used as a \
0-form  always set"
}], "Text",
 CellChangeTimes->{{3.69667835363925*^9, 3.696678370031351*^9}, {
  3.696678405457486*^9, 3.696678481774205*^9}, {3.696678514557897*^9, 
  3.696678581965564*^9}},ExpressionUUID->"5244bae9-f75b-4371-896f-\
1624c9e5eabe"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"h", ",", "NumericFunction"}], "]"}]], "Input",
 CellChangeTimes->{{3.6966785876328573`*^9, 3.696678593013698*^9}, {
  3.696679976002872*^9, 3.6966799928344183`*^9}, {3.696680087858039*^9, 
  3.696680099080987*^9}},ExpressionUUID->"e965bb57-6666-4563-90a8-\
9039e25a8378"],

Cell[BoxData[
 RowBox[{"Attributes", "[", "h", "]"}]], "Input",
 CellChangeTimes->{{3.696680108436735*^9, 
  3.696680118569179*^9}},ExpressionUUID->"44cc6501-48e3-472b-a3eb-\
fd0486d321e8"],

Cell[TextData[StyleBox["\[FilledSquare]",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.694171607518086*^9, 3.69417168681349*^9}, {
   3.69545011971943*^9, 3.695450123783057*^9}, 3.695481239067109*^9, {
   3.7073764909196672`*^9, 
   3.7073764931663237`*^9}},ExpressionUUID->"97af0d1b-0b72-4315-b2e1-\
b6a4ed1dd47f"],

Cell[TextData[StyleBox["Associativity:",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.695481378512012*^9, 
  3.6954813894560423`*^9}},ExpressionUUID->"a20fb6fe-e513-4538-9759-\
cbb49418ed01"],

Cell[BoxData[
 RowBox[{"w3", " ", "=", 
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "h", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"u", "*", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6091433804543047`*^9, 3.6091434103450146`*^9}, 
   3.694156724843733*^9, {3.707375805812117*^9, 
   3.707375810555987*^9}},ExpressionUUID->"c1db98d1-04c6-4ded-a6f8-\
e7d4ba529d1e"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"w3", " ", "\[Equal]", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"Cos", "[", 
      RowBox[{"u", "*", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694171715253262*^9, 3.694171719741493*^9}, {
  3.694171754613311*^9, 3.694171819332995*^9}, {3.707375365276956*^9, 
  3.7073754812059402`*^9}, {3.707375513797494*^9, 3.707375533565096*^9}, {
  3.707375932826651*^9, 
  3.707375933385878*^9}},ExpressionUUID->"ab4c79d2-b6a5-4625-b65a-\
3b18edf8f942"],

Cell[BoxData[
 RowBox[{"w3", " ", "\[Equal]", 
  RowBox[{"extprod", "[", " ", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "h", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"u", "*", "v"}], "]"}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694171715253262*^9, 3.694171719741493*^9}, {
  3.694171754613311*^9, 3.694171876404243*^9}, {3.707375585537781*^9, 
  3.707375592605344*^9}, {3.707375627893559*^9, 3.707375695003419*^9}, {
  3.707375944263266*^9, 
  3.7073759450099497`*^9}},ExpressionUUID->"3bc43774-6ddc-423d-8908-\
c24072a6d7e8"],

Cell["\<\
and this confirms the associativity of extprod. The strict coordinate of this \
2-form is\
\>", "Text",
 CellChangeTimes->{{3.69417209217806*^9, 3.6941722587929697`*^9}, 
   3.707375756740736*^9},ExpressionUUID->"cfd7bb64-dacc-4b1b-b61c-\
30d57aaa17a4"],

Cell[BoxData[
 RowBox[{"strictcoords", "[", "w3", "]"}]], "Input",
 CellChangeTimes->{{3.694171949033008*^9, 3.694171966068013*^9}, {
  3.707375823817864*^9, 
  3.707375825145117*^9}},ExpressionUUID->"49a76518-7d6f-4e51-87f0-\
419cb51490b8"],

Cell["\<\
 Clearly, the exterior product of three 1-forms of dimension 2 is zero:\
\>", "Text",
 CellChangeTimes->{{3.609216249538077*^9, 3.609216334377929*^9}, {
   3.6093086665503273`*^9, 3.6093086714706087`*^9}, 
   3.694172305808475*^9},ExpressionUUID->"8632cc52-96fd-4197-a430-\
e608b163dcd9"],

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "g", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6092160822505083`*^9, 3.609216157741826*^9}, {
  3.694172324344392*^9, 3.6941724004068727`*^9}, {3.707376558526997*^9, 
  3.707376590693548*^9}},ExpressionUUID->"1ecb49d0-3a96-47eb-8c74-\
8e8537bf199a"],

Cell["Now we consider 1-forms in dimension 3:", "Text",
 CellChangeTimes->{{3.609216789849981*^9, 
  3.609216812481275*^9}},ExpressionUUID->"6797d8fe-8a61-4b92-b386-\
ae4ebcef79dd"],

Cell[BoxData[
 RowBox[{"extprod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6091402188970003`*^9, 3.609140224441317*^9}, {
   3.609142821985362*^9, 3.6091428627446938`*^9}, 3.609142910601431*^9, {
   3.609142950990741*^9, 3.609142964984541*^9}, {3.6091435169461117`*^9, 
   3.609143530265874*^9}, 
   3.615034059357437*^9},ExpressionUUID->"aa292b1e-75e3-4462-b9b8-\
28ca61fa750e"],

Cell["Again we verify the associativity:", "Text",
 CellChangeTimes->{{3.609216843546052*^9, 3.609216862265123*^9}, 
   3.6093087120219283`*^9},ExpressionUUID->"4a588bd9-17e9-47f2-9717-\
7961e91d4e8d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "w3", "]"}], ";", 
  RowBox[{"w3", "=", " ", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "g", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.6941582477977343`*^9, {3.694172671520575*^9, 3.694172720517679*^9}, {
   3.7073766800777617`*^9, 
   3.707376727412428*^9}},ExpressionUUID->"142b50f1-e7f7-46c2-80da-\
9c35d4a8293a"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"w3", "\[Equal]", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "h", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "g", "]"}], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.694172735199551*^9, 3.694172822701437*^9}, {
  3.707376745518309*^9, 3.707376759964772*^9}, {3.7073768005432243`*^9, 
  3.7073768294286327`*^9}},ExpressionUUID->"a78b4269-b1cf-4853-b2c8-\
c26fd370919f"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"w3", "\[Equal]", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "h", "]"}], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
       RowBox[{
        RowBox[{"d", "[", "g", "]"}], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}], ",", 
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694172735199551*^9, 3.694172892900568*^9}, {
  3.707376845078041*^9, 
  3.70737689484658*^9}},ExpressionUUID->"0a624552-079a-438e-abd2-\
af903724500a"],

Cell["We calculate the strict coordinates of this 3-form", "Text",
 CellChangeTimes->{{3.694174274874819*^9, 
  3.6941743579120693`*^9}},ExpressionUUID->"879be9f3-2fee-4e5c-bd3c-\
43f990f299ed"],

Cell[BoxData[
 RowBox[{"strictcoords", "[", "w3", "]"}]], "Input",
 CellChangeTimes->{{3.69417290100651*^9, 3.694172915694612*^9}, {
   3.6941737045389223`*^9, 3.694173705038376*^9}, {3.694173831056624*^9, 
   3.69417383902099*^9}, 3.69417389526993*^9, {3.707376908402063*^9, 
   3.707376908943982*^9}},ExpressionUUID->"b08b0e6a-1220-4d9f-b111-\
62c92e98e791"],

Cell["\<\
The only strict coordinate coincides with the determinant of the coordinate \
triples of the three 1-forms:\
\>", "Text",
 CellChangeTimes->{{3.694174384934897*^9, 3.69417445721565*^9}, 
   3.694244856900518*^9},ExpressionUUID->"0c4b2851-64fa-46dc-bea7-\
45f10b811276"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "-", 
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "h", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       RowBox[{"d", "[", "g", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "}"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.694172929962441*^9, 3.6941729492210627`*^9}, {
  3.6941730099633083`*^9, 3.694173070347374*^9}, {3.694173268340365*^9, 
  3.694173412096404*^9}, {3.694173562190103*^9, 3.694173578135697*^9}, {
  3.694173866818151*^9, 
  3.694173873485216*^9}},ExpressionUUID->"c58026bf-7fa2-4ed6-a10c-\
9575dfa18b06"],

Cell[TextData[{
 StyleBox["Notation",
  FontColor->RGBColor[0, 0, 1]],
 ". Traditioally, the exterior product extprod is denoted by ",
 Cell[BoxData[
  FormBox["\[Wedge]", TraditionalForm]],ExpressionUUID->
  "126ebab4-e3df-4914-841e-a297e8613726"],
 ":"
}], "Text",
 CellChangeTimes->{{3.70737699724459*^9, 3.707377000588277*^9}, {
  3.707384361479292*^9, 
  3.707384438301653*^9}},ExpressionUUID->"a9974bef-86a7-43bd-b290-\
fa053c06654e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"extprod", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "\[DotEqual]", " ", 
  RowBox[{"a", "\[Wedge]", "b"}]}]], "Input",
 CellChangeTimes->{{3.707384446057562*^9, 
  3.707384488567584*^9}},ExpressionUUID->"0fe42e15-b64d-4712-aa22-\
69f3c8df0fa8"],

Cell["\<\
(read \[DotEqual] -> \[OpenCurlyDoubleQuote]is traditionally denoted by\
\[CloseCurlyDoubleQuote] ); this notation can be used only in symbolic, not \
evaluatable formulas. Applied in calculations instead of extprod may lead to \
errors:\
\>", "Text",
 CellChangeTimes->{{3.707385460634164*^9, 
  3.707385746743655*^9}},ExpressionUUID->"6c03d46a-5aea-459c-ba41-\
77947bffc1ee"],

Cell[BoxData[
 RowBox[{"w3", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "h", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], "\[Wedge]", 
   RowBox[{
    RowBox[{"d", "[", "g", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], "\[Wedge]", 
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.707385891852957*^9, 
  3.7073859338283587`*^9}},ExpressionUUID->"51a098d8-1250-476f-a5fb-\
8231c06d7022"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.707386017531603*^9, 
  3.7073860263315763`*^9}},ExpressionUUID->"d699d0a0-f37e-4a1f-a6b2-\
4368cdf8d364"],

Cell[TextData[{
 "We prove\n",
 StyleBox["Proposition 2",
  FontColor->RGBColor[0, 0, 1]],
 ". With the exterior product ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Wedge]", " ", 
    RowBox[{"the", "  ", "vector", " ", "space"}]}], TraditionalForm]],
  ExpressionUUID->"e30501ac-80b8-4baf-b1d3-51e923c59151"],
 " and Module ",
 Cell[BoxData[
  RowBox[{"\[And]", 
   SuperscriptBox["M", "n"], " "}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{
   3.694071129092206*^9, {3.694071176993775*^9, 3.694071186876473*^9}, {
    3.6940712729007797`*^9, 3.694071401731885*^9}},ExpressionUUID->
  "976a56f0-28d8-4e20-9a0b-7bf7ac011181"],
 "  becomes an associative algebra with unity the constant function 1. The \
exterior product is anti-commutative, what means: For \[Omega] \[Element] ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Wedge]", "p"], 
   SuperscriptBox["M", "n"], " "}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{
   3.694071129092206*^9, {3.694071176993775*^9, 3.694071186876473*^9}, {
    3.6940712729007797`*^9, 3.694071401731885*^9}},ExpressionUUID->
  "efc1aeb1-0474-42cb-b5ce-84f10e0ec797"],
 "and  \n\[Theta]\[Element] ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Wedge]", "q"], 
   SuperscriptBox["M", "n"], " "}]], "Input",
  Evaluatable->False,
  CellChangeTimes->{
   3.694071129092206*^9, {3.694071176993775*^9, 3.694071186876473*^9}, {
    3.6940712729007797`*^9, 3.694071401731885*^9}},ExpressionUUID->
  "722aa6ac-fc85-43e5-a06c-8f56e9e7fd52"],
 " the rule"
}], "Text",
 CellChangeTimes->{{3.694245078065048*^9, 3.694245310102871*^9}, {
   3.694245544180727*^9, 3.6942455798526697`*^9}, {3.694245687281592*^9, 
   3.6942456956200523`*^9}, {3.694245764379517*^9, 3.694245893578524*^9}, {
   3.694245968428111*^9, 3.694246092505127*^9}, 3.694246124836149*^9, {
   3.694246170041972*^9, 3.6942462039606247`*^9}, 3.6942463849113903`*^9, {
   3.695481761888035*^9, 3.695481764640624*^9}, {3.695540947317814*^9, 
   3.695540958461426*^9}, 
   3.696394516927621*^9},ExpressionUUID->"e39ad930-e803-4a64-a169-\
c3035ba01ae4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Theta]", " ", "\[Wedge]", "\[Omega]"}], " ", "\[Equal]", " ", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"p", "*", "q"}]], 
   RowBox[{"\[Omega]", "\[Wedge]", " ", "\[Theta]"}], "                              ", 
   RowBox[{"(", "4", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.694246227424355*^9, 3.694246371828175*^9}, {
  3.694247952291396*^9, 
  3.6942479595310993`*^9}},ExpressionUUID->"275dbe25-181c-44b0-a312-\
27202e157a6c"],

Cell["is valid.", "Text",
 CellChangeTimes->{{3.694246392368514*^9, 
  3.694246411777017*^9}},ExpressionUUID->"fa79ef79-553d-44e5-a2d7-\
f63074f9990a"],

Cell[TextData[{
 StyleBox["Proof. ",
  FontColor->RGBColor[0, 0, 1]],
 "Clearly, the exterior product is bilinear:"
}], "Text",
 CellChangeTimes->{{3.694246497810258*^9, 3.694246525573669*^9}, {
  3.694246562989455*^9, 
  3.694246609837019*^9}},ExpressionUUID->"cc0464e4-146b-42a2-b648-\
4a3a832b363e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "\[Wedge]", 
    RowBox[{"(", " ", 
     RowBox[{
      SubscriptBox["\[Theta]", "1"], "+", " ", 
      SubscriptBox["\[Theta]", "2"]}], ")"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"\[Omega]", "\[Wedge]", 
     SubscriptBox["\[Theta]", "1"]}], "+", 
    RowBox[{"\[Omega]", "\[Wedge]", 
     SubscriptBox["\[Theta]", "2"]}]}]}], ";", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Omega]", "\[Wedge]", "a"}], "*", "\[Theta]"}], "\[Equal]", " ", 
   RowBox[{"a", "*", 
    RowBox[{"(", 
     RowBox[{"\[Omega]", "\[Wedge]", "\[Theta]"}], ")"}]}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6942466850532923`*^9, 3.694246869963778*^9}, {
  3.694246930603113*^9, 
  3.694247018146845*^9}},ExpressionUUID->"fb546825-5725-4834-b1de-\
692c335e9935"],

Cell["for example", "Text",
 CellChangeTimes->{{3.694247083620092*^9, 
  3.694247098004273*^9}},ExpressionUUID->"199e99fd-3617-4aad-9b19-\
bff0d632045f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Pi", "*", 
        RowBox[{
         RowBox[{"d", "[", "g", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"d", "[", "h", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ")"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"Pi", "*", 
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"d", "[", "g", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "+", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{"d", "[", "h", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.69424711899226*^9, 3.694247162665699*^9}, {
  3.694247194010079*^9, 3.69424732416826*^9}, {3.6942473569357853`*^9, 
  3.694247409200935*^9}, {3.707386107538468*^9, 
  3.707386287563703*^9}},ExpressionUUID->"7b28a965-9b84-4aee-afe6-\
d9a13b0cd3f3"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"u", "*", "v"}], "]"}], "*", 
        RowBox[{
         RowBox[{"d", "[", "g", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"d", "[", "h", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ")"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"u", "*", "v"}], "]"}], "*", 
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
        RowBox[{"d", "[", "g", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "+", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "f", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{"d", "[", "h", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.69424711899226*^9, 3.694247162665699*^9}, {
   3.694247194010079*^9, 3.69424732416826*^9}, {3.6942473569357853`*^9, 
   3.694247409200935*^9}, {3.6942475018255587`*^9, 3.694247551152401*^9}, {
   3.707386317379067*^9, 3.707386333447698*^9}, 3.707386381101631*^9, {
   3.707386437476713*^9, 
   3.707386491340386*^9}},ExpressionUUID->"760002d6-25b0-4407-943d-\
3d3354137be2"],

Cell[BoxData[
 RowBox[{"Attributes", "[", "TensorWedge", "]"}]], "Input",ExpressionUUID->"a1a42050-82eb-4a9b-888f-8df1a3b85716"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Attributes", "[", "extprod", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.695482061315769*^9, 3.6954820806265783`*^9}, {
   3.6954821664107637`*^9, 3.695482224409944*^9}, 
   3.695482429328492*^9},ExpressionUUID->"4feca66c-2c4b-4741-b12a-\
da928d222a3b"],

Cell["\<\
The associativity corresponds to the flatness of the Function TensorWedge; it \
has been confirmed by some examples above. To confirm the anti-commutativity \
(4) we assume n = dim =5 and consider some examples.\
\>", "Text",
 CellChangeTimes->{{3.6942476954207087`*^9, 3.694247740132159*^9}, {
   3.694247802540077*^9, 3.6942478659556723`*^9}, {3.694247968602858*^9, 
   3.694248084866027*^9}, 
   3.694248126137865*^9},ExpressionUUID->"828580cf-8701-4031-9a33-\
9e733be087c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "5"}], ";"}]], "Input",
 CellChangeTimes->{{3.694248129844801*^9, 
  3.6942481512340117`*^9}},ExpressionUUID->"a82aae1c-8c10-416f-9fc2-\
57db1860c4ef"],

Cell["\<\
We may assume p\[LessEqual]q. For p = 0 and all q formula (4) is obvious. \
Consider the differentials of the functions h[i][u1,u2,u3,u4,u5] and set\
\>", "Text",
 CellChangeTimes->{{3.694248187560987*^9, 3.694248300704341*^9}, {
  3.694248471391242*^9, 
  3.694248561438458*^9}},ExpressionUUID->"37ba48c0-bad9-4e9c-b8d5-\
a7c2f59ffc76"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Theta]", "[", "i_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"h", "[", "i", "]"}], "]"}], "[", 
   RowBox[{"u1", ",", "u2", ",", "u3", ",", "u4", ",", "u5"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.694248593190832*^9, 3.694248599606563*^9}, {
  3.694248632790216*^9, 3.694248649806595*^9}, {3.694248683414168*^9, 
  3.6942486945103493`*^9}, {3.6942487449189672`*^9, 
  3.694248751350307*^9}},ExpressionUUID->"4b8c4185-42f6-44fb-9cbb-\
5652ceadce7b"],

Cell["p=1=q.", "Text",
 CellChangeTimes->{{3.6942487772046337`*^9, 3.6942487906289377`*^9}, {
  3.69666476141136*^9, 
  3.6966647656834908`*^9}},ExpressionUUID->"a58f40dd-c815-40b7-88bf-\
6aa90a01e42b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "2", "]"}]}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
      RowBox[{"\[Theta]", "[", "1", "]"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694248801173849*^9, 3.694249002179563*^9}, {
  3.707386910222081*^9, 
  3.7073869526292257`*^9}},ExpressionUUID->"a3625025-fa3a-4c7a-8fae-\
3dc20727bb09"],

Cell["p=1,q=2.", "Text",
 CellChangeTimes->{{3.694249043466919*^9, 3.694249055218745*^9}, 
   3.6942493714726048`*^9},ExpressionUUID->"912ff316-8448-4731-89ba-\
8b7eb1ac2c04"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "3", "]"}]}], "]"}]}], "]"}], "\[Equal]", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "3", "]"}]}], "]"}], ",", " ", 
     RowBox[{"\[Theta]", "[", "1", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694248801173849*^9, 3.694249002179563*^9}, {
  3.6942490905419893`*^9, 3.694249148163199*^9}, {3.694249229458091*^9, 
  3.694249298538661*^9}, {3.696394776991185*^9, 3.69639480297364*^9}, {
  3.696394851444623*^9, 3.696394860012558*^9}, {3.696394895068839*^9, 
  3.696394922587871*^9}, {3.696395039174582*^9, 3.696395075587194*^9}, {
  3.707386967966559*^9, 3.707386999038472*^9}, {3.707387030613268*^9, 
  3.707387152580153*^9}},ExpressionUUID->"e46eb69f-10a8-42bc-9b83-\
d348ac3a2a13"],

Cell["p=1, q=3.", "Text",
 CellChangeTimes->{{3.694249343752692*^9, 
  3.694249365616683*^9}},ExpressionUUID->"afbaa47e-62ed-4178-9bc6-\
81caaf739023"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "4", "]"}]}], "]"}]}], "]"}], "\[Equal]", 
   RowBox[{"-", " ", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
        RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
        RowBox[{"\[Theta]", "[", "4", "]"}]}], "]"}], ",", " ", 
      RowBox[{"\[Theta]", "[", "1", "]"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694248801173849*^9, 3.694249002179563*^9}, {
   3.6942490905419893`*^9, 3.694249148163199*^9}, {3.694249229458091*^9, 
   3.694249298538661*^9}, {3.694249378072707*^9, 3.6942494422088757`*^9}, 
   3.6942494850338917`*^9, {3.694249517160236*^9, 3.694249582311634*^9}, {
   3.707387190738532*^9, 3.707387314969347*^9}, 3.7073874222285*^9, 
   3.70738745271308*^9, {3.7073875354750347`*^9, 
   3.707387548611103*^9}},ExpressionUUID->"18147cd8-837c-4358-aeda-\
e72cf0412fbe"],

Cell["p=2,q=2.", "Text",
 CellChangeTimes->{{3.694249620774678*^9, 
  3.694249645462288*^9}},ExpressionUUID->"dde6b9d9-ef7e-4296-9c01-\
0d04dec6954c"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "2", "]"}]}], "]"}], ",", 
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "4", "]"}]}], "]"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "4", "]"}]}], "]"}], ",", 
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "2", "]"}]}], "]"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.694248801173849*^9, 3.694249002179563*^9}, {
   3.6942490905419893`*^9, 3.694249148163199*^9}, {3.694249229458091*^9, 
   3.694249298538661*^9}, {3.694249378072707*^9, 3.6942494422088757`*^9}, 
   3.6942494850338917`*^9, {3.694249517160236*^9, 3.694249582311634*^9}, {
   3.694249655046235*^9, 3.694249783622819*^9}, {3.707387592264121*^9, 
   3.707387859357177*^9}},ExpressionUUID->"869dc65f-5a10-42f0-9385-\
2d4846f924d5"],

Cell["p=2,q=3.", "Text",
 CellChangeTimes->{{3.694249620774678*^9, 3.694249645462288*^9}, 
   3.694249839685017*^9},ExpressionUUID->"82b4db9d-27ef-4764-8bf2-\
94cb7303bd6f"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "2", "]"}]}], "]"}], ",", 
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "4", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "5", "]"}]}], "]"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "4", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "5", "]"}]}], "]"}], ",", 
     RowBox[{"extprod", "[", " ", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "2", "]"}]}], "]"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.694248801173849*^9, 3.694249002179563*^9}, {
   3.6942490905419893`*^9, 3.694249148163199*^9}, {3.694249229458091*^9, 
   3.694249298538661*^9}, {3.694249378072707*^9, 3.6942494422088757`*^9}, 
   3.6942494850338917`*^9, {3.694249517160236*^9, 3.694249582311634*^9}, {
   3.694249655046235*^9, 3.694249783622819*^9}, {3.694249887289722*^9, 
   3.6942499262771482`*^9}, {3.707387877874508*^9, 3.707388062415172*^9}, 
   3.707388288679841*^9},ExpressionUUID->"a3aa3625-d6ba-4b4f-88f9-\
84277c06d671"],

Cell["The user may confirm more cases. \[FilledSquare]", "Text",
 CellChangeTimes->{{3.6942500262915897`*^9, 
  3.694250055544482*^9}},ExpressionUUID->"de2b0ab1-de13-4dc3-a03e-\
24aa39028354"],

Cell["We mention yet", "Text",
 CellChangeTimes->{{3.694250064989196*^9, 
  3.694250091955304*^9}},ExpressionUUID->"b7b552be-1a80-4404-b5bb-\
9db9c42ec57c"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"strictcoords", "[", 
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "4", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "5", "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", " ", 
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[Theta]", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "5"}], "}"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.694250098083838*^9, 3.694250109309836*^9}, {
  3.69425014315735*^9, 3.6942502794663467`*^9}, {3.707396985526309*^9, 
  3.707397024344681*^9}, {3.7073970661279573`*^9, 
  3.707397081928357*^9}},ExpressionUUID->"a7851dd9-ca0c-40b4-90a5-\
efc3474d392d"],

Cell["and", "Text",
 CellChangeTimes->{{3.6942503221453037`*^9, 
  3.694250322777419*^9}},ExpressionUUID->"de808e4c-3d9e-40d0-8442-\
e30f88236036"],

Cell[BoxData[
 RowBox[{
  RowBox[{"strictcoords", "[", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "4", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "5", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "6", "]"}]}], "]"}], "]"}], "\[Equal]", 
  RowBox[{"{", "0", "}"}]}]], "Input",
 CellChangeTimes->{{3.694250387010694*^9, 3.69425041840172*^9}, {
  3.7073971103121347`*^9, 
  3.7073971594393263`*^9}},ExpressionUUID->"b00a09fa-2f90-4c49-824c-\
2b2ee6c44e08"],

Cell["\<\
since the degree of the form  p=6 > dim =5 is greater than the dimension of \
the manifold.\
\>", "Text",
 CellChangeTimes->{{3.6942504382006187`*^9, 3.694250541064159*^9}, 
   3.694250600407487*^9},ExpressionUUID->"f3b19776-9526-4a18-90ca-\
b87db5d158dd"],

Cell["\<\
Now we will introduce local basis representations for multilinear functions \
and, in particular, for p-forms. \
\>", "Text",
 CellChangeTimes->{{3.69548269068526*^9, 3.6954826941965723`*^9}, {
  3.695541157419389*^9, 3.695541158914978*^9}, {3.6955414967284193`*^9, 
  3.695541621703918*^9}},ExpressionUUID->"83ac46ec-9693-474a-8bee-\
003b5bb3c595"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.695542193394319*^9, 3.695542194763631*^9}, {
  3.695542569433702*^9, 
  3.695542576177009*^9}},ExpressionUUID->"df9ca957-3682-47ca-9d1a-\
f0be9b1ddf86"],

Cell[BoxData[
 RowBox[{"?", "d"}]], "Input",
 CellChangeTimes->{{3.695542245090435*^9, 
  3.6955422527640038`*^9}},ExpressionUUID->"5c37885c-77bc-4159-98d7-\
cbaa71fbfc33"],

Cell["\<\
We already introduced a simpler notation for the basis 1-forms:\
\>", "Text",
 Evaluatable->True,
 CellChangeTimes->{{3.695620384243918*^9, 3.695620440795226*^9}, {
  3.69639523833696*^9, 
  3.696395260456995*^9}},ExpressionUUID->"933923fe-50b7-4b17-bdd8-\
77fb638eb644"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dx", "[", "2", "]"}], " ", "==", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"x", "[", "2", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}], ",", 
    RowBox[{"x", "[", "4", "]"}], ",", 
    RowBox[{"x", "[", "5", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.694354120125146*^9, 3.6943541469447536`*^9}, {
   3.694354306893662*^9, 3.6943543957111673`*^9}, {3.69435446903512*^9, 
   3.6943545269268713`*^9}, 3.69554179535201*^9, {3.695541884131007*^9, 
   3.6955419275189533`*^9}, {3.695541964101838*^9, 3.695542006397696*^9}, {
   3.69554211947031*^9, 3.6955421579330463`*^9}, {3.69562610651618*^9, 
   3.695626203487417*^9}, {3.696140461379093*^9, 3.696140483422941*^9}, {
   3.6963952927172003`*^9, 3.696395334397421*^9}, {3.6963954288884153`*^9, 
   3.696395461759858*^9}, {3.7073972243690853`*^9, 
   3.707397234830893*^9}},ExpressionUUID->"517842c3-ed22-4006-90d3-\
7e6b5020b6aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "5"}], ";", " ", 
  RowBox[{"dx", "[", "5", "]"}]}]], "Input",
 CellChangeTimes->{{3.695626034346772*^9, 
  3.6956260539287777`*^9}},ExpressionUUID->"6854fe47-4dfd-496f-836e-\
4cf60840185c"],

Cell["\<\
dx[i] evaluated for a vector field yields its i-th coordinate:\
\>", "Text",
 CellChangeTimes->{{3.695620591169128*^9, 
  3.695620662657579*^9}},ExpressionUUID->"bf914d01-17c5-443e-828f-\
d13a38671a99"],

Cell[BoxData[
 RowBox[{"?", "val"}]], "Input",
 CellChangeTimes->{{3.696395569906773*^9, 
  3.696395574214531*^9}},ExpressionUUID->"9d95e7a7-1b7f-4fcf-b132-\
d06a8cf6951a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"val", "[", 
     RowBox[{"dx", "[", "2", "]"}], "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}], "[", 
   RowBox[{"vec", "[", 
    RowBox[{"a", "[", 
     RowBox[{
      RowBox[{"x", "[", "1", "]"}], ",", 
      RowBox[{"x", "[", "2", "]"}], ",", 
      RowBox[{"x", "[", "3", "]"}]}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695543117599963*^9, 3.695543246516137*^9}, 
   3.6956206853029327`*^9, 3.695620719859591*^9, 3.696395550516086*^9, 
   3.696395663715186*^9, 
   3.696395788354569*^9},ExpressionUUID->"7de76035-1502-4580-a1b7-\
5c9672503bb1"],

Cell["The differential of a function is a 1-form:", "Text",
 CellChangeTimes->{{3.6956212017969007`*^9, 
  3.6956212346204367`*^9}},ExpressionUUID->"068f260a-e9d1-4c76-b96c-\
9711e951594b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "h", "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}], ",", 
   RowBox[{"x", "[", "3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6956207662749367`*^9, 
  3.6956207763068533`*^9}},ExpressionUUID->"f12bf3a5-3ed5-49a1-be4e-\
557d10775f59"],

Cell["with the  basis representation", "Text",
 CellChangeTimes->{{3.695621254386938*^9, 
  3.6956212943398027`*^9}},ExpressionUUID->"a36078fe-93b4-4cbd-9070-\
d4abe8b73427"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "*", 
     RowBox[{"dx", "[", "i", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "dim"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695620786479755*^9, 
  3.69562091712831*^9}},ExpressionUUID->"f95f814c-977c-480c-af06-\
1173664b36fc"],

Cell["or explicitly", "Text",
 CellChangeTimes->{{3.695621309059732*^9, 
  3.695621317019595*^9}},ExpressionUUID->"8793b23b-40d8-4143-a719-\
7b215c388369"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "h", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}]}], "]"}], "\[Equal]", " ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}], ",", 
         RowBox[{"x", "[", "3", "]"}]}], "]"}], ",", 
       RowBox[{"x", "[", "i", "]"}]}], "]"}], "*", 
     RowBox[{"dx", "[", "i", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "dim"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6956207662749367`*^9, 3.6956207763068533`*^9}, {
  3.695620992267191*^9, 
  3.695621102894225*^9}},ExpressionUUID->"c1bde684-8e59-474d-9b02-\
7d8383236a4b"],

Cell[TextData[{
 "Now we remember the tensor product of ",
 StyleBox["multi",
  IgnoreSpellCheck->True],
 "linear functions, see \nExample 3, and show\n",
 StyleBox["Lemma 2.",
  FontColor->RGBColor[0, 0, 1]],
 "  The family of all tensor products \ntpr[dx[i1],...,dx[ip]], 1\[LessEqual] \
ij \[LessEqual] dim, j= 1,...,p,\nis a",
 StyleBox[" local basis field ",
  FontColor->RGBColor[0, 0, 1]],
 "for the multilinear functions of degree p.\n",
 StyleBox["Proof. ",
  FontColor->RGBColor[0, 0, 1]],
 "To confirm the statement consider a four-dimensional manifold",
 "\n",
 "and a multilinear function of degree 3 with the coordinate Array"
}], "Text",
 CellChangeTimes->{{3.695621627297374*^9, 3.695621837471868*^9}, {
   3.6956218910553217`*^9, 3.69562205972613*^9}, {3.6956220917819357`*^9, 
   3.695622293924451*^9}, 3.696395899075946*^9, 
   3.696396127435828*^9},ExpressionUUID->"a72a7779-846f-40e0-8035-\
7a09bde82181"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "ar3", "]"}], ";", " ", 
  RowBox[{"dim", "=", " ", "4"}], ";", 
  RowBox[{"ar3", " ", "=", 
   RowBox[{"Array", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", "4"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.695622441555119*^9, 3.695622468083157*^9}, {
  3.695622519084696*^9, 3.695622576262689*^9}, {3.6956259155653963`*^9, 
  3.695625953617956*^9}, {3.696396059303249*^9, 
  3.696396077018629*^9}},ExpressionUUID->"08c60183-a24e-4d79-94f3-\
22fa6e0bd132"],

Cell[BoxData[
 RowBox[{"ar3", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "4", ",", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.69562260162994*^9, 
  3.695622663761915*^9}},ExpressionUUID->"bbaf4fc6-ffb0-4b63-aba4-\
491a96f9557d"],

Cell["Set", "Text",
 CellChangeTimes->{{3.695622726976507*^9, 
  3.695622729112376*^9}},ExpressionUUID->"bf5cf7ff-fb94-4af8-ba26-\
ae3c693e4ed7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "dx3", "]"}], ";", 
  RowBox[{
   RowBox[{"dx3", "[", 
    RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], ":=", " ", 
   RowBox[{"TensorProduct", "[", 
    RowBox[{
     RowBox[{"dx", "[", "i", "]"}], ",", 
     RowBox[{"dx", "[", "j", "]"}], ",", 
     RowBox[{"dx", "[", "k", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6956227425200853`*^9, 3.695622822073036*^9}, {
  3.69562307549044*^9, 3.6956230925030937`*^9}, {3.6956231298246927`*^9, 
  3.695623145126625*^9}, {3.695625016261261*^9, 
  3.6956250314414186`*^9}},ExpressionUUID->"b64cf499-cb50-47f7-8f92-\
b2d2ddeeae08"],

Cell[BoxData[
 RowBox[{"dx", "[", "4", "]"}]], "Input",
 CellChangeTimes->{{3.695623195994051*^9, 3.695623201494158*^9}, 
   3.695625885302401*^9},ExpressionUUID->"58cd1399-a150-42da-bc8c-\
31793bb114f1"],

Cell[BoxData[
 RowBox[{"dx3", "[", 
  RowBox[{"1", ",", "2", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.695622826683197*^9, 3.6956228519654007`*^9}, 
   3.6956258495105343`*^9},ExpressionUUID->"a8e7d177-6020-489c-8139-\
e41c9f37fa51"],

Cell[TextData[{
 StyleBox["Local basis field",
  FontColor->RGBColor[0, 0, 1]],
 " means that any multilinear function of degree p (here p=3) locally has a \
presentation of the form"
}], "Text",
 CellChangeTimes->{{3.695639889851795*^9, 3.695639974403088*^9}, {
  3.695640029722609*^9, 
  3.695640063466247*^9}},ExpressionUUID->"feb8c45f-c658-4dea-92d6-\
ee7b02256cca"],

Cell[BoxData[
 RowBox[{"ar3", "==", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ar3", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "j", ",", "k"}], "]"}], "]"}], "*", 
     RowBox[{"dx3", "[", 
      RowBox[{"i", ",", "j", ",", "k"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "dim"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6956251235544853`*^9, 3.6956252664312553`*^9}, 
   3.695625315651843*^9, {3.695626405217236*^9, 
   3.695626410958015*^9}},ExpressionUUID->"3e9cf613-de7c-4a3d-9694-\
60f73c0e62f7"],

Cell["\<\
 with uniquely defined coefficients, namely the coordinate function, e.g.\
\>", "Text",
 CellChangeTimes->{{3.695626470284532*^9, 3.695626510124159*^9}, {
   3.6956265531718607`*^9, 3.695626565126383*^9}, {3.695640087826065*^9, 
   3.695640160841606*^9}, 3.6956401916377296`*^9, {3.6956404992387333`*^9, 
   3.695640505942173*^9}},ExpressionUUID->"c446922f-6be9-42ad-a889-\
ea7b4b3e991f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"val", "[", "ar3", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}], ",", 
    RowBox[{"x", "[", "4", "]"}]}], "]"}], "[", 
  RowBox[{
   RowBox[{"stb", "[", "2", "]"}], ",", 
   RowBox[{"stb", "[", "1", "]"}], ",", 
   RowBox[{"stb", "[", "4", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.695640255717205*^9, 3.695640309704431*^9}, {
  3.695640357864697*^9, 3.695640359922288*^9}, {3.695640391160205*^9, 
  3.695640477791733*^9}},ExpressionUUID->"3ad16d0a-e865-4588-a4bd-\
50e241ac8e0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"val", "[", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ar3", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j", ",", "k"}], "]"}], "]"}], "*", 
       RowBox[{"dx3", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "dim"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "dim"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "dim"}], "}"}]}], "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}], ",", 
    RowBox[{"x", "[", "4", "]"}]}], "]"}], "[", 
  RowBox[{
   RowBox[{"stb", "[", "2", "]"}], ",", 
   RowBox[{"stb", "[", "1", "]"}], ",", 
   RowBox[{"stb", "[", "4", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.695640255717205*^9, 3.695640309704431*^9}, {
  3.695640357864697*^9, 3.695640359922288*^9}, {3.695640391160205*^9, 
  3.695640477791733*^9}, {3.6956405268954067`*^9, 
  3.695640576247405*^9}},ExpressionUUID->"5d2d397b-9005-4d4a-b347-\
2b9c10af07a7"],

Cell["\<\
The sum may represent the null array iff all the coefficients are zero. This \
confirms the statement. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.695626470284532*^9, 3.695626510124159*^9}, {
  3.6956265531718607`*^9, 3.695626565126383*^9}, {3.695640087826065*^9, 
  3.695640160841606*^9}, {3.6956406787969513`*^9, 
  3.695640754620739*^9}},ExpressionUUID->"27f78f9f-fd25-45c5-8d15-\
8cee39d5b992"],

Cell[TextData[{
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 ". the representation is valid in any given chart (= coordinate system) of \
the  manifold,but in general not globally. Remember, that as a real vector \
space the space of multilinear functions on a manifold is infinite \
dimensional. \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.69564083935574*^9, 
  3.695641056528529*^9}},ExpressionUUID->"6a21450f-cba5-4a37-866f-\
d35e0bcd4609"],

Cell[TextData[{
 "Now we consider the following relation between the exterior product and the \
tensor Product:\n",
 StyleBox["Lemma 4",
  FontColor->RGBColor[0, 0, 1]],
 ". For 1-forms \[Theta][i] the following identity is valid:"
}], "Text",
 CellChangeTimes->{{3.695652924508822*^9, 3.695653158571233*^9}, 
   3.70739784865226*^9},ExpressionUUID->"130563b9-287c-4b94-a21c-\
08e44899a6cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{"\[Theta]", "[", "1", "]"}], ",", "...", ",", 
    RowBox[{"\[Theta]", "[", "p", "]"}]}], "]"}], "\[Equal]", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Signature", "[", 
      RowBox[{"{", 
       RowBox[{"i1", ",", "...", ",", "ip"}], "}"}], "]"}], "*", 
     "                                         ", 
     RowBox[{"(", "5", ")"}], 
     RowBox[{"TensorProduct", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "i1", "]"}], ",", "...", ",", 
       RowBox[{"\[Theta]", "[", "ip", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i1", ",", "...", ",", "ip"}], "}"}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.695653186077825*^9, 3.69565319822712*^9}, {
  3.695653229869776*^9, 3.695653295346277*^9}, {3.695653336843088*^9, 
  3.6956534027136106`*^9}, {3.6956534367219057`*^9, 3.695653449865643*^9}, {
  3.695653481968754*^9, 3.6956535924888277`*^9}, {3.695702477258954*^9, 
  3.695702481271237*^9}, {3.695794867996018*^9, 3.6957949286911287`*^9}, {
  3.695794979287456*^9, 3.695795014626902*^9}, {3.707397475693742*^9, 
  3.707397484933241*^9}, {3.707398094249446*^9, 
  3.707398159512526*^9}},ExpressionUUID->"2fb0bee4-5769-4b82-b67d-\
e2b5253758fb"],

Cell[TextData[{
 "where the sum runs over all permutations of order p.\n",
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " We confirm the statement for a 5-dimensional manifold and specify the \
1-forms:"
}], "Text",
 CellChangeTimes->{{3.6956536219624968`*^9, 3.695653688150613*^9}, {
   3.695703216655753*^9, 3.695703296887258*^9}, 
   3.696404379122828*^9},ExpressionUUID->"1958fb81-c351-410d-90c6-\
692186102bd6"],

Cell[BoxData[
 RowBox[{"?", "altform"}]], "Input",
 CellChangeTimes->{{3.69640438710433*^9, 
  3.69640439112328*^9}},ExpressionUUID->"057abc3d-d4bb-4c8c-8cb3-\
2e4994b16361"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nn", "=", "dim"}], ";", 
  RowBox[{"Clear", "[", 
   RowBox[{"dim", ",", "\[Theta]"}], "]"}], ";", 
  RowBox[{
   RowBox[{"\[Theta]", "[", "i_", "]"}], " ", ":=", " ", 
   RowBox[{"vec", "[", 
    RowBox[{"h", "[", "i", "]"}], "]"}]}], ";", 
  RowBox[{"dim", "=", "nn"}], ";"}]], "Input",
 CellChangeTimes->{{3.695641308516754*^9, 3.695641351680073*^9}, {
  3.695641404858042*^9, 3.695641438576191*^9}, {3.69573932357041*^9, 
  3.695739350671706*^9}, {3.69573939264695*^9, 3.695739416574748*^9}, {
  3.695739448122143*^9, 3.695739481549316*^9}, {3.69614054111045*^9, 
  3.6961405670140667`*^9}, {3.6961474761898737`*^9, 3.696147492779345*^9}, {
  3.6964044370788116`*^9, 3.6964044398267937`*^9}, {3.696404483506579*^9, 
  3.6964044971542664`*^9}},ExpressionUUID->"90a32c1c-d827-4dbc-be1d-\
d06d7eaa2cd7"],

Cell["Case p = 2:", "Text",
 CellChangeTimes->{{3.695703587867475*^9, 3.695703608756027*^9}, 
   3.695740659257516*^9},ExpressionUUID->"7e87f382-4a05-467a-aaa1-\
d96fd06a405c"],

Cell[BoxData[
 RowBox[{"dim", "=", "5"}]], "Input",
 CellChangeTimes->{{3.696404514078167*^9, 
  3.696404533777646*^9}},ExpressionUUID->"8430f58e-1852-4a05-8557-\
c76234a0894f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
    RowBox[{"\[Theta]", "[", "2", "]"}]}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"TensorProduct", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "2", "]"}]}], "]"}], "-", " ", 
   RowBox[{"TensorProduct", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "1", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.695626640546685*^9, 3.695626645860241*^9}, {
  3.695626704642112*^9, 3.695626752650672*^9}, {3.6956436383615723`*^9, 
  3.6956436767008142`*^9}, {3.695703618194974*^9, 3.6957037291315517`*^9}, {
  3.707398226811318*^9, 
  3.7073982427676373`*^9}},ExpressionUUID->"22f2e206-eb42-4805-b4e3-\
366b808a6e7f"],

Cell["Case p=3:", "Text",
 CellChangeTimes->{{3.6957038485850277`*^9, 3.6957039016645403`*^9}, {
  3.695740611745578*^9, 
  3.6957406525055447`*^9}},ExpressionUUID->"b6516a4d-8824-4b01-8cf1-\
f4f1b5a89dfb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "tpr", "]"}], ";", 
  RowBox[{
   RowBox[{"tpr", "[", 
    RowBox[{"{", 
     RowBox[{"i1_", ",", "i2_", ",", "i3_"}], "}"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"TensorProduct", "[", 
     RowBox[{
      RowBox[{"\[Theta]", "[", "i1", "]"}], ",", 
      RowBox[{"\[Theta]", "[", "i2", "]"}], ",", 
      RowBox[{"\[Theta]", "[", "i3", "]"}]}], "]"}], "*", 
    RowBox[{"Signature", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6956273679267473`*^9, 3.695627390302184*^9}, {
   3.695627426101122*^9, 3.6956274261384363`*^9}, {3.695627466549588*^9, 
   3.695627521176984*^9}, {3.695627977062731*^9, 3.695627987840736*^9}, {
   3.695628043344574*^9, 3.695628089336607*^9}, {3.6956281805389557`*^9, 
   3.6956282332869043`*^9}, {3.6956286008002367`*^9, 3.695628649915804*^9}, {
   3.6956289270108356`*^9, 3.695628993873002*^9}, 3.69562903906467*^9, {
   3.6956292376175117`*^9, 3.695629254190366*^9}, {3.695629725262126*^9, 
   3.695629770994515*^9}, {3.6956416211543922`*^9, 3.695641643318083*^9}, {
   3.6957287761020517`*^9, 3.695728779777439*^9}, {3.695729672843903*^9, 
   3.695729711347808*^9}, {3.69572992890126*^9, 
   3.695729941849441*^9}},ExpressionUUID->"3958e97f-dd91-4ac0-91b4-\
72ffb0d5cc8d"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
     RowBox[{"\[Theta]", "[", "3", "]"}]}], "]"}], "\[Equal]", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"tpr", "[", 
      RowBox[{"{", 
       RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i3", ",", "3"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6957400057139263`*^9, 3.695740014785324*^9}, {
  3.695740093961231*^9, 3.695740334127933*^9}, {3.707398293581835*^9, 
  3.707398330487155*^9}},ExpressionUUID->"333a96bd-fc0d-42c4-9bb2-\
bf083e587686"],

Cell["Higher dimensions:", "Text",
 CellChangeTimes->{{3.695740726489333*^9, 
  3.695740735433503*^9}},ExpressionUUID->"cd326062-33e5-410c-bf21-\
0d452af349a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "6"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
      RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
      RowBox[{"\[Theta]", "[", "3", "]"}]}], "]"}], "\[Equal]", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"tpr", "[", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "i2", ",", "i3"}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i3", ",", "3"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6957403603954697`*^9, 3.6957403703578653`*^9}, 
   3.695740424876457*^9, {3.7073983519439993`*^9, 
   3.707398375446351*^9}},ExpressionUUID->"f20f3479-de35-44a2-91e1-\
481207445aae"],

Cell["Case p = 4 :", "Text",
 CellChangeTimes->{{3.695740748498766*^9, 
  3.695740767395884*^9}},ExpressionUUID->"3871ee85-dc9f-4a0c-b9f8-\
cb20cbfb0c52"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "tpr", "]"}], ";", 
  RowBox[{
   RowBox[{"tpr", "[", 
    RowBox[{"{", 
     RowBox[{"i1_", ",", "i2_", ",", "i3_", ",", "i4_"}], "}"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"TensorProduct", "[", 
     RowBox[{
      RowBox[{"\[Theta]", "[", "i1", "]"}], ",", 
      RowBox[{"\[Theta]", "[", "i2", "]"}], ",", 
      RowBox[{"\[Theta]", "[", "i3", "]"}], ",", 
      RowBox[{"\[Theta]", "[", "i4", "]"}]}], "]"}], "*", 
    RowBox[{"Signature", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6956273679267473`*^9, 3.695627390302184*^9}, {
   3.695627426101122*^9, 3.6956274261384363`*^9}, {3.695627466549588*^9, 
   3.695627521176984*^9}, {3.695627977062731*^9, 3.695627987840736*^9}, {
   3.695628043344574*^9, 3.695628089336607*^9}, {3.6956281805389557`*^9, 
   3.6956282332869043`*^9}, {3.6956286008002367`*^9, 3.695628649915804*^9}, {
   3.6956289270108356`*^9, 3.695628993873002*^9}, 3.69562903906467*^9, {
   3.6956292376175117`*^9, 3.695629254190366*^9}, {3.695629725262126*^9, 
   3.695629770994515*^9}, {3.6956416211543922`*^9, 3.695641643318083*^9}, {
   3.6957287761020517`*^9, 3.695728779777439*^9}, {3.695729672843903*^9, 
   3.695729711347808*^9}, {3.69572992890126*^9, 3.695729941849441*^9}, {
   3.695740815876512*^9, 
   3.695740872765172*^9}},ExpressionUUID->"fad0e507-95ab-4197-bcaf-\
f0d4e2447461"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", "5"}], ";", 
  RowBox[{"Timing", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "4", "]"}]}], "]"}], "\[Equal]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"tpr", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i4", ",", "4"}], "}"}]}], "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6957403603954697`*^9, 3.6957403703578653`*^9}, 
   3.695740424876457*^9, {3.695740920178219*^9, 3.695740948825281*^9}, {
   3.695740981698587*^9, 3.6957410432964478`*^9}, 3.695741249211973*^9, {
   3.695741291802148*^9, 3.695741303702434*^9}, 3.6963967855537453`*^9, {
   3.6963968336718283`*^9, 3.696396853028782*^9}, {3.696402478222748*^9, 
   3.696402495826811*^9}, {3.6964040571377363`*^9, 3.696404089807363*^9}, 
   3.696404670381531*^9, {3.70739840877404*^9, 3.707398423174777*^9}, {
   3.707398456312447*^9, 
   3.707398463551806*^9}},ExpressionUUID->"55acd8b2-43d2-4977-a1b3-\
69b7cdc15643"],

Cell[TextData[{
 "Needed 3.28 s with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v. 11.1.1.; 0.600000 s with v. 9.0.1.0 ."
}], "Text",
 CellChangeTimes->{{3.696404737711677*^9, 3.696404752399591*^9}, 
   3.696680899690428*^9, 3.696680933106702*^9, {3.707398481903554*^9, 
   3.707398560813486*^9}, 3.707398613270564*^9, {3.707400184011108*^9, 
   3.707400218098823*^9}},ExpressionUUID->"b915a774-7ae1-4669-bdb6-\
453489019934"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", "6"}], ";", 
  RowBox[{"Timing", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{"\[Theta]", "[", "1", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "2", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "3", "]"}], ",", 
       RowBox[{"\[Theta]", "[", "4", "]"}]}], "]"}], "\[Equal]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"tpr", "[", 
        RowBox[{"{", 
         RowBox[{"i1", ",", "i2", ",", "i3", ",", "i4"}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i1", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i2", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i3", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i4", ",", "4"}], "}"}]}], "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6957403603954697`*^9, 3.6957403703578653`*^9}, 
   3.695740424876457*^9, {3.695740920178219*^9, 3.695740948825281*^9}, {
   3.695740981698587*^9, 3.6957410432964478`*^9}, 3.695741249211973*^9, {
   3.695741291802148*^9, 3.695741303702434*^9}, 3.6963967855537453`*^9, {
   3.6963968336718283`*^9, 3.696396853028782*^9}, {3.696402478222748*^9, 
   3.696402495826811*^9}, {3.6964040571377363`*^9, 3.696404089807363*^9}, 
   3.696404774859415*^9, {3.70740024848258*^9, 
   3.7074002771789093`*^9}},ExpressionUUID->"6e580730-244e-42a5-adc4-\
a780009409a4"],

Cell["Needed  23.428 s, in v.11.1,1.264000 s in v. 9.0.1.0 .", "Text",
 CellChangeTimes->{{3.696405303435224*^9, 3.696405312187419*^9}, {
  3.696681031889196*^9, 3.696681038113133*^9}, {3.7074002959453297`*^9, 
  3.707400358865975*^9}},ExpressionUUID->"2002d20b-b89e-4e28-af61-\
739a3aafd3d5"],

Cell["The user may consider other cases.\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6957413786448927`*^9, 
  3.695741408238199*^9}},ExpressionUUID->"890791f7-1fc9-491b-b637-\
96b55fc363b7"],

Cell["\<\
Now we apply Lemma 2 to p-forms. Let \[Beta] be a p-form with coordinates \
b[i1,...,ip]; we omit writing the point coordinates of the field. Then\
\>", "Text",
 CellChangeTimes->{{3.695792480031726*^9, 3.695792549343554*^9}, {
   3.695792619736196*^9, 3.6957927407183447`*^9}, {3.6957927819501762`*^9, 
   3.69579281038206*^9}, {3.6957928567977667`*^9, 3.6957928765016537`*^9}, {
   3.695792907021637*^9, 3.695792980957039*^9}, {3.695793151243804*^9, 
   3.695793176571109*^9}, {3.695793227723282*^9, 3.695793284962779*^9}, 
   3.695793869435831*^9, 
   3.696396907162051*^9},ExpressionUUID->"d3aeb1d5-01d1-4a89-9865-\
ab275edf49be"],

Cell["\<\
\[Beta] == \[Sum] b[i1,...,ip]*tpr[dx[i1],...,dx[ip],  ij = 1,...,dim.\t\t(*)\
\>", "Text",
 CellChangeTimes->{{3.695792480031726*^9, 3.695792549343554*^9}, {
  3.695792619736196*^9, 3.6957927407183447`*^9}, {3.6957927819501762`*^9, 
  3.69579281038206*^9}, {3.6957928567977667`*^9, 3.6957928765016537`*^9}, {
  3.695792907021637*^9, 3.695792980957039*^9}, {3.695793151243804*^9, 
  3.695793176571109*^9}, {3.695793227723282*^9, 3.695793284962779*^9}, {
  3.695793879790943*^9, 
  3.69579391108428*^9}},ExpressionUUID->"9e3ba9d0-b04e-46dd-96ab-\
0a9abd27f0f4"],

Cell["Since \[Beta] is a p-form, we can apply Lemma 1 and formula (3).:", \
"Text",
 CellChangeTimes->{{3.695792480031726*^9, 3.695792549343554*^9}, {
   3.695792619736196*^9, 3.6957927407183447`*^9}, {3.6957927819501762`*^9, 
   3.69579281038206*^9}, {3.6957928567977667`*^9, 3.6957928765016537`*^9}, {
   3.695792907021637*^9, 3.695792980957039*^9}, {3.695793151243804*^9, 
   3.695793176571109*^9}, {3.695793227723282*^9, 3.695793284962779*^9}, 
   3.69579391900436*^9},ExpressionUUID->"b9cfa625-3af7-4c9d-b1af-\
2d7e07a3fa09"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"i1", ",", "...", ",", "ip"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Signature", "[", 
     RowBox[{"{", 
      RowBox[{"i1", ",", "...", ",", "ip"}], "}"}], "]"}], "*", 
    RowBox[{"b", "[", 
     RowBox[{"j1", ",", "...", ",", "jp"}], "]"}]}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6957933041306047`*^9, 3.695793351762741*^9}, {
  3.695793395001994*^9, 3.6957934228340178`*^9}, {3.69579359972826*^9, 
  3.6957936090642014`*^9}},ExpressionUUID->"230cbd61-dc49-4e85-9907-\
c508ed6cfce8"],

Cell["\<\
where j1<...<jp is the natural ordered set {i1,...ip}; remember  \
Signature[{i1,...,ip}] ==0, if {i1,...,ip} isn\[CloseCurlyQuote]t a \
permutation, e.g.\
\>", "Text",
 CellChangeTimes->{{3.695793481576388*^9, 3.695793591551324*^9}, {
  3.6957936352479277`*^9, 3.695793652974719*^9}, {3.695793692214499*^9, 
  3.69579373524617*^9}},ExpressionUUID->"d1624f3b-49f4-45c8-abcf-\
28da220a9e9b"],

Cell[BoxData[
 RowBox[{"Signature", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "3", ",", "2", ",", "5"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.69579373991611*^9, 
  3.695793791646366*^9}},ExpressionUUID->"add7bbc9-6f09-470e-a602-\
7d810661fd84"],

Cell[BoxData[
 RowBox[{"Signature", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "3", ",", "2", ",", "3"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.69579373991611*^9, 
  3.695793810094367*^9}},ExpressionUUID->"04e929be-0c2b-48d7-aba7-\
e494c3ad1453"],

Cell["\<\
Thus we may collect all terms whose indices give the same subset of p  \
elements  {1,...,dim} and sum in (*) over the strict coordinates first:\
\>", "Text",
 CellChangeTimes->{{3.695793956220142*^9, 3.6957940774508047`*^9}, {
  3.695794119346711*^9, 
  3.6957941989861097`*^9}},ExpressionUUID->"7bd98796-8aaa-47f6-9405-\
e23ba635b388"],

Cell[TextData[{
 "\[Beta] == ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox[
    RowBox[{"\[Sum]", " "}], 
    RowBox[{
     RowBox[{
      RowBox[{"j1", "<"}], ".."}], "<", "jp"}]], TraditionalForm]],
  ExpressionUUID->"0056360e-5e14-4d7d-8090-d7e43cff19f4"],
 "b[j1,...,jp]*\[Sum] Signature[{i1,...,ip}]tpr[dx[i1],...,dx[ip],  ij = \
1,...,dim."
}], "Text",
 CellChangeTimes->{{3.695792480031726*^9, 3.695792549343554*^9}, {
  3.695792619736196*^9, 3.6957927407183447`*^9}, {3.6957927819501762`*^9, 
  3.69579281038206*^9}, {3.6957928567977667`*^9, 3.6957928765016537`*^9}, {
  3.695792907021637*^9, 3.695792980957039*^9}, {3.695793151243804*^9, 
  3.695793176571109*^9}, {3.695793227723282*^9, 3.695793284962779*^9}, {
  3.695793879790943*^9, 3.69579391108428*^9}, {3.695794305718676*^9, 
  3.6957944222159233`*^9}, {3.6957945062893143`*^9, 
  3.695794526502729*^9}},ExpressionUUID->"94a0133f-be0b-4910-9554-\
e1ba7c9a898f"],

Cell[TextData[{
 "By Lemma 3, (5), the last sums equal dx[j1]",
 Cell[BoxData[
  FormBox["\[Wedge]", TraditionalForm]],ExpressionUUID->
  "6c299e41-204c-48cc-a0e7-e0373096be39"],
 "...",
 Cell[BoxData[
  FormBox["\[Wedge]", TraditionalForm]],ExpressionUUID->
  "29d003a4-594d-40b6-9157-fc423ebe857a"],
 "dx[jp], and it follows:\n\n",
 StyleBox["Lemma 5",
  FontColor->RGBColor[0, 0, 1]],
 ". The family {dx[j1]",
 Cell[BoxData[
  FormBox["\[Wedge]", TraditionalForm]],ExpressionUUID->
  "30399469-0c8a-43a7-a491-605ced0995b6"],
 "...",
 Cell[BoxData[
  FormBox["\[Wedge]", TraditionalForm]],ExpressionUUID->
  "ef4330b6-f7cd-45f9-94c8-f04732cd433c"],
 "dx[jp]}, 1\[LessEqual]j1<...<jp\[LessEqual]dim, is a local basis field for \
the space of p-forms, that means any p-form \[Beta] has a uniquely defined \
representation"
}], "Text",
 CellChangeTimes->{{3.695795049312765*^9, 3.695795202751336*^9}, {
   3.695795280774557*^9, 3.695795561121745*^9}, {3.707397884316025*^9, 
   3.707397886683044*^9}, 
   3.707400442033799*^9},ExpressionUUID->"0ecaec82-720f-493e-b3d7-\
12d96372ea84"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Beta]", " ", "==", " ", 
     RowBox[{
      FormBox[
       UnderscriptBox[
        RowBox[{"\[Sum]", " "}], 
        RowBox[{
         RowBox[{
          RowBox[{"j1", "<"}], ".."}], "<", "jp"}]],
       TraditionalForm], 
      RowBox[{"b", "[", 
       RowBox[{"j1", ",", "...", ",", "jp"}], "]"}], "*", 
      RowBox[{
       RowBox[{"dx", "[", "j1", "]"}], 
       FormBox["\[Wedge]",
        TraditionalForm]}]}]}], "..."}], 
   FormBox["\[Wedge]",
    TraditionalForm], 
   RowBox[{"dx", "[", "jp", "]"}]}], "       ", 
  RowBox[{"(", "6", ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6957956032049417`*^9, 3.695795633192643*^9}, {
  3.695795670339212*^9, 
  3.695795687227393*^9}},ExpressionUUID->"22c4aa3d-4c8e-4fe1-88fd-\
caf83e30e309"],

Cell["where b[j1,...,jp] are the strict coordinates of \[Beta]. \
\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6957957109956303`*^9, 
  3.695795771630787*^9}},ExpressionUUID->"04fccc5b-fdb4-4d0a-81db-\
a211af10adc8"],

Cell[TextData[{
 StyleBox["Example 5",
  FontColor->RGBColor[0, 0, 1]],
 ". Consider the 3-form"
}], "Text",
 CellChangeTimes->{{3.695798473237637*^9, 3.69579848202973*^9}, {
  3.695798540853423*^9, 
  3.695798565300994*^9}},ExpressionUUID->"fd113fcb-ccef-49e4-94dc-\
19b42c82aa21"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", " ", "4"}], ";", " ", 
  RowBox[{"\[Beta]", " ", "=", 
   RowBox[{"extform", "[", 
    RowBox[{"f", ",", "3"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6957985734552603`*^9, 
  3.6957986671648903`*^9}},ExpressionUUID->"1409f24e-29f1-46ce-bffb-\
826911a4f5a3"],

Cell[BoxData[
 RowBox[{"\[Beta]", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "2", ",", "3"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "1", "]"}], ",", 
      RowBox[{"dx", "[", "2", "]"}], ",", 
      RowBox[{"dx", "[", "3", "]"}]}], "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "2", ",", "4"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "1", "]"}], ",", 
      RowBox[{"dx", "[", "2", "]"}], ",", 
      RowBox[{"dx", "[", "4", "]"}]}], "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "3", ",", "4"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "1", "]"}], ",", 
      RowBox[{"dx", "[", "3", "]"}], ",", 
      RowBox[{"dx", "[", "4", "]"}]}], "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "3", ",", "4"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "2", "]"}], ",", 
      RowBox[{"dx", "[", "3", "]"}], ",", 
      RowBox[{"dx", "[", "4", "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.695799234415988*^9, 3.695799448894285*^9}, {
  3.695799485469968*^9, 3.695799496181821*^9}, {3.695799526949891*^9, 
  3.695799624804818*^9}, {3.707400504990953*^9, 3.707400566511175*^9}, {
  3.707400597646879*^9, 
  3.707400660080881*^9}},ExpressionUUID->"49c73bd8-d483-41f0-8930-\
e720b9ff3090"],

Cell["Consider the 2-form", "Text",
 CellChangeTimes->{{3.695799697515091*^9, 3.695799722595105*^9}, {
  3.695799808114346*^9, 
  3.695799822538156*^9}},ExpressionUUID->"48cb8d2f-58f1-4e32-9d84-\
c8048c737465"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[Beta]", "]"}], ";", "  ", 
  RowBox[{"\[Beta]", " ", "=", 
   RowBox[{"extform", "[", 
    RowBox[{"f", ",", "2"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.695799727811942*^9, 3.695799759163135*^9}, {
  3.6957998277465553`*^9, 
  3.695799835770941*^9}},ExpressionUUID->"10638307-4848-4fc5-9cfa-\
da987f68dd16"],

Cell[BoxData[
 RowBox[{"\[Beta]", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "1", "]"}], ",", 
      RowBox[{"dx", "[", "2", "]"}]}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "3"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "1", "]"}], ",", 
      RowBox[{"dx", "[", "3", "]"}]}], "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"1", ",", "4"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "1", "]"}], ",", 
      RowBox[{"dx", "[", "4", "]"}]}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "2", "]"}], ",", 
      RowBox[{"dx", "[", "3", "]"}]}], "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"2", ",", "4"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "2", "]"}], ",", 
      RowBox[{"dx", "[", "4", "]"}]}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"3", ",", "4"}], "]"}], "*", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"dx", "[", "3", "]"}], ",", 
      RowBox[{"dx", "[", "4", "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.695799866634203*^9, 3.695799932961248*^9}, {
  3.695799967314499*^9, 3.6958001806647377`*^9}, {3.6958002259008713`*^9, 
  3.6958002489353533`*^9}, {3.707400684945134*^9, 
  3.7074008480240726`*^9}},ExpressionUUID->"0671f6da-7cf9-43c3-9a1f-\
fc3acf5aa9fd"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{
  3.695800287136859*^9},ExpressionUUID->"01e10df8-66c5-4dfc-913c-\
d14668656d6a"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3.4. The Exterior Differential ", "Subsubsection",
 CellChangeTimes->{{3.5866649932855587`*^9, 3.586665013117693*^9}, {
   3.5872725258470573`*^9, 3.587272530654332*^9}, {3.5898752162352247`*^9, 
   3.589875218169628*^9}, 3.5899533142260494`*^9, {3.609309548254758*^9, 
   3.6093095610144877`*^9}, 3.6095615905629835`*^9, 3.6177190633933744`*^9, 
   3.6177712155926075`*^9, 3.6274424857387977`*^9, 3.627443068992622*^9, {
   3.695800313878134*^9, 3.695800317398121*^9}, {3.6958008232260303`*^9, 
   3.695800835001595*^9}, 3.695800878657358*^9, {3.6964078325679007`*^9, 
   3.6964078336155024`*^9}, 3.696681243200186*^9, 3.696691374822603*^9, {
   3.707400901589538*^9, 3.707400906172799*^9}, 
   3.7074480013077173`*^9},ExpressionUUID->"08623beb-3316-4144-b6db-\
a292a96c15d6"],

Cell[TextData[{
 "We consider the exterior algebra ",
 "\[And]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "25816b22-0ceb-4716-a5f3-91685a97ea5e"],
 " of an n-dimensional manifold and prove"
}], "Text",
 CellChangeTimes->{{3.695816943064419*^9, 3.695816998623901*^9}, {
   3.695817043535577*^9, 3.6958170492873087`*^9}, {3.695817103799027*^9, 
   3.6958173987248173`*^9}, {3.695821087225621*^9, 3.695821157120872*^9}, {
   3.695821189447736*^9, 3.6958212551352797`*^9}, {3.6958212874620857`*^9, 
   3.695821427485042*^9}, {3.695821496428504*^9, 3.695821583180047*^9}, {
   3.695821625955619*^9, 3.6958219907525043`*^9}, {3.695822022109494*^9, 
   3.695822177959426*^9}, {3.6958222271110897`*^9, 3.6958222378785973`*^9}, {
   3.6958222993980207`*^9, 3.69582238958984*^9}, 3.695822542468267*^9, {
   3.695826854489255*^9, 3.695826888623507*^9}, 3.695826924736938*^9, {
   3.695965425590702*^9, 3.695965536318214*^9}, {3.70744456137956*^9, 
   3.707444576633152*^9}},ExpressionUUID->"cec2607e-a91b-4f62-a210-\
d1ead8918ed0"],

Cell[TextData[{
 StyleBox["Theorem 1",
  FontColor->RGBColor[0, 0, 1]],
 ". There exists a uniquely defined linear differential operator, the ",
 StyleBox["exterior differential ",
  FontColor->RGBColor[0, 0, 1]],
 "\ndd: \[And]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "ffceed6f-5cea-411c-8a69-b79f0a9906b8"],
 "\[LongRightArrow]\[And]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "d50df2ea-51ca-4d47-b35b-109af3386340"],
 "\nwith the following properties:\n1. For functions f [x,..] \[Element]  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Wedge]", "0"], TraditionalForm]],ExpressionUUID->
  "3606ace9-d561-4545-9bc0-88eb1ef692f5"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "b340f194-0556-4761-8ca0-4b935b1b1001"],
 " the exterior differential equals the differential:\ndd[f[x,..][x,... ] \
==d[f][x,..].\n2. The exterior differential of a p-form is a (p+1)-form:\ndd: \
",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Wedge]", "p"], TraditionalForm]],ExpressionUUID->
  "4d85871d-dc3b-4c56-becc-230e3bfd2613"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "105ad750-5e0b-4f20-b4fe-066fff5098f1"],
 "\[LongRightArrow]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Wedge]", 
    RowBox[{"p", "+", "1"}]], TraditionalForm]],ExpressionUUID->
  "65033a05-1426-4e3c-bdfe-7f4048f5a637"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "033c17cf-3c8c-4872-ae50-19bd0281a7ef"],
 ". \n3. The exterior differential satisfies the product rule:\nIf \[Beta] \
\[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Wedge]", "p"], TraditionalForm]],ExpressionUUID->
  "0c874089-1f2e-4fda-8e03-2363da6441dd"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "e72e4442-8588-4dd9-b009-3e6a44996513"],
 " and \[Theta] \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Wedge]", "q"], TraditionalForm]],ExpressionUUID->
  "c8cfc5e9-2777-4e73-9d2d-3ddb9f850d3d"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "1ac009cf-c0f3-45f2-998c-26e41cc7f227"],
 " one has\ndd[\[Beta]",
 Cell[BoxData[
  FormBox["\[Wedge]", TraditionalForm]],ExpressionUUID->
  "97a93168-d6ae-43fc-8de8-75607b059150"],
 "\[Theta]] == dd[\[Beta]",
 Cell[BoxData[
  FormBox["]", TraditionalForm]],ExpressionUUID->
  "5eef113a-a02d-41b6-a845-2ec2c0d5d3cd"],
 Cell[BoxData[
  FormBox["\[Wedge]", TraditionalForm]],ExpressionUUID->
  "5d6d278e-c8f3-4b5b-ac48-89fa5369bd86"],
 "\[Theta] + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "p"], TraditionalForm]],ExpressionUUID->
  "917c9c11-5230-4739-92db-911fe39ca210"],
 "\[Beta]",
 Cell[BoxData[
  FormBox["\[Wedge]", TraditionalForm]],ExpressionUUID->
  "cac89c92-92a6-4abc-b2c0-8c35e78a0dff"],
 "dd[\[Theta]].\n4. For all elements \[Omega] \[Element] ",
 "\[And]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "n"], TraditionalForm]],ExpressionUUID->
  "3efda69c-543d-4665-8dfb-fb1162e0622a"],
 " one has dd[dd[\[Omega]]]== 0."
}], "Text",
 CellChangeTimes->{{3.695816943064419*^9, 3.695816998623901*^9}, {
   3.695817043535577*^9, 3.6958170492873087`*^9}, {3.695817103799027*^9, 
   3.6958173987248173`*^9}, {3.695821087225621*^9, 3.695821157120872*^9}, {
   3.695821189447736*^9, 3.6958212551352797`*^9}, {3.6958212874620857`*^9, 
   3.695821427485042*^9}, {3.695821496428504*^9, 3.695821583180047*^9}, {
   3.695821625955619*^9, 3.6958219907525043`*^9}, {3.695822022109494*^9, 
   3.695822177959426*^9}, {3.6958222271110897`*^9, 3.6958222378785973`*^9}, {
   3.6958222993980207`*^9, 3.69582238958984*^9}, 3.695822542468267*^9, {
   3.695826854489255*^9, 3.695826888623507*^9}, 3.695826924736938*^9, {
   3.695965425590702*^9, 3.695965536318214*^9}, {3.70744456137956*^9, 
   3.7074445830258217`*^9}, 
   3.707445224664171*^9},ExpressionUUID->"c145ac93-fff6-44e8-925b-\
7720a664a600"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". First we prove the uniqueness. Let dd be a linear differential operator \
satisfying the rules 1-4. Then, by 1. and 4., \ndd[d[f]]==dd[dd[f]]== 0 for \
functions f. By 3. and 4. we conclude"
}], "Text",
 CellChangeTimes->{{3.695822933919207*^9, 3.6958230110548*^9}, {
   3.6958230498865356`*^9, 3.695823173757234*^9}, {3.6958232127409697`*^9, 
   3.695823347955565*^9}, 3.69582693330299*^9, {3.695906674345512*^9, 
   3.695906684585743*^9}},ExpressionUUID->"4f178cdf-cd51-4b1c-93cc-\
0e4270289330"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"dx", "[", "i1", "]"}], "\[Wedge]"}], "..."}], "\[Wedge]", 
    RowBox[{"dx", "[", "ip", "]"}]}], "]"}], "\[Equal]", " ", 
  RowBox[{"0", "                                             ", 
   RowBox[{"(", "7", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6958233625948668`*^9, 3.695823448299184*^9}, {
  3.6958239650947933`*^9, 
  3.695823971919083*^9}},ExpressionUUID->"46c55cf2-fc10-4565-b9bf-\
c16969953d01"],

Cell["\<\
Now we consider the strict basis representation of the p-form \[Beta], see \
Lemma 4,\
\>", "Text",
 CellChangeTimes->{{3.6958236665369463`*^9, 
  3.695823763912257*^9}},ExpressionUUID->"54b8323f-40a7-419c-8528-\
2e3562c799bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Beta]", " ", "==", " ", 
     RowBox[{
      FormBox[
       UnderscriptBox[
        RowBox[{"\[Sum]", " "}], 
        RowBox[{
         RowBox[{
          RowBox[{"j1", "<"}], ".."}], "<", "jp"}]],
       TraditionalForm], 
      RowBox[{"b", "[", 
       RowBox[{"j1", ",", "...", ",", "jp"}], "]"}], "*", 
      RowBox[{
       RowBox[{"dx", "[", "j1", "]"}], 
       FormBox["\[Wedge]",
        TraditionalForm]}]}]}], "..."}], 
   FormBox["\[Wedge]",
    TraditionalForm], 
   RowBox[{"dx", "[", "jp", "]"}]}], "       ", 
  RowBox[{"(", "6", ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6957956032049417`*^9, 3.695795633192643*^9}, {
  3.695795670339212*^9, 
  3.695795687227393*^9}},ExpressionUUID->"80415a8f-a2a6-4c53-bcf0-\
4a756b2602f9"],

Cell["\<\
Since dd is linear, the strict coordinates b[j1,...,jp] are functions; using \
1., 4. and (7) it follows\
\>", "Text",
 CellChangeTimes->{{3.695823808325897*^9, 3.69582394439889*^9}, {
  3.6958239810467243`*^9, 3.695823988110662*^9}, {3.6958266082656927`*^9, 
  3.695826615177343*^9}, {3.695906748528984*^9, 
  3.695906752472519*^9}},ExpressionUUID->"804d0cd1-ce3b-4dc7-a126-\
05100732c554"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dd", "[", "\[Beta]", "]"}], "=", 
       RowBox[{
        FormBox[
         UnderscriptBox[
          RowBox[{"\[Sum]", 
           RowBox[{"d", "["}]}], 
          RowBox[{
           RowBox[{
            RowBox[{"j1", "<"}], ".."}], "<", "jp"}]],
         TraditionalForm], 
        RowBox[{"b", "[", 
         RowBox[{"j1", ",", "..", ",", "jp"}], "]"}]}]}], "]"}], "\[Wedge]", 
     RowBox[{"dx", "[", "j1", "]"}], 
     FormBox["\[Wedge]",
      TraditionalForm]}], "..."}], 
   FormBox["\[Wedge]",
    TraditionalForm], 
   RowBox[{"dx", "[", "jp", "]"}]}], " ", 
  RowBox[{"(", "8", ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.695823997031646*^9, 3.695824188773759*^9}, {
  3.695824226437401*^9, 3.6958242499011793`*^9}, {3.695824281757052*^9, 
  3.6958242942069883`*^9}, {3.695824341991714*^9, 
  3.695824453995535*^9}},ExpressionUUID->"7997c96a-3b41-4cbd-9c04-\
f7d72ed5058d"],

Cell["\<\
This formula shows the uniqueness of the operator dd. Now we take (8) as the \
definition of dd and prove that the so defined operator has the properties \
1-4. Clearly it is linear and has the properties 1 and 2. We leave it to the \
user to prove that (8) implies 3. and 4. and go another way: we transfer (8) \
into a Mathematica definition and confirm 3. and 4. in several examples. \
First we need an appropriate definition of the basis p-forms. Here it is:\
\>", "Text",
 CellChangeTimes->{{3.695826484762384*^9, 3.695826563617731*^9}, {
  3.695826668392981*^9, 3.6958268048159523`*^9}, {3.695826949367793*^9, 
  3.695826969479023*^9}, {3.695906813864677*^9, 3.695906909095805*^9}, {
  3.695906997343207*^9, 3.695907150662793*^9}, {3.696398212011031*^9, 
  3.696398216146913*^9}},ExpressionUUID->"2f98f22e-f357-495b-b084-\
93f4a5b5956c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nn", "=", "dim"}], ";", 
  RowBox[{"Clear", "[", 
   RowBox[{"bdx", ",", "dim"}], "]"}], ";", 
  RowBox[{
   RowBox[{"bdx", "[", 
    RowBox[{"i_List", ",", 
     RowBox[{"n_:", "dim"}]}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "=", 
        RowBox[{"Length", "[", "i", "]"}]}], ",", "w"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"p", ">", "n"}], ")"}], "||", 
         RowBox[{"Not", "[", 
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"subs", "[", 
             RowBox[{"n", ",", "p"}], "]"}], ",", "i"}], "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Invalid argument \>\"", ",", "i", ",", "\"\< !\>\""}], 
          "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", " ", 
       RowBox[{
        RowBox[{"p", "\[Equal]", "0"}], ",", 
        RowBox[{"Return", "[", "1", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"w", "[", "0", "]"}], "=", "1"}], ";", 
         RowBox[{"j", "=", "1"}]}], ",", 
        RowBox[{"j", "\[LessEqual]", 
         RowBox[{"Length", "[", "i", "]"}]}], ",", 
        RowBox[{"j", "++"}], ",", 
        RowBox[{
         RowBox[{"w", "[", "j", "]"}], "=", 
         RowBox[{"extprod", "[", 
          RowBox[{
           RowBox[{"w", "[", 
            RowBox[{"j", "-", "1"}], "]"}], ",", 
           RowBox[{"dx", "[", 
            RowBox[{"i", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "]"}]}]}], "]"}], ";", 
      RowBox[{"w", "[", "p", "]"}]}]}], "]"}]}], ";", 
  RowBox[{"dim", "=", "nn"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.695886588718581*^9, 3.6958868381945543`*^9}, 
   3.695886926294963*^9, {3.6958869998506536`*^9, 3.6958870034251833`*^9}, {
   3.6958870726923122`*^9, 3.6958871016610737`*^9}, {3.69588713422713*^9, 
   3.6958872489032583`*^9}, 3.695887293526753*^9, {3.695887365865672*^9, 
   3.6958874525493803`*^9}, {3.695887538831772*^9, 3.6958875500532084`*^9}, 
   3.695887604551209*^9, {3.695887655103627*^9, 3.695887660364101*^9}, 
   3.695887818125947*^9, 3.6958879353861*^9, 3.695887992853581*^9, {
   3.6958881881781588`*^9, 3.695888216944305*^9}, {3.695888264886981*^9, 
   3.6958882872401733`*^9}, {3.695888345981758*^9, 3.695888506292804*^9}, {
   3.6958885385890408`*^9, 3.6958885986358013`*^9}, {3.695888649791148*^9, 
   3.6958886510280848`*^9}, 3.69588868880735*^9, {3.6958995446730824`*^9, 
   3.695899573133791*^9}, {3.695899645797398*^9, 3.6958996784688*^9}, {
   3.695907511127062*^9, 3.6959075294834146`*^9}, {3.6961475144857187`*^9, 
   3.696147541107728*^9}, {3.707445627150703*^9, 
   3.707445669628058*^9}},ExpressionUUID->"93e82ab2-7290-4c43-b316-\
90afd7905fdf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"bdx", "::", "usage"}], " ", "=", 
   "\"\<bdx[{i1,..,ip},n:dim]\[DotEqual]dx[i1]\[Wedge]...\[Wedge]dx[ip]is an \
element of the local standard basis in the space of p-forms on an \
n-dimensional manifold.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.69599900188935*^9, 3.695999289447948*^9}, {
   3.695999347090671*^9, 3.695999361559904*^9}, {3.695999400190772*^9, 
   3.6959994039591303`*^9}, 
   3.707445717177888*^9},ExpressionUUID->"96f10a4b-fcd6-4972-9e86-\
f68b5bd4f2d8"],

Cell[BoxData[
 RowBox[{"?", "bdx"}]], "Input",
 CellChangeTimes->{{3.7074457412616243`*^9, 
  3.7074457508508463`*^9}},ExpressionUUID->"8d3e611f-2941-45d3-9034-\
83ddb78b4ee9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bdx", "[", 
   RowBox[{"{", "1", "}"}], "]"}], "\[Equal]", 
  RowBox[{"dx", "[", "1", "]"}]}]], "Input",
 CellChangeTimes->{{3.695907289854945*^9, 
  3.695907311076694*^9}},ExpressionUUID->"ba9d4203-2ae1-421b-ac9b-\
b677fa202ba3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bdx", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], "]"}], "\[Equal]", 
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{"dx", "[", "1", "]"}], ",", 
    RowBox[{"dx", "[", "2", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695907289854945*^9, 3.695907338413217*^9}, {
  3.695907370509199*^9, 3.69590737513253*^9}, {3.707445771249053*^9, 
  3.707445790620721*^9}},ExpressionUUID->"87ad36e8-a1ca-4cb3-aeb7-\
1414d617ed64"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "5"}], ";", 
  RowBox[{
   RowBox[{"bdx", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "5"}], "}"}], "]"}], "\[Equal]", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"dx", "[", "1", "]"}], ",", 
     RowBox[{"dx", "[", "2", "]"}], ",", 
     RowBox[{"dx", "[", "5", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.695907289854945*^9, 3.695907338413217*^9}, {
  3.695907370509199*^9, 3.695907453267941*^9}, {3.7074458133446407`*^9, 
  3.707445830036791*^9}},ExpressionUUID->"25e0c5c5-0a2b-4aa0-ae78-\
50a5c1207b80"],

Cell["Here is a Module corresponding to (8):", "Text",
 CellChangeTimes->{{3.6959076459697742`*^9, 
  3.6959076713536587`*^9}},ExpressionUUID->"d127ba3f-4676-4c13-ae72-\
e13daac62e34"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dd", "[", "a_", "]"}], "[", "x__", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"car", ",", " ", 
      RowBox[{"n", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "x", "}"}], "]"}]}], ",", "p", ",", "sp", ",", "grad", 
      ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"grad", "[", "f_", "]"}], ":=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{
           RowBox[{"{", "x", "}"}], "[", 
           RowBox[{"[", "i", "]"}], "]"}]], "f"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"Not", "[", 
        RowBox[{
         RowBox[{"Head", "[", "a", "]"}], "===", " ", "List"}], "]"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"grad", "[", "a", "]"}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"car", " ", "=", 
      RowBox[{"strictcoords", "[", "a", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"p", " ", "=", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"Dimensions", "[", "a", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sp", " ", "=", " ", 
      RowBox[{"subs", "[", 
       RowBox[{"n", ",", "p"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"grad", "[", 
         RowBox[{"car", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[Wedge]", 
        RowBox[{"bdx", "[", 
         RowBox[{
          RowBox[{"sp", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", "n"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Binomial", "[", 
          RowBox[{"n", ",", "p"}], "]"}]}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 Evaluatable->False,
 InitializationCell->True,
 CellChangeTimes->{{3.695823183012631*^9, 3.695823183669278*^9}, {
   3.695827206493144*^9, 3.695827240284958*^9}, {3.6958278687040567`*^9, 
   3.6958281170947523`*^9}, {3.695828163990118*^9, 3.695828254458939*^9}, 
   3.695828337774869*^9, 3.695828375101153*^9, {3.6958807271649513`*^9, 
   3.695880741675791*^9}, 3.695880776387699*^9, {3.695880814051429*^9, 
   3.695880826579088*^9}, {3.695880993945937*^9, 3.695881033969866*^9}, {
   3.695881124240807*^9, 3.695881193744793*^9}, {3.695881661260838*^9, 
   3.695881765275378*^9}, 3.695881795275511*^9, {3.695883061153633*^9, 
   3.695883125408827*^9}, {3.6958831593128767`*^9, 3.695883203312458*^9}, {
   3.695899929706781*^9, 3.6958999346920013`*^9}, {3.6959000182098083`*^9, 
   3.6959001297848988`*^9}, {3.695905438370263*^9, 3.6959054569331837`*^9}, {
   3.695905488893354*^9, 3.6959055039556723`*^9}, {3.695905586852167*^9, 
   3.6959055881087427`*^9}, {3.6959646990250587`*^9, 3.695964902787821*^9}, {
   3.695971205380842*^9, 3.695971215184586*^9}, 
   3.696691452112419*^9},ExpressionUUID->"08be5531-4a65-4baa-9f5a-\
7134b3db16e6"],

Cell["\<\
This Module operated well, but I preferred to use a more general definition, \
which can be applied in many differential geometric situations; it is \
contained in eudiffgeov3.m:\
\>", "Text",
 CellChangeTimes->{{3.696601608493717*^9, 
  3.696601791788474*^9}},ExpressionUUID->"014581d4-6094-43e6-8a68-\
57ab7b30712b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dd", "[", "aa_", "]"}], "[", "x__", "]"}], ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ts", "=", 
         RowBox[{"aa", "[", "x", "]"}]}], ",", "ttp", ",", 
        RowBox[{"he", "=", 
         RowBox[{"Head", "[", 
          RowBox[{"aa", "[", "x", "]"}], "]"}]}], ",", " ", "pp", ",", 
        RowBox[{"di", "=", " ", 
         RowBox[{"Length", "[", 
          RowBox[{"{", "x", "}"}], "]"}]}], ",", "Arr", ",", "diff", ",", 
        "dts"}], "}"}], ",", "\n", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Not", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"he", "===", " ", "tensor"}], ")"}], "||", 
            RowBox[{"(", 
             RowBox[{"he", "===", " ", "List"}], ")"}]}], "]"}], "&&", 
          RowBox[{"MemberQ", "[", 
           RowBox[{
            RowBox[{"Attributes", "[", "aa", "]"}], ",", "NumericFunction"}], 
           "]"}]}], ",", "\n", 
         RowBox[{"Return", "[", 
          RowBox[{
           RowBox[{"d", "[", "aa", "]"}], "[", "x", "]"}], "]"}]}], "]"}], 
       ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"he", "===", " ", "tensor"}], ",", "\n", 
         RowBox[{
          RowBox[{"ttp", " ", "=", " ", 
           RowBox[{"type", "[", "ts", "]"}]}], ";", 
          RowBox[{"pp", " ", "=", " ", 
           RowBox[{"ttp", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"Not", "[", 
             RowBox[{
              RowBox[{"ttp", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "2"}], "]"}], "]"}], "==", " ", "0"}], 
             "]"}], ",", 
            RowBox[{
             RowBox[{"Print", "[", "\"\<Tensor isn't covariant!\>\"", "]"}], 
             ";", 
             RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"Not", "[", 
             RowBox[{
              RowBox[{"ttp", "[", 
               RowBox[{"[", "3", "]"}], "]"}], "==", "di"}], "]"}], ",", 
            RowBox[{
             RowBox[{"Print", "[", "\"\<Dimensions differ!\>\"", "]"}], ";", 
             RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"pp", "==", " ", "0"}], ",", 
            RowBox[{
             RowBox[{"ts", " ", "=", 
              RowBox[{
               RowBox[{"aa", "[", "x", "]"}], "[", 
               RowBox[{
                RowBox[{"{", "}"}], ",", 
                RowBox[{"{", "}"}]}], "]"}]}], ";", 
             RowBox[{"Goto", "[", "diff", "]"}]}]}], "]"}]}]}], "]"}], ";", 
       "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"he", "===", " ", "tensor"}], ",", 
         RowBox[{
          RowBox[{"ts", "=", 
           RowBox[{"tensorToArray", "[", "ts", "]"}]}], ";", " ", 
          RowBox[{"Goto", "[", "diff", "]"}]}]}], "]"}], ";", "\n", 
       RowBox[{"Label", "[", "Arr", "]"}], ";", "\n", 
       RowBox[{"pp", "=", 
        RowBox[{"TensorRank", "[", "ts", "]"}]}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pp", "==", "1"}], ")"}], "&&", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Length", "[", " ", 
             RowBox[{"Flatten", "[", "ts", "]"}], "]"}], "==", "1"}], ")"}]}],
          ",", 
         RowBox[{
          RowBox[{"pp", "=", "0"}], ";", 
          RowBox[{"ts", "=", 
           RowBox[{
            RowBox[{"Flatten", "[", "ts", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", 
          RowBox[{"Goto", "[", "diff", "]"}]}]}], "]"}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Not", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"TensorDimensions", "[", "ts", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "==", "di"}], "]"}], ",", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Dimensions differ!\>\"", "]"}], ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Not", "[", 
          RowBox[{
           RowBox[{"TensorDimensions", "[", "ts", "]"}], "==", " ", 
           RowBox[{"Table", "[", 
            RowBox[{"di", ",", 
             RowBox[{"{", "pp", "}"}]}], "]"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Invalid Array!\>\"", "]"}], ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", 
       RowBox[{"Label", "[", "diff", "]"}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pp", ">", "1"}], ")"}], "&&", 
          RowBox[{"(", 
           RowBox[{"Not", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"TensorSymmetry", "[", "ts", "]"}], " ", "===", " ", 
               RowBox[{"Antisymmetric", "[", 
                RowBox[{"Range", "[", "pp", "]"}], "]"}]}], ")"}], "\n", "||", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"TensorSymmetry", "[", "ts", "]"}], " ", "===", " ", 
               RowBox[{"ZeroSymmetric", "[", 
                RowBox[{"{", "}"}], "]"}]}], ")"}]}], "]"}], ")"}]}], ",", 
         "\n", 
         RowBox[{
          RowBox[{"Print", "[", 
           RowBox[{"\"\<Tensor \>\"", ",", 
            RowBox[{"aa", "[", "x", "]"}], ",", 
            "\"\< is not antisymmetric!\>\""}], "]"}], ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", 
       RowBox[{"dts", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", "pp"}], ")"}], "*", 
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"pp", "+", "1"}], ")"}], "*", 
           RowBox[{"Normal", "[", 
            RowBox[{"Symmetrize", "[", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"ts", ",", 
                RowBox[{"{", 
                 RowBox[{"{", "x", "}"}], "}"}]}], "]"}], ",", 
              RowBox[{"Antisymmetric", "[", 
               RowBox[{"Range", "[", 
                RowBox[{"pp", "+", "1"}], "]"}], "]"}]}], "]"}], "]"}]}], 
          "]"}]}]}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"he", "===", "tensor"}], ")"}], "&&", 
          RowBox[{"(", 
           RowBox[{"pp", ">=", "di"}], ")"}]}], ",", " ", 
         RowBox[{"Return", "[", 
          RowBox[{"nulltensor", "[", 
           RowBox[{
            RowBox[{"pp", "+", "1"}], ",", "0", ",", "di"}], "]"}], "]"}]}], 
        "]"}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"he", "===", "tensor"}], ",", " ", 
         RowBox[{"Return", "[", 
          RowBox[{"ArrayTotensor", "[", 
           RowBox[{"dts", ",", 
            RowBox[{"pp", "+", "1"}]}], "]"}], "]"}]}], "]"}], ";", "\n", 
       "dts"}]}], "]"}]}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"dd", "/:", " ", 
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{"h1_", "+", "h2_"}], "]"}], "[", "u__", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"dd", "[", "h1", "]"}], "[", "u", "]"}], " ", "+", 
    RowBox[{
     RowBox[{"dd", "[", "h2", "]"}], "[", "u", "]"}]}]}], ";"}]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.696602157496896*^9, 3.696602159248803*^9}, {
   3.696687483045814*^9, 3.69668760504758*^9}, {3.696687737207241*^9, 
   3.6966878751115627`*^9}, 3.696687926298942*^9, 3.696687960936233*^9, {
   3.696688042059054*^9, 3.696688100890867*^9}, 3.6966889019459877`*^9, {
   3.696691492168871*^9, 
   3.696691497396749*^9}},ExpressionUUID->"87a9ff3e-9bda-41cb-b9e6-\
01ab27e37bad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "dd"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.695999559531743*^9, 3.695999583597209*^9}, {
   3.6959996141811543`*^9, 3.6959997255641403`*^9}, {3.6959998270118847`*^9, 
   3.695999887203178*^9}, {3.69599994940617*^9, 3.695999979186714*^9}, 
   3.696000011830449*^9, {3.6966012184369373`*^9, 3.696601247160274*^9}, {
   3.696691779620254*^9, 
   3.696691783346821*^9}},ExpressionUUID->"d06cd785-2a5a-46b3-9388-\
0e5019c08f45"],

Cell[BoxData[
 StyleBox["\<\"dd[ta][x,...] yields the exterior differential of the p-form \
ta[x,...];\\nremember:a 0-form ta[x...] must must be a function with the \
Attribute NumericFunction; \\nfor antisymmetric covariant tensors ta[x,...] \
the operator dd returns a covariant tensor, \\nand for an antisymmetric Array \
ta[x,...] it returns the derived Array; all dimensions \\nof the Array \
ta[x,...] must equal the number of the variables x,...\"\>", "MSG"]], "Print",\
 "PrintUsage",
 CellChangeTimes->{3.708321849327977*^9},
 CellTags->
  "Info363708329049-6824778",ExpressionUUID->"04379eeb-ac44-4e25-a095-\
664f5f17361b"]
}, Open  ]],

Cell["\<\
We demonstrate that dd has the properties stated in Theorem 1.\
\>", "Text",
 CellChangeTimes->{{3.696602276593389*^9, 
  3.696602317265588*^9}},ExpressionUUID->"98a990ca-cc04-401a-bc2a-\
fa562fb1a1ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.69588878735567*^9, 3.695888788920896*^9}, {
  3.695907707845709*^9, 
  3.6959077126022043`*^9}},ExpressionUUID->"eeb7e3ab-058c-4fd8-be69-\
720c3a2a3865"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "h", "]"}], ";", 
  RowBox[{
   RowBox[{"Attributes", "[", "h", "]"}], "=", 
   RowBox[{"{", "}"}]}]}]], "Input",
 CellChangeTimes->{{3.696688212449917*^9, 3.696688232708817*^9}, {
  3.70744689210417*^9, 
  3.707446926159668*^9}},ExpressionUUID->"acac8dbb-872f-4726-8077-\
4119fc5dca7a"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"h", ",", "NumericFunction"}], "]"}]], "Input",
 CellChangeTimes->{{3.707446280949026*^9, 3.707446301569693*^9}, {
  3.707446339865035*^9, 3.707446345929755*^9}, {3.707446822409338*^9, 
  3.70744682399111*^9}, {3.707446856202476*^9, 
  3.7074468683706636`*^9}},ExpressionUUID->"2a19d8a9-b5c5-423d-9c0f-\
38ba844cf5e3"],

Cell[BoxData[
 RowBox[{"Attributes", "[", "h", "]"}]], "Input",
 CellChangeTimes->{{3.7074469419078197`*^9, 
  3.707446953007496*^9}},ExpressionUUID->"a537d40f-00aa-4b9d-b3fb-\
732a1b02b87d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "h", "]"}], "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellChangeTimes->{{3.695964176244886*^9, 3.695964212447456*^9}, {
   3.6959642632433968`*^9, 3.695964286166924*^9}, {3.695964939094514*^9, 
   3.695964948305635*^9}, {3.695965032219178*^9, 3.695965038944672*^9}, {
   3.6959666933611526`*^9, 3.6959667523447733`*^9}, {3.696590386581437*^9, 
   3.696590427029283*^9}, 3.696602193667261*^9, 
   3.696688179698886*^9},ExpressionUUID->"c8dc49c3-6457-46c2-a12d-\
11bb8e5da1fa"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{
   RowBox[{"d", "[", "h", "]"}], "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695965050570773*^9, 3.695965073506781*^9}, {
   3.6959651094647503`*^9, 3.695965115055822*^9}, {3.6959652147000837`*^9, 
   3.695965223815518*^9}, {3.6959653173450613`*^9, 3.695965347078732*^9}, 
   3.696688203185463*^9},ExpressionUUID->"e80939f4-67c5-4700-9cb3-\
7c7284dfea47"],

Cell["Thus rule 1. is satisfied; rule  2. is clear by definition.", "Text",
 CellChangeTimes->{{3.6959656854710093`*^9, 3.695965772251513*^9}, {
  3.695966781715534*^9, 
  3.695966793035385*^9}},ExpressionUUID->"1d0c046a-463d-4a26-987b-\
7faa4ca74c18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[Theta]", "]"}], ";", 
  RowBox[{
   RowBox[{"\[Theta]", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", " ", 
   RowBox[{"vec", "[", 
    RowBox[{"f", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.695905726193321*^9, 3.695905788913109*^9}, {
   3.696590955790742*^9, 3.696591010332526*^9}, 
   3.707446990988641*^9},ExpressionUUID->"8be3fac8-b422-4a96-bbca-\
22692cea494f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "\[Theta]", "]"}], "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellChangeTimes->{{3.695905804430793*^9, 3.6959058454646463`*^9}, 
   3.69659090829316*^9, 
   3.6966023729782333`*^9},ExpressionUUID->"03be3a8c-a06e-42fc-9d74-\
795560a0d1fe"],

Cell["This is a 2-form with", "Text",
 CellChangeTimes->{{3.696602413200696*^9, 3.696602423200667*^9}, 
   3.7074464519903193`*^9},ExpressionUUID->"d6726597-4e2d-44e4-9d90-\
5d1e97f0b126"],

Cell[BoxData[
 RowBox[{"strictcoords", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6959077534397507`*^9, 
  3.6959077774653*^9}},ExpressionUUID->"58a8ca7b-0db1-4b7f-8348-704ca9bb4d85"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"dd", "[", "\[Theta]", "]"}], "]"}], "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellChangeTimes->{{3.6959058842403517`*^9, 3.695905932976918*^9}, 
   3.695907876364621*^9, 3.696591114083839*^9, {3.696591144973259*^9, 
   3.696591156939967*^9}, 3.696602445329719*^9, {3.696602498392502*^9, 
   3.6966025269291067`*^9}},ExpressionUUID->"ad02ddb4-5917-4a41-9a2d-\
8f11ce40c26e"],

Cell["This confirms 4.", "Text",
 CellChangeTimes->{{3.695908065907549*^9, 
  3.6959080992317467`*^9}},ExpressionUUID->"047dfdb7-e75e-4396-b8dc-\
37aa0f80575c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[Beta]", "]"}], ";", " ", 
  RowBox[{
   RowBox[{"\[Beta]", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
   RowBox[{"vec", "[", 
    RowBox[{"f1", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.69590599772121*^9, 3.695906096070388*^9}, {
   3.696591224932269*^9, 3.696591258154439*^9}, 
   3.707447051953033*^9},ExpressionUUID->"946d1de3-b22f-4ad6-863f-\
eb48cfc7ffdb"],

Cell["dd is additive :", "Text",
 CellChangeTimes->{{3.695966245049304*^9, 
  3.6959662847702017`*^9}},ExpressionUUID->"f9d2a060-de02-4896-a6d0-\
80abea1d94ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dd", "[", 
    RowBox[{"plus", "[", 
     RowBox[{"\[Beta]", ",", "\[Theta]"}], "]"}], "]"}], "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", "\[Beta]", "]"}], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
   RowBox[{
    RowBox[{"dd", "[", "\[Theta]", "]"}], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.695965866628561*^9, 3.695965871266564*^9}, {
  3.6959659337643538`*^9, 3.695965956578886*^9}, {3.6959661369316387`*^9, 
  3.695966219169056*^9}, {3.6965912709547873`*^9, 3.6965913447702436`*^9}, {
  3.696602498408283*^9, 3.6966024984121637`*^9}, {3.696602570224904*^9, 
  3.6966025994644833`*^9}, {3.696602739404292*^9, 
  3.6966027553594303`*^9}},ExpressionUUID->"36c8d388-3b95-40d3-8ba8-\
e7982bee1d99"],

Cell["and a linear map of the real vector spaces:", "Text",
 CellChangeTimes->{{3.695966297583067*^9, 
  3.695966331878829*^9}},ExpressionUUID->"82feed7a-741c-4c27-bc63-\
fc19c5a235e8"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{"plus", "[", 
      RowBox[{
       RowBox[{"3", "*", "\[Beta]"}], ",", 
       RowBox[{"Pi", "*", "\[Theta]"}]}], "]"}], "]"}], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{"3", "*", 
     RowBox[{
      RowBox[{"dd", "[", "\[Beta]", "]"}], "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"Pi", "*", 
     RowBox[{
      RowBox[{"dd", "[", "\[Theta]", "]"}], "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.695965866628561*^9, 3.695965871266564*^9}, {
  3.6959659337643538`*^9, 3.695965956578886*^9}, {3.6959661369316387`*^9, 
  3.695966219169056*^9}, {3.695966355959433*^9, 3.695966445390666*^9}, {
  3.695966540874852*^9, 3.695966541142161*^9}, {3.6959665733538847`*^9, 
  3.6959665895420523`*^9}, {3.6965913683616657`*^9, 3.696591432753317*^9}, {
  3.696602498419964*^9, 
  3.69660249842386*^9}},ExpressionUUID->"0b7b6001-c91c-43e4-b829-\
bc5c1bf4b4b3"],

Cell["Now we consider the exterior product", "Text",
 CellChangeTimes->{{3.695966619084667*^9, 3.695966649300193*^9}, {
  3.707447112346168*^9, 
  3.707447116298564*^9}},ExpressionUUID->"bfaced54-ff07-4839-8d0a-\
e6ea73df2fad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[CapitalBeta]", "]"}], ";", 
  RowBox[{
   RowBox[{"\[CapitalBeta]", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"\[Beta]", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
     RowBox[{"\[Theta]", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.696591522056573*^9, 3.696591590568255*^9}, {
  3.696666622840456*^9, 3.696666665318943*^9}, {3.707447131344521*^9, 
  3.707447165599524*^9}},ExpressionUUID->"ec35a373-f8ef-4fca-8dc5-\
1e729e4210ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", "\[CapitalBeta]", "]"}], "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellChangeTimes->{{3.695906103804736*^9, 3.695906209581579*^9}, 
   3.6959062408788347`*^9, {3.696591469825157*^9, 3.6965915030570583`*^9}, {
   3.696591582175829*^9, 3.6965916317275677`*^9}, 3.6966024984314413`*^9, {
   3.696666507447102*^9, 3.696666512773138*^9}, 
   3.696666684665197*^9},ExpressionUUID->"9acb7faa-dbe7-49bb-9f0f-\
054a29f2e054"],

Cell["This 3-form has only 1 strict coordinate:", "Text",
 CellChangeTimes->{{3.6959081311333923`*^9, 
  3.69590816043746*^9}},ExpressionUUID->"a5a6799b-b1e3-4960-9720-\
18265ca10c58"],

Cell[BoxData[
 RowBox[{"strictcoords", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.695907950278001*^9, 
  3.695907962847934*^9}},ExpressionUUID->"26eb2844-a252-473b-b6b2-\
18ba8f46d3d0"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", "\[CapitalBeta]", "]"}], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"dd", "[", "\[Beta]", "]"}], "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
      RowBox[{"\[Theta]", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}], "-", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"\[Beta]", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
      RowBox[{
       RowBox[{"dd", "[", "\[Theta]", "]"}], "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6959062575117493`*^9, 3.695906398188513*^9}, 
   3.69590799235286*^9, {3.696591672967461*^9, 3.696591714759112*^9}, {
   3.696602498435833*^9, 3.696602498437804*^9}, 3.6966668185374937`*^9, {
   3.707447276039462*^9, 
   3.707447316121643*^9}},ExpressionUUID->"ef52553b-f629-4d74-b453-\
914343849a44"],

Cell["\<\
This confirms 3. Rule 4 is trivial, since a 4-form over a 3-dimensional \
manifold is zero:\
\>", "Text",
 CellChangeTimes->{{3.695908187069869*^9, 3.695908210823868*^9}, {
  3.69590824090077*^9, 
  3.6959083105642757`*^9}},ExpressionUUID->"80a13a12-cd32-411b-a050-\
c142aeac14fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", " ", 
   RowBox[{"dd", "[", "\[CapitalBeta]", "]"}], "]"}], "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellChangeTimes->{{3.695906440181129*^9, 3.6959064778272457`*^9}, 
   3.69590651057999*^9, {3.696591748678279*^9, 3.69659182873335*^9}, {
   3.6966024984405613`*^9, 3.6966024984421997`*^9}, {3.69660296799837*^9, 
   3.6966029869668827`*^9}, {3.696603023142972*^9, 
   3.696603033849814*^9}},ExpressionUUID->"c9fb8bff-0707-46c9-800e-\
ddb6ab84f0b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.695968052512393*^9, 
  3.695968057579453*^9}},ExpressionUUID->"e5978336-5ca3-4e66-8860-\
8ec5de8d16c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dd", "[", "h", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}], ",", 
    RowBox[{"x", "[", "4", "]"}]}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"d", "[", "h", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}], ",", 
    RowBox[{"x", "[", "4", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695968063521289*^9, 3.695968176892558*^9}, {
   3.696591847189694*^9, 3.696591892669311*^9}, 3.6966024984447737`*^9, {
   3.6966891950916224`*^9, 
   3.6966891997965117`*^9}},ExpressionUUID->"8a20bf45-a28a-4f08-bded-\
a5f0b3f988ed"],

Cell[BoxData[
 RowBox[{"?", "altform"}]], "Input",
 CellChangeTimes->{{3.695968248422431*^9, 
  3.695968252714013*^9}},ExpressionUUID->"f626907f-fdde-47d3-aeaf-\
c57beaaf9dde"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[Beta]", "]"}], ";", 
  RowBox[{
   RowBox[{"\[Beta]", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}], "=", 
   RowBox[{"altform", "[", 
    RowBox[{
     RowBox[{"b", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.695968204768211*^9, 3.695968229578701*^9}, {
  3.695968289268005*^9, 3.695968347203792*^9}, {3.69659195442957*^9, 
  3.696591999668777*^9}, {3.696594435123348*^9, 
  3.696594479959921*^9}},ExpressionUUID->"ec610560-4b93-49b6-9ea7-\
3fd32e079c93"],

Cell[BoxData[
 RowBox[{"\[Beta]", "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}], ",", 
   RowBox[{"x", "[", "3", "]"}], ",", 
   RowBox[{"x", "[", "4", "]"}]}], "]"}]], "Input",ExpressionUUID->"1d91fc3d-\
f2f5-4f64-ad68-4c10ca4d4fff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[Theta]", "]"}], ";", 
  RowBox[{
   RowBox[{"\[Theta]", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}], "=", 
   RowBox[{"altform", "[", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", "2"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.695968204768211*^9, 3.695968229578701*^9}, {
   3.695968289268005*^9, 3.695968425873858*^9}, 3.696592040852631*^9, {
   3.69659453205204*^9, 
   3.696594540254553*^9}},ExpressionUUID->"473c44aa-f712-4ace-b1d0-\
ac17a7026db1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dd", "[", 
    RowBox[{"plus", "[", 
     RowBox[{"\[Beta]", ",", "\[Theta]"}], "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}], ",", 
    RowBox[{"x", "[", "4", "]"}]}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", "\[Beta]", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}], "+", 
   RowBox[{
    RowBox[{"dd", "[", "\[Theta]", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6959684435964127`*^9, 3.6959685387447577`*^9}, {
  3.6965921329470577`*^9, 3.696592176402766*^9}, {3.696602498447789*^9, 
  3.696602498450979*^9}},ExpressionUUID->"5efbefce-24a9-40f4-a01e-\
11c3d8a8ef33"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"dd", "[", 
    RowBox[{"plus", "[", 
     RowBox[{"\[Beta]", ",", "\[Theta]"}], "]"}], "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}], ",", 
   RowBox[{"x", "[", "3", "]"}], ",", 
   RowBox[{"x", "[", "4", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6959687679685698`*^9, 3.695968804085989*^9}, 
   3.6959688527983*^9, {3.696592197842476*^9, 3.696592232522645*^9}, {
   3.696602498453731*^9, 3.696602498455307*^9}, {3.69660344358258*^9, 
   3.696603478468111*^9}},ExpressionUUID->"e69fab5d-318e-4bb9-a4ce-\
ac46067c73e4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[CapitalBeta]", "]"}], ";", 
  RowBox[{
   RowBox[{"\[CapitalBeta]", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}], "=", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"\[Beta]", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", 
     RowBox[{"\[Theta]", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.696591522056573*^9, 3.696591590568255*^9}, {
  3.696666622840456*^9, 3.696666665318943*^9}, {3.696677392539997*^9, 
  3.69667744630352*^9}, {3.707447532060555*^9, 
  3.7074475550550833`*^9}},ExpressionUUID->"6ecd0ace-f6e8-4870-8769-\
f1346c1ab3dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dd", "[", "\[CapitalBeta]", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}], ",", 
    RowBox[{"x", "[", "3", "]"}], ",", 
    RowBox[{"x", "[", "4", "]"}]}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dd", "[", "\[Beta]", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", 
     RowBox[{"\[Theta]", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}]}], "]"}], " ", "+", " ", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"\[Beta]", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", 
     RowBox[{
      RowBox[{"dd", "[", "\[Theta]", "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6959684435964127`*^9, 3.695968630655959*^9}, {
   3.6959686681928864`*^9, 3.6959686836088123`*^9}, 3.695968735838084*^9, 
   3.696592328809087*^9, {3.6965923783217363`*^9, 3.696592385073229*^9}, {
   3.696592673200912*^9, 3.696592690749833*^9}, 3.6965929850664062`*^9, 
   3.696593021819694*^9, {3.6966024984582644`*^9, 3.6966024984615173`*^9}, {
   3.707447574334944*^9, 
   3.7074476293981867`*^9}},ExpressionUUID->"08a080d3-379a-4280-87ce-\
6efce3ed1d60"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[Beta]", "]"}], ";", 
  RowBox[{
   RowBox[{"\[Beta]", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}], "=", 
   RowBox[{"altform", "[", 
    RowBox[{
     RowBox[{"b", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", "1"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.695968204768211*^9, 3.695968229578701*^9}, {
  3.695968289268005*^9, 3.695968347203792*^9}, {3.695968934887065*^9, 
  3.695968940772997*^9}, {3.69667778041819*^9, 3.696677808546453*^9}, {
  3.696677843180748*^9, 
  3.696677866068325*^9}},ExpressionUUID->"df6deac3-9c11-4f0d-bfb9-\
7caf3bb174b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[CapitalBeta]", "]"}], ";", 
  RowBox[{
   RowBox[{"\[CapitalBeta]", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}], "=", " ", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{"\[Beta]", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", 
     RowBox[{"\[Theta]", "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}], ",", 
       RowBox[{"x", "[", "4", "]"}]}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.696592855725223*^9, 3.696592860469069*^9}, {
   3.696592895476664*^9, 3.696592957564312*^9}, {3.6965935981039886`*^9, 
   3.696593618597972*^9}, 3.6965942983887253`*^9, 3.696594574684217*^9, 
   3.696594619607883*^9, 3.696603581191022*^9, 3.696603942681217*^9, {
   3.696604008730785*^9, 3.696604056047241*^9}, {3.696604325370571*^9, 
   3.696604394683094*^9}, {3.696604955105485*^9, 3.6966049733985147`*^9}, {
   3.696677595692122*^9, 3.696677604534768*^9}, {3.7074476617899647`*^9, 
   3.707447678318756*^9}, 
   3.707447814084042*^9},ExpressionUUID->"cda67598-9248-4446-ae41-\
dfe85a44cc4d"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", "\[CapitalBeta]", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"dd", "[", "\[Beta]", "]"}], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}], ",", 
        RowBox[{"x", "[", "3", "]"}], ",", 
        RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", 
      RowBox[{"\[Theta]", "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}], ",", 
        RowBox[{"x", "[", "3", "]"}], ",", 
        RowBox[{"x", "[", "4", "]"}]}], "]"}]}], "]"}], " ", "-", " ", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{"\[Beta]", "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}], ",", 
        RowBox[{"x", "[", "3", "]"}], ",", 
        RowBox[{"x", "[", "4", "]"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"dd", "[", "\[Theta]", "]"}], "[", 
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], ",", 
        RowBox[{"x", "[", "2", "]"}], ",", 
        RowBox[{"x", "[", "3", "]"}], ",", 
        RowBox[{"x", "[", "4", "]"}]}], "]"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6959684435964127`*^9, 3.695968630655959*^9}, {
   3.6959686681928864`*^9, 3.6959686836088123`*^9}, 3.695968735838084*^9, 
   3.695969000854848*^9, {3.695969032813447*^9, 3.695969045860021*^9}, 
   3.696603793639751*^9, {3.696603841394208*^9, 3.696603851778489*^9}, {
   3.6966045702401037`*^9, 3.696604586890773*^9}, {3.707447708143956*^9, 
   3.707447769670681*^9}},ExpressionUUID->"3b3057ab-41ae-41de-9aec-\
22b840dfcb2d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"dd", "[", "\[CapitalBeta]", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}], ",", 
   RowBox[{"x", "[", "3", "]"}], ",", 
   RowBox[{"x", "[", "4", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.695969079469472*^9, 3.695969106843338*^9}, {
   3.6959691446506*^9, 3.6959691482916737`*^9}, 3.696678012509304*^9, 
   3.696678074369306*^9},ExpressionUUID->"4f299c4a-f0b6-4d2b-aca5-\
000a074b6723"],

Cell["The user may test the rules for other forms.\[FilledSquare]", "Text",
 CellChangeTimes->{{3.695969229647936*^9, 3.695969319109283*^9}, 
   3.695969371471608*^9, {3.6966911188734703`*^9, 
   3.696691206560378*^9}},ExpressionUUID->"b28d43ee-c69c-46b2-b1e8-\
4fb75381fe8f"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "f", ",", "h", ",", "\[CapitalBeta]", ",", "\[Beta]", ",", "\[Theta]", ",", 
   "sh"}], "]"}]], "Input",
 CellChangeTimes->{{3.696691209991288*^9, 
  3.69669120999244*^9}},ExpressionUUID->"21e79dff-2061-4bb4-b917-\
d18f9d2bb0fe"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" 1.4. The Derivation Equations", "Subsection",
 CellChangeTimes->{{3.586839514507707*^9, 3.5868395266264005`*^9}, {
   3.5872725402788825`*^9, 3.5872725434780655`*^9}, 3.6095615970681953`*^9, 
   3.6096567356047544`*^9, 3.615036647915494*^9, 3.6150391086202383`*^9, 
   3.6177712240322223`*^9, 3.617772205182746*^9, 3.6274431059022865`*^9, 
   3.627452822850827*^9, {3.629188873900796*^9, 3.629188876833601*^9}, {
   3.696082736788767*^9, 3.696082738980699*^9}, 
   3.696432140772999*^9},ExpressionUUID->"58505d0f-92b2-4767-a144-\
c70a1b1e1843"],

Cell[CellGroupData[{

Cell["1.4.1. The Orthonormal Cobasis {\[Sigma][1], \[Sigma][2]}", \
"Subsubsection",
 CellChangeTimes->{{3.5867788245861397`*^9, 3.586778908304928*^9}, {
   3.5867789597698717`*^9, 3.586778962401022*^9}, 3.586839376202797*^9, {
   3.5868713690839806`*^9, 3.586871375838793*^9}, {3.587272548686363*^9, 
   3.587272552854602*^9}, {3.622724946885109*^9, 3.6227249489287124`*^9}, 
   3.62272763823198*^9, 3.6274528348004484`*^9, 3.6275363610569324`*^9, 
   3.696691353280182*^9, 3.696738598662863*^9, 3.7074480119079323`*^9, 
   3.7074576275973673`*^9},ExpressionUUID->"aef1d765-6338-48da-aaae-\
6ec55bd20198"],

Cell["\<\
The orthonormal cobasis   {\[Sigma][1], \[Sigma][2]} is the dual basis to the \
orthonormal Basis {amf[1], amf[2]} of the tangent spaces. It is defined (in \
eudiffgeov3.m)  by\
\>", "Text",
 CellChangeTimes->{{3.609650787300531*^9, 3.609650922932289*^9}, {
   3.6148618497223225`*^9, 3.6148618498159227`*^9}, {3.6149177824513445`*^9, 
   3.614917782482545*^9}, {3.61491854824109*^9, 3.614918549130291*^9}, {
   3.6150366787472577`*^9, 3.6150367104430704`*^9}, {3.622727589949895*^9, 
   3.6227276048479214`*^9}, 
   3.686289011130885*^9},ExpressionUUID->"1175fb32-3026-41b2-8317-\
ef6112ba7bae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.695973640898653*^9, 3.695973642709732*^9}, {
  3.6965726062615633`*^9, 
  3.696572608933517*^9}},ExpressionUUID->"1f3bde43-652c-44d4-a5ab-\
227625ca97f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "i_", "]"}], "[", "f_", "]"}], "[", "u__", 
    "]"}], " ", ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], "===", "List"}], "&&", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], "\[GreaterEqual]", 
         RowBox[{"Length", "[", 
          RowBox[{"{", "u", "}"}], "]"}]}]}], ")"}], "&&", 
      RowBox[{"(", 
       RowBox[{"i", ">=", " ", "1"}], ")"}], "&&", 
      RowBox[{"(", 
       RowBox[{"i", "<=", " ", 
        RowBox[{"Length", "[", 
         RowBox[{"f", "[", "u", "]"}], "]"}]}], ")"}]}], ",", "\n", 
     RowBox[{"Return", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"amf", "[", "i", "]"}], "[", "f", "]"}], "[", "u", "]"}], 
       ".", 
       RowBox[{
        RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}]}], "]"}], ",", "\n", 
     RowBox[{
      RowBox[{"Print", "[", "\"\<Invalid argument!\>\"", "]"}], ";", 
      RowBox[{"Return", "[", "]"}]}]}], "]"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5862684374261866`*^9, 3.586268590883964*^9}, {
   3.586268694356882*^9, 3.5862687381573877`*^9}, {3.5862689068290353`*^9, 
   3.586268967629513*^9}, {3.5868451322760253`*^9, 3.586845153622246*^9}, {
   3.5868451909133787`*^9, 3.5868454031145163`*^9}, {3.5868455663498526`*^9, 
   3.5868456048040524`*^9}, {3.586845689054871*^9, 3.5868457266850233`*^9}, {
   3.5868458045404763`*^9, 3.5868458267597475`*^9}, {3.586845979053458*^9, 
   3.586845987693952*^9}, {3.5868460253081036`*^9, 3.5868460401399517`*^9}, {
   3.5868461640450387`*^9, 3.586846178851886*^9}, {3.5868462272766557`*^9, 
   3.5868462390363283`*^9}, 3.5868463462864623`*^9, {3.586846553173296*^9, 
   3.58684656827516*^9}, {3.586846604924256*^9, 3.5868466802425632`*^9}, {
   3.586846871252489*^9, 3.5868468892185163`*^9}, {3.586847223476635*^9, 
   3.5868472486350737`*^9}, {3.5868472800588713`*^9, 3.586847288730367*^9}, {
   3.586847402107852*^9, 3.5868474363878126`*^9}, {3.5868475906426353`*^9, 
   3.5868476198363056`*^9}, {3.5868477813165417`*^9, 3.5868477944282913`*^9}, 
   3.609650066236288*^9, {3.6096500990871677`*^9, 3.6096501028473825`*^9}, {
   3.6096501406985474`*^9, 3.6096501659779935`*^9}, {3.609650204137176*^9, 
   3.609650254747071*^9}, {3.6096505070675025`*^9, 3.6096505316539087`*^9}, {
   3.6096505653868384`*^9, 3.6096505818417797`*^9}, 3.6148618498159227`*^9, 
   3.614917782498145*^9, 3.6149184396336985`*^9, {3.615036953864993*^9, 
   3.615036975872252*^9}, {3.617775036650119*^9, 3.6177750639501667`*^9}, {
   3.6959745996715*^9, 3.6959746063673573`*^9}, 
   3.6965725947363787`*^9},ExpressionUUID->"651902ca-1ae5-47c7-b41f-\
a39664d7c99a"],

Cell[BoxData[
 RowBox[{"?", "\[Sigma]"}]], "Input",
 CellChangeTimes->{{3.622727446679243*^9, 
  3.6227274648688755`*^9}},ExpressionUUID->"76b5afbc-9773-40cf-94e6-\
f749f4e6b90e"],

Cell[BoxData[
 RowBox[{"Context", "[", "\[Sigma]", "]"}]], "Input",
 CellChangeTimes->{{3.622727476397296*^9, 
  3.622727495444929*^9}},ExpressionUUID->"47f11530-a369-4bc5-8674-\
7d3a93017019"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, {
  3.5868454727975016`*^9, 3.586845508677554*^9}, {3.586847494630144*^9, 
  3.5868475090139666`*^9}, {3.6096503908708563`*^9, 3.6096504000783834`*^9}, {
  3.6959746361543217`*^9, 3.695974645290473*^9}, {3.696430061855884*^9, 
  3.696430068208069*^9}},ExpressionUUID->"59d1b9a3-7382-4d01-a0bd-\
94b551defa77"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.695973843719655*^9, 3.695973953315555*^9}, {
  3.6959740192012453`*^9, 3.695974028266622*^9}, {3.695974063759506*^9, 
  3.695974076818591*^9}},ExpressionUUID->"990138ec-3df1-4e4e-88f8-\
ba2be52fc377"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, {
  3.5868454727975016`*^9, 3.586845508677554*^9}, {3.586847494630144*^9, 
  3.5868475090139666`*^9}, {3.5868477190429797`*^9, 3.586847749885744*^9}, {
  3.586847865477355*^9, 3.586847871125678*^9}, {3.609650411374029*^9, 
  3.609650424006752*^9}},ExpressionUUID->"f18a7a30-f18f-4c0c-8b80-\
894f391852b4"],

Cell["By definition we have", "Text",
 CellChangeTimes->{{3.6096511679643035`*^9, 
  3.609651177323839*^9}},ExpressionUUID->"4c2b803c-fc34-48bb-9a8d-\
de21510c1a56"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6096493267409916`*^9, 3.609649346334112*^9}, {
   3.6096499062221365`*^9, 3.6096499841265917`*^9}, 3.6148618498315225`*^9, 
   3.614917782513745*^9, 
   3.6149185578819065`*^9},ExpressionUUID->"84ce839e-cd1c-43a5-afae-\
467c34f9097b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, 
   3.5868463633494387`*^9, {3.586847469821725*^9, 3.586847475909073*^9}, {
   3.5868475678933344`*^9, 
   3.5868475750537443`*^9}},ExpressionUUID->"ebad0c6f-e252-4654-b06a-\
e39fbac067f0"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "4", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, 
   3.5868463633494387`*^9, {3.586847469821725*^9, 3.586847475909073*^9}, {
   3.5868475678933344`*^9, 3.5868475750537443`*^9}, {3.617774888730659*^9, 
   3.6177748964370728`*^9}},ExpressionUUID->"6d4b9b7c-dcb4-4290-a587-\
f22da6db13f2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sg", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"vec", "[", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.695974844023982*^9, 
  3.695974919348197*^9}},ExpressionUUID->"fa885d55-2eca-48fb-8a38-\
ab81ed934559"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sg", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, 
   3.5868463633494387`*^9, {3.586847469821725*^9, 3.586847475909073*^9}, {
   3.5868475678933344`*^9, 3.5868475750537443`*^9}, {3.5868476634187984`*^9, 
   3.5868476818378515`*^9}, {3.695974713649837*^9, 3.695974721981968*^9}, {
   3.695974816368575*^9, 3.6959748206049757`*^9}, {3.695974944864386*^9, 
   3.6959749495717087`*^9}, {3.6964304214657707`*^9, 
   3.6964304440975246`*^9}},ExpressionUUID->"4987aefe-62eb-44b0-8e71-\
2db2e2cf11a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]", "[", "1", "]"}], "[", 
   RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, {
  3.5862690108319836`*^9, 
  3.5862690363924456`*^9}},ExpressionUUID->"a798006c-68eb-4e70-b6ea-\
f19c9ebab3b4"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", " ", 
     RowBox[{"v", " ", "\[Element]", " ", "Reals"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.586834921828021*^9, 3.5868349307725325`*^9}, {
  3.6177716436597595`*^9, 
  3.6177716527701755`*^9}},ExpressionUUID->"1a76d473-6ac8-4231-b96d-\
b89b102dc1d7"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", " ", 
     RowBox[{"v", " ", "\[Element]", " ", "Reals"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5862685978523626`*^9, 3.586268637618637*^9}, {
  3.5862690108319836`*^9, 3.5862690869863396`*^9}, {3.609650667958705*^9, 
  3.60965070004354*^9}},ExpressionUUID->"3e4251ca-f488-4513-95c3-\
380b3a228c91"],

Cell[TextData[{
 "We verify some classical formulas first expressed in traditional notation, \
then proved by calculation with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.5868371669714355`*^9, 
  3.586837253204368*^9}},ExpressionUUID->"16725ddf-dbb1-4b59-b3ed-\
534bc8492213"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.696430928357308*^9, 
  3.696430939024088*^9}},ExpressionUUID->"658bcc6a-b20b-45fb-bbfc-\
3a31a22d3c0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["1.",
    FontColor->RGBColor[0, 0, 1]], 
   StyleBox[
    RowBox[{
     StyleBox[" ",
      FontColor->RGBColor[0, 0, 1]], "  "}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"[", 
      RowBox[{"B", "-", "R"}], "]"}], ",", " ", 
     RowBox[{"(", "41.6", ")"}]}], ")"}], "                    ", 
   RowBox[{"d", "[", "sf", "]"}]}], " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868372815939918`*^9, 3.586837377709489*^9}, {
  3.586837463149376*^9, 3.5868375120501733`*^9}, {3.586837863366267*^9, 
  3.5868378687105727`*^9}, {3.614861849847122*^9, 3.614861849847122*^9}, {
  3.6149177825293446`*^9, 3.6149177825293446`*^9}, {3.614918462362939*^9, 
  3.6149184637981415`*^9}},ExpressionUUID->"d3d8f982-6022-45da-8a14-\
a40e2516a5a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}]}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", 
        RowBox[{"{", 
         RowBox[{"s", ",", "t"}], "}"}]}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", 
        RowBox[{"{", 
         RowBox[{"s", ",", "t"}], "}"}]}]}]}], ")"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.586835336082715*^9, 3.586835446246016*^9}, {
   3.5868355063994565`*^9, 3.58683551555098*^9}, {3.586835582798826*^9, 
   3.586835692009073*^9}, {3.5897805003550973`*^9, 3.5897805009010983`*^9}, {
   3.5897806863542237`*^9, 3.589780691627033*^9}, {3.614861849847122*^9, 
   3.6148618498627224`*^9}, {3.614917782544945*^9, 3.614917782544945*^9}, 
   3.6149184651709437`*^9, 
   3.6149185594419093`*^9},ExpressionUUID->"bcb9b2e2-4aaf-4756-9033-\
4d90dc22e369"],

Cell["Remark, This formula is analogue to", "Text",
 CellChangeTimes->{{3.627536749229617*^9, 
  3.6275367729456587`*^9}},ExpressionUUID->"16e13cbd-73c8-4d2b-ac58-\
c4509367f206"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", 
    RowBox[{"du", ".", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}]}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", 
    RowBox[{"dv", ".", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.627536801045308*^9, 3.627536901658886*^9}, {
  3.627537027722509*^9, 3.6275370808798027`*^9}, {3.696431061791625*^9, 
  3.6964310799347553`*^9}},ExpressionUUID->"b211d8f8-3c6f-4362-85be-\
a0e7218f831f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["2.",
    FontColor->RGBColor[0, 0, 1]], "   ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"[", 
      RowBox[{"B", "-", "R"}], "]"}], ",", " ", 
     RowBox[{"(", "42.13", ")"}]}], ")"}], "                ", "fund1"}], " ",
   "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "1", "]"}], "^", "2"}], "  ", "+", "  ", 
   RowBox[{
    RowBox[{"\[Sigma]", "[", "2", "]"}], "^", "2", " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868377489117208`*^9, 3.5868378393648944`*^9}, {
   3.586837873052821*^9, 3.5868379575736556`*^9}, 
   3.5904957105154095`*^9},ExpressionUUID->"ea6bb6d5-8b17-4e7b-ac9b-\
5c42d68c779d"],

Cell["We evaluate the corresponding symmetric bilinear form:", "Text",
 CellChangeTimes->{{3.5868380097146378`*^9, 
  3.586838051907051*^9}},ExpressionUUID->"d2264ea6-a231-42cb-9d79-\
39e9c4284647"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vs", "=", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], ";", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{"vs", ",", "vs"}], "]"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "vs"}], ")"}], "^", "2"}], "-", 
    " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "vs"}], ")"}], "^", "2"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.586836684445837*^9, 3.586836692207281*^9}, {
   3.586836738835948*^9, 3.586836753262773*^9}, {3.5868367939941025`*^9, 
   3.5868368662162333`*^9}, {3.5868369358372154`*^9, 3.586836950725067*^9}, {
   3.586836982972912*^9, 3.5868370924811754`*^9}, 3.5904957105154095`*^9, {
   3.69643123555866*^9, 3.696431244694457*^9}, {3.696431276718196*^9, 
   3.6964312857976227`*^9}, 3.6964313216775227`*^9, 3.6964313590453568`*^9, {
   3.707452744093211*^9, 
   3.707452744925331*^9}},ExpressionUUID->"388c73b4-4b0b-421d-a0bd-\
9dc24c98e9a4"],

Cell["\<\
3.   ([B-R], (42.7))   The  area element             dA\[Equal] \[Sigma][1]\
\[Wedge]\[Sigma][2]\
\>", "Text",
 CellChangeTimes->{
  3.627535506181225*^9},ExpressionUUID->"8a632e65-d621-4bd5-99d1-\
10a49fe661c1"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868384410843105`*^9, 3.5868384512198906`*^9}, {
   3.586838491404189*^9, 3.586838569777672*^9}, 3.586838627365966*^9, {
   3.586838866175625*^9, 3.5868388901109934`*^9}, {3.586839064039942*^9, 
   3.586839101438081*^9}},ExpressionUUID->"69e12b5e-11dc-4fbb-abaa-\
863d7ad39f4e"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"extprod", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588414285618554*^9, 3.5884143135270033`*^9}, {
  3.609651368687784*^9, 3.6096513743031054`*^9}, {3.609651417118554*^9, 
  3.6096514250310073`*^9}},ExpressionUUID->"35e86083-a52c-4d9c-aac5-\
c63e3fa1a32b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}], "\[Equal]", " ", 
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.58841475574098*^9, 3.5884148014646597`*^9}, {
  3.6096514383987713`*^9, 
  3.6096514445281224`*^9}},ExpressionUUID->"be1c7790-049e-4289-9b1b-\
c22546084688"],

Cell["\<\
Remember that  the determinant on the right side of the equation is the only \
strict coordinate of \[Sigma][1]\[Wedge]\[Sigma][2] in the local basis du, \
dv; since (du,dv) and (\[Sigma][1][sf][u,v],\[Sigma][2][sf][u,v]}) define the \
same orientation of the tangent space, this determinant is always assumed to \
be positive.\
\>", "Text",
 CellChangeTimes->{{3.586839212899456*^9, 3.586839299018382*^9}, {
   3.590736505584259*^9, 3.5907365286878996`*^9}, {3.617953744410181*^9, 
   3.617953914697921*^9}, 
   3.696431476523197*^9},ExpressionUUID->"b0d75645-185f-4cbe-8ac2-\
be269f9a265c"],

Cell[TextData[{
 StyleBox["The basis transformation.",
  FontColor->RGBColor[0, 0, 1]],
 "\nWe calculate the decomposition of the \[Sigma][i] with respect to the \
basis du,dv, stating"
}], "Text",
 CellChangeTimes->{{3.590721556004931*^9, 3.5907216598688717`*^9}, {
  3.590722468989151*^9, 3.5907224724133463`*^9}, {3.5907350609125214`*^9, 
  3.59073506573293*^9}},
 CellTags->"bastr",ExpressionUUID->"36a7c052-766f-445a-9b18-ba1f42c2759f"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Sigma]", "(", "1", ")"}], "\[LongEqual]", 
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "(", 
        RowBox[{"1", ",", "1"}], ")"}], " ", "du"}], "+", " ", 
      RowBox[{
       RowBox[{"rgT", "(", 
        RowBox[{"1", ",", "2"}], ")"}], " ", "dv"}]}]}], 
    SqrtBox[
     RowBox[{"rgT", "(", 
      RowBox[{"1", ",", "1"}], ")"}]]]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.590735088992571*^9, 3.5907351925767527`*^9}, {
  3.590735232356823*^9, 3.590735292619729*^9}, {3.6176262984584913`*^9, 
  3.617626319160675*^9}},ExpressionUUID->"f4581b36-144f-4569-81c6-\
310f4abe9646"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Sigma]", "(", "2", ")"}], "\[LongEqual]", 
   RowBox[{
    FractionBox[
     SqrtBox[
      TemplateBox[{RowBox[{"{", 
          RowBox[{"rgT", "(", 
            RowBox[{"i", ",", "j"}], ")"}], "}"}]},
       "Det"]], 
     SqrtBox[
      RowBox[{"rgT", "(", 
       RowBox[{"1", ",", "1"}], ")"}]]], " ", "dv"}], " ", "\[Equal]", " ", 
   RowBox[{
    FractionBox["dA", 
     SqrtBox[
      RowBox[{"rgT", "(", 
       RowBox[{"1", ",", "1"}], ")"}]]], " ", "dv"}]}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.590735088992571*^9, 3.5907351925767527`*^9}, {
  3.590735232356823*^9, 3.590735292619729*^9}, {3.590735627864318*^9, 
  3.5907357745045753`*^9}, {3.617626330122302*^9, 3.6176263320654135`*^9}, {
  3.6176264002583137`*^9, 3.617626413915095*^9}, {3.6275357480926514`*^9, 
  3.6275357802951083`*^9}},ExpressionUUID->"ba0a1b71-57e5-4eae-a972-\
eb52ca55cd07"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5907358558431177`*^9, 
  3.5907358594467244`*^9}},ExpressionUUID->"3edc5f42-30ea-4027-b2a1-\
cadc97ec25bb"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", " ", "s2"}], "}"}]}], " ", "==", " ", "\n", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "u", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", 
        RowBox[{"{", 
         RowBox[{"s1", ",", " ", "s2"}], "}"}]}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "2"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "v", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ".", 
        RowBox[{"{", 
         RowBox[{"s1", ",", " ", "s2"}], "}"}]}]}]}], ")"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5907173613780117`*^9, 3.5907173699605026`*^9}, {
   3.5907174455358257`*^9, 3.590717473390419*^9}, {3.5907175080954037`*^9, 
   3.5907176306184115`*^9}, {3.5907177498192296`*^9, 3.590717791333604*^9}, {
   3.5907179684707355`*^9, 3.590718084885394*^9}, {3.5907203135178647`*^9, 
   3.5907203282297063`*^9}, {3.590720362173648*^9, 3.590720399942808*^9}, 
   3.590720439646079*^9, 3.5907349903223977`*^9, {3.5907353529138346`*^9, 
   3.5907354339715767`*^9}, {3.6096516615155334`*^9, 
   3.6096516949464455`*^9}, {3.6096517297964387`*^9, 3.609651768851672*^9}, {
   3.61762605087033*^9, 
   3.6176260543665295`*^9}},ExpressionUUID->"9c6bccdc-0b5b-4d1b-bab2-\
700d93329a95"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", " ", "s2"}], "}"}]}], " ", "==", " ", "\n", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"dA", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ")"}], "*", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "v", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"s1", ",", " ", "s2"}], "}"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5907173613780117`*^9, 3.5907173699605026`*^9}, {
   3.5907174455358257`*^9, 3.590717473390419*^9}, {3.5907175080954037`*^9, 
   3.5907176306184115`*^9}, {3.5907177498192296`*^9, 3.590717791333604*^9}, {
   3.5907179684707355`*^9, 3.590718084885394*^9}, {3.5907203135178647`*^9, 
   3.5907203282297063`*^9}, {3.590720362173648*^9, 3.590720399942808*^9}, 
   3.590720439646079*^9, {3.590721070544164*^9, 3.590721087006106*^9}, {
   3.5907211626374316`*^9, 3.590721228294187*^9}, 3.590721882841625*^9, {
   3.5907219660703855`*^9, 3.5907219725897584`*^9}, {3.5907220046705933`*^9, 
   3.5907220343012877`*^9}, {3.590722076702713*^9, 3.5907220826040506`*^9}, 
   3.5907355108953123`*^9, {3.6096518755697765`*^9, 3.60965190080122*^9}, 
   3.6176260623649874`*^9},ExpressionUUID->"54f6fafd-9e8f-46db-bd35-\
49e339b48040"],

Cell["Here remember", "Text",
 CellChangeTimes->{{3.590735889554777*^9, 
  3.590735895997588*^9}},ExpressionUUID->"635e3acb-8744-4d75-b083-\
75399c162f93"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", " ", "v"}], "]"}], "\[Equal]", " ", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5907359427352705`*^9, 3.590736093166335*^9}, {
   3.590736161681655*^9, 3.590736167609666*^9}, 3.614861849893923*^9, 
   3.614863501578024*^9, {3.6176264560655055`*^9, 
   3.6176264578096056`*^9}},ExpressionUUID->"fb8a02e6-c739-4d25-a5f4-\
5510082c5d51"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ",", " ", "0"}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.609652212502048*^9, 3.6096522185163918`*^9}, {
  3.6096522543684425`*^9, 3.609652287800355*^9}, {3.6176264757526317`*^9, 
  3.6176264781367683`*^9}},ExpressionUUID->"c8bed13a-0b97-4fd1-aa38-\
b57b4f16cdd1"],

Cell["\<\
We state and test the following formulas expressing the orthonormal basis \
with respect to the tangent basis tv[1],tv[2]:\
\>", "Text",
 CellChangeTimes->{{3.6096536113480573`*^9, 3.6096536808440323`*^9}, {
   3.615037408346988*^9, 3.615037421618747*^9}, 3.615117680678119*^9, {
   3.696431941014389*^9, 
   3.6964319802943983`*^9}},ExpressionUUID->"d09f208e-16cb-4f84-a639-\
086fb5aa3bd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6096536860943327`*^9, 3.609653696557931*^9}, 
   3.617600024337888*^9},ExpressionUUID->"dbda564a-e4ea-4f3d-acdc-\
a4f01dd4ea7c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6096537089286385`*^9, 3.609653730893895*^9}, 
   3.617600085770796*^9},ExpressionUUID->"77cf5b15-8ac4-42b5-b4e9-\
a9ca996eb9c3"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "==", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.60965374165051*^9, 3.609653754030218*^9}, {
   3.60965379095033*^9, 3.609653907929021*^9}, 3.6148618499095225`*^9, 
   3.614917782591745*^9, 3.6149185669143224`*^9, 3.617600024353488*^9, 
   3.6176265331969175`*^9},ExpressionUUID->"fc771e94-b06c-466b-a06b-\
96a7acfa8885"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{
          RowBox[{"tv", "[", "1", "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "2"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}]}]}], " ", ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"dA", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.60965374165051*^9, 3.609653754030218*^9}, {
   3.60965379095033*^9, 3.6096539246169753`*^9}, {3.6096540031054645`*^9, 
   3.609654147059698*^9}, {3.6096541915242414`*^9, 3.6096541999007206`*^9}, 
   3.6096542338676634`*^9, {3.609654281572392*^9, 3.609654289737859*^9}, 
   3.6148618499095225`*^9, 3.6149177826073446`*^9, 3.6149185725303326`*^9, 
   3.617600024353488*^9, 3.617600085786396*^9, {3.6176265366951175`*^9, 
   3.617626541950418*^9}},ExpressionUUID->"0a452160-534b-47de-a2e2-\
554c6135ef17"],

Cell["\<\
The next four identities verify the duality of the orthonormal basis and \
cobasis:\
\>", "Text",
 CellChangeTimes->{{3.6096566616205225`*^9, 
  3.6096567048279943`*^9}},ExpressionUUID->"5b95221f-974f-4cab-bd13-\
655ad8d7f796"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ",", "0"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.609655949502792*^9, 3.6096559526939745`*^9}, {
   3.609655983711749*^9, 3.6096559907591515`*^9}, {3.6096560255621424`*^9, 
   3.60965603671278*^9}, 
   3.6176265453316116`*^9},ExpressionUUID->"e738a781-5b66-4c0f-8691-\
2d5a90f203fb"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "2"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}]}], "}"}]}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"dA", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.609655949502792*^9, 3.6096559526939745`*^9}, {
  3.609655983711749*^9, 3.6096559907591515`*^9}, {3.6096560255621424`*^9, 
  3.609656054616804*^9}, {3.6096561620579495`*^9, 3.609656183154156*^9}, {
  3.609656261770653*^9, 3.609656267947006*^9}, {3.609656328491469*^9, 
  3.6096563674596977`*^9}, {3.6096564022096853`*^9, 3.609656417282548*^9}, {
  3.617626547645744*^9, 
  3.617626552389015*^9}},ExpressionUUID->"fa068db1-40ac-4aac-8180-\
db6dcd0bc36d"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "2"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}]}], "}"}]}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"dA", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "*", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.609655949502792*^9, 3.6096559526939745`*^9}, {
  3.609655983711749*^9, 3.6096559907591515`*^9}, {3.6096560255621424`*^9, 
  3.6096560682745857`*^9}, {3.6096561208885946`*^9, 3.6096561300971217`*^9}, {
  3.6096565385274825`*^9, 3.60965656017072*^9}, {3.6176265555741973`*^9, 
  3.6176265598944445`*^9}},ExpressionUUID->"479c1b70-cb3c-45f2-b884-\
822e6ba15377"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", " ", "1"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], ",", "0"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.609656584423107*^9, 3.6096566004730253`*^9}, 
   3.6176265614995365`*^9},ExpressionUUID->"0895ae30-4ad1-4f0f-9d0d-\
6ad120acc0c2"],

Cell["\<\
In the case of orthogonal parameters u,v, i.e. rgT[1,2][sf][u,v] == 0, the \
formulas simplify to\
\>", "Text",
 CellChangeTimes->{{3.6096570629004745`*^9, 3.6096571596600094`*^9}, 
   3.617626564157688*^9},ExpressionUUID->"4805d512-51fa-4f46-91a4-\
334fd1be9fb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "1", "]"}], " ", "\[Equal]", " ", 
   RowBox[{"tv1", "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rgT", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], ";", " ", 
  RowBox[{
   RowBox[{"amf", "[", "2", "]"}], " ", "\[Equal]", " ", 
   RowBox[{"tv2", "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rgT", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.60965716946657*^9, 3.609657242111725*^9}, {
  3.609657306679418*^9, 3.609657312062726*^9}, {3.6148618499251223`*^9, 
  3.6148618499251223`*^9}, {3.614917782622945*^9, 3.614917782622945*^9}, {
  3.6149185737315345`*^9, 3.6149185765395393`*^9}, {3.6176265667318354`*^9, 
  3.6176265693079824`*^9}, {3.627456912774128*^9, 
  3.627456919154539*^9}},ExpressionUUID->"40e2dcd0-5610-449b-a733-\
aedfa7e53acf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]", "[", "1", "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"d", "[", "u", "]"}], "*", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rgT", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], ";", " ", 
  RowBox[{
   RowBox[{"\[Sigma]", "[", "2", "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"d", "[", "v", "]"}], "*", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"rgT", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.60965716946657*^9, 3.6096572875913267`*^9}, {
   3.609657332815913*^9, 3.609657361215537*^9}, 3.6096575886875477`*^9, 
   3.609657638831416*^9, {3.61762657188413*^9, 
   3.6176265734042172`*^9}},ExpressionUUID->"ff358a57-be26-41fb-b701-\
ea93eabe0774"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.4.2. Derivation of the Orthonormal Frame", "Subsubsection",
 CellChangeTimes->{{3.5868395957793555`*^9, 3.586839624635006*^9}, {
   3.587272558157905*^9, 3.587272561670106*^9}, 3.609656777205134*^9, 
   3.609673033665471*^9, 3.6177723089073277`*^9, 3.617778896920499*^9, 
   3.6275363705105495`*^9, 3.627538259815281*^9, 3.6964321495256233`*^9, 
   3.696574264047344*^9, 3.696738609268914*^9, 3.696739083472045*^9, 
   3.70745763411831*^9, 
   3.707458322840109*^9},ExpressionUUID->"4a8faeb7-e75b-4a3f-a7b8-\
e632a7f9039a"],

Cell["\<\
Now we consider the second part of the derivation equations [B-R], (41.6), \
traditionally written as \
\>", "Text",
 CellChangeTimes->{{3.5868413763872004`*^9, 3.586841403410746*^9}, {
  3.586841435555585*^9, 
  3.5868414605550146`*^9}},ExpressionUUID->"aed6f4a2-4d37-4ee6-8435-\
5a58665fb192"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"amf", "[", "j", "]"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"j", ",", "k"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "k", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586841471104618*^9, 3.586841517365264*^9}, {
   3.5868415742765193`*^9, 3.586841612878727*^9}, {3.5868416500478535`*^9, 
   3.586841798703356*^9}, {3.586842211630974*^9, 3.586842226862845*^9}, 
   3.5868422721024323`*^9, {3.586842430621499*^9, 3.586842442502179*^9}, {
   3.6148618499407225`*^9, 3.6148618499407225`*^9}, {3.614917782622945*^9, 
   3.614917782638545*^9}, {3.614918685490131*^9, 3.614918689499338*^9}, 
   3.696566168733652*^9},ExpressionUUID->"d566fc05-6b1c-4eed-bf5c-\
b4ac9511e661"],

Cell["\<\
that means we decompose the derivatives of the frame vectors in the frame \
itself. The main point here is that the formula defines the local structure \
forms of the frame: \
\>", "Text",
 CellChangeTimes->{{3.5868418968969717`*^9, 3.5868419627467384`*^9}, {
   3.586842047258572*^9, 3.5868420475225873`*^9}, {3.5868420867948337`*^9, 
   3.5868421500584517`*^9}, 
   3.6151176978140993`*^9},ExpressionUUID->"cc63675b-b31d-4540-a0e5-\
14939440b033"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Omega]", "[", 
   RowBox[{"j", ",", "k"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"amf", "[", "j", "]"}], "]"}], ".", 
   RowBox[{"amf", "[", "k", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868421823663*^9, 3.586842199812298*^9}, {
  3.5868422541254044`*^9, 3.5868422601407485`*^9}, {3.586842300638065*^9, 
  3.586842314316847*^9}, {3.6148618499563227`*^9, 3.6148618499563227`*^9}, {
  3.614917782638545*^9, 3.6149177826541452`*^9}, {3.6149186917613416`*^9, 
  3.6149186932433443`*^9}},ExpressionUUID->"55c2f275-814e-4c7c-8d02-\
8da0cf2bbdd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.6177762838567095`*^9, 3.617776319034771*^9}, 
   3.6965663088278637`*^9},ExpressionUUID->"5fe4f1b5-3454-4134-bf07-\
5543e0312c37"],

Cell[TextData[{
 "The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " definition of these differential forms is given in eudiffgeov3.m:"
}], "Text",
 CellChangeTimes->{{3.5868424600031796`*^9, 3.586842469555726*^9}, {
   3.58684251140312*^9, 3.5868425428909206`*^9}, {3.622728161082498*^9, 
   3.6227281812221336`*^9}, 
   3.686289012546689*^9},ExpressionUUID->"ce0e750b-cf28-4221-9478-\
95919b69fb2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"j_", ",", "k_"}], "]"}], "[", "f_", "]"}], "[", "u__", "]"}], 
   " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"m", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "u", "}"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], "===", "List"}], ",", 
        RowBox[{"n", "=", 
         RowBox[{"Length", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Invalid argument\>\"", " ", ",", 
           RowBox[{"f", "[", "u", "]"}], ",", "\"\< !\>\""}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"m", ">", "n"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", "\"\<Invalid dimensions!\>\"", "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"j", ">=", "1"}], "&&", 
         RowBox[{"j", "\[LessEqual]", "n"}], "&&", 
         RowBox[{"k", ">=", "1"}], "&&", 
         RowBox[{"k", "\[LessEqual]", "n"}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"j", "\[Equal]", "k"}], ",", 
          RowBox[{"Return", "[", 
           RowBox[{"null", "[", "m", "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Return", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"amf", "[", "k", "]"}], "[", "f", "]"}], "[", "u", 
             "]"}], ".", 
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{
               RowBox[{"amf", "[", "j", "]"}], "[", "f", "]"}], "]"}], "[", 
             "u", "]"}]}], "]"}]}], "]"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", "\"\<Invalid arguments!\>\"", "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}]}]}], "]"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.696567129409029*^9, 3.6965671757963*^9}, {
   3.696567244327417*^9, 3.696567304079176*^9}, {3.6965673365490837`*^9, 
   3.696567348052772*^9}, {3.696567383572599*^9, 3.696567512547426*^9}, {
   3.696567546235365*^9, 3.6965675792034693`*^9}, {3.6965676357381287`*^9, 
   3.696567639033265*^9}, {3.6965676720592813`*^9, 3.6965676820026503`*^9}, 
   3.696567713650614*^9, {3.696567763329969*^9, 3.696567824962274*^9}, {
   3.696567855481145*^9, 3.696567876857346*^9}, {3.696567929992927*^9, 
   3.696567940496449*^9}, {3.69656801384007*^9, 3.696568030872246*^9}, {
   3.69656806727236*^9, 3.69656815507026*^9}, 3.696568255375176*^9, {
   3.6965683985819798`*^9, 3.6965684191574383`*^9}, {3.696568483739208*^9, 
   3.696568513933001*^9}, {3.696568567828333*^9, 3.696568604732918*^9}, {
   3.696568639475992*^9, 3.6965686458598347`*^9}, 3.6965687681946707`*^9, {
   3.6965688249542294`*^9, 3.696568906766461*^9}, {3.696568977087229*^9, 
   3.696569005257621*^9}, {3.696569140480998*^9, 3.696569149368161*^9}, {
   3.696569651224029*^9, 3.696569681432152*^9}, 3.6965706224041348`*^9, 
   3.6965706617676764`*^9, {3.6965719228361273`*^9, 
   3.696571926388936*^9}},ExpressionUUID->"d548d9c9-d5ad-4bf8-a8e0-\
ca49935b4d3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868429252377896`*^9, 3.5868429767887383`*^9}, {
  3.586843433238846*^9, 3.5868434795654955`*^9}, {3.586848719485202*^9, 
  3.5868487233644238`*^9}},ExpressionUUID->"c2af5c3a-d6cd-4cec-b6aa-\
edf6934997ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"1", ",", "4"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868429252377896`*^9, 3.5868429767887383`*^9}, {
  3.586843433238846*^9, 3.5868434795654955`*^9}, {3.586848719485202*^9, 
  3.5868487233644238`*^9}, {3.609672962921425*^9, 
  3.609672970666868*^9}},ExpressionUUID->"406cb43f-49d5-45e6-b8ce-\
e992b6589ff3"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Omega]", "[", 
     RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868429252377896`*^9, 3.5868429767887383`*^9}, {
  3.586843433238846*^9, 3.5868434795654955`*^9}, {3.586843579253197*^9, 
  3.5868435857265673`*^9}, {3.5868487299978027`*^9, 3.5868487340450344`*^9}, {
  3.60967251944306*^9, 
  3.609672531130728*^9}},ExpressionUUID->"01a4978d-aed3-4727-8d95-\
a545baa1e1ef"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{
       RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6096579861182795`*^9, 3.609657997869952*^9}, {
  3.60965803910231*^9, 3.609658120935991*^9}, {3.614861849987523*^9, 
  3.614861849987523*^9}, {3.6149177826853447`*^9, 3.614917782700945*^9}, {
  3.6149187024473605`*^9, 
  3.614918703913763*^9}},ExpressionUUID->"0e7a3180-d118-487f-ad30-\
5dbbaf879509"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%%", "+", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868435996083612`*^9, 3.586843645676996*^9}, {
  3.5868487453106785`*^9, 3.586848749404913*^9}, {3.6096725624665203`*^9, 
  3.609672580851572*^9}},ExpressionUUID->"1aa3a8ac-2c3e-48de-9066-\
093acbe55231"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586843679460929*^9, 3.58684368874146*^9}, {
  3.586848755308251*^9, 
  3.58684876770896*^9}},ExpressionUUID->"5e836ee3-b982-4b9c-8bfe-\
608c76c58134"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Omega]", "[", 
     RowBox[{"2", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.586843679460929*^9, 3.586843727773692*^9}, {
  3.5868487753243957`*^9, 3.5868487778365393`*^9}, {3.696569794014282*^9, 
  3.696569808384685*^9}},ExpressionUUID->"811fad58-e375-4bfe-ac9d-\
18cb124852c9"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586843679460929*^9, 3.586843727773692*^9}, {
  3.5868437628767*^9, 3.5868438044780793`*^9}, {3.5868487931904173`*^9, 
  3.586848796973634*^9}, {3.609672698259287*^9, 
  3.609672711827063*^9}},ExpressionUUID->"1c7bd226-6451-4ac0-baf3-\
6445e9d2e20d"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Omega]", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868438496236615`*^9, 3.586843878845333*^9}, {
  3.586848804459062*^9, 3.5868488065651827`*^9}, {3.696569850307273*^9, 
  3.6965698609202137`*^9}},ExpressionUUID->"29d796f9-a2a5-452e-aebd-\
acd3b10fcb09"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868438496236615`*^9, 3.586843928902196*^9}, {
  3.586848816950776*^9, 
  3.5868488500336685`*^9}},ExpressionUUID->"1f19f0b6-ff7f-4fa8-a60e-\
4567bc1a892c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]", "[", 
    RowBox[{"3", ",", "3"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5868438496236615`*^9, 3.586843953133582*^9}, {
  3.586848858750167*^9, 
  3.586848863541441*^9}},ExpressionUUID->"1a739352-63b7-4c28-9a3b-\
2c76ac93c5b1"],

Cell["\<\
Following [B-R], (41.12) we define for surfaces in the 3-space\
\>", "Text",
 CellChangeTimes->{{3.5868493567396507`*^9, 3.586849361010895*^9}, {
  3.586849409451666*^9, 3.5868494290347853`*^9}, {3.696571888050712*^9, 
  3.6965719032345867`*^9}},ExpressionUUID->"41c7c55b-4906-4358-8ecc-\
9d530439b6e6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "1", "]"}], "[", "f_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", 
       RowBox[{"2", ",", "3"}], "]"}], "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Length", "[", 
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", "3"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "2", "]"}], "[", "f_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", 
       RowBox[{"3", ",", "1"}], "]"}], "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Length", "[", 
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", "3"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", "f_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "[", "f", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Length", "[", 
      RowBox[{"f", "[", 
       RowBox[{"u", ",", "v"}], "]"}], "]"}], "\[Equal]", "3"}]}]}], 
  ";"}]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868494748924084`*^9, 3.5868495473585534`*^9}, 
   3.617775849770347*^9, {3.6177759029820404`*^9, 3.617775946038116*^9}, {
   3.6177760265654573`*^9, 3.6177760341158705`*^9}, {3.625727939966119*^9, 
   3.6257279578437505`*^9}},ExpressionUUID->"30c05db7-1838-4ce3-8a9d-\
4ef81c409012"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "\[Omega]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.615037843228862*^9, 3.615037851164316*^9}, {
  3.6150378904935656`*^9, 3.615037974870392*^9}, {3.6150381937269096`*^9, 
  3.615038345791607*^9}, {3.615038395609456*^9, 3.615038458136033*^9}, {
  3.617776085533561*^9, 3.6177761088088017`*^9}, {3.6227280311030703`*^9, 
  3.62272804258469*^9}},ExpressionUUID->"dcdb6cd5-0e93-4fba-8039-\
afd7fc37a83d"],

Cell[BoxData[
 StyleBox["\<\"\[Omega][i,j][f][u,...] is the (i,j)-th structure form in the \
derivation equations \\nof the immersion f[u,...]into the n-dimensional \
Euclidean space.For n=3 one sets \[Omega][1]=\[Omega][2,3], \[Omega][2]=\
\[Omega][3,1], \[Omega][3]=\[Omega][1,2].\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.708321849500905*^9},
 CellTags->
  "Info373708329049-6824778",ExpressionUUID->"0506b40b-363b-4965-8d77-\
a32dc3d4feaa"]
}, Open  ]],

Cell[TextData[{
 "Clearly, the matrix {\[Omega][j,k][sf][u,v]} is skew symmetric. \n\n",
 StyleBox["Example 6",
  FontColor->RGBColor[0, 0, 1]],
 " The local structure forms of a sphere:"
}], "Text",
 CellChangeTimes->{{3.5868440279308605`*^9, 3.586844087339258*^9}, {
   3.586848951379465*^9, 3.5868489860914507`*^9}, 3.6177773205253305`*^9, {
   3.696742322960927*^9, 3.6967423397128973`*^9}, 
   3.696742379624613*^9},ExpressionUUID->"66d92b6a-d364-4bc1-836e-\
649c60ffec41"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"r", ">", "0"}], "&&", 
    RowBox[{"v", ">", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}]}], "&&", 
    RowBox[{"v", "<", 
     RowBox[{"Pi", "/", "2"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868443089369326`*^9, 3.5868443716615205`*^9}, 
   3.6177773788694324`*^9},ExpressionUUID->"b68e93d5-a7a2-4aaa-a09d-\
2f845797d5c7"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "1", "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"r", ">", "0"}], "&&", 
    RowBox[{"v", ">", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}]}], "&&", 
    RowBox[{"v", "<", 
     RowBox[{"Pi", "/", "2"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868443089369326`*^9, 3.5868443716615205`*^9}, {
   3.586844407878592*^9, 3.5868444400784335`*^9}, 
   3.5868495899029865`*^9},ExpressionUUID->"365b8827-c04a-47f0-9f8f-\
ab7aabfbffef"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "2", "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"r", ">", "0"}], "&&", 
    RowBox[{"v", ">", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}]}], "&&", 
    RowBox[{"v", "<", 
     RowBox[{"Pi", "/", "2"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868443089369326`*^9, 3.5868443716615205`*^9}, {
   3.586844407878592*^9, 3.5868444400784335`*^9}, 3.5868495899029865`*^9, {
   3.5868496805901737`*^9, 
   3.5868496948869915`*^9}},ExpressionUUID->"6b0a20ba-2271-4d6d-9124-\
888a2b0913d5"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"r", ">", "0"}], "&&", 
    RowBox[{"v", ">", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}]}], "&&", 
    RowBox[{"v", "<", 
     RowBox[{"Pi", "/", "2"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5868443089369326`*^9, 3.5868443716615205`*^9}, {
   3.586844407878592*^9, 3.5868444400784335`*^9}, 3.5868495899029865`*^9, {
   3.5868496805901737`*^9, 
   3.5868497038715057`*^9}},ExpressionUUID->"3e291cce-3d0e-45bc-b545-\
0816e2a660a8"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.707458188688527*^9, 
  3.707458188696176*^9}},ExpressionUUID->"1c14fd19-24fe-4cc5-be61-\
4de9275766d6"],

Cell[TextData[{
 "With the notations introduced above",
 StyleBox[" the derivation equations",
  FontColor->RGBColor[0, 0, 1]],
 " of the moving frame are the following\n(see [B-R], (41.13))"
}], "Text",
 CellChangeTimes->{{3.586870595603422*^9, 3.5868707256452503`*^9}, 
   3.587276591534601*^9},ExpressionUUID->"69a587f6-ac2f-481f-b047-\
c9620cc6b16c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "sf", "]"}], " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "1", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "2", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868707506520944`*^9, 3.5868707637405176`*^9}, {
  3.5868708348454423`*^9, 3.586870922985597*^9}, {3.614861850049923*^9, 
  3.614861850049923*^9}, {3.6149177827477455`*^9, 3.6149177827477455`*^9}, {
  3.614918705364566*^9, 
  3.6149187071117687`*^9}},ExpressionUUID->"34aff66f-0c27-4a8a-b04c-\
1674bfdc1dd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"amf", "[", "1", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "3", "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "2", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586870881739125*^9, 3.586871024151775*^9}, {
  3.614861850049923*^9, 3.614861850065523*^9}, {3.6149177827633452`*^9, 
  3.6149177827633452`*^9}, {3.6149187088433714`*^9, 
  3.6149187119165773`*^9}},ExpressionUUID->"be3a8357-ea9c-470c-a7bb-\
fdb4042515a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"amf", "[", "2", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"amf", "[", "1", "]"}]}], "*", 
    RowBox[{"\[Omega]", "[", "3", "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "1", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868711037119145`*^9, 3.5868711559408064`*^9}, {
  3.614861850065523*^9, 3.614861850065523*^9}, {3.614917782778945*^9, 
  3.614917782778945*^9}, {3.6149187133361797`*^9, 
  3.6149187168929863`*^9}},ExpressionUUID->"da4dbc35-6d6e-4ddb-8553-\
6772c1541880"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"amf", "[", "3", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "1", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "2", "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "1", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868712300253363`*^9, 3.5868712863882356`*^9}, 
   3.587276317927952*^9, {3.614861850081123*^9, 3.614861850081123*^9}, {
   3.614917782794545*^9, 3.614917782794545*^9}, {3.6149187181409883`*^9, 
   3.6149187213857937`*^9}},ExpressionUUID->"269adaa8-6ec6-4691-9550-\
3c1f80602206"],

Cell[TextData[{
 "Prove these identities with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", e.g."
}], "Text",
 CellChangeTimes->{{3.6177787011713552`*^9, 
  3.617778723697795*^9}},ExpressionUUID->"c51429e0-79a4-4ee6-9180-\
c747a9a8bda0"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    StyleBox[".",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}],
     FontColor->GrayLevel[0]]}], " ", "\[Equal]", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], " ", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      StyleBox[".",
       FontColor->GrayLevel[0]], 
      StyleBox[
       RowBox[{"{", 
        RowBox[{"s", ",", "t"}], "}"}],
       FontColor->GrayLevel[0]]}]}], "+", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], 
      StyleBox[".",
       FontColor->GrayLevel[0]], 
      StyleBox[
       RowBox[{"{", 
        RowBox[{"s", ",", "t"}], "}"}],
       FontColor->GrayLevel[0]]}]}]}]}], " ", "]"}]], "Input",
 CellChangeTimes->{
  3.696573831997011*^9, 3.696573865796074*^9, {3.696573924995085*^9, 
   3.6965739360509253`*^9}, {3.696573970803851*^9, 3.696573987554798*^9}, {
   3.696574076765099*^9, 3.6965741263855143`*^9}, 
   3.696574162909019*^9},ExpressionUUID->"be76db0c-fffb-4e45-94d3-\
3adb56efec43"],

Cell[BoxData[
 RowBox[{
  StyleBox["Simplify",
   FontColor->GrayLevel[0]], 
  StyleBox["[",
   FontColor->GrayLevel[0]], 
  RowBox[{
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}]}],
    FontColor->GrayLevel[0]], 
   StyleBox["-",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ".", 
      RowBox[{"{", 
       RowBox[{"s", ",", "t"}], "}"}]}]}],
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["+",
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}],
     FontColor->GrayLevel[0]], 
    StyleBox["*",
     FontColor->GrayLevel[0]], 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox[
        RowBox[{"\[Omega]", "[", "1", "]"}],
        FontColor->GrayLevel[0]], "[", "sf", "]"}], " ", "[", 
      RowBox[{"u", ",", "v"}], "]"}], 
     StyleBox[".",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"{", 
       RowBox[{"s", ",", "t"}], "}"}],
      FontColor->GrayLevel[0]]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6177774546699657`*^9, 3.6177774857920203`*^9}, 
   3.617777584618194*^9, {3.617777635658284*^9, 3.617777680789163*^9}, {
   3.6177777202260323`*^9, 3.6177778181162043`*^9}, {3.617777882045117*^9, 
   3.617777930467602*^9}, {3.617778075594657*^9, 
   3.617778118276332*^9}},ExpressionUUID->"0366fa3d-92a0-4a7b-872b-\
1a1d54de1a93"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5. The Integrability Conditions", "Subsection",
 CellChangeTimes->{{3.586871511559031*^9, 3.58687153347707*^9}, {
   3.5872725777430253`*^9, 3.5872725852784567`*^9}, 3.6150391162116723`*^9, 
   3.6151171023083725`*^9, 3.617779463887895*^9, 
   3.6178037497835894`*^9},ExpressionUUID->"ccb17bc2-bb90-4a7d-8c45-\
734698373130"],

Cell[CellGroupData[{

Cell["1.5.1. Summary", "Subsubsection",
 CellChangeTimes->{{3.5872726720544195`*^9, 3.587272684318121*^9}, 
   3.696574292896085*^9, 3.696574606988552*^9, 3.707458329832011*^9, 
   3.707458639525173*^9},
 CellTags->"intcond",ExpressionUUID->"08bde261-96d9-4ec4-8aba-101d9a66df0b"],

Cell[TextData[{
 "The local structure forms {\[Sigma][1], \[Sigma][2], \[Omega][1], \
\[Omega][2], \[Omega][3] } define all the local geometric properties of the \
surface which are invariant under Euclidean motions. One can prove that if \
the parameter representations of two surfaces have the same local structure \
forms on the same parameter manifold U, then the surfaces are congruent, i.e. \
they differ by an Euclidean motion only. But the forms are not independent of \
each other: they satisfy the so-called integrability conditions, which are \
obtained by exterior differentiation of the derivation equations. This \
operation yields the null vector at the left side; thus the components of the \
frame vectors at the right side after inserting the decomposition of the \
vector differentials using the derivation equations equal zero too, and this \
gives ",
 StyleBox["the integrability conditions",
  FontColor->RGBColor[0, 0, 1]],
 " (see [B-R] (41.14)):"
}], "Text",
 CellChangeTimes->{{3.5868715874843645`*^9, 3.5868718438864145`*^9}, {
  3.5868718815136805`*^9, 3.5868721317693205`*^9}, {3.5868721625013742`*^9, 
  3.586872176073398*^9}, {3.5868722337713647`*^9, 3.5868725303553286`*^9}, {
  3.5868731941242933`*^9, 3.5868732558838263`*^9}, {3.586956213834609*^9, 
  3.5869562430378604`*^9}, {3.609673188706339*^9, 3.6096731893043737`*^9}, {
  3.6178036508950157`*^9, 3.617803683046672*^9}, {3.617803722686342*^9, 
  3.617803723263543*^9}},ExpressionUUID->"3d42e2ba-10a5-4ea0-a05f-\
de970b28585b"],

Cell[BoxData[
 RowBox[{"?", "dd"}]], "Input",
 CellChangeTimes->{{3.615097909507529*^9, 
  3.61509791044353*^9}},ExpressionUUID->"37326151-9fb5-4852-b147-\
283da3c58914"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Sigma]", "[", "1", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Sigma]", "[", "2", "]"}]}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "3", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586872685089178*^9, 3.586872778533523*^9}, 
   3.5868730982448096`*^9},ExpressionUUID->"309a24e1-3b9b-46be-8f20-\
bf9661d936e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Sigma]", "[", "2", "]"}], "]"}], " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "3", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586872802700906*^9, 3.586872836820857*^9}, 
   3.5868730999729085`*^9},ExpressionUUID->"c205c8a8-8e7c-4cfe-bf6c-\
8b617842f021"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"0", " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
     RowBox[{"\[Omega]", "[", "2", "]"}]}], "  ", "-", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "\[Wedge]", 
     RowBox[{"\[Omega]", "[", "1", "]"}]}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.58687286695158*^9, 
  3.5868729460291033`*^9}},ExpressionUUID->"da9c991c-9d77-4456-be6c-\
a3a22852a5ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Omega]", "[", "1", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Omega]", "[", "2", "]"}]}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "3", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868729989181285`*^9, 3.5868730083976707`*^9}, 
   3.5868731054782233`*^9},ExpressionUUID->"086af0da-2f84-473d-ae9c-\
e9c84c22b4ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Omega]", "[", "2", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Omega]", "[", "3", "]"}]}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "1", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868729989181285`*^9, 3.586873060821669*^9}, 
   3.5868731077973557`*^9},ExpressionUUID->"20b061fa-bd72-4536-9e3a-\
1175b35a914f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "[", 
   RowBox[{"\[Omega]", "[", "3", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Omega]", "[", "1", "]"}]}], "\[Wedge]", 
   RowBox[{"\[Omega]", "[", "2", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868729989181285`*^9, 3.5868730307969522`*^9}, {
  3.586873067326041*^9, 
  3.5868731114075623`*^9}},ExpressionUUID->"9e02d3d7-09d8-4370-b049-\
aab9c0049620"],

Cell["\<\
Remember that dd denotes the exterior derivation of a differential form. In \
the next subsections we check these formulas verifying them for the general \
surface \
\>", "Text",
 CellChangeTimes->{{3.5868731271234617`*^9, 3.586873157483198*^9}, {
   3.5868734330679607`*^9, 3.5868734850189323`*^9}, 
   3.6096733558729005`*^9},ExpressionUUID->"1d10034c-0a33-4f4f-b303-\
3cd3ca43fa9f"],

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.586873495594537*^9, 
  3.5868735006288247`*^9}},ExpressionUUID->"9ff7db2e-73c2-4735-b79f-\
52d8a1b9b809"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.5.2. Proof of the First Three Integrability Conditions", \
"Subsubsection",
 CellChangeTimes->{{3.5868735471634865`*^9, 3.5868736064348764`*^9}, {
   3.587272697133854*^9, 3.5872727162779493`*^9}, 3.609673071961662*^9, 
   3.609673856896558*^9, {3.6275418923074813`*^9, 3.6275418948658857`*^9}, 
   3.627542023143312*^9, 3.696574617141037*^9, 3.696575106735902*^9, 
   3.6967390946247396`*^9, 3.696739892257196*^9, 3.707458645590783*^9, 
   3.707458886876192*^9},ExpressionUUID->"403a1f6b-610d-451a-8913-\
1e699dd08de0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.6178040647481422`*^9, 3.6178040701301517`*^9}, 
   3.696061442284789*^9},ExpressionUUID->"0ce1619e-398c-48a3-8320-\
c2361fe3406d"],

Cell[BoxData[
 RowBox[{"?", "dd"}]], "Input",
 CellChangeTimes->{{3.69658004085715*^9, 3.6965800434473*^9}, 
   3.6967391939592648`*^9},ExpressionUUID->"644274d5-74e5-48ad-b002-\
838a915258a6"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"dd", "[", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6965800366874847`*^9, 3.696580105096417*^9}, {
   3.696580155992929*^9, 3.696580163150649*^9}, 3.696602498467387*^9, {
   3.696739342494751*^9, 
   3.696739353529828*^9}},ExpressionUUID->"57f39672-21ee-4c69-ac97-\
838b8d3c4bb2"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "+", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, 3.6096736847557116`*^9, {
   3.6960616494274073`*^9, 3.696061654031486*^9}, 3.696061724100232*^9, {
   3.696739410057803*^9, 
   3.696739446221409*^9}},ExpressionUUID->"47f5c457-2889-4b71-8294-\
2e829d86e30e"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "-", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, {3.5869225150126677`*^9, 
   3.586922546334459*^9}, 3.6096736868738327`*^9, 3.696574797919711*^9, {
   3.696574943006999*^9, 3.696574946738764*^9}, {3.69673946438853*^9, 
   3.696739485236732*^9}},ExpressionUUID->"30af8779-c02b-4ba5-b3c3-\
0e1e9cdf72c4"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], " ", "-", " ", 
   RowBox[{"extprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.586922604102763*^9, 3.5869226717776337`*^9}, {
   3.6096736921791363`*^9, 3.6096736932831993`*^9}, {3.696739657112913*^9, 
   3.696739698443687*^9}, 3.6967397733279448`*^9, {3.69673981043943*^9, 
   3.696739833866859*^9}, {3.707458739405954*^9, 
   3.707458799748007*^9}},ExpressionUUID->"39a86b96-20db-4938-b314-\
268e488e873b"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.5.3. Proof of the Last Three Integrability Conditions", \
"Subsubsection",
 CellChangeTimes->{{3.5868735471634865`*^9, 3.5868736064348764`*^9}, {
   3.5869227233315825`*^9, 3.5869227259707336`*^9}, {3.5872727214142427`*^9, 
   3.5872727254704747`*^9}, 3.6275420292741227`*^9, 3.627543603172095*^9, 
   3.69657511315303*^9, 3.6965795565393257`*^9, 3.696739910609717*^9, 
   3.6967407925651093`*^9, 3.707458894749063*^9, 
   3.707459976682879*^9},ExpressionUUID->"31449abb-39a5-4d33-9915-\
ebb8c9dc8bc2"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dd", "[", 
      RowBox[{
       RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "+", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, {3.586922786729209*^9, 
   3.586922801385047*^9}, 3.609673696218367*^9, {3.6965774490736856`*^9, 
   3.696577478509328*^9}, {3.6965775316886663`*^9, 3.696577540356264*^9}, {
   3.696578570668425*^9, 3.696578575155723*^9}, {3.696578613474476*^9, 
   3.696578634315378*^9}, {3.696739976236548*^9, 3.6967400421240377`*^9}, {
   3.707458947441284*^9, 
   3.707458977225902*^9}},ExpressionUUID->"4ceeb843-4950-4e44-bc93-\
9d8ebca7c9db"],

Cell[TextData[{
 "To confirm this identity ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v.9.0.1  needed 37.996000 s."
}], "Text",
 CellChangeTimes->{{3.696579409075878*^9, 3.6965794816675453`*^9}, 
   3.696740115571507*^9, {3.70745904054714*^9, 3.707459050707531*^9}, {
   3.707459083763472*^9, 3.707459094477701*^9}, 3.707459126979409*^9, {
   3.707459817316455*^9, 
   3.707459819563609*^9}},ExpressionUUID->"37553efb-005b-45a6-ac69-\
bc117b649ae4"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dd", "[", 
      RowBox[{
       RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "+", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, {3.586922786729209*^9, 
   3.586922801385047*^9}, {3.586922842405393*^9, 3.5869228588633347`*^9}, 
   3.6096736984744964`*^9, {3.696577650154325*^9, 3.696577657306892*^9}, 
   3.696577718529784*^9, {3.6965782443260317`*^9, 3.6965782553504553`*^9}, {
   3.69674013287554*^9, 3.696740186634142*^9}, {3.707459157215536*^9, 
   3.7074591812757473`*^9}},ExpressionUUID->"c8e92b65-6ef7-4848-969b-\
21fbe27c9d84"],

Cell["\<\
To confirm this identity Mathematica v.9.0.1  needed 101.916000 s.\
\>", "Text",
 CellChangeTimes->{{3.696579409075878*^9, 3.6965794816675453`*^9}, 
   3.696740115571507*^9, 3.6967405368885193`*^9, 3.707459803454194*^9, 
   3.707459842892269*^9, 
   3.7074599268844357`*^9},ExpressionUUID->"c4ee5276-774e-43e5-8750-\
b6e56a4ca95c"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dd", "[", 
      RowBox[{
       RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Omega]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.586873642464937*^9, 3.586873909904234*^9}, {
   3.586873966567475*^9, 3.5868740303521233`*^9}, {3.586922786729209*^9, 
   3.586922801385047*^9}, {3.586922842405393*^9, 3.586922905792019*^9}, 
   3.609673706290943*^9, {3.696577748921853*^9, 3.696577763674402*^9}, {
   3.696578531964192*^9, 3.696578555395598*^9}, {3.696740613447707*^9, 
   3.696740627343464*^9}, {3.696740662616637*^9, 3.696740713846163*^9}, {
   3.707459870417859*^9, 
   3.707459882449514*^9}},ExpressionUUID->"c77a6327-df41-4a34-ad33-\
269f06401fab"],

Cell["\<\
To confirm this identity Mathematica v.9.0.1 needed 24.724000 s.\
\>", "Text",
 CellChangeTimes->{{3.696579409075878*^9, 3.6965794816675453`*^9}, 
   3.696740115571507*^9, 3.6967407644787807`*^9, {3.707459912189362*^9, 
   3.7074599180196047`*^9}, {3.7074599512199583`*^9, 
   3.707459951989067*^9}},ExpressionUUID->"a01e9387-67d6-430a-9385-\
d7946087795b"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.6. The Local Uniqueness Theorem", "Subsection",
 CellChangeTimes->{{3.586925078299279*^9, 3.5869250892189035`*^9}, {
   3.586956741153708*^9, 3.586956744008871*^9}, {3.58727274251845*^9, 
   3.587272745541623*^9}, 3.609673862642886*^9, 3.6096744232569513`*^9, 
   3.6275436090533047`*^9, 
   3.62763300809087*^9},ExpressionUUID->"cd87d909-2f47-4b4e-8341-\
2bb7e038a732"],

Cell["\<\
The following theorem shows that the coincidence of the local forms implies \
the congruence of the  surfaces, at least locally:\
\>", "Text",
 CellChangeTimes->{{3.586933018513775*^9, 
  3.5869331255938997`*^9}},ExpressionUUID->"79147f62-6a87-4c94-85e6-\
2f2c1d97c6a8"],

Cell[TextData[{
 StyleBox["Theorem",
  FontColor->RGBColor[0, 0, 1]],
 ". Let U be a 2-dimensional smooth, connected manifold and sf, sh: U \
\[LongRightArrow] ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["E", "3"]}], TraditionalForm]],ExpressionUUID->
  "4fadd221-9011-4b19-b943-24439d5570de"],
 " two immersions, i.e. regular surfaces. Assume that on U adapted moving \
frames \n\t{fr[i][u,v]}  =  {fr[i][sf][u,v]]} , {a[i][u,v]]}  = {fr[i][sh] \
[u,v]} \n are defined such that the local structure forms of these frames \
coincide. Then there exists an Euclidean motion g such that the images of the \
immersion are congruent under g:\n \t\t\tsh[u,v] = g(sf[u,v])."
}], "Text",
 CellChangeTimes->{{3.5869251578988323`*^9, 3.5869254337306085`*^9}, {
   3.5869254654274216`*^9, 3.586925472082802*^9}, {3.5869320455321236`*^9, 
   3.586932237993132*^9}, {3.5869322892510633`*^9, 3.5869324135211716`*^9}, {
   3.586932453442455*^9, 3.5869324812730465`*^9}, {3.5869325165130625`*^9, 
   3.5869325244015136`*^9}, {3.5869325595775256`*^9, 3.586932617057813*^9}, {
   3.58693264969768*^9, 3.586932690361006*^9}, {3.586932747721287*^9, 
   3.5869327600729933`*^9}, {3.5869328383714714`*^9, 3.586932856682519*^9}, 
   3.5869335946817303`*^9, 3.586956296499154*^9, 3.586956353798055*^9, {
   3.5869568059534144`*^9, 3.5869568158809824`*^9}, {3.614861850127923*^9, 
   3.6148618502215233`*^9}, {3.6149177828413453`*^9, 3.6149177828881454`*^9}, 
   3.614918908632923*^9, {3.614918984511456*^9, 3.6149189923426695`*^9}, {
   3.6151165748299*^9, 3.615116623223332*^9}, {3.6151166671561446`*^9, 
   3.615116667483745*^9}, 3.615117715287099*^9, {3.696577935527398*^9, 
   3.696577937463399*^9}, {3.696577983470872*^9, 
   3.696577984078948*^9}},ExpressionUUID->"69b666ff-7a4b-4bba-87f9-\
23b0b7a68b11"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". We fix a point  {uo,vo} \[Element] U.  Since the Euclidean group acts \
simply transitively on the set of all orthonormal frames {x, {amf[i]}}  there \
exist a uniquely defined Euclidean motion g such that\n \tsh[uo,vo] =  \
g(sf(uo,vo)),  a[i][uo,vo]]}   = {g(fr[i][uo,vo])}.\n Then the frame { \
{g(fr[i][sf] [u,v]}},i= 0,1,2,3, is an adapted  moving frame of the immersion \
g(sf[u,v]), and since the exterior differentiation permutes with affine \
transformations (constant linear transformations), the local structure  forms \
of the immersions sh and g(sf) coincide too. Now connect the arbitrary point  \
{u,v} \[Element] U and the point  {uo,vo} with a smooth  curve \[Gamma][t]  \
\[Element] U. Let \[Gamma]'[t] denote its tangent vector. Then the moving \
frame  a[i][u,v]]}   = {g(fr[i][u,v])} satisfies along the curve the linear \
system of differential equations defined by the derivation equations:   "
}], "Text",
 CellChangeTimes->{{3.5869332170111284`*^9, 3.5869333239052424`*^9}, {
   3.5869333657456355`*^9, 3.586933515737215*^9}, {3.586933547283019*^9, 
   3.5869336328259115`*^9}, {3.586933666305827*^9, 3.586933708409235*^9}, {
   3.58693374206616*^9, 3.586933749513586*^9}, {3.586933781593421*^9, 
   3.5869338632340903`*^9}, {3.586933899161145*^9, 3.586933919313298*^9}, {
   3.58693394941702*^9, 3.5869341166735864`*^9}, {3.586934188537697*^9, 
   3.586934343241545*^9}, {3.5869344038260107`*^9, 3.586934414377614*^9}, {
   3.5869344666816053`*^9, 3.5869345057538404`*^9}, {3.586934535931566*^9, 
   3.58693461397803*^9}, {3.586934647222932*^9, 3.586934701882058*^9}, {
   3.586934745481552*^9, 3.586934988265438*^9}, {3.586935061969654*^9, 
   3.586935066201896*^9}, {3.5869381562725463`*^9, 3.586938182793063*^9}, 
   3.586956913361558*^9, {3.5872007151327934`*^9, 3.587200734573905*^9}, 
   3.587200779909498*^9, 3.5882493512465467`*^9, {3.6148618504243236`*^9, 
   3.614861850705124*^9}, {3.6149177830753455`*^9, 3.614917783309346*^9}, {
   3.614919002186287*^9, 3.6149190081142974`*^9}, {3.6151167411822543`*^9, 
   3.6151167415098553`*^9}, {3.6151167961591806`*^9, 3.6151168121258764`*^9}, 
   3.6151168598544564`*^9, {3.61511689040298*^9, 3.6151169114786167`*^9}, {
   3.627632759838233*^9, 3.627632780247069*^9}, 3.62763295111657*^9, {
   3.6965780391673183`*^9, 
   3.696578041222514*^9}},ExpressionUUID->"1aea1f5c-4ed6-49d5-9b90-\
c9df754ca833"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"g", 
     RowBox[{"(", "sf", ")"}]}], "]"}], "[", 
   RowBox[{"\[Gamma]", "'"}], "]"}], " ", "\[Equal]", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "1", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"a", "[", "2", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868707506520944`*^9, 3.5868707637405176`*^9}, {
  3.5868708348454423`*^9, 3.586870922985597*^9}, {3.586935121068034*^9, 
  3.586935134571807*^9}, {3.586935166590638*^9, 3.586935170139841*^9}, {
  3.5869352335524683`*^9, 3.586935234159503*^9}, {3.586935284517383*^9, 
  3.586935293012869*^9}, {3.588249351262147*^9, 3.588249351262147*^9}, {
  3.627633302665989*^9, 
  3.6276333310298395`*^9}},ExpressionUUID->"0f1fc921-d268-44b5-9798-\
796641297c26"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"a", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"\[Gamma]", "'"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "2", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "2", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.586870881739125*^9, 3.586871024151775*^9}, {
  3.586935234775538*^9, 3.586935235935604*^9}, {3.5869352988932056`*^9, 
  3.5869353290609307`*^9}, {3.588249351277747*^9, 
  3.588249351277747*^9}},ExpressionUUID->"9667e09f-75bf-4fdb-b65c-\
4328a1d6b1a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"a", "[", "2", "]"}], "]"}], "[", 
   RowBox[{"\[Gamma]", "'"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"a", "[", "1", "]"}]}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "1", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868711037119145`*^9, 3.5868711559408064`*^9}, {
  3.586935236511637*^9, 3.5869352376797037`*^9}, {3.586935304164507*^9, 
  3.5869353410446167`*^9}, {3.588249351277747*^9, 
  3.588249351277747*^9}},ExpressionUUID->"d6cde09b-7953-4639-973c-\
13dcbe98d9dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"a", "[", "3", "]"}], "]"}], "[", 
   RowBox[{"\[Gamma]", "'"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "1", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "2", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"a", "[", "2", "]"}], "*", 
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", 
     RowBox[{"\[Gamma]", "'"}], "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5868712300253363`*^9, 3.5868712863882356`*^9}, {
   3.586935238407746*^9, 3.586935239094785*^9}, {3.586935307740711*^9, 
   3.586935347892008*^9}, {3.588249351277747*^9, 3.588249351277747*^9}, 
   3.6148618507363243`*^9, 3.6149177833249464`*^9, 
   3.6149190547115793`*^9},ExpressionUUID->"02c61507-2cff-4117-bdab-\
d68886dd373e"],

Cell["\<\
The moving frame  {sh[\[Gamma][t]], {amf[i][sh] [\[Gamma][t]]}} satisfies the \
same system of differential equations since the local structure forms \
coincide. Since the solutions are uniquely defined by the same  initial \
conditions at the point {uo,vo}, the solution coincide for all t, in \
particular we have 
sh[u,v] = g(sf[u,v]). QED.\
\>", "Text",
 CellChangeTimes->{{3.5869354369941044`*^9, 3.5869354442895217`*^9}, {
   3.58693550440296*^9, 3.5869355558179007`*^9}, {3.5869378853850527`*^9, 
   3.5869381324961863`*^9}, 3.586938166736145*^9, {3.5869381971368837`*^9, 
   3.586938204552308*^9}, {3.586956962889391*^9, 3.586957003976741*^9}, 
   3.586957622721131*^9, {3.5992328267612457`*^9, 3.5992328273532796`*^9}, 
   3.614861850767524*^9, 3.614917783356146*^9, 3.614919070732807*^9, {
   3.6178048719871607`*^9, 3.6178048748419657`*^9}, {3.627632896774674*^9, 
   3.627632918525112*^9}},ExpressionUUID->"2a5d71c6-f527-4c15-833a-\
fc615f0cf48f"],

Cell[TextData[{
 StyleBox["A technical hint",
  FontColor->RGBColor[0, 0, 1]],
 ". The notation"
}], "Text",
 CellChangeTimes->{{3.5882281307953806`*^9, 
  3.588228173978851*^9}},ExpressionUUID->"e0cc2083-16b6-4516-88fe-\
577b2892a0d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p\.b4", "[", "v", "]"}], "-", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"p", "[", "v", "]"}], ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5882279420925875`*^9, 3.588227998653823*^9}, {
   3.58822803602296*^9, 3.588228040750231*^9}, {3.5882281856145163`*^9, 
   3.5882281962061224`*^9}, 3.58822826364598*^9, {3.5882283076694975`*^9, 
   3.5882283390942945`*^9}, {3.588249511474428*^9, 3.5882495126600304`*^9}, {
   3.5882498746829853`*^9, 3.5882498819464006`*^9}, {3.5883161677869563`*^9, 
   3.588316178531571*^9}},ExpressionUUID->"e13bf9be-977e-4aae-9139-\
11ef51611fd0"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6151170140388913`*^9, 
  3.6151170222756543`*^9}},ExpressionUUID->"26331f13-95fa-4c8f-9439-\
9c171665f6be"],

Cell["can\[CloseCurlyQuote]t be used for denoting a derivation. Use  \
\[OpenCurlyQuote] instead:", "Text",
 CellChangeTimes->{{3.5882495550609045`*^9, 3.5882496043257914`*^9}, 
   3.5882496943756723`*^9},ExpressionUUID->"ed0448e7-430f-4a1f-b32a-\
9c227dbaa160"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"p", "'"}], "[", "v", "]"}], "-", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"p", "[", "v", "]"}], ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5882279420925875`*^9, 3.588227998653823*^9}, {
   3.58822803602296*^9, 3.588228040750231*^9}, {3.5882281856145163`*^9, 
   3.5882281962061224`*^9}, 3.58822826364598*^9, {3.5882283076694975`*^9, 
   3.5882283390942945`*^9}, {3.588249511474428*^9, 3.5882495126600304`*^9}, {
   3.588249718586057*^9, 3.5882497197461233`*^9}, {3.588249896938258*^9, 
   3.5882499049297156`*^9}, {3.5882506904956474`*^9, 
   3.5882507097617493`*^9}},ExpressionUUID->"de755044-b8b2-4fb7-b568-\
3c7d6a68674a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"p", "''"}], "[", "v", "]"}], "-", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"p", "[", "v", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5882279420925875`*^9, 3.588227998653823*^9}, {
   3.58822803602296*^9, 3.588228040750231*^9}, {3.5882281856145163`*^9, 
   3.5882281962061224`*^9}, 3.58822826364598*^9, {3.5882283076694975`*^9, 
   3.5882283390942945`*^9}, {3.588249511474428*^9, 3.5882495126600304`*^9}, {
   3.588249718586057*^9, 3.5882497197461233`*^9}, {3.588249896938258*^9, 
   3.5882499049297156`*^9}},ExpressionUUID->"f06006ba-9b75-4e7a-85ad-\
9abf8368500a"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Spherical Image and Gaussian Curvature", "Section",
 CellChangeTimes->{{3.587201424502367*^9, 3.5872014450525427`*^9}, {
   3.587272807823185*^9, 3.587272810622345*^9}, 3.615117108938384*^9, 
   3.615196425961876*^9, 3.6178038595453825`*^9, 3.617860550133771*^9, {
   3.696742247521402*^9, 3.696742253281556*^9}, {3.697175352147081*^9, 
   3.697175355026701*^9}, 
   3.697210612415804*^9},ExpressionUUID->"8165a65b-da93-4bd3-a36c-\
e8f3836dd76a"],

Cell[CellGroupData[{

Cell["2.1. The Gauss Map", "Subsection",
 CellChangeTimes->{{3.5872730558623724`*^9, 3.58727307645455*^9}, {
  3.5885090107494955`*^9, 
  3.5885090141486893`*^9}},ExpressionUUID->"9920cbf1-e07b-43ad-8ac5-\
407583d118ee"],

Cell[CellGroupData[{

Cell["2.1.1. Orientation and Spherical Image", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, {3.587273125318345*^9, 3.5872731524058943`*^9}, 
   3.609674435089628*^9, 3.609674810368093*^9, 3.627633117149062*^9, 
   3.6276338957264566`*^9, 3.696579594579175*^9, 3.6966913401917067`*^9, 
   3.696740804534132*^9, {3.6967445835349483`*^9, 3.6967445869506693`*^9}, 
   3.707459986475709*^9, 
   3.707460580423995*^9},ExpressionUUID->"e501a131-cafc-4ffe-a5aa-\
cc7e92b6dbec"],

Cell[TextData[{
 "We consider the ",
 StyleBox["normal unit vector",
  FontColor->RGBColor[0, 0, 1]],
 " amf[3][sf][u,v] of the surface. Belonging to the orthogonal complement of \
the tangent plane  it is uniquely defined up to  sign by the surface. A \
choice of the normal vector is equivalent to define an ",
 StyleBox["orientation of the tangent plane",
  FontColor->RGBColor[0, 0, 1]],
 " at the point sf[u,v]: a pair of linearly independent tangent vectors \
{tu,tv} is said to be positively oriented if the triple {tu, tv, \
amf[3][sf][u,v]} is positively oriented, what means \n\
Det[{tu,tv,amf[3][sf][u,v]}]>0. The surface is said to be ",
 StyleBox["orientable",
  FontColor->RGBColor[0, 0, 1]],
 ", if there exists a continuous unit normal vector field defined globally, \
i.e. for all of its points. Locally, on a parameter region U,  any surface is \
orientable. Since almost all our considerations are of a local character we \
may assume that an ",
 StyleBox["oriented surface",
  FontColor->RGBColor[0, 0, 1]],
 " is given, where the orientation is defined by the choice of the normal \
vector field. The map"
}], "Text",
 CellChangeTimes->{{3.5872016123241096`*^9, 3.587201709836687*^9}, {
   3.587201928221178*^9, 3.5872020310770607`*^9}, {3.5872020625648623`*^9, 
   3.587202289884864*^9}, {3.587202330429183*^9, 3.587202334956442*^9}, {
   3.5872023682943487`*^9, 3.5872024447247205`*^9}, {3.587202514020684*^9, 
   3.587202534012827*^9}, 3.5872033283652616`*^9, {3.587203382236343*^9, 
   3.5872035072444925`*^9}, {3.5872036682127*^9, 3.58720378221322*^9}, {
   3.5872038187973127`*^9, 3.5872038959167233`*^9}, {3.587203950612852*^9, 
   3.5872039793004932`*^9}, {3.5872733423347573`*^9, 3.5872733493661594`*^9}, 
   3.5882544812004633`*^9, {3.6148618508767242`*^9, 3.6148618510327244`*^9}, {
   3.614917783449746*^9, 3.6149177835589466`*^9}, {3.6149194945075517`*^9, 
   3.614919498859959*^9}, 3.615180003675227*^9, 3.615263631108482*^9, {
   3.696742000470536*^9, 
   3.696742070067545*^9}},ExpressionUUID->"50ca4d36-385e-4665-8985-\
a4ecf0f5c519"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sph", "[", "sf", "]"}], ":", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}], " ", "\[Element]", " ", 
    RowBox[{"U", " ", "\[RightTeeArrow]", 
     RowBox[{
      RowBox[{"sph", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Element]", " ", 
   SuperscriptBox["S", "2"]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5872734225673466`*^9, 3.5872734983276796`*^9}, {
   3.5872735378889427`*^9, 3.5872735984794083`*^9}, 3.614861851063925*^9, 
   3.614917783574547*^9, 3.6149195004823623`*^9},
 TextAlignment->Center,ExpressionUUID->"ac978075-cdff-4e70-9b44-b2bbf9f124b0"],

Cell[TextData[{
 " is named the ",
 StyleBox["Gauss map",
  FontColor->RGBColor[0, 0, 1]],
 " and  its range the ",
 StyleBox["spherical image",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface. The range is a part of the unit sphere; eidetic, the range \
 becomes larger if the surface crooks more. As a first example we show:"
}], "Text",
 CellChangeTimes->{{3.587273389727468*^9, 3.5872734079835124`*^9}, {
   3.5872737091427374`*^9, 3.5872737288618655`*^9}, 3.587273759398612*^9, {
   3.5872738016460285`*^9, 3.5872738019420457`*^9}, {3.5872744723103886`*^9, 
   3.5872744980938635`*^9}, {3.587274591870227*^9, 3.5872747256548786`*^9}, 
   3.587274844822695*^9, {3.5872748751184273`*^9, 3.587274896542653*^9}, {
   3.5885089495569954`*^9, 3.588508967285009*^9}, {3.588563973357298*^9, 
   3.588564070217868*^9}, 3.6152638209419174`*^9, {3.6178603571017303`*^9, 
   3.617860398341089*^9}, {3.6276334991839356`*^9, 
   3.627633522396776*^9}},ExpressionUUID->"9e6f3136-5395-49a7-b2e2-\
e74f5643455c"],

Cell[TextData[{
 StyleBox["Lemma 1.",
  FontColor->RGBColor[0, 0, 1]],
 "  The connected, oriented surface sf[u,v] is a part of a plane iff its \
spherical image consists of a single point only, and this is the case iff the \
local structure forms \[Omega][1][sf] and \[Omega][2][sf] are null forms."
}], "Text",
 CellChangeTimes->{{3.5872749116795187`*^9, 3.58727492778244*^9}, {
   3.5872756902220488`*^9, 3.587275723389946*^9}, {3.587275757518898*^9, 
   3.587275826734857*^9}, {3.587276885118393*^9, 3.5872770007990093`*^9}, 
   3.587278493639395*^9, {3.696742221897702*^9, 3.6967422231622562`*^9}},
 CellTags->"lem2.1.1",ExpressionUUID->"52cd7c6c-5159-46e7-907b-111e15782e55"],

Cell[TextData[{
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " If the surface is a plane, we may choose a constant orthonormal frame"
}], "Text",
 CellChangeTimes->{{3.5872758457349434`*^9, 
  3.587276064721469*^9}},ExpressionUUID->"b009babb-6c75-4b38-ae02-\
35e471982e82"],

Cell[" {amf[i][sf][uv]} =  {amf[i]}  =  const, ", "Text",
 CellChangeTimes->{{3.5872758457349434`*^9, 3.587276112414197*^9}, {
  3.614861851079525*^9, 3.6148618511263247`*^9}, {3.6149177835901465`*^9, 
  3.6149177836057463`*^9}, {3.6149195029939666`*^9, 
  3.614919505521171*^9}},ExpressionUUID->"c53c0638-de34-4fd6-bc2e-\
62739b7d88c5"],

Cell["\<\
and then the spherical image consists of the point amf[3] only. Conversely, \
assume that this is the case. Then the last derivation equation is\
\>", "Text",
 CellChangeTimes->{{3.5872758457349434`*^9, 3.587276075154066*^9}, {
   3.587276129198157*^9, 3.5872761676863585`*^9}, 3.587276210702819*^9, {
   3.587276689094181*^9, 3.58727670428605*^9}, 3.609674694729479*^9, 
   3.614861851173125*^9, 3.6149177836369467`*^9, 
   3.614919510154379*^9},ExpressionUUID->"540d3ab2-5df7-4c76-a9a0-\
6cffe786799a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"amf", "[", "3", "]"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "1", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "2", "]"}]}], " ", "-", "  ", 
   RowBox[{
    RowBox[{"amf", "[", "2", "]"}], "*", 
    RowBox[{"\[Omega]", "[", "1", "]"}]}]}], " ", "\[Equal]", " ", 
  "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.587276222756508*^9, 3.587276254568328*^9}, {
  3.5872766188021607`*^9, 3.587276647768818*^9}, {3.6148618511887245`*^9, 
  3.6148618512043247`*^9}, {3.6149177836369467`*^9, 3.614917783652547*^9}, {
  3.614919511620782*^9, 
  3.614919514491187*^9}},ExpressionUUID->"a555550b-64f2-40d4-a3fe-\
ea1f9f62cf6d"],

Cell["\<\
what means that the structure forms \[Omega][1][sf] and \[Omega][2][sf] are \
zero. We may assume that the constant normal vector amf[3][sf][u,v])==stb[3] \
is the third standard basis vector and the point sf[u0,v0] the origin of the \
space, the
tangent plane at this point is the the coordinate (x[1],x[2])-plane. Consider \
a smooth curve \[Gamma][t] \[Epsilon] U with  starting at {u0,v0}. Then the \
third component of the corresponding curve sf[\[Gamma][t]] is\
\>", "Text",
 CellChangeTimes->{{3.5872768218717756`*^9, 3.5872768696945105`*^9}, {
   3.587277024326355*^9, 3.5872770369180756`*^9}, {3.587277075214266*^9, 
   3.5872771185187426`*^9}, {3.5872771569349403`*^9, 3.587277405814175*^9}, 
   3.587277488806922*^9, 3.588564173458849*^9, 3.6148618513291254`*^9, 
   3.6149177837773466`*^9, 3.6149195159887896`*^9, {3.696742738262228*^9, 
   3.6967427545661488`*^9}, {3.696742787213621*^9, 3.6967428090371513`*^9}, {
   3.696742866444928*^9, 3.6967429173639507`*^9}, {3.696743817229321*^9, 
   3.696743898372465*^9}, {3.696743929276594*^9, 3.6967440492986813`*^9}, {
   3.696744091355075*^9, 3.6967441210268803`*^9}, {3.6967441559870234`*^9, 
   3.696744175497531*^9}, {3.696744207858656*^9, 3.696744224369549*^9}, 
   3.696744260049333*^9, {3.696744336584738*^9, 3.6967443547208014`*^9}, {
   3.696744389168148*^9, 
   3.696744413936363*^9}},ExpressionUUID->"2a1a64ec-0c01-4ace-802c-\
9e21b4fd3642"],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", "t", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"amf", "[", "3", "]"}], ".", 
   RowBox[{"sf", "[", 
    RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5872774239342117`*^9, 3.5872774471485395`*^9}, {
   3.587277494258234*^9, 3.5872774972324038`*^9}, 3.587277620992483*^9, 
   3.614861851344725*^9, 3.6149177837773466`*^9, 
   3.614919517252392*^9},ExpressionUUID->"bceadbf0-8716-487c-9482-\
573c6eeb4142"],

Cell["It suffices", "Text",
 CellChangeTimes->{{3.5872775523315554`*^9, 3.587277562951163*^9}, {
  3.696744471102983*^9, 
  3.6967444723909616`*^9}},ExpressionUUID->"64ce7a14-7b8b-44bd-9ab2-\
1fb3b84d751b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", "0", "]"}], " ", "=", " ", "0"}], ",", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "'"}], "[", "t", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", "sf", "]"}], "[", 
       RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], "]"}]}], "\[Equal]", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], ".", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
          RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "*", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", 
          RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
          RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}], "*", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", 
          RowBox[{"\[Gamma]", "[", "t", "]"}], "]"}]}]}], ")"}], "[", 
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], "]"}]}], " ", "\[Equal]", 
    " ", "0"}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.587277570849615*^9, 3.587277746249647*^9}, {
   3.587277786936974*^9, 3.587278019964302*^9}, {3.588249351308947*^9, 
   3.588249351308947*^9}, 3.5885643651051855`*^9, {3.614861851360325*^9, 
   3.614861851360325*^9}, {3.614917783792947*^9, 3.614917783808547*^9}, {
   3.614919518219593*^9, 3.6149195227748013`*^9}, 3.6178605131526556`*^9, {
   3.6967445109524097`*^9, 
   3.69674451463227*^9}},ExpressionUUID->"127b1710-fa50-47cc-9752-\
7217b20a039c"],

Cell["\<\
h[t] is the constant 0.  Thus the curve, and especially the arbitrary points \
sf[\[Gamma][t]],  belong to the (x[1],x[2])-plane, the surface must be a part \
of it. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.587278097846757*^9, 3.5872782393828526`*^9}, {
  3.587278271978717*^9, 3.5872782972861643`*^9}, {3.5872783359033732`*^9, 
  3.587278410622647*^9}, {3.6151804251099677`*^9, 
  3.6151804335027823`*^9}},ExpressionUUID->"608e76b0-5032-4a19-8973-\
6aca6f177f5d"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.2. Ruled Surfaces", "Subsubsection",
 CellChangeTimes->{{3.587278731126979*^9, 3.5872787512791314`*^9}, {
   3.587278983598419*^9, 3.5872789947820587`*^9}, 3.609674817385494*^9, 
   3.6096757163849144`*^9, 3.6097331138408127`*^9, 3.6178605575971975`*^9, 
   3.617889654026325*^9, 3.627633901248866*^9, 3.627713371971609*^9, {
   3.696744593255096*^9, 3.696744596062244*^9}, 3.696753233152919*^9, 
   3.707460585928196*^9, 
   3.707467825759379*^9},ExpressionUUID->"ef16d79e-0471-4be3-8373-\
bb5cd1597da8"],

Cell[TextData[{
 "A ",
 StyleBox["ruled surface",
  FontColor->RGBColor[0, 0, 1]],
 " is defined as a surface generated by a 1-parametric family  of  lines in \
the space:"
}], "Text",
 CellChangeTimes->{{3.5872798729672885`*^9, 3.587279932870714*^9}, {
   3.5872915077116566`*^9, 3.587291508071677*^9}, {3.587291538183399*^9, 
   3.5872915904473886`*^9}, {3.588140984931316*^9, 3.5881409909841266`*^9}, 
   3.6097331232008295`*^9},ExpressionUUID->"a73ae35a-e936-451d-bc33-\
3733b7e8157b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ruled", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"x", "[", "v", "]"}], ",", "3"}], "]"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], "*", " ", "u"}]}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5872799484616065`*^9, 3.5872801346102533`*^9}, {
  3.6967460475995398`*^9, 3.6967460687629957`*^9}, {3.6967461458632803`*^9, 
  3.696746174763009*^9}},ExpressionUUID->"9fd727de-1c72-4bfe-b92c-\
64c3e54c4de6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruled", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5872801382974644`*^9, 
  3.587280151312209*^9}},ExpressionUUID->"8db182e1-0785-42a2-aa59-\
0e782a8b97bb"],

Cell[TextData[{
 "The curve ruled[x,y][0,v] == vec[x[v,3]] is the so called ",
 StyleBox["directrix",
  FontColor->RGBColor[0, 0, 1]],
 " of the ruled surface; its lines are named the ",
 StyleBox["rulings",
  FontColor->RGBColor[0, 0, 1]],
 " or the ",
 StyleBox["generators",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface."
}], "Text",
 CellChangeTimes->{{3.5872912912692766`*^9, 3.587291449687338*^9}, {
   3.6151807423774195`*^9, 3.615180771745099*^9}, {3.6151808356567545`*^9, 
   3.6151808665295205`*^9}, {3.6151853507540035`*^9, 
   3.6151853884411592`*^9}, {3.6178620539173813`*^9, 3.6178620744445553`*^9}, 
   3.6178621047092867`*^9, {3.696746218073269*^9, 
   3.6967462198255663`*^9}},ExpressionUUID->"a907eb54-f30a-4ed7-a363-\
5aa4265cc075"],

Cell[TextData[{
 StyleBox["Example 1.",
  FontColor->RGBColor[0, 0, 1]],
 " Pl\[UDoubleDot]cker's conoid"
}], "Text",
 CellChangeTimes->{{3.6178621217502613`*^9, 3.6178621217502613`*^9}, 
   3.6178621590303936`*^9, {3.617862243166206*^9, 3.6178622692116957`*^9}, 
   3.6178890558120747`*^9, {3.696746464031117*^9, 
   3.69674646573501*^9}},ExpressionUUID->"124dc096-7994-4794-8e3e-\
a95803503bb2"],

Cell[TextData[{
 "See Pl\[UDoubleDot]cker\[CloseCurlyQuote]s conoid in ",
 Cell[BoxData[
  FormBox[
   ButtonBox["MathWorld",
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["http://mathworld.wolfram.com/RuledSurface.html"], None},
    ButtonNote->"http://mathworld.wolfram.com/RuledSurface.html"], 
   TraditionalForm]],ExpressionUUID->"30db303a-5666-462a-9087-7d64cde8b02e"],
 ". Here one finds the following parameter representation:"
}], "Text",
 CellChangeTimes->{{3.617864676993413*^9, 3.6178646913572345`*^9}, {
  3.617864747428441*^9, 3.617864779605282*^9}, {3.6178648119571323`*^9, 
  3.617864811959132*^9}, {3.6178649148010144`*^9, 3.6178649148050146`*^9}, {
  3.617871561964284*^9, 
  3.617871589563862*^9}},ExpressionUUID->"6de376b9-7f68-44f7-8817-\
c2e49e9f743f"],

Cell[BoxData[
 RowBox[{"?", "pluckerconoid"}]], "Input",
 CellChangeTimes->{{3.627635830615226*^9, 
  3.6276358374012375`*^9}},ExpressionUUID->"2ecfd4cd-af9a-414f-b0c0-\
8aac9fef2bc8"],

Cell[BoxData[
 RowBox[{"Context", "[", "pluckerconoid", "\[NoBreak]", "]"}]], "Input",
 CellChangeTimes->{{3.6276342521178365`*^9, 
  3.627634274102275*^9}},ExpressionUUID->"e2cc0750-eef0-4b93-b44f-\
05ecf6ca244f"],

Cell[BoxData[
 RowBox[{"pluckerconoid", "\[NoBreak]", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.627634622301491*^9, 
  3.6276346261546974`*^9}},ExpressionUUID->"efc89913-e6be-4288-a8d5-\
055c7f65fac0"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"pluckerconoid", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178629384309726`*^9, 3.6178630199276342`*^9}, 
   3.6178631166731677`*^9, 3.696747391275351*^9, {3.696747422093665*^9, 
   3.696747439765142*^9}, 3.696749949833199*^9, {3.696750016503871*^9, 
   3.6967500190116367`*^9}},ExpressionUUID->"4e56c838-71b2-4980-bced-\
b502b903ea19"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plue", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.627710413806487*^9, 
  3.6277104211540995`*^9}},ExpressionUUID->"25b83752-2ed7-44ac-96a8-\
34d48d4c64a6"],

Cell["In Alfred Gray\[CloseCurlyQuote]s collection SURF.m of surfaces we \
find", "Text",
 CellChangeTimes->{{3.6178716140272617`*^9, 3.617871654019549*^9}, {
  3.6276361523764563`*^9, 
  3.6276361548724604`*^9}},ExpressionUUID->"4315f6f5-613b-43d7-8a1d-\
8687a6faca2e"],

Cell[BoxData[
 RowBox[{"?", "plucker"}]], "Input",
 CellChangeTimes->{{3.6178651419460063`*^9, 
  3.61786514672528*^9}},ExpressionUUID->"5055769c-ed97-407b-b9f7-\
70b21a95e939"],

Cell[BoxData[
 RowBox[{"plucker", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 
  3.617863203720146*^9}},ExpressionUUID->"5322748e-15fa-4476-b37a-\
2fd1a1ee916d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plucker", "[", "n", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 3.617863203720146*^9}, {
  3.617865251261259*^9, 
  3.617865266631138*^9}},ExpressionUUID->"77498715-2517-48fe-82b5-\
94d0489aeb9f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plucker", "[", 
   RowBox[{"m", ",", "n", ",", "a"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 3.617863203720146*^9}, {
  3.617865251261259*^9, 3.617865266631138*^9}, {3.6178653096295977`*^9, 
  3.617865327110597*^9}},ExpressionUUID->"9aeb4ae5-470a-4fa8-ad8b-\
2dd0f8d21495"],

Cell[TextData[{
 "The parameter transformation u ->  ",
 Cell[BoxData[
  RowBox[{"u", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["v", "2"]}]]}]],
  CellChangeTimes->{3.6178655826392126`*^9, 3.617865915217235*^9},
  ExpressionUUID->"9cbd6156-81a0-4d90-9609-c06f64092f73"],
 ", v-> u*v, leads to another representation:"
}], "Text",
 CellChangeTimes->{{3.617871698939118*^9, 
  3.617871791051387*^9}},ExpressionUUID->"fb9d9643-a372-4ca1-b29e-\
712d12253d66"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"plucker", "[", 
    RowBox[{
     RowBox[{"u", "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"v", "^", "2"}]}], "]"}]}], ",", 
     RowBox[{"u", "*", "v"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", "Reals"}], ",", 
     RowBox[{
      RowBox[{"-", "1"}], "<", "v"}], ",", 
     RowBox[{"v", "<", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 3.617863203720146*^9}, {
  3.617865251261259*^9, 3.617865266631138*^9}, {3.6178653096295977`*^9, 
  3.617865327110597*^9}, {3.617865529005145*^9, 3.6178655743677397`*^9}, {
  3.617865892209919*^9, 
  3.6178659117370358`*^9}},ExpressionUUID->"ba1e398f-bbad-4d1b-aed4-\
010ea2415f0e"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"u", "*", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"v", "^", "2"}]}], "]"}], ",", "v", ",", "0"}], "}"}]}], " ", 
   "+", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"2", "v", "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"v", "^", "2"}]}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6276363173319473`*^9, 
  3.6276364753580265`*^9}},ExpressionUUID->"aae0a66b-bff7-4dc9-8cd7-\
cce421f6a334"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["v", "2"]}]]}], ",", 
     RowBox[{"u", " ", "v"}], ",", 
     RowBox[{"2", " ", "v", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["v", "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178656197713366`*^9, 3.6178657398552046`*^9}, {
  3.6178659266398883`*^9, 3.617866004487341*^9}, {3.617866533208582*^9, 
  3.6178665589580545`*^9}, {3.627704276657631*^9, 
  3.6277042993088703`*^9}},ExpressionUUID->"98eb5e1a-cde2-47ce-ba4a-\
9b09b970a92a"],

Cell["Sometimes this is replaced by", "Text",
 CellChangeTimes->{{3.6178718182349415`*^9, 
  3.617871829883608*^9}},ExpressionUUID->"fac63950-f404-4a20-a154-\
1a81467d11d2"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["v", "2"]}]]}], ",", 
     RowBox[{"u", " ", "v"}], ",", 
     RowBox[{"1", "-", 
      RowBox[{"v", "^", "2"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178656197713366`*^9, 3.6178657398552046`*^9}, {
  3.6178659266398883`*^9, 3.617866004487341*^9}, {3.6178662201736774`*^9, 
  3.6178662267100515`*^9}, {3.6178662869614973`*^9, 3.6178663606737137`*^9}, {
  3.627704398010244*^9, 
  3.62770440127065*^9}},ExpressionUUID->"0cf8942e-f454-4fba-8064-\
a85b141351e5"],

Cell["\<\
The parameter transformation u -> u*Cos[v], v -> u*Sin[v] leads to the first \
representation \
\>", "Text",
 CellChangeTimes->{{3.6178718556990843`*^9, 3.6178719641712885`*^9}, {
  3.627636615209074*^9, 
  3.627636617517878*^9}},ExpressionUUID->"351f6804-e668-4367-88a8-\
e34b19ea2ea5"],

Cell[BoxData[
 RowBox[{"plucker", "[", 
  RowBox[{
   RowBox[{"u", "*", 
    RowBox[{"Cos", "[", "v", "]"}]}], ",", 
   RowBox[{"u", "*", 
    RowBox[{"Sin", "[", "v", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178631833399806`*^9, 3.617863203720146*^9}, {
  3.6178633404619675`*^9, 3.6178633596330643`*^9}, {3.617863499920088*^9, 
  3.6178635314698925`*^9}, {3.6178642016802263`*^9, 
  3.6178642248475513`*^9}},ExpressionUUID->"0cbf4232-d93a-4276-94b4-\
ade51561f28b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"u", "\[Element]", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6178642461317687`*^9, 
  3.6178642963036385`*^9}},ExpressionUUID->"77034e04-3247-4fa8-a9c2-\
3f2a98b841e7"],

Cell[BoxData[
 RowBox[{"pluckerconoid", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6178719880536547`*^9, 
  3.6178720015174246`*^9}},ExpressionUUID->"fe9a18b9-ec06-48eb-9ef8-\
0d331575ce83"],

Cell["We will find the singularities of \
Pl\[UDoubleDot]cker\[CloseCurlyQuote]s conoid:", "Text",
 CellChangeTimes->{{3.6277045326072807`*^9, 
  3.6277045719817495`*^9}},ExpressionUUID->"59d36a20-81bf-4b3f-8584-\
69e85c38a3b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "pluckerconoid", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.62763666404416*^9, 
  3.627636689369005*^9}},ExpressionUUID->"959b21c8-91d9-4e35-9082-\
ae6acfe1b5fe"],

Cell["In general, almost all of the points are regular:", "Text",
 CellChangeTimes->{{3.6277054595765085`*^9, 
  3.627705484240152*^9}},ExpressionUUID->"791e842b-90b2-4618-bca3-\
669fc41e64cb"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{
   RowBox[{"d", "[", "pluckerconoid", "]"}], "[", 
   RowBox[{"u", ",", 
    RowBox[{"Pi", "/", "4"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.627636783220171*^9, 3.6276368132864237`*^9}, {
  3.6276369338332367`*^9, 
  3.627636937501243*^9}},ExpressionUUID->"6832af88-e610-4c82-be0a-\
6c8ab039e3c4"],

Cell["but there exist singularities, e.g. ", "Text",
 CellChangeTimes->{{3.6277054904021626`*^9, 
  3.6277055388090477`*^9}},ExpressionUUID->"8a4d1255-15e2-4e2d-a9b2-\
275643e4e872"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{
   RowBox[{"d", "[", "pluckerconoid", "]"}], "[", 
   RowBox[{"0", ",", 
    RowBox[{"Pi", "/", "4"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.627636783220171*^9, 3.6276368420256743`*^9}, {
  3.6276369624642873`*^9, 
  3.6276369687686987`*^9}},ExpressionUUID->"4a9b8a44-3be0-49a4-8dd3-\
51f69806d594"],

Cell["\<\
All singularities of Pl\[UDoubleDot]cker\[CloseCurlyQuote]s conoid can be \
found as the solutions of\
\>", "Text",
 CellChangeTimes->{{3.6276391377005286`*^9, 3.6276391796072025`*^9}, {
  3.6277045172412534`*^9, 
  3.6277045185048556`*^9}},ExpressionUUID->"b1b07da9-a72d-40c9-b475-\
e4e2c0c902c5"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Cross", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"pluckerconoid", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], ",", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"pluckerconoid", "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}], "]"}], 
    "\[Equal]", " ", 
    RowBox[{"null", "[", "3", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.6276377756515236`*^9, 3.6276377974507623`*^9}, {
   3.6276378401384373`*^9, 3.6276378469888496`*^9}, {3.627637964227457*^9, 
   3.627638125448541*^9}, 
   3.69674698257545*^9},ExpressionUUID->"848a522b-df3d-4900-9ef5-\
3df6f87ac2df"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"1", "+", 
      SqrtBox["2"]}], "]"}]}], "-", 
   RowBox[{"3", "*", 
    RowBox[{"Pi", "/", "4"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6276383924558125`*^9, 3.6276384450203056`*^9}, {
   3.6276384817643704`*^9, 3.62763852707485*^9}, 3.6276385653955183`*^9, 
   3.6276386286188297`*^9, {3.6276386919619417`*^9, 
   3.627638698313153*^9}},ExpressionUUID->"ac464e83-a492-4415-9109-\
a8dbfaf05591"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"1", "-", 
      SqrtBox["2"]}], "]"}]}], "+", 
   RowBox[{"Pi", "/", "4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6276383924558125`*^9, 3.6276384450203056`*^9}, {
   3.6276384817643704`*^9, 3.62763852707485*^9}, 3.6276385653955183`*^9, {
   3.6276386286188297`*^9, 3.6276386594786844`*^9}, {3.627638735166418*^9, 
   3.6276387382552233`*^9}, {3.6276387696640787`*^9, 3.627638778776495*^9}, {
   3.6276389958878784`*^9, 
   3.627639012769108*^9}},ExpressionUUID->"940d6d4e-bacb-48d4-b08d-\
8ca5d5fcd039"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"pluckerconoid", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], ",", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"pluckerconoid", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", "0"}], ",", 
    RowBox[{"v", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"RandomInteger", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "100"}], ",", "100"}], "}"}], "]"}]}], "+", "1"}], 
       ")"}], "*", 
      RowBox[{"Pi", "/", "4"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.627638272456001*^9, 3.6276382915076346`*^9}, {
   3.6276392224664783`*^9, 3.627639225290083*^9}, 3.627639256933939*^9, {
   3.6276392956114073`*^9, 3.6276393412504883`*^9}, {3.6276393727353435`*^9, 
   3.6276393851569653`*^9}},ExpressionUUID->"7eab40ae-060f-4657-987b-\
4294cfc69b91"],

Cell["Here is the self intersection set of the surface", "Text",
 CellChangeTimes->{{3.627711158021394*^9, 3.627711189299449*^9}, {
  3.627711637584737*^9, 
  3.627711661563979*^9}},ExpressionUUID->"f1495331-84cb-4ac0-9989-\
6cc559ff9a0f"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"pluckerconoid", "[", 
    RowBox[{"0", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6277104558797607`*^9, 
  3.6277105779811754`*^9}},ExpressionUUID->"438f4680-8c82-422c-a299-\
f4cf94557597"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plz", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6277106014904165`*^9, 
  3.6277106082452283`*^9}},ExpressionUUID->"3fd6fffb-dc81-49f0-9562-\
de025d549c7d"],

Cell["and here the singular points", "Text",
 CellChangeTimes->{{3.6277116754324036`*^9, 
  3.627711692828434*^9}},ExpressionUUID->"1cefde43-b3fa-4248-bf19-\
48e3e52ecbf2"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PointSize", "[", "Large", "]"}], ",", 
     RowBox[{"Point", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"pluckerconoid", "[", 
         RowBox[{"0", ",", 
          RowBox[{"Pi", "/", "4"}]}], "]"}], ",", 
        RowBox[{"pluckerconoid", "[", 
         RowBox[{"0", ",", 
          RowBox[{"3", "*", 
           RowBox[{"Pi", "/", "4"}]}]}], "]"}]}], "}"}], "]"}]}], "}"}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6277106381816807`*^9, 3.6277106719557405`*^9}, {
  3.6277107148246155`*^9, 3.627710787973144*^9}, {3.627710976249875*^9, 
  3.627711010975536*^9}},ExpressionUUID->"f207c050-7af3-4c97-aa86-\
197a79fd0840"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plupts", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.627711020179552*^9, 
  3.6277110358731794`*^9}},ExpressionUUID->"3670463b-2d09-45ca-b0d2-\
c67e1bbda455"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"plue", ",", "plz", ",", "plupts"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.627711044203594*^9, 
  3.6277111076645055`*^9}},ExpressionUUID->"318d551d-037b-48f8-848e-\
5141a2aa2295"],

Cell["The normal vector of Pl\[UDoubleDot]ckers conoid is", "Text",
 CellChangeTimes->{{3.627705618790388*^9, 3.627705637682021*^9}, 
   3.6277103163063154`*^9, {3.627711708196461*^9, 3.6277117299116993`*^9}, 
   3.6967475554221582`*^9},ExpressionUUID->"17a5d85e-a917-49c6-b920-\
9795fc465724"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", "pluckerconoid", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", ",", "v"}], "}"}], ",", "Reals"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6276370178241854`*^9, 
  3.6276371021573343`*^9}},ExpressionUUID->"9d2105a9-c287-4390-9de3-\
1d935b84a705"],

Cell["The Gauss map is", "Text",
 CellChangeTimes->{{3.6276374654251757`*^9, 3.627637487579215*^9}, {
  3.6277056821420994`*^9, 
  3.6277056823293*^9}},ExpressionUUID->"6a457e1e-180a-41b5-a23a-d11355eafd0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sphim", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "v"}], "]"}], " ", 
       RowBox[{"Sin", "[", "v", "]"}]}], 
      SqrtBox[
       RowBox[{"2", "+", 
        SuperscriptBox["u", "2"], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"4", " ", "v"}], "]"}]}]}]]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"Cos", "[", "v", "]"}], "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"3", " ", "v"}], "]"}]}], 
       SqrtBox[
        RowBox[{"2", "+", 
         SuperscriptBox["u", "2"], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", "v"}], "]"}]}]}]]]}], ",", 
     FractionBox["u", 
      SqrtBox[
       RowBox[{"2", "+", 
        SuperscriptBox["u", "2"], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"4", " ", "v"}], "]"}]}]}]]]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6276372851630573`*^9, 3.6276373458435645`*^9}, 
   3.6277058416991796`*^9},ExpressionUUID->"5a6d1307-dc02-4e83-b519-\
f91e929e044b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphim", "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", ".", 
    RowBox[{"sphim", "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696748471795547*^9, 3.696748484896433*^9}, {
  3.69674852125595*^9, 3.6967485447436037`*^9}, {3.696748581759274*^9, 
  3.696748630566595*^9}},ExpressionUUID->"69f02040-2c0f-42b9-8cac-\
e51a65374b96"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sphim", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696747810082012*^9, 3.6967479020047483`*^9}, {
   3.6967492585744553`*^9, 3.6967492675384398`*^9}, {3.696749590579679*^9, 
   3.696749593055243*^9}, {3.696749709234764*^9, 3.696749763381806*^9}, {
   3.707461849956217*^9, 3.707461861830339*^9}, {3.707462750945122*^9, 
   3.707462757747106*^9}, 
   3.707463358992277*^9},ExpressionUUID->"21f4e606-e4c8-4bc3-8af4-\
a9022152938c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphplue", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6967492850463943`*^9, 
  3.696749295008881*^9}},ExpressionUUID->"35a1ba9e-c009-4ea5-83f0-\
d9967d2ec25d"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphero", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"Opacity", "[", ".3", "]"}]}], "}"}]}], ",", 
   RowBox[{"Mesh", "\[Rule]", " ", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696748685252787*^9, 3.696748688636936*^9}, {
  3.696748743594203*^9, 3.6967489172445307`*^9}, {3.696749094675291*^9, 
  3.696749147307135*^9}},ExpressionUUID->"17826ef9-9c02-495f-9abd-\
f0d49a113385"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sph1", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.696749163903729*^9, 
  3.6967491726737413`*^9}},ExpressionUUID->"ce26fd3a-73d5-483c-881f-\
71b86ffacf26"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"sph1", ",", "sphplue"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.6967493079759083`*^9, 
  3.696749342696526*^9}},ExpressionUUID->"10230c53-c416-47d8-8f78-\
a51531bd3430"],

Cell["\<\
The normal vector is not defined at the singularities, e.g. for u==0, v==Pi/4\
\>", "Text",
 CellChangeTimes->{{3.6276376036332197`*^9, 3.6276376579157157`*^9}, {
  3.627639506353979*^9, 
  3.627639520740205*^9}},ExpressionUUID->"07e52110-724f-4db5-b8eb-\
22a12fbf789c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphim", "[", 
   RowBox[{"0", ",", 
    RowBox[{"Pi", "/", "4"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{3.627637693114378*^9, 
  3.696750048871291*^9},ExpressionUUID->"ab4b4add-ea50-48d8-af9e-\
dd2890338673"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " neglects the singularities:"
}], "Text",
 CellChangeTimes->{{3.6276396265711913`*^9, 
  3.627639672472472*^9}},ExpressionUUID->"7cb14625-7f9f-40c4-9e12-\
6bdb13efcfa7"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphim", "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{"sphim", "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", ",", "v"}], "}"}], ",", "Reals"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.627637131491386*^9, 3.62763716789225*^9}, {
  3.6276395650960827`*^9, 
  3.6276395909669285`*^9}},ExpressionUUID->"f6f138e0-c45b-42a6-97e2-\
fc0adbf16b60"],

Cell["Now we will find the Singularities of the Gauss map:", "Text",
 CellChangeTimes->{{3.627640568548254*^9, 3.627640572526261*^9}, {
   3.6276406312547646`*^9, 3.627640666748827*^9}, 3.6277075401233644`*^9, 
   3.6277134619681673`*^9},ExpressionUUID->"404aff16-3389-43a7-9ca7-\
02f93a8d1786"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sphim", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], ",", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sphim", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", ",", "v"}], "}"}], ",", "Reals"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.627639717563552*^9, 3.6276397958876905`*^9}, {
  3.6967509495042343`*^9, 3.696750987363236*^9}, {3.696751018197042*^9, 
  3.696751032514669*^9}, {3.696751151202495*^9, 
  3.696751169129985*^9}},ExpressionUUID->"f269343e-0776-4c2d-81c4-\
40bc64d2d2ad"],

Cell["\<\
Mathematica calculates the rank neglecting the singularities:\
\>", "Text",
 CellChangeTimes->{{3.69675149727041*^9, 
  3.696751537558069*^9}},ExpressionUUID->"f4fc6843-09e3-4183-b4ed-\
517593ef4eae"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{
   RowBox[{"d", "[", "sphim", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6276404634660683`*^9, 3.627640474062487*^9}, {
  3.6967513183571463`*^9, 
  3.696751348506277*^9}},ExpressionUUID->"13f5d1df-a27a-4f26-aab6-\
2f3e0c7f53bb"],

Cell["But in reality there exists singularities", "Text",
 CellChangeTimes->{{3.6276407905730143`*^9, 3.6276408133042545`*^9}, 
   3.69675205597822*^9},ExpressionUUID->"be0a9567-dc32-4c57-9106-\
33182b8af7dd"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"%%", "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.696751202198518*^9, 3.696751255760942*^9}, 
   3.6967515622991543`*^9},ExpressionUUID->"14239881-7611-43e5-b109-\
de5894fbc76e"],

Cell["namely", "Text",
 CellChangeTimes->{{3.6276406994056845`*^9, 3.627640708812501*^9}, 
   3.696751383439587*^9, {3.696752094913762*^9, 
   3.696752097377532*^9}},ExpressionUUID->"9aa962f3-b73c-4b6a-b9da-\
d99f74116526"],

Cell[BoxData[
 RowBox[{"sphim", "[", 
  RowBox[{"u", ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "+", 
      RowBox[{"2", " ", "\[Pi]", "*", "21"}]}], ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696752002639387*^9, 
  3.6967520113554564`*^9}},ExpressionUUID->"c897683e-3e50-4aab-a8be-\
31859d70b84e"],

Cell[BoxData[
 RowBox[{"sphim", "[", 
  RowBox[{"u", ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "2"], "-", 
      RowBox[{"2", " ", "\[Pi]", "*", "13"}]}], ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696752002639387*^9, 3.6967520113554564`*^9}, 
   3.6967521243716707`*^9, {3.696752159114307*^9, 
   3.6967521781862717`*^9}},ExpressionUUID->"0a3c553f-5bee-4d02-966d-\
0d1c7d1a2bdc"],

Cell["For all values of C[1] This is the North pole of the sphere.", "Text",
 CellChangeTimes->{{3.6967522514842157`*^9, 
  3.696752304874518*^9}},ExpressionUUID->"cfad1562-06fd-4874-bd3d-\
0d3aac4f43d0"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6178720672371836`*^9, 
  3.6178720672391834`*^9}},ExpressionUUID->"609f2df2-e223-412c-b07c-\
b4795af95161"],

Cell["\<\
Considering a general ruled surface we may assume that the tangent vectors of \
the lines \
\>", "Text",
 CellChangeTimes->{{3.5872802010710545`*^9, 3.587280211198634*^9}, {
   3.5872802433104706`*^9, 3.587280252998025*^9}, 3.5872900805590277`*^9, 
   3.58729163854414*^9, 3.627641063746297*^9, {3.627710251051401*^9, 
   3.627710285511862*^9}},ExpressionUUID->"b62e058c-c45e-41b7-b00e-\
7116c6c8d98b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "\[Equal]", " ", 
  RowBox[{"vec", "[", 
   RowBox[{
    RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.587280265413735*^9, 3.5872802986966386`*^9}, {
  3.609733214002528*^9, 3.6097332291143923`*^9}, {3.6967523351290483`*^9, 
  3.696752354056445*^9}},ExpressionUUID->"f2bcfb4c-bb40-498b-9fc3-\
1f78f107c425"],

Cell["are unit vectors; thus we have", "Text",
 CellChangeTimes->{{3.587280322107978*^9, 3.5872803471424093`*^9}, {
  3.5872804063267946`*^9, 3.58728041062304*^9}, {3.6276410735899143`*^9, 
  3.6276410811599283`*^9}},ExpressionUUID->"525513bb-1008-429d-bfca-\
b7d9d3521f2c"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", 
      RowBox[{"ruled", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}]}], "\[Equal]", " ", 
    "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5872806978644695`*^9, 3.587280778003053*^9}, 
   3.58728083266718*^9, 3.587289862213539*^9, 3.614861851375925*^9, 
   3.614917783808547*^9, 3.614919529482813*^9, {3.6151810048464317`*^9, 
   3.6151810151570215`*^9}, {3.6967523972401943`*^9, 
   3.6967524254484873`*^9}},ExpressionUUID->"6a8932c8-8074-4f1f-b520-\
006d9e2eab76"],

Cell["We calculate", "Text",
 CellChangeTimes->{{3.587280659127254*^9, 
  3.5872806747591476`*^9}},ExpressionUUID->"ef827b8e-314a-448c-9fa4-\
833e1d3dd4e6"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}]}], "\[Equal]", " ", 
    "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5872809006570687`*^9, 3.587280909512575*^9}, {
   3.587290118485197*^9, 3.5872901269076786`*^9}, 3.6148618516099253`*^9, 
   3.6149177838397474`*^9, 3.615181162949475*^9, {3.696752452784482*^9, 
   3.696752462056059*^9}, {3.7074612599781113`*^9, 
   3.707461262178925*^9}},ExpressionUUID->"647a099d-e30b-440f-aa52-\
7928ba872146"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}]}], "\[Equal]", " ", 
    "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5872809006570687`*^9, 3.587280909512575*^9}, {
   3.587290118485197*^9, 3.5872901269076786`*^9}, {3.5872906447672987`*^9, 
   3.5872906711228065`*^9}, 3.6148618516411257`*^9, 3.614917783855347*^9, 
   3.6151811681617727`*^9, {3.696752579484025*^9, 3.6967525879750633`*^9}, {
   3.707461381847883*^9, 
   3.707461383668394*^9}},ExpressionUUID->"4d8c8a50-a8aa-4922-aede-\
537eaad4f08c"],

Cell["\<\
As curve vec[x[v],3] we may take any curve intersecting all lines of the \
family. Thus we may assume vec[x[v],3] being an orthogonal trajectory of the \
rulings amf[1][ruledsf][u,v] == vec[y[v],3] on the ruled surface. Then \
D[vec[x[v],3],v].vec[y[v],3]\[Equal] 0,  the surface ruled[x,y][u,v] is a \
family of normals of the directrix vec[x[v],3]. The normal unit vectors \
vec[y[v],3] in general  form a curve on the unit sphere; in the neighborhood \
of  regular points of this curve we may assume that v is the arc length of \
this spherical curve. We collect these assumptions to \
\>", "Text",
 CellChangeTimes->{{3.609733354343555*^9, 3.6097334420075693`*^9}, {
   3.609733472912337*^9, 3.609733575912228*^9}, {3.6097336162885375`*^9, 
   3.6097336413759727`*^9}, {3.609733687194593*^9, 3.609733713808115*^9}, {
   3.609733771040389*^9, 3.6097338766884317`*^9}, {3.609733958888133*^9, 
   3.6097340466561527`*^9}, {3.6097340950399203`*^9, 3.609734099769191*^9}, {
   3.6097341449277735`*^9, 3.6097341633838296`*^9}, {3.609734695385258*^9, 
   3.609734749161334*^9}, 3.614919788302868*^9, 3.615263967187282*^9, {
   3.617889351635394*^9, 3.617889393225067*^9}, {3.6277130956483235`*^9, 
   3.627713100983533*^9}, {3.696752664174611*^9, 3.6967526808147173`*^9}, {
   3.696752712270362*^9, 3.696752713254043*^9}, {3.6967527554940863`*^9, 
   3.696752766781839*^9}, {3.696752825445714*^9, 
   3.696752849709599*^9}},ExpressionUUID->"fc3eaf83-00f5-4e24-8be5-\
fb9e18f4b5b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruledass", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"vec", "[", 
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ".", 
       RowBox[{"vec", "[", 
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}]}], "\[Equal]", " ", 
      "1"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"vec", "[", 
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ",", "v"}], "]"}],
        ".", 
       RowBox[{"vec", "[", 
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}]}], "\[Equal]", "0"}],
      "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"vec", "[", 
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ",", "v"}], "]"}],
        ".", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"vec", "[", 
          RowBox[{
           RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ",", "v"}], 
        "]"}]}], "\[Equal]", " ", "1"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"vec", "[", 
          RowBox[{
           RowBox[{"x", "[", "v", "]"}], ",", "3"}], "]"}], ",", "v"}], "]"}],
        ".", 
       RowBox[{"vec", "[", 
        RowBox[{
         RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}]}], "\[Equal]", " ", 
      "0"}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.609731174164606*^9, 3.609731191246636*^9}, {
   3.6097312423211255`*^9, 3.6097313830177727`*^9}, {3.6097314152786293`*^9, 
   3.6097315223728175`*^9}, {3.6097319516387715`*^9, 3.609731998204853*^9}, 
   3.6097348047275124`*^9, {3.696752894520747*^9, 3.696753003348412*^9}, {
   3.707462414698777*^9, 3.7074624219322777`*^9}, {3.707479620227162*^9, 
   3.707479626410791*^9}},ExpressionUUID->"e2b23936-b97d-45cb-b111-\
eba1ef5f5b08"],

Cell["\<\
Applying these assumptions leads to a certain simplification of the \
expression for the moving orthonormal frame:\
\>", "Text",
 CellChangeTimes->{{3.6097341810798416`*^9, 3.6097342414882965`*^9}, 
   3.6097348204804134`*^9},ExpressionUUID->"0c964480-9a46-4a5f-9d94-\
23f14208c4f0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "1", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5872806978644695`*^9, 3.587280778003053*^9}, 
   3.58728083266718*^9, 3.587289862213539*^9, {3.609731672757082*^9, 
   3.6097316754558864`*^9}, 3.614861851656726*^9, 3.614917783870947*^9, 
   3.6151811698088675`*^9, {3.617889476638414*^9, 
   3.617889479259218*^9}},ExpressionUUID->"4769b3c8-c77f-483b-a805-\
d35a10daa10e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5872809006570687`*^9, 3.587280909512575*^9}, {
   3.587290118485197*^9, 3.5872901269076786`*^9}, {3.60973172877678*^9, 
   3.6097317311635847`*^9}, 3.614861851656726*^9, 3.614917783886547*^9, 
   3.615181170673917*^9, {3.617889487449233*^9, 
   3.6178894894616365`*^9}},ExpressionUUID->"e0e1432f-300e-41f5-a008-\
cf9b8de5a69e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"ruled", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5872809006570687`*^9, 3.587280909512575*^9}, {
   3.587290118485197*^9, 3.5872901269076786`*^9}, {3.5872906447672987`*^9, 
   3.5872906711228065`*^9}, 3.6097317401336*^9, 3.614861851656726*^9, 
   3.614917783886547*^9, 3.615181171545966*^9, {3.6178895031428604`*^9, 
   3.6178895055608644`*^9}},ExpressionUUID->"a84c14a8-1678-494e-b7b5-\
83c37822d394"],

Cell["\<\
For a general ruled surface the tangent plane of the surface considered along \
the generating lines  will not be constant:\
\>", "Text",
 CellChangeTimes->{{3.6097343540487347`*^9, 
  3.6097344491681757`*^9}},ExpressionUUID->"9070ac72-ce4c-4413-b8bb-\
80f8b4b1fa21"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"%", ",", "u"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5881411069079304`*^9, 3.5881411142243433`*^9}, {
   3.588141144332396*^9, 3.5881411750956497`*^9}, 
   3.6097317567632294`*^9},ExpressionUUID->"b1cef166-3877-4eeb-bef6-\
8facdb4be8eb"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/.", 
   RowBox[{"u", "\[Rule]", " ", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6097328746299925`*^9, 3.6097328943484273`*^9}, {
  3.6097330057014227`*^9, 
  3.6097330357626753`*^9}},ExpressionUUID->"f3008c1c-8a72-4141-ad85-\
f693a8de2b8e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "pluckerconoid", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7074673402537317`*^9, 3.7074673441641273`*^9}, {
  3.707467463521255*^9, 
  3.7074675550544853`*^9}},ExpressionUUID->"6f0cf977-2a44-41c5-8c9d-\
aae220820f85"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", ".", "%"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.707467695368637*^9, 
  3.707467755629363*^9}},ExpressionUUID->"d8e610f1-90dc-4a6d-b809-\
209bd821957b"],

Cell[TextData[{
 "A ruled surface for which the tangent planes along the generating lines are \
constant is the envelope of a 1-parametric family of planes. Such surfaces \
are said to be ",
 StyleBox["developable",
  FontColor->RGBColor[0, 0, 1]],
 ". The next subsections contain examples of developable surfaces."
}], "Text",
 CellChangeTimes->{{3.609734481608031*^9, 3.609734649871655*^9}, {
  3.609734874064478*^9, 
  3.60973488441607*^9}},ExpressionUUID->"663ce2e8-18e9-44da-b26f-\
2eadf05f4468"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.3. Circular Cones", "Subsubsection",
 CellChangeTimes->{{3.587278731126979*^9, 3.5872787512791314`*^9}, {
   3.587278983598419*^9, 3.5872789947820587`*^9}, {3.5875394069211664`*^9, 
   3.5875394299312067`*^9}, {3.5892067941410646`*^9, 3.589206796884221*^9}, 
   3.5896130524556894`*^9, 3.6096757219372315`*^9, 3.609739435859398*^9, 
   3.6178897837717533`*^9, 3.617890621555625*^9, 3.6277135758373213`*^9, 
   3.6277157139759*^9, 3.696753242633532*^9, 3.696766101090289*^9, 
   3.70746783372156*^9, 
   3.7074791773545*^9},ExpressionUUID->"f1b9374a-a10e-4b93-999b-becd4d551031"],

Cell[TextData[{
 StyleBox["Example 2. ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Circular Cones",
  FontColor->GrayLevel[0]],
 StyleBox[".",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{
  3.617941903491912*^9, {3.6179445243277154`*^9, 3.6179445260437183`*^9}, {
   3.696764445600851*^9, 
   3.696764447296914*^9}},ExpressionUUID->"8a2af423-f5b0-4b5b-94d4-\
3c91d00a2e66"],

Cell[BoxData[
 RowBox[{"?", "circularcone"}]], "Input",
 CellChangeTimes->{{3.6151821603215213`*^9, 
  3.6151821615225897`*^9}},ExpressionUUID->"a52ef0bb-e7d1-4a3b-b4ad-\
9715a8dbb931"],

Cell[BoxData[
 RowBox[{"Context", "[", "circularcone", "]"}]], "Input",
 CellChangeTimes->{{3.627714597378127*^9, 
  3.627714607533745*^9}},ExpressionUUID->"d9adb974-c187-476e-9bb3-\
a2358e655997"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "[", 
  RowBox[{"v", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6097399536040115`*^9, 3.6097399569472027`*^9}, 
   3.6148618516879253`*^9, 3.614864731452984*^9, 3.6151811727360344`*^9, 
   3.6151821410514193`*^9},ExpressionUUID->"e376a518-6e8f-436c-9029-\
91c5b748d84e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circularcone", "[", 
   RowBox[{"1", ",", ".5"}], "]"}], "[", 
  RowBox[{
   RowBox[{"-", "Pi"}], ",", "Pi", ",", 
   RowBox[{"-", "1"}], ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.6097399536040115`*^9, 3.6097399569472027`*^9}, 
   3.6148618516879253`*^9, 3.614864731452984*^9, 3.6151811727360344`*^9, 
   3.6151821410514193`*^9, {3.61518224160217*^9, 
   3.6151823043477592`*^9}},ExpressionUUID->"76ae3dfd-d4ca-466e-852a-\
9785857a34c0"],

Cell[TextData[{
 "Here is the parameter representation of a",
 StyleBox[" circular cone with the opening  angle parameter a",
  FontColor->RGBColor[0, 0, 1]],
 ";"
}], "Text",
 CellChangeTimes->{{3.5875390653897667`*^9, 3.5875391467751093`*^9}, {
  3.6097367551930723`*^9, 
  3.609736762248476*^9}},ExpressionUUID->"f3b798c2-dc2d-45ff-aca6-\
5b6752ca4d9d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"u", ",", "v", ",", "a"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"cone", "[", "a_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", 
      RowBox[{"Cos", "[", "v", "]"}], " ", 
      RowBox[{"Sin", "[", 
       FractionBox["a", "2"], "]"}]}], ",", 
     RowBox[{"u", " ", 
      RowBox[{"Sin", "[", 
       FractionBox["a", "2"], "]"}], " ", 
      RowBox[{"Sin", "[", "v", "]"}]}], ",", 
     RowBox[{"u", " ", 
      RowBox[{"Cos", "[", 
       FractionBox["a", "2"], "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cone", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", " ", 
     RowBox[{"Cos", "[", "v", "]"}]}], ",", 
    RowBox[{"u", " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], ",", "u"}], "}"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5872948975265427`*^9, 3.5872949467553587`*^9}, {
   3.587295055234563*^9, 3.5872951071875343`*^9}, {3.58729514766685*^9, 
   3.5872951496909657`*^9}, {3.587295297660429*^9, 3.5872953178275824`*^9}, {
   3.5872953816602335`*^9, 3.587295400275298*^9}, 3.58729564402924*^9, {
   3.587296119420431*^9, 3.58729612220759*^9}, 3.587296180140904*^9, {
   3.5872968322122*^9, 3.58729691385187*^9}, {3.5872969927723837`*^9, 
   3.587297041619178*^9}, 3.5872995662082434`*^9, 3.5873007900452433`*^9, {
   3.587300836185882*^9, 3.587300857290089*^9}, {3.5873009825162516`*^9, 
   3.587301025218694*^9}, 3.5873015813395023`*^9, {3.5873016792821045`*^9, 
   3.5873016953790255`*^9}, 3.5873017301390133`*^9, {3.5873018736832237`*^9, 
   3.587301885521901*^9}, 3.5873023656363616`*^9, {3.587362824728996*^9, 
   3.587362858495927*^9}, {3.5873655403923225`*^9, 3.587365560400467*^9}, {
   3.587365642144143*^9, 3.5873656656024847`*^9}, 3.5873659192889943`*^9, {
   3.6097353257093105`*^9, 3.6097353561790533`*^9}, 3.60973566592377*^9, {
   3.6097357072661343`*^9, 3.6097358183264866`*^9}, {3.6097358569586964`*^9, 
   3.609735895822919*^9}, {3.6148618517035255`*^9, 3.6148618517035255`*^9}, {
   3.614864731468584*^9, 
   3.614864731484184*^9}},ExpressionUUID->"cf5fff37-1356-4a23-99d2-\
005a410bedb5"],

Cell["expressed with circularcone :", "Text",
 CellChangeTimes->{{3.609738511000499*^9, 
  3.609738550375751*^9}},ExpressionUUID->"c7e50f95-81b7-4d35-8d24-\
9824faa97a70"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cone", "[", "a", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"circularcone", "[", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"a", "/", "2"}], "]"}], ",", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", "/", "2"}], "]"}]}], "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.609736354019127*^9, 3.6097364236911116`*^9}, {
  3.6148618517035255`*^9, 3.6148618517035255`*^9}, {3.614864731499784*^9, 
  3.614864731499784*^9}},ExpressionUUID->"3a522405-864e-47ef-95a5-\
f2b88018642a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cone", "[", 
   RowBox[{"u", ",", "v"}], "]"}], "==", 
  RowBox[{
   RowBox[{"circularcone", "[", 
    RowBox[{"1", ",", " ", "1"}], "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5872932058577847`*^9, 3.587293215873358*^9}, 
   3.5872948874259653`*^9, {3.6097364393220053`*^9, 3.6097364881637993`*^9}, {
   3.6097367155078025`*^9, 3.6097367297066145`*^9}, {3.6148618517191257`*^9, 
   3.6148618517191257`*^9}, {3.6148647315153837`*^9, 
   3.6148647315153837`*^9}},ExpressionUUID->"32963694-0b0f-48d5-bbd4-\
115160d3afad"],

Cell["\<\
Here a denotes the angle between two opposite generators of the circular cone\
\>", "Text",
 CellChangeTimes->{{3.5873628884356394`*^9, 3.5873628961790824`*^9}, {
  3.5873631146025753`*^9, 
  3.587363137978913*^9}},ExpressionUUID->"ae71143a-806d-4a5d-b572-\
7308f691acca"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], "*", 
      RowBox[{"Cos", "[", "v", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], "*", 
      RowBox[{"Sin", "[", "v", "]"}]}], ",", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", "/", "2"}], "]"}]}], "}"}], ".", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"v", "+", "Pi"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"v", "+", "Pi"}], "]"}]}], ",", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", "/", "2"}], "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587363187949771*^9, 3.5873632063528233`*^9}, {
  3.587363405322204*^9, 3.587363414033702*^9}, {3.587364073017394*^9, 
  3.5873640870571966`*^9}, {3.587364145360532*^9, 3.5873641558491316`*^9}, {
  3.5873650971939735`*^9, 3.587365103712346*^9}, {3.5873651748564157`*^9, 
  3.587365181856816*^9}, {3.5873655843958397`*^9, 3.5873656085542216`*^9}, {
  3.587365705545769*^9, 
  3.5873657138572445`*^9}},ExpressionUUID->"9dd95f57-de86-423d-9cbe-\
9f173c10a2f3"],

Cell["In the next cell try some values of a:", "Text",
 CellChangeTimes->{{3.5873652832916174`*^9, 
  3.587365315627467*^9}},ExpressionUUID->"1ca85730-e25a-42f9-b10b-\
f6439b227803"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cone", "[", 
     RowBox[{"2", "*", 
      RowBox[{"Pi", "/", "10"}]}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587292881024205*^9, 3.587293043506499*^9}, {
   3.5872931006277657`*^9, 3.5872931337866626`*^9}, {3.587293221739693*^9, 
   3.5872932468991323`*^9}, {3.5872932802280383`*^9, 3.587293303739383*^9}, {
   3.5872933712442446`*^9, 3.587293384002974*^9}, 3.587295167828003*^9, {
   3.587295346019195*^9, 3.5872953481313157`*^9}, {3.587295417195266*^9, 
   3.5872954187073526`*^9}, 3.5872955288836546`*^9, {3.587295665403463*^9, 
   3.5872956745789876`*^9}, {3.5872957076028767`*^9, 3.587295718787516*^9}, 
   3.587295950548772*^9, {3.587296019203699*^9, 3.587296034386567*^9}, 
   3.587296273172225*^9, {3.5873020711465178`*^9, 3.5873020813291*^9}, 
   3.5873021189782534`*^9, {3.5873021523621635`*^9, 3.587302157585462*^9}, {
   3.587302190002316*^9, 3.5873021999618855`*^9}, 3.587302265473633*^9, {
   3.5873023851534777`*^9, 3.5873024626499104`*^9}, {3.587365325152012*^9, 
   3.5873653364146557`*^9}, {3.5873659389441185`*^9, 
   3.5873659632795105`*^9}, {3.5873775764752693`*^9, 3.587377577659337*^9}, 
   3.6148618517191257`*^9, 3.614864731530984*^9, {3.617890074603064*^9, 
   3.6178900946490993`*^9}, {3.62771476283982*^9, 3.6277147774922457`*^9}, 
   3.696764693326165*^9},ExpressionUUID->"2da6e031-dd09-4041-b6df-\
5c254408eb14"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"cone", "[", 
    RowBox[{"u", ",", "v"}], "]"}], "-", 
   RowBox[{
    RowBox[{"cone", "[", 
     RowBox[{"Pi", "/", "2"}], "]"}], "[", 
    RowBox[{
     RowBox[{"u", "*", 
      RowBox[{"Sqrt", "[", "2", "]"}]}], ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587292881024205*^9, 3.587293043506499*^9}, {
   3.5872931006277657`*^9, 3.5872931337866626`*^9}, {3.587293221739693*^9, 
   3.5872932468991323`*^9}, {3.5872932802280383`*^9, 3.587293303739383*^9}, {
   3.5872933712442446`*^9, 3.587293384002974*^9}, 3.587295167828003*^9, {
   3.587295346019195*^9, 3.5872953481313157`*^9}, {3.587295417195266*^9, 
   3.5872954187073526`*^9}, 3.5872955288836546`*^9, {3.587295665403463*^9, 
   3.5872956745789876`*^9}, {3.5872957076028767`*^9, 3.587295718787516*^9}, 
   3.587295950548772*^9, {3.587296019203699*^9, 3.587296034386567*^9}, 
   3.587296273172225*^9, {3.5873020711465178`*^9, 3.5873020813291*^9}, 
   3.5873021189782534`*^9, {3.5873021523621635`*^9, 3.587302157585462*^9}, {
   3.587302190002316*^9, 3.5873021999618855`*^9}, 3.587302265473633*^9, {
   3.5873023851534777`*^9, 3.587302489929471*^9}, {3.5873659905340695`*^9, 
   3.5873660240139847`*^9}, 3.5873660610071*^9, {3.5873663265912905`*^9, 
   3.5873663338547063`*^9}, {3.614861851734726*^9, 3.614861851734726*^9}, {
   3.614864731546584*^9, 
   3.614864731546584*^9}},ExpressionUUID->"4068cc6f-c7f4-4af6-af64-\
7de534b27756"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"cone", "[", "a", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"u", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587367193391869*^9, 3.5873672317900653`*^9}, {
   3.5873672813919024`*^9, 3.587367295423705*^9}, {3.614861851734726*^9, 
   3.614861851734726*^9}, 3.6148647315621843`*^9, 3.614917783933347*^9, 
   3.615181206984994*^9},ExpressionUUID->"67226df2-fd76-42fd-9964-\
2fa4e151ea6a"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ".", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.61518282362146*^9, 
  3.615182837275241*^9}},ExpressionUUID->"5af9967e-2b34-4c37-b497-\
6fa4d24b7bf1"],

Cell[TextData[{
 "The spherical image is a circle on the unit sphere. The vector \
amf[3][cone[a]][u,v] does not depend on u, it is constant along the \
generators.The tangent planes form a 1-parameter family;  tangent to  the \
cone along the generating lines. The cone is the ",
 ButtonBox["envelope",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Envelope_(mathematics)"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Envelope_(mathematics)"],
 " of this family of planes."
}], "Text",
 CellChangeTimes->{{3.5873769759596725`*^9, 3.5873769972388897`*^9}, {
   3.5873770459446754`*^9, 3.587377192903081*^9}, {3.5873775421113043`*^9, 
   3.5873775659356666`*^9}, {3.5873780405038104`*^9, 3.587378092671794*^9}, 
   3.589204165124693*^9, {3.614861851765926*^9, 3.614861851812726*^9}, 
   3.614864731593384*^9, 3.614917783964547*^9, 3.61518121426541*^9, {
   3.696765416497308*^9, 
   3.696765416498987*^9}},ExpressionUUID->"fd6b6c70-6243-4314-836d-\
71dedcbf9531"],

Cell["\<\
Here is the first fundamental form of the circular cone with parameter a:\
\>", "Text",
 CellChangeTimes->{{3.5875392110940228`*^9, 
  3.5875392468024855`*^9}},ExpressionUUID->"9ca85e20-246d-4982-b5d1-\
9f2eefa645fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    FormBox["fund1",
     TraditionalForm], "[", 
    RowBox[{"cone", "[", "a", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587302621247982*^9, 3.5873026846016054`*^9}, 
   3.5873027534025407`*^9, {3.5873033248071203`*^9, 3.5873033282391267`*^9}, 
   3.590495710531009*^9, 3.614861851843926*^9, 
   3.614864731624584*^9},ExpressionUUID->"3bea98f2-8355-41a3-a599-\
b0cc561e2889"],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.5873027745887527`*^9, 
  3.5873027831682434`*^9}},ExpressionUUID->"ddd43119-2207-411d-8f6e-\
8206452e0c22"],

Cell["Since", "Text",
 CellChangeTimes->{{3.5896106720295086`*^9, 
  3.589610673963912*^9}},ExpressionUUID->"d2d0714a-cdf8-4736-9b23-\
f28cce9ce99a"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"Cos", "[", "a", "]"}]}], " ", ")"}], "/", "2"}], "\[Equal]", 
   " ", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"a", "/", "2"}], "]"}], "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.58961068427553*^9, 
  3.589610786065709*^9}},ExpressionUUID->"629539e5-29a7-4fa5-888c-\
9383fb145a74"],

Cell["\<\
the first fundamental form of the cone with parameter a can be written in \
traditional form as\
\>", "Text",
 CellChangeTimes->{{3.5896108644714465`*^9, 
  3.589610910959528*^9}},ExpressionUUID->"cb172e11-c07b-4696-a72c-\
d2c27c826f07"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["ds", "2"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["du", "2"], " ", "+", " ", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     RowBox[{
      SuperscriptBox["sin", "2"], "(", 
      FractionBox["a", "2"], ")"}], " ", 
     SuperscriptBox["dv", "2"]}]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5896109202103443`*^9, 
  3.5896110848218336`*^9}},ExpressionUUID->"671c720d-7de2-499b-ac87-\
d0533700b830"],

Cell[TextData[{
 "The ",
 StyleBox["plane in polar coordinates",
  FontColor->RGBColor[0, 0, 1]],
 " r, \[Phi] has the parameter representation"
}], "Text",
 CellChangeTimes->{{3.589611215674863*^9, 3.5896112858281865`*^9}},
 CellTags->"polco",ExpressionUUID->"dcc8e844-58e8-4107-a0ed-93d6e9e46201"],

Cell[BoxData[
 RowBox[{
  RowBox[{"polcoord", "[", 
   RowBox[{"r_", ",", "\[Phi]_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r", "*", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}]}], ",", " ", 
    RowBox[{"r", "*", 
     RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], "}"}], " "}]], "Input",
 CellChangeTimes->{{3.589611309758629*^9, 3.589611399879987*^9}, 
   3.5896227230329013`*^9},ExpressionUUID->"3ae43f23-b9bc-43f9-bed2-\
5e736565a627"],

Cell["\<\
The first fundamental form of the plane in these coordinates is\
\>", "Text",
 CellChangeTimes->{{3.5896114233736277`*^9, 
  3.5896114457284675`*^9}},ExpressionUUID->"f9aa49e7-acd0-44f1-8e09-\
6497a29b5f2c"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox["fund1",
      TraditionalForm], "[", "polcoord", "]"}], "[", 
    RowBox[{"r", ",", "\[Phi]\[Phi]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5896115173949933`*^9, 3.5896115745690937`*^9}, 
   3.5896116780440755`*^9, 
   3.5904957105466094`*^9},ExpressionUUID->"49b63c91-7bfa-4f4c-9382-\
f2bf7f692b44"],

Cell["In traditional form:", "Text",
 CellChangeTimes->{{3.5896116022123423`*^9, 
  3.5896116119155593`*^9}},ExpressionUUID->"10e02b32-09f0-45c0-839c-\
cda648f8a993"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["ds", "2"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["dr", "2"], "+", " ", 
    RowBox[{
     SuperscriptBox["r", "2"], 
     SuperscriptBox["d\[Phi]", "2"]}]}]}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.589611617359969*^9, 
  3.5896117282137637`*^9}},ExpressionUUID->"60d88420-5de2-4c8b-95de-\
59e714e32c4f"],

Cell["Thus the map ", "Text",
 CellChangeTimes->{{3.5896117816906576`*^9, 3.5896117861366653`*^9}, 
   3.5896118362283535`*^9},ExpressionUUID->"936ee590-bc0d-4a7f-97df-\
92915c3b7813"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{"u", ",", " ", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"a", "/", "2"}], "]"}], "*", "v"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5896118084291043`*^9, 3.589611809895507*^9}, {
  3.589611866227206*^9, 
  3.589611949827753*^9}},ExpressionUUID->"13eaf523-b97d-4e37-ab6c-\
114f35b2cb64"],

Cell["\<\
 is an isometry of the cone with parameter a onto a certain region of the \
plane. We consider the part of  cone[1]  with u< R=1 and obtain the picture\
\>", "Text",
 CellChangeTimes->{{3.58961199938904*^9, 3.589612149695304*^9}, {
   3.58961222168943*^9, 3.5896122512046824`*^9}, {3.5896123690160894`*^9, 
   3.5896123697492905`*^9}, {3.5896124644102564`*^9, 3.589612466797061*^9}, 
   3.614861851875126*^9, 
   3.6148647316557837`*^9},ExpressionUUID->"100dd3dc-1ddf-4449-9695-\
ab8650f5080f"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"polcoord", "[", 
    RowBox[{"u", ",", " ", 
     RowBox[{
      RowBox[{"Sin", "[", ".5", "]"}], "*", "v"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.589612155046113*^9, 3.589612207477805*^9}, {
   3.589612261875101*^9, 3.5896123416224413`*^9}, 3.589612379109307*^9, 
   3.5896124778106804`*^9, 
   3.589622759817766*^9},ExpressionUUID->"62418119-affb-42bd-a40c-\
99ce1d743473"],

Cell["\<\
The map can be obtained by cutting the cone along the line v== 0 and laying \
down all its other generating lines into the x,y-plane; this often is said as \
\[OpenCurlyDoubleQuote]developing it into the plane\[CloseCurlyDoubleQuote]. \
Of course, the isometry is valid only locally: The circle u == 1 must be cut \
and is only then developable into a circle arc whose length depends on a. \
\>", "Text",
 CellChangeTimes->{{3.5896126509449844`*^9, 3.5896127547447667`*^9}, {
  3.589612787770025*^9, 3.589612852681739*^9}, {3.5896129059714327`*^9, 
  3.589612984767171*^9}, {3.5896131463990545`*^9, 3.5896132386264167`*^9}, {
  3.615264023461501*^9, 
  3.615264024773576*^9}},ExpressionUUID->"2982f072-a8ed-449a-a479-\
9b1781ea8d36"],

Cell["\<\
The built-in function Cone yields a cone as a  Graphics3D object:\
\>", "Text",
 CellChangeTimes->{{3.587555743989889*^9, 3.5875557629299726`*^9}, {
  3.587555807577526*^9, 3.5875558655058393`*^9}, {3.587556515250003*^9, 
  3.587556566753948*^9}},ExpressionUUID->"2c173230-6bb9-4d8b-b3a7-\
afaaca6f34eb"],

Cell[BoxData[
 RowBox[{"?", "Cone"}]], "Input",
 CellChangeTimes->{{3.5875558693020563`*^9, 
  3.5875558720292125`*^9}},ExpressionUUID->"35655846-6abc-4b25-996c-\
66c1c53b8ede"],

Cell[BoxData[
 RowBox[{"Cone", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"Tan", "[", 
    FractionBox["1", "2"], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{3.5875574251940484`*^9, 3.6148618519063263`*^9, 
  3.614917783995747*^9},ExpressionUUID->"6e27d46d-d522-4a53-a237-\
5c5b0f9493aa"],

Cell[BoxData[
 RowBox[{"co1", " ", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"Graphics3D", "[", "%", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5875564103430023`*^9, 3.587556438523614*^9}, {
  3.587556962923608*^9, 
  3.5875569664438095`*^9}},ExpressionUUID->"b9bedfbb-2549-42ae-ab22-\
6eb6516f568a"],

Cell["We plot the surface  opposite to co1  by cone", "Text",
 CellChangeTimes->{{3.587558692569538*^9, 3.587558711641629*^9}, {
  3.587558788978052*^9, 3.5875588102972717`*^9}, {3.6277152642513056`*^9, 
  3.627715276548127*^9}},ExpressionUUID->"b75d32a4-7243-47e9-b8b4-\
0260a082fd9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cone", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5875559643094907`*^9, 3.587555973026989*^9}, 
   3.614861851921926*^9, 
   3.614864731686984*^9},ExpressionUUID->"f7d26317-05e9-47b6-b8d3-\
8038363290d5"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"1", "/", 
   RowBox[{"Cos", "[", 
    RowBox[{"1", "/", "2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6151842927934914`*^9, 
  3.615184323403242*^9}},ExpressionUUID->"8cd3436a-e4ca-486f-8068-\
40e45b9a99b1"],

Cell[BoxData[
 RowBox[{"co2", " ", "=", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"cone", "[", "1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", 
      RowBox[{"-", "1.139"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5875566103584423`*^9, 3.5875566887569265`*^9}, {
   3.5875575681262236`*^9, 3.587557569437299*^9}, {3.587557626693574*^9, 
   3.5875576269725895`*^9}, {3.5875577747100396`*^9, 3.587557780154351*^9}, {
   3.5875578458291073`*^9, 3.5875578481092377`*^9}, {3.5875584166217546`*^9, 
   3.5875584181818438`*^9}, 3.587558498653447*^9, 3.587558539606789*^9, {
   3.5875585741337643`*^9, 3.58755858018111*^9}, 3.614861851921926*^9, 
   3.6148647317025843`*^9, {3.6151836825005846`*^9, 3.615183683916666*^9}, {
   3.6151837288772373`*^9, 3.6151837305003304`*^9}, {3.615184362476477*^9, 
   3.615184364692604*^9}},ExpressionUUID->"45a32af9-c7d5-4dbf-8065-\
38de72b0f4ff"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"co1", ",", "co2"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5875575114239807`*^9, 
  3.5875575243397193`*^9}},ExpressionUUID->"2c471db5-3181-4956-a9b1-\
6e1e863322df"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.4. Conical Surfaces", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, 3.589613294661715*^9, 
   3.5896228998436117`*^9, 3.6097394807369647`*^9, 3.6097411436570787`*^9, 
   3.6178906549864836`*^9, 3.617944252481638*^9, 3.627715806580064*^9, 
   3.6277165361065516`*^9, 3.696766108408618*^9, 3.6967674737211103`*^9, 
   3.707479183052153*^9, 
   3.7074820396483297`*^9},ExpressionUUID->"de9c4c3b-3456-4790-928c-\
191283361a20"],

Cell[TextData[{
 " A ruled surface is called ",
 StyleBox["conical ",
  FontColor->RGBColor[0, 0, 1]],
 "if all its rulings  have a common point, say the origin. Thus the surface \
is defined by  vec[y[v],3] being a curve on the unit sphere:"
}], "Text",
 CellChangeTimes->{{3.587291182439052*^9, 3.587291253231101*^9}, {
   3.5872918463990283`*^9, 3.587291860454832*^9}, {3.6097350506905804`*^9, 
   3.609735056359905*^9}, 3.6179419782004433`*^9, 3.617942024688525*^9, {
   3.6179420573861823`*^9, 3.6179420643125944`*^9}, {3.6179434846950893`*^9, 
   3.617943490045899*^9}, {3.6179445410041447`*^9, 3.6179445500833607`*^9}, {
   3.696742411944615*^9, 3.696742411947959*^9}, {3.696766170190878*^9, 
   3.696766171390038*^9}, {3.69676632208431*^9, 3.696766329548135*^9}, {
   3.696766834486726*^9, 
   3.696766835774486*^9}},ExpressionUUID->"f0a70574-9de7-45e1-acb1-\
d23f4d41871e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"conesf", "[", "y_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], "*", "u"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.587292095259262*^9, 3.587292166330327*^9}, {
  3.696766856790251*^9, 
  3.696766859518043*^9}},ExpressionUUID->"36f3d535-012d-4fcf-b5b4-\
cc39f4704dee"],

Cell[BoxData[
 RowBox[{"?", "conesf"}]], "Input",
 CellChangeTimes->{{3.6151879081844697`*^9, 3.6151881733726377`*^9}, {
   3.6179435529452095`*^9, 3.617943629603744*^9}, {3.617943683735839*^9, 
   3.617943707759881*^9}, 3.617943754403963*^9, 3.617943886052594*^9, 
   3.617948041571166*^9, {3.622616200775807*^9, 
   3.6226162254706497`*^9}},ExpressionUUID->"a8a18882-6c03-41e4-919f-\
163ba1df89b0"],

Cell[BoxData[
 RowBox[{"Context", "[", "conesf", "]"}]], "Input",
 CellChangeTimes->{{3.622616261803114*^9, 
  3.6226162857959557`*^9}},ExpressionUUID->"5eb02480-3fe7-463b-80c4-\
8327fd4cbeee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"conesf", "[", "y", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.587292408188161*^9, 
  3.587292436585785*^9}},ExpressionUUID->"50ab86f0-6a44-4550-80dd-\
ff5e51d6ec9b"],

Cell["\<\
As before we assume that the curve vec[y[v],3] lies on the unit sphere and  \
that v is its arc length; then ruledass is satisfied;\
\>", "Text",
 CellChangeTimes->{{3.587540430813365*^9, 3.5875404624814205`*^9}, {
   3.5875404962086797`*^9, 3.5875405929912496`*^9}, {3.609740743897213*^9, 
   3.6097407692406626`*^9}, 3.615184574313594*^9, {3.6151846406823893`*^9, 
   3.6151846992017365`*^9}, {3.696766969893147*^9, 
   3.6967669855809793`*^9}},ExpressionUUID->"78cbfab1-7d50-4307-b1a8-\
4bbf3cd561c6"],

Cell[BoxData["ruledass"], "Input",
 CellChangeTimes->{{3.6097406879370127`*^9, 
  3.6097406914172115`*^9}},ExpressionUUID->"faf8a161-d8e9-4d37-8a98-\
ba7bf7731469"],

Cell[" The simplification under these condition yields:", "Text",
 CellChangeTimes->{{3.609740786200633*^9, 
  3.6097407934400473`*^9}},ExpressionUUID->"963ec9eb-0abb-412c-b88d-\
15ca13c78df2"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "ruledass"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.587539794488247*^9, 3.5875399826401777`*^9}, {
   3.5875400133566313`*^9, 3.5875400957715764`*^9}, 3.58754036527765*^9, {
   3.587548649578514*^9, 3.587548649812515*^9}, {3.588249351340147*^9, 
   3.588249351340147*^9}, {3.6097400255921288`*^9, 3.609740054356774*^9}, {
   3.609740095708139*^9, 3.60974011669934*^9}, {3.6097401494602137`*^9, 
   3.609740164915097*^9}, {3.6097402113237514`*^9, 3.609740268059997*^9}, 
   3.614861851953126*^9, 3.6149177840113473`*^9, 
   3.6151812556737785`*^9},ExpressionUUID->"e84b9d06-942a-45d5-ae38-\
7f7717bb6d48"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"%", ".", "%"}], ",", "ruledass"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.615184854845639*^9, 3.61518486657131*^9}, {
  3.615184929956935*^9, 
  3.6151849709232783`*^9}},ExpressionUUID->"2f3d3706-e4e9-41de-bb13-\
bd0ed596a1b8"],

Cell["\<\
The normal vector of the surface is constant along the generating lines, the \
surface is developable, once more: \
\>", "Text",
 CellChangeTimes->{{3.5875406082012763`*^9, 3.587540632225319*^9}, {
   3.587548159254053*^9, 3.587548167506468*^9}, 3.587548689857785*^9, {
   3.6097404018726506`*^9, 3.6097404565847797`*^9}, {3.6097411060729284`*^9, 
   3.6097411181606197`*^9}},ExpressionUUID->"c7c9a2c7-266d-490a-a232-\
f4ea71446bec"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"%%", ",", "u"}], "]"}], ",", "ruledass"}], "]"}]], "Input",
 CellChangeTimes->{{3.5875401840365314`*^9, 3.5875402950931263`*^9}, {
   3.5875485494419384`*^9, 3.587548549675939*^9}, {3.588249351355747*^9, 
   3.5882493513713474`*^9}, {3.609740484835396*^9, 3.6097404878005657`*^9}, 
   3.6151850264194527`*^9},ExpressionUUID->"34a2b3dc-0a71-4951-9e51-\
0af6ec5ac886"],

Cell["Under the above assumptions, we have: The vectors ", "Text",
 CellChangeTimes->{{3.5875493479449415`*^9, 3.58754937602499*^9}, {
   3.5875496573714848`*^9, 3.5875496662635*^9}, {3.707481490676208*^9, 
   3.707481538601816*^9}, {3.707481609611754*^9, 3.707481628671773*^9}, 
   3.70748171975406*^9},ExpressionUUID->"93a0af86-fee9-433a-9d8a-\
ed5a423eddc1"],

Cell["\<\
{vec[y[v],3],  D[vec[y[v],3],v], Cross[vec[y[v],3], D[vec[y[v],3],v]]}\
\>", "Text",
 CellChangeTimes->{{3.5875493479449415`*^9, 3.58754937602499*^9}, {
  3.5875496573714848`*^9, 3.5875496662635*^9}, {3.707481490676208*^9, 
  3.707481538601816*^9}, {3.707481609611754*^9, 
  3.7074816373786373`*^9}},ExpressionUUID->"e73ab885-296f-4c56-8fb4-\
a3ecbaa79391"],

Cell["\<\
form the orthonormal moving 3-frame of the surface; it does not depend on u:\
\>", "Text",
 CellChangeTimes->{{3.5875498669734526`*^9, 3.5875499120107317`*^9}, {
   3.587549954926407*^9, 3.587549970245634*^9}, 
   3.7074817068968*^9},ExpressionUUID->"9faa0b9a-0265-40cc-8894-e4bb30b9583b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", 
      RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}]}], ",", "ruledass"}], 
  " ", "]"}]], "Input",
 CellChangeTimes->{{3.587549409190649*^9, 3.587549645827464*^9}, {
   3.587549711363179*^9, 3.587549807303348*^9}, 3.587549850172223*^9, {
   3.6148618519843264`*^9, 3.6148618519999266`*^9}, {3.614917784042547*^9, 
   3.6149177840581474`*^9}, {3.6151812596670065`*^9, 3.615181270946652*^9}, {
   3.707479910086006*^9, 3.707479922372451*^9}, {3.70747995795728*^9, 
   3.707479969195092*^9}, {3.707480583671328*^9, 
   3.707480651822403*^9}},ExpressionUUID->"943fc235-65bb-4f94-a817-\
9fc27b9d2708"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"u", ">", "0"}], ")"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "2", "]"}], "[", 
        RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"vec", "[", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ",", "v"}], 
       "]"}]}], ",", "ruledass"}], "]"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.587549409190649*^9, 3.587549645827464*^9}, {
   3.587549711363179*^9, 3.587549807303348*^9}, 3.587549850172223*^9, {
   3.6148618519843264`*^9, 3.6148618519999266`*^9}, {3.614917784042547*^9, 
   3.6149177840581474`*^9}, {3.6151812596670065`*^9, 3.615181270946652*^9}, 
   3.707479910086006*^9, 3.707479983337962*^9, {3.7074806781910057`*^9, 
   3.7074807177432117`*^9}, {3.707480783766965*^9, 3.707480797727048*^9}, {
   3.707480988128728*^9, 3.707481006838031*^9}, {3.70748105107927*^9, 
   3.707481064589363*^9}, {3.707481180004176*^9, 3.7074811832684097`*^9}, {
   3.707481227398241*^9, 
   3.7074812786803923`*^9}},ExpressionUUID->"91321051-74dc-4d6a-99f7-\
236a4e3422f6"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"u", ">", "0"}], ")"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", 
        RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
      RowBox[{"Cross", "[", 
       RowBox[{
        RowBox[{"vec", "[", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ",", " ", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"vec", "[", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ",", "v"}], 
         "]"}]}], "]"}]}], ",", "ruledass"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587549409190649*^9, 3.587549645827464*^9}, {
   3.587549711363179*^9, 3.587549807303348*^9}, 3.587549850172223*^9, {
   3.6148618519843264`*^9, 3.6148618519999266`*^9}, {3.614917784042547*^9, 
   3.6149177840581474`*^9}, {3.6151812596670065`*^9, 3.615181270946652*^9}, 
   3.707479910086006*^9, 3.707479983337962*^9, 3.7074802386099377`*^9, 
   3.7074813062418747`*^9, {3.7074813506650953`*^9, 3.707481384648301*^9}, {
   3.707481571482875*^9, 
   3.707481582618596*^9}},ExpressionUUID->"27bcf7c1-c820-4827-bce5-\
d0ff0631227e"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", 
        RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
      RowBox[{"Cross", "[", 
       RowBox[{
        RowBox[{"vec", "[", 
         RowBox[{
          RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ",", " ", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"vec", "[", 
           RowBox[{
            RowBox[{"y", "[", "v", "]"}], ",", "3"}], "]"}], ",", "v"}], 
         "]"}]}], "]"}]}], ",", "ruledass"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587549976423245*^9, 3.5875500258129315`*^9}, {
   3.6097408644981112`*^9, 3.609740903912366*^9}, 3.6148618520155263`*^9, 
   3.6149177840737476`*^9, 3.6151812746748652`*^9, {3.696767297863453*^9, 
   3.696767312594925*^9}},ExpressionUUID->"9132e47b-aae4-45c1-bb4a-\
b1c6363e13a9"],

Cell["Here is the first fundamental form of the  conical surface:", "Text",
 CellChangeTimes->{{3.5875392110940228`*^9, 3.5875392468024855`*^9}, {
   3.5875503815403566`*^9, 3.5875504304308424`*^9}, 
   3.6179442107983646`*^9},ExpressionUUID->"8df13c7a-f87f-4b7e-ac11-\
04555ffe8a2a"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FormBox["fund1",
         TraditionalForm], "[", 
        RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", "ruledass"}], "]"}]}],
   "]"}]], "Input",
 CellChangeTimes->{{3.587302621247982*^9, 3.5873026846016054`*^9}, 
   3.5873027534025407`*^9, {3.5873033248071203`*^9, 3.5873033282391267`*^9}, {
   3.5875504420840626`*^9, 3.5875505150141907`*^9}, 3.590495710562209*^9, {
   3.609740930352878*^9, 
   3.609740964005803*^9}},ExpressionUUID->"de0644c2-c3f6-4075-96ce-\
2112c5954951"],

Cell["Thus, in traditional notation, the first fundamental form is", "Text",
 CellChangeTimes->{{3.588144859952071*^9, 3.5881448887037153`*^9}, {
  3.5896222176076136`*^9, 
  3.5896222211800203`*^9}},ExpressionUUID->"defdd300-632b-4375-8d23-\
57386fdec252"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ds", "2"], " ", "==", 
  RowBox[{
   SuperscriptBox["du", 
    RowBox[{"2", "  "}]], "+", " ", 
   RowBox[{
    SuperscriptBox["u", "2"], 
    SuperscriptBox["dv", "2"]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.588144893206973*^9, 
  3.588144994745781*^9}},ExpressionUUID->"04648580-8862-4e6b-9a3d-\
8fb2b24b651c"],

Cell[TextData[{
 "and with the map defined by the equality of the parameters   r = u, \[Phi]  \
= v we obtain a local  isometry of the conical surface with the Euclidean \
plane in polar coordinates see ",
 ButtonBox["above",
  BaseStyle->"Hyperlink",
  ButtonData->"polco"],
 " ."
}], "Text",
 CellChangeTimes->{{3.58814502199934*^9, 3.5881450378552465`*^9}, {
  3.58814511029739*^9, 3.5881451394640584`*^9}, {3.588145246302169*^9, 
  3.5881452463101697`*^9}, {3.588145293663878*^9, 3.588145374903525*^9}, {
  3.5881609609546366`*^9, 3.588160965305886*^9}, {3.5896223283834085`*^9, 
  3.5896223388510265`*^9}, {3.589622379957099*^9, 3.589622382078703*^9}, {
  3.589622940793684*^9, 3.5896229828357573`*^9}, {3.5896230368274527`*^9, 
  3.5896230368274527`*^9}},ExpressionUUID->"cda56270-35b3-471a-8ed3-\
e5320ac9fbca"],

Cell[TextData[{
 StyleBox["Example 3.",
  FontColor->RGBColor[0, 0, 1]],
 " A loxodromic cone"
}], "Text",
 CellChangeTimes->{{3.696773495895562*^9, 3.696773501863308*^9}, {
  3.6967735330197163`*^9, 
  3.696773580766758*^9}},ExpressionUUID->"aa73ed87-5d9d-4aba-88b1-\
4fe438cec8f5"],

Cell[TextData[{
 "Here is a parameter representation of a ",
 ButtonBox["loxodrome",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Loxodrome.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/Loxodrome.html"],
 " on the unit sphere, a ",
 ButtonBox["spherical spiral ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/SphericalSpiral.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/SphericalSpiral.html"]
}], "Text",
 CellChangeTimes->{{3.6967737147813377`*^9, 3.696773771581369*^9}, {
  3.6967744500930557`*^9, 3.6967744500955477`*^9}, {3.6967745792950773`*^9, 
  3.6967745945270777`*^9}, {3.6967746543541117`*^9, 
  3.696774654356575*^9}},ExpressionUUID->"f7f0766c-a55e-48f5-b100-\
4592bac86652"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "sphlox", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"sphlox", "[", "a_", "]"}], " ", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"a", "*", "t"}], ")"}]}], "*", 
        RowBox[{"Cos", "[", "t", "]"}]}], ")"}], "/", "\n", "   ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"2", "*", "a", "*", "t"}], ")"}]}]}], ")"}]}], ",", " ", 
     "\n", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"a", "*", "t"}], ")"}]}], "*", 
        RowBox[{"Sin", "[", "t", "]"}]}], ")"}], "/", "\n", "   ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"2", "*", "a", "*", "t"}], ")"}]}]}], ")"}]}], ",", " ", 
     "\n", "  ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"2", "*", "a", "*", "t"}], ")"}]}]}], ")"}], "/", "\n", 
      "   ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"2", "*", "a", "*", "t"}], ")"}]}]}], ")"}]}]}], 
    "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4481623905625*^9, 3.448162392109375*^9}, {
  3.696771167135748*^9, 3.696771196039157*^9}, {3.696771308542749*^9, 
  3.696771335464411*^9}, {3.699335181718562*^9, 
  3.699335229889515*^9}},ExpressionUUID->"5510d66f-d56a-439f-b166-\
28f2c1cc852f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sphlox", "::", "usage"}], " ", "=", " ", 
   "\"\<sphlox[a][t] is a parameter representation of a loxodrome on the unit \
sphere depending on the parameter a.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6993349655989*^9, 3.699335115450632*^9}, {
   3.699335263848884*^9, 3.699335308688299*^9}, 
   3.699335585713736*^9},ExpressionUUID->"920230cc-59de-4ed7-b60e-\
87257dc2e4ec"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphlox", "[", "a", "]"}], "[", "t", "]"}], ".", 
   RowBox[{
    RowBox[{"sphlox", "[", "a", "]"}], "[", "t", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696771464331699*^9, 3.696771480941564*^9}, {
  3.69677151152636*^9, 3.696771541517692*^9}, {3.699335337268668*^9, 
  3.6993353952795143`*^9}},ExpressionUUID->"70cea343-38d4-4df0-8d4e-\
76a8db611164"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphlox", "[", ".3", "]"}], "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696771556488043*^9, 3.6967718169326344`*^9}, {
  3.699335419905802*^9, 
  3.699335444807255*^9}},ExpressionUUID->"1003de18-6213-47fd-b45d-\
d7d984d7c2b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lox", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6967718350189867`*^9, 
  3.696771842339809*^9}},ExpressionUUID->"516c9e31-a073-42df-a611-\
715c4cbb2e55"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", "lox"}], "}"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
   RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696771847570071*^9, 3.69677187024341*^9}, {
  3.696771908783475*^9, 
  3.696771944459291*^9}},ExpressionUUID->"09d0400b-2166-4090-ac56-\
a527b866994a"],

Cell["\<\
Here is a part of the conical surface defined by the loxodrome:\
\>", "Text",
 CellChangeTimes->{{3.6967747146137457`*^9, 
  3.6967747553894243`*^9}},ExpressionUUID->"597a7e10-8f2c-456b-8d0d-\
92f65a82cbc6"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"u", "*", 
    RowBox[{
     RowBox[{"sphlox", "[", ".3", "]"}], "[", "t", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "15"}], ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "1.8"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Opacity", "[", ".6", "]"}]}], "}"}]}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
   RowBox[{"Axes", "\[Rule]", "None"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696772024142989*^9, 3.6967720457387753`*^9}, 
   3.6967720992280293`*^9, {3.6967721420986032`*^9, 3.696772160898388*^9}, {
   3.696772202618165*^9, 3.696772205425898*^9}, 3.696772258210557*^9, {
   3.696772296155202*^9, 3.696772386425411*^9}, {3.696772430260285*^9, 
   3.6967724454249363`*^9}, 3.696772611100182*^9, {3.699335474575809*^9, 
   3.6993354860391397`*^9}},ExpressionUUID->"ac7b810e-d9be-4e20-b049-\
9eebe588021d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"loxcone", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.696772491493537*^9, 
  3.696772506960235*^9}},ExpressionUUID->"fba6908a-a541-444a-b122-\
c9a554551aa1"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", "lox", ",", "loxcone"}], "}"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
   RowBox[{"Axes", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.696772510792905*^9, 3.696772517137003*^9}, {
  3.69677255576853*^9, 3.6967725680074167`*^9}, {3.696772673162922*^9, 
  3.6967726856628036`*^9}},ExpressionUUID->"31c9a411-dff6-4748-ab20-\
c18e70c2ee37"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6967747853003798`*^9, 
  3.696774785302565*^9}},ExpressionUUID->"4e7fb75a-c701-4b45-8c46-\
234e6a925240"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.5. Cylindrical Surfaces", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, {3.5875506376928062`*^9, 
   3.58755065084363*^9}, 3.6097411500414433`*^9, 3.609744994379327*^9, 
   3.617944348905407*^9, 3.6179453910184374`*^9, {3.627716730155094*^9, 
   3.6277167346655025`*^9}, 3.6277171001395473`*^9, 3.69676748010643*^9, 
   3.696825507011649*^9, 3.7074820454707327`*^9, 
   3.707485267888876*^9},ExpressionUUID->"d69479b6-ac81-4139-9292-\
0fb5d2f63d56"],

Cell[TextData[{
 "A ruled surface is said to be ",
 StyleBox["cylindrical",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" or a",
  FontColor->GrayLevel[0]],
 StyleBox[" cylinder,",
  FontColor->RGBColor[0, 0, 1]],
 " if all its generating lines are parallel. In this case its parameter \
representation has the form \nvec[x[v]] + u vec[a], vec[a] = constant, not \
the null vector. We assume vec[a] = stb[3], that the directrix intersects the \
generating lines orthogonally and lies in the plane z==0. Thus we suppose the \
parameter representation to be"
}], "Text",
 CellChangeTimes->{{3.587553102264791*^9, 3.587553151345598*^9}, {
   3.587553246298029*^9, 3.5875534525058236`*^9}, {3.587553671769365*^9, 
   3.587553876378068*^9}, {3.587554060673609*^9, 3.5875540834409113`*^9}, {
   3.588564643440874*^9, 3.5885646536744924`*^9}, {3.5885647572430744`*^9, 
   3.588564762640684*^9}, {3.5885648533236427`*^9, 3.588564937423391*^9}, 
   3.5885649858302755`*^9, {3.5885650220535393`*^9, 3.5885650255167456`*^9}, {
   3.588565093548465*^9, 3.588565129428528*^9}, 3.5885651668217936`*^9, {
   3.588565473877133*^9, 3.588565491099563*^9}, 3.6097437815449567`*^9, 
   3.615185309945669*^9, {3.615264079771722*^9, 3.6152640993158393`*^9}, {
   3.617944759092528*^9, 3.617944795518592*^9}, 3.617944826391046*^9, {
   3.617944945918456*^9, 3.6179449649660892`*^9}, 
   3.696825111261567*^9},ExpressionUUID->"7a95758b-e875-43ae-a2d3-\
bfb54b902523"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.696825158915254*^9, 3.696825165980448*^9}, 
   3.696825205840407*^9},ExpressionUUID->"c878d43e-0905-4a07-b444-\
66ce1d66f0fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cylindersf", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "[", "v", "]"}], ",", 
    RowBox[{"y", "[", "v", "]"}], ",", "u"}], "}"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5875539174934196`*^9, 3.5875540237964993`*^9}, {
   3.5875544463496685`*^9, 3.587554446916701*^9}, 3.5875549322674613`*^9, {
   3.5875550888534174`*^9, 3.587555104389306*^9}, {3.6097443219728675`*^9, 
   3.6097443494924417`*^9}},ExpressionUUID->"706ab530-e772-48b9-b7e6-\
a9f76793dd72"],

Cell[BoxData[
 RowBox[{"?", "cylindersf"}]], "Input",
 CellChangeTimes->{{3.615187599736828*^9, 3.6151877880615993`*^9}, 
   3.6179448499938874`*^9, {3.622616460594263*^9, 
   3.622616472216284*^9}},ExpressionUUID->"68a751aa-bf97-4ac2-8800-\
8a9c3a0f0e6f"],

Cell[BoxData[
 RowBox[{"Context", "[", "cylindersf", "]"}]], "Input",
 CellChangeTimes->{{3.6226164762098904`*^9, 
  3.622616493728721*^9}},ExpressionUUID->"d40a1711-ad5e-41ce-82a5-\
4b67c08ebdee"],

Cell["A special case is", "Text",
 CellChangeTimes->{{3.6097443626391935`*^9, 
  3.609744379281145*^9}},ExpressionUUID->"cd07be60-2f2f-4665-8cb2-\
fa47f1a59bd5"],

Cell[BoxData[
 RowBox[{"?", "circularcylinder"}]], "Input",
 CellChangeTimes->{{3.6097439348607264`*^9, 
  3.609743944041251*^9}},ExpressionUUID->"f127f40c-6f99-44e9-b33e-\
bf18979492ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"circularcylinder", "[", "a", "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.609744115587063*^9, 
  3.6097441296198654`*^9}},ExpressionUUID->"5afd1408-bf77-4697-9cb3-\
b7ee2713fdec"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cylinder", "[", "a_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"circularcylinder", "[", "a", "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}], " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5875539174934196`*^9, 3.5875540237964993`*^9}, {
   3.5875544463496685`*^9, 3.5875545218449864`*^9}, {3.587554553540799*^9, 
   3.587554574661007*^9}, 3.5875549421500263`*^9, {3.58755512963875*^9, 
   3.5875551798056197`*^9}, {3.587555221229989*^9, 3.5875552221160393`*^9}, 
   3.5875552711018414`*^9, 3.587555335188507*^9, {3.5875607561415677`*^9, 
   3.58756076387001*^9}, {3.5875609656385503`*^9, 3.587560970365821*^9}, {
   3.6097442549010315`*^9, 
   3.6097442800674706`*^9}},ExpressionUUID->"c4fee53e-f5cd-4964-8e04-\
521ffb7c33c5"],

Cell[BoxData[
 RowBox[{"cy1", " ", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"cylinder", "[", ".5", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "1"}], ",", "2.3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.587554597538316*^9, 3.587554678861967*^9}, {
   3.5875548571821666`*^9, 3.5875548631575084`*^9}, {3.587555015485221*^9, 
   3.587555031589142*^9}, {3.587560057349599*^9, 3.587560095149761*^9}, {
   3.609744228741535*^9, 3.6097442294445753`*^9}, 3.6148618520311265`*^9, 
   3.6149177840737476`*^9},ExpressionUUID->"a3e2ddc8-882f-48eb-87ee-\
02b35076f101"],

Cell["In Mathematica Cylinder is a Graphics3D object :", "Text",
 CellChangeTimes->{{3.588565563780091*^9, 
  3.5885656192069883`*^9}},ExpressionUUID->"988b2df5-c963-47b1-9766-\
9d7bd0e59b82"],

Cell[BoxData[
 RowBox[{"?", "Cylinder"}]], "Input",
 CellChangeTimes->{{3.587559881636549*^9, 
  3.5875598989385386`*^9}},ExpressionUUID->"eeb73e3e-3e30-4df2-8a48-\
5791f55e3687"],

Cell[BoxData[
 RowBox[{"cy2", " ", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Cylinder", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"-", "1.3"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "2"}], "}"}]}], "}"}], ",", ".5"}], 
     "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.587559923827962*^9, 3.587560042114728*^9}, {
  3.58756010946058*^9, 3.5875601130607853`*^9}, {3.5875601522060246`*^9, 
  3.58756016296564*^9}},ExpressionUUID->"6d36d67f-615d-4054-9de1-\
3fa803a3b1ff"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"cy1", ",", "cy2"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587560120740225*^9, 3.587560134066987*^9}, {
  3.587560249348581*^9, 
  3.587560256972017*^9}},ExpressionUUID->"4437e643-4986-4186-8c2e-\
f6fbed3e485b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"cylinder", "[", "a", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"(", 
    RowBox[{"a", ">", "0"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5875610023946524`*^9, 3.58756104606015*^9}, {
   3.58756133208951*^9, 3.587561367965562*^9}, {3.5875614118850737`*^9, 
   3.5875614266689196`*^9}, {3.5875615312299004`*^9, 
   3.5875615491479254`*^9}, {3.60974449055751*^9, 3.6097444971398864`*^9}, 
   3.6148618520311265`*^9, 3.614917784089348*^9, 
   3.615181284609433*^9},ExpressionUUID->"96f3b7d0-1d31-47d9-b6cc-\
79fce2ba3878"],

Cell["\<\
The normal vector doesn\[CloseCurlyQuote]t depend on u, the cylinder is \
developable. The spherical image is the unit circle.  For a cylindrical \
surface the spherical image is a part of the equator:\
\>", "Text",
 CellChangeTimes->{{3.5875615964976335`*^9, 3.5875616142576494`*^9}, {
   3.5875617607620287`*^9, 3.5875618261617694`*^9}, 3.5876201866455812`*^9, {
   3.6097446080412292`*^9, 3.60974465385685*^9}, 
   3.6152641126426015`*^9},ExpressionUUID->"1cabd0b1-b348-4860-951f-\
e26bb5fab3b4"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", 
    RowBox[{"cylindersf", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.587561671403918*^9, 3.5875617060689*^9}, 
   3.614861852046726*^9, 3.6149177841049476`*^9, 
   3.615181286408536*^9},ExpressionUUID->"a39ecacf-3f08-4fcc-ac48-\
ff0807abacac"],

Cell["\<\
These surfaces are developable too. The first fundamental form is\
\>", "Text",
 CellChangeTimes->{{3.587620372457508*^9, 3.5876203935175447`*^9}, {
  3.609744685168641*^9, 
  3.609744702696644*^9}},ExpressionUUID->"f3bbfdaf-11b1-4380-a9cb-\
91af7db1631c"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FormBox["fund1",
       TraditionalForm], "[", 
      RowBox[{"cylindersf", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "x", "]"}], "[", "v", 
       "]"}], "^", "2"}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "y", "]"}], "[", "v", 
       "]"}], "^", "2"}]}], "\[Equal]", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588145723022436*^9, 3.588145758972492*^9}, 
   3.5881457897422523`*^9, 3.5904957105778093`*^9, {3.6148618520623264`*^9, 
   3.6148618520779266`*^9}, {3.6149177841205473`*^9, 
   3.6149177841205473`*^9}},ExpressionUUID->"edd9fb6d-8051-4307-a8d6-\
121c83d6d4f3"],

Cell["\<\
Obviously, this metric equals the metric of the Euclidean plane in \
orthonormal Cartesian coordinates. Thus the surface is locally isometric to \
the Euclidean plane, the isometry is defined by equal  parameters.\
\>", "Text",
 CellChangeTimes->{{3.588145812464552*^9, 3.5881458169518085`*^9}, {
   3.588160786594664*^9, 3.588160926090643*^9}, 3.589623261935848*^9, {
   3.5896233630623236`*^9, 3.589623446423092*^9}, {3.609744915512816*^9, 
   3.6097449577452316`*^9}, 3.615185967266266*^9, 
   3.6152641629144773`*^9},ExpressionUUID->"1dbc5c11-ccb3-4441-94b8-\
cdfad0cd26b7"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.6. Tangent Surfaces", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, {3.5875506376928062`*^9, 
   3.58755065084363*^9}, {3.5875621007464747`*^9, 3.5875621112900777`*^9}, 
   3.609745012249349*^9, 3.6098188216334867`*^9, 3.6179455096254463`*^9, 
   3.617947264841502*^9, 3.627717223226165*^9, 3.627745740101883*^9, {
   3.696825520618287*^9, 3.696825528687915*^9}, {3.696825576193948*^9, 
   3.696825594949691*^9}, 3.696827562306263*^9, 3.7074852832741117`*^9, 
   3.707485332474983*^9, 
   3.7074857878848467`*^9},ExpressionUUID->"06267eac-aafb-442b-8c46-\
b806b748d659"],

Cell[TextData[{
 "Let x{v] be an arbitrary smooth regular curve in the space. Then its ",
 StyleBox["tangent surface",
  FontColor->RGBColor[0, 0, 1]],
 " (also named ",
 StyleBox["tangent developable",
  FontColor->RGBColor[0, 0, 1]],
 ") is defined by"
}], "Text",
 CellChangeTimes->{{3.587620429179208*^9, 3.587620528239382*^9}, {
   3.58762060146591*^9, 3.5876206099835253`*^9}, {3.5882547189130597`*^9, 
   3.5882547566322174`*^9}, {3.6179455507315183`*^9, 3.6179456100116224`*^9}, 
   3.696825618920657*^9, 
   3.7074853324752293`*^9},ExpressionUUID->"30c63c8c-8974-4868-b0ca-\
6c4eee132dd7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tangsf", "[", "x_", "]"}], "[", 
   RowBox[{"u_", ",", " ", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"x", "[", "v", "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"x", "[", "v", "]"}], ",", " ", "v"}], "]"}], "*", 
    "u"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5876205386446*^9, 3.587620546663014*^9}, {
   3.587620618813141*^9, 3.587620638874776*^9}, {3.587620784657032*^9, 
   3.5876208247491026`*^9}, 3.587731804014976*^9, 3.707485332475597*^9, 
   3.7074854121917953`*^9},ExpressionUUID->"5dc3f428-46e8-4726-9a25-\
cc467ce23162"],

Cell[BoxData[
 RowBox[{"?", "tangsf"}]], "Input",
 CellChangeTimes->{{3.6151860940185156`*^9, 3.61518611857092*^9}, {
   3.615187275916306*^9, 3.6151873529487123`*^9}, {3.615187448988205*^9, 
   3.615187498012009*^9}, 3.6151875548302593`*^9, 3.622722251673976*^9, 
   3.6227223103456783`*^9, 
   3.70748533247585*^9},ExpressionUUID->"109a05cc-3063-4164-9852-\
1c960dd1aaef"],

Cell[BoxData[
 RowBox[{"Context", "[", "tangsf", "]"}]], "Input",
 CellChangeTimes->{{3.6227223600005655`*^9, 3.6227223788141985`*^9}, 
   3.707485332476104*^9},ExpressionUUID->"ffd6db8f-4598-4e2e-a199-\
fecb5524b33e"],

Cell["\<\
The curve itself lies on its tangent surface: set u=0. A general space curve \
is \
\>", "Text",
 CellChangeTimes->{{3.587621303264343*^9, 3.587621319441571*^9}, {
   3.587621391529298*^9, 3.5876214238837547`*^9}, 
   3.707485332476324*^9},ExpressionUUID->"65affb4d-2f9b-4a24-96ba-\
2f3c72107212"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"curve", "[", "v_", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5876209324048915`*^9, 3.5876209401893053`*^9}, {
   3.587620972294162*^9, 3.587620981076977*^9}, 3.6148618520779266`*^9, 
   3.6149177841361475`*^9, 3.69682573091651*^9, 
   3.70748533247659*^9},ExpressionUUID->"51c85c7d-4c8a-4696-a8ae-\
3dd458ebbaa8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "v_", "]"}], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{"x", "[", "v_", "]"}], "[", "2", "]"}], ",", 
   RowBox[{
    RowBox[{"x", "[", "v_", "]"}], "[", "3", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.708321850167595*^9},ExpressionUUID->"226f74ad-95e6-4f95-b7cb-\
65c22886d365"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"?", "curve"}]], "Input",
 CellChangeTimes->{{3.696825824781363*^9, 3.69682582791914*^9}, 
   3.7074853324794703`*^9},ExpressionUUID->"1c69de2b-fdec-4443-8cbc-\
8f17cf69bdfb"],

Cell[TextData[{
 StyleBox["All points of the space curve are singularities of its tangent \
surface",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.587621445770593*^9, 3.5876214903866715`*^9}, {
   3.6277412917072697`*^9, 3.6277412932672725`*^9}, 3.696825806870921*^9, 
   3.707485332479644*^9},ExpressionUUID->"a2083c47-efa5-47fb-a7b2-\
373e92a24815"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", 
      RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", 
      RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.587620867742778*^9, 3.587620899972434*^9}, {
   3.587620992870598*^9, 3.5876210110446296`*^9}, {3.5876210566279097`*^9, 
   3.5876210894971676`*^9}, 3.6176000248214893`*^9, 3.617600085801996*^9, 
   3.707485332479919*^9},ExpressionUUID->"8d616ffd-0a7c-4d02-a808-\
0150e9dfdda5"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"u", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.5876211520064774`*^9, 3.587621171943312*^9}, {
   3.5876212035333676`*^9, 3.5876212069809732`*^9}, 
   3.7074853324801207`*^9},ExpressionUUID->"32d1a578-6ea2-4e1c-8725-\
5e7699b3c216"],

Cell["We shall assume that v is the arc length of the space curve:", "Text",
 CellChangeTimes->{{3.5876215279827375`*^9, 3.587621564190401*^9}, 
   3.6152641666586914`*^9, 
   3.70748533248029*^9},ExpressionUUID->"6f570d83-1e8d-4cfb-99eb-\
048e87f04a2f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"arcl", " ", "=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"curve", "[", "v", "]"}], ",", "v"}], "]"}], ".", " ", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"curve", "[", "v", "]"}], ",", "v"}], "]"}]}], "==", "1"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"curve", "[", "v", "]"}], ",", "v"}], "]"}], ".", " ", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"curve", "[", "v", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", "2"}], "}"}]}], "]"}]}], "==", " ", "0"}]}], 
    "}"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.58762160342447*^9, 3.58762167150299*^9}, {
   3.5876218099844327`*^9, 3.5876218138688393`*^9}, {3.587621898998189*^9, 
   3.587621913833815*^9}, {3.5876219516638813`*^9, 3.5876219707739153`*^9}, {
   3.587622105526952*^9, 3.587622222090357*^9}, {3.587732305290656*^9, 
   3.5877323565367465`*^9}, {3.5877346417807617`*^9, 
   3.5877346617487965`*^9}, {3.5877347212941017`*^9, 
   3.5877347303421173`*^9}, {3.588162712104797*^9, 3.5881627655508537`*^9}, {
   3.588162871047888*^9, 3.588162886310761*^9}, {3.614861852109126*^9, 
   3.6148618521247263`*^9}, {3.6149177841361475`*^9, 3.614917784167348*^9}, 
   3.707485332480604*^9},ExpressionUUID->"9a2d8f3e-0380-418c-bc4b-\
92d0d0ea8690"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], "2"], 
     "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], "2"], 
     "+", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], "2"]}], 
    "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "1", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "2", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}], " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "v", "]"}], "[", "3", "]"}]}]}], 
    "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7083218502746696`*^9},ExpressionUUID->"6f09a1ac-5fb1-4431-9b6a-\
7d19a3fb54c8"]
}, Open  ]],

Cell["\<\
Now we calculate the spherical image of the regular part of the tangent \
surface:\
\>", "Text",
 CellChangeTimes->{{3.5876231220247374`*^9, 3.5876231738636284`*^9}, 
   3.707485332482305*^9},ExpressionUUID->"5d5ed5f2-e5cf-457f-93fe-\
f94ea8599a9b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", "arcl"}], "]"}]], "Input",
 CellChangeTimes->{{3.5881630905624437`*^9, 3.5881631391492224`*^9}, 
   3.6148618521403265`*^9, 3.6149177841829476`*^9, 3.6151813113289614`*^9, 
   3.707485332482585*^9},ExpressionUUID->"c4ac8a1e-a2d4-4cb6-8d95-\
8e0179cb71db"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", ">", "0"}], ",", "arcl"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587621684622613*^9, 3.587621793027203*^9}, 
   3.5876222348823795`*^9, {3.5876223777942305`*^9, 3.5876223968730636`*^9}, {
   3.5881629216867847`*^9, 3.5881629433340225`*^9}, {3.5881630472379656`*^9, 
   3.5881630616367893`*^9}, 3.6148618521559267`*^9, 3.6149177841985474`*^9, 
   3.615181313257072*^9, 
   3.7074853324828777`*^9},ExpressionUUID->"d36401c7-f796-4f6b-9b7d-\
9eb5d8f2f1e6"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "<", "0"}], ",", "arcl"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.587621684622613*^9, 3.587621793027203*^9}, 
   3.5876222348823795`*^9, {3.5876223777942305`*^9, 3.5876223968730636`*^9}, {
   3.5881629216867847`*^9, 3.5881629433340225`*^9}, {3.588162991834797*^9, 
   3.5881630291659317`*^9}, 3.609815167604488*^9, 3.614861852171527*^9, 
   3.6149177841985474`*^9, 3.61518131444914*^9, 
   3.707485332483169*^9},ExpressionUUID->"d875256c-bee7-4d48-9360-\
4080aadbbad4"],

Cell["\<\
Obviously, this vector does not depend on u. It is proportional to the \
binormal vector of the curve. Indeed, denote  the orthonormal Frenet frame of \
the curve by frc[i][v]\
\>", "Text",
 CellChangeTimes->{{3.587732407077636*^9, 3.587732462603733*^9}, {
   3.5881617314507065`*^9, 3.588161813658409*^9}, {3.5881619205945253`*^9, 
   3.5881620015621567`*^9}, 3.588162068818003*^9, 3.5881621797223463`*^9, {
   3.5881632090832224`*^9, 3.5881632112343454`*^9}, {3.6098152094808826`*^9, 
   3.609815219712468*^9}, 3.6277416758579445`*^9, 
   3.707485332483406*^9},ExpressionUUID->"e2a49758-600c-4d8f-99d7-\
852c1f82b149"],

Cell[BoxData[
 RowBox[{"?", "frenet"}]], "Input",
 CellChangeTimes->{{3.5881621858806987`*^9, 3.5881621891138835`*^9}, 
   3.707485332483597*^9},ExpressionUUID->"57314b49-8ae4-4dab-ad85-\
90ac7c427f61"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"frc", "[", "i_", "]"}], "[", "v_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"frenet", "[", "curve", "]"}], "[", "v", "]"}], "[", 
   RowBox[{"[", "i", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5881620864630127`*^9, 3.5881621696497707`*^9}, {
   3.588162213157259*^9, 3.5881622519004745`*^9}, 3.6277415330552936`*^9, 
   3.70748533248387*^9},ExpressionUUID->"cf5e24d0-ea24-4d8c-8ce0-\
e6e9668ea05d"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"frc", "[", "1", "]"}], "[", "v", "]"}], ",", "arcl"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.588162260438963*^9, 3.588162294247897*^9}, 
   3.62774161653104*^9, 
   3.707485332484103*^9},ExpressionUUID->"96826c99-57fd-4e68-ac73-\
4c4d37e9b8d7"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"frc", "[", "2", "]"}], "[", "v", "]"}], ",", "arcl"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.588162260438963*^9, 3.58816232507666*^9}, 
   3.627741618200243*^9, 
   3.707485332484337*^9},ExpressionUUID->"32b673a0-db72-434c-8d61-\
12354d50d84c"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"frc", "[", "3", "]"}], "[", "v", "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "/.", 
    RowBox[{"u", "\[Rule]", "1"}]}], ",", "arcl"}], "]"}]], "Input",
 CellChangeTimes->{{3.5881624193480525`*^9, 3.5881624769663477`*^9}, 
   3.588162509207192*^9, 3.588163534773851*^9, {3.588163584366688*^9, 
   3.5881636160775013`*^9}, {3.6098154243721743`*^9, 3.609815444524327*^9}, 
   3.6148618522027264`*^9, 3.6149177841985474`*^9, 3.6151813235776625`*^9, 
   3.62774162194425*^9, 
   3.7074853324846373`*^9},ExpressionUUID->"d5c34c5f-4c3f-4fed-a75c-\
1e90d9e109d9"],

Cell[TextData[{
 StyleBox["Lemma 2",
  FontColor->RGBColor[0, 0, 1]],
 ".  The tangent  planes of the tangent surface of a regular generally curved \
 curve form a 1-parametric family of planes, namely the osculating planes of \
the curve.\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.588163746058936*^9, 3.588163855090172*^9}, {
   3.588163888538085*^9, 3.588163931786559*^9}, 3.609815337807223*^9, 
   3.6098153803756576`*^9, {3.6098158536767287`*^9, 3.6098158536827292`*^9}, {
   3.696826293955559*^9, 3.696826320939296*^9}, 
   3.707485332484935*^9},ExpressionUUID->"7923199b-1eba-4177-bd36-\
3b8890a9075e"],

Cell["\<\
Again the spherical image  is a curve on the unit sphere only.  The first \
fundamental form of the tangent surface is\
\>", "Text",
 CellChangeTimes->{{3.5876231834576454`*^9, 3.5876232754354067`*^9}, {
   3.587732519481433*^9, 3.5877325282954483`*^9}, 
   3.7074853324851418`*^9},ExpressionUUID->"6160422f-95b2-48c4-874b-\
7fb394044116"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"u", ">", "0"}], ",", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FormBox["fund1",
         TraditionalForm], "[", 
        RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", "arcl"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5876233192090836`*^9, 3.5876233215178876`*^9}, {
   3.58762344825251*^9, 3.5876235183590336`*^9}, 3.5904957105934095`*^9, {
   3.609815592204774*^9, 3.6098156350922265`*^9}, 
   3.707485332485485*^9},ExpressionUUID->"9077b358-1142-4e41-84a0-\
e7f6700f52a5"],

Cell[TextData[{
 "The coefficient of ",
 Cell[BoxData[
  SuperscriptBox["s2", "2"]],
  CellChangeTimes->{3.587623484054573*^9, 3.587623520870638*^9, 
   3.587731983789692*^9, 3.5877325449718776`*^9, 3.588143353745921*^9, 
   3.5881434770949764`*^9},ExpressionUUID->
  "7b11fd70-d8b6-4c11-99cc-35d03b5dd691"],
 " depends on the curvature of the curve:"
}], "Text",
 CellChangeTimes->{{3.5881611650823126`*^9, 3.5881612328341875`*^9}, 
   3.5881615556586523`*^9, 
   3.707485332485834*^9},ExpressionUUID->"653a0a30-47a6-4063-82b1-\
7254b428ab62"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"u", "*", 
        RowBox[{
         RowBox[{"curvature", "[", "curve", "]"}], "[", "v", "]"}]}], ")"}], 
      "^", "2"}]}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"rgT", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "[", 
      RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", "arcl"}], "]"}]], "Input",
 CellChangeTimes->{{3.587732635249236*^9, 3.587732665138889*^9}, {
   3.587734459322841*^9, 3.5877344750476685`*^9}, {3.587734557213013*^9, 
   3.587734573624242*^9}, {3.588143552923313*^9, 3.588143610522608*^9}, {
   3.588143658443349*^9, 3.588143660107444*^9}, {3.5881437021078463`*^9, 
   3.5881437113943777`*^9}, 3.6098156989718804`*^9, 3.6148618522183266`*^9, 
   3.6148631365061827`*^9, {3.61518849458801*^9, 3.6151885227476206`*^9}, {
   3.617946380169375*^9, 3.6179464749551415`*^9}, {3.6179465495700727`*^9, 
   3.617946552346877*^9}, {3.617946583468932*^9, 3.617946594357751*^9}, 
   3.707485332486158*^9},ExpressionUUID->"ee278483-3e2b-4c5c-bb20-\
f5794a53693c"],

Cell["\<\
Denote the curvature of the generating curve by k[v]. Then the first \
fundamental form is in traditional notation\
\>", "Text",
 CellChangeTimes->{{3.58816433061037*^9, 3.588164431618148*^9}, {
   3.588166702827053*^9, 3.5881667068342824`*^9}, 
   3.7074853324863777`*^9},ExpressionUUID->"4c1260b3-2772-42a1-a175-\
dd194400ddec"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["ds", "2"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["du", "2"], "+", 
    RowBox[{"2", " ", "du", " ", "dv"}], "+", 
    RowBox[{
     SuperscriptBox["dv", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox["u", "2"]}], "+", "1"}], ")"}]}]}]}], 
  TraditionalForm]], "Input",
 CellChangeTimes->{{3.5881644831580954`*^9, 3.5881645610145483`*^9}, {
   3.588164594589469*^9, 3.5881646515087247`*^9}, 3.588164796428014*^9, {
   3.588166618812248*^9, 3.5881666271647253`*^9}, {3.588166660402627*^9, 
   3.588166674374426*^9}, 
   3.707485332486664*^9},ExpressionUUID->"7290befe-8565-4e0d-a81e-\
59f2946559b0"],

Cell[TextData[{
 StyleBox["Lemma 3",
  FontColor->RGBColor[0, 0, 1]],
 ". A tangent surface of a generally curved curve is locally isometric to the \
Euclidean plane."
}], "Text",
 CellChangeTimes->{{3.5881661309633446`*^9, 3.5881661511865015`*^9}, {
   3.5881661837943664`*^9, 3.588166194841998*^9}, {3.5881662727544546`*^9, 
   3.5881663097305694`*^9}, {3.5881663506989126`*^9, 
   3.5881664278183236`*^9}, {3.588166502170576*^9, 3.5881666479229126`*^9}, 
   3.588166770114902*^9, {3.696826412794614*^9, 3.696826416194414*^9}, 
   3.707485332486833*^9},ExpressionUUID->"742e924c-79d3-4e5d-ba94-\
5ee757279163"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". Let k[v] be the curvature of the curve as a function of the arc length.  \
We consider a plane curve with the same curvature.Then the tangent surface of \
this curve is a part of the plane and this part with the coordinates u,v of \
the tangent surface has the same first fundamental form as ",
 Cell[BoxData[
  StyleBox[
   SuperscriptBox["ds", "2"],
   FontWeight->"Bold"]],
  CellChangeTimes->{{3.5881644831580954`*^9, 3.5881645610145483`*^9}, {
    3.588164594589469*^9, 3.5881646515087247`*^9}, 3.588164796428014*^9, {
    3.588166618812248*^9, 3.5881666271647253`*^9}},ExpressionUUID->
  "f0154be8-07df-45e4-9da9-c29f4e4ba873"],
 " above; the map defined by equal parameters  is an isometry.\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.5881661309633446`*^9, 3.5881661511865015`*^9}, {
   3.5881661837943664`*^9, 3.588166194841998*^9}, {3.5881662727544546`*^9, 
   3.5881663097305694`*^9}, {3.5881663506989126`*^9, 
   3.5881664278183236`*^9}, {3.588166502170576*^9, 3.5881666479229126`*^9}, {
   3.588166770114902*^9, 3.588166781762568*^9}, {3.589623715895505*^9, 
   3.589623784606435*^9}, {3.609815789441055*^9, 3.6098157902561016`*^9}, {
   3.6098158333205643`*^9, 3.609815833331565*^9}, 3.615264176211238*^9, {
   3.6179466864915133`*^9, 3.617946694260327*^9}, 3.6179473026156626`*^9, 
   3.707485332487084*^9},ExpressionUUID->"ebb84a0c-03ce-47bc-906d-\
261f8c7db466"],

Cell[TextData[{
 StyleBox["Example 4.",
  FontColor->RGBColor[0, 0, 1]],
 " To plot an image of a tangent surface it isn\[CloseCurlyQuote]t necessary \
to assume v to be the arc length of the curve. If not done yet, first load ",
 ButtonBox["CURVES`",
  BaseStyle->"Hyperlink",
  ButtonData->"curves"],
 " Take a space curve of A. Gray\[CloseCurlyQuote]s list, e. g."
}], "Text",
 CellChangeTimes->{{3.6098159294240613`*^9, 3.6098160902722616`*^9}, {
   3.6098165374328375`*^9, 3.60981659482412*^9}, {3.6098166414167852`*^9, 
   3.6098166414217854`*^9}, 3.6152641791634064`*^9, {3.627745547535145*^9, 
   3.6277455529327545`*^9}, {3.6968265679699907`*^9, 3.696826569793976*^9}, 
   3.7074853324873323`*^9},ExpressionUUID->"9637fd22-e4d6-4f25-bcac-\
bc85297c51a8"],

Cell[BoxData[
 RowBox[{"?", "twistedn"}]], "Input",
 CellChangeTimes->{{3.6151885869542933`*^9, 3.61518858813136*^9}, 
   3.707485332487515*^9},ExpressionUUID->"de3b81a7-1dce-4a3c-9daf-\
f9506af67822"],

Cell[BoxData[
 RowBox[{
  RowBox[{"twistedn", "[", 
   RowBox[{"3", ",", "1"}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.6098163918435106`*^9, 3.6098164178099957`*^9}, 
   3.6098166758507547`*^9, 
   3.707485332487733*^9},ExpressionUUID->"f524c8bb-5720-4fdc-bc7b-\
e4d751415f91"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"twistedn", "[", 
      RowBox[{"3", ",", "1"}], "]"}], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", " ", "Red"}], "}"}]}]}], "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.6098167011682024`*^9, 3.6098167997948437`*^9}, {
   3.6098172238280973`*^9, 3.609817253964821*^9}, 3.6098184802129583`*^9, 
   3.7074853324879932`*^9},ExpressionUUID->"3ac259a9-f942-4b7a-adc1-\
90073ef1760e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cubic", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6098172685086527`*^9, 3.6098172828574734`*^9}, 
   3.7074853324881897`*^9},ExpressionUUID->"8e942553-d97d-4e70-b2b8-\
95875eb69870"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tangsf", "[", 
   RowBox[{"twistedn", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.609817055443466*^9, 
  3.707485332488413*^9},ExpressionUUID->"c13d7338-c815-4685-a5d7-\
ae7c63e6a8e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"tangsf", "[", 
       RowBox[{"twistedn", "[", 
        RowBox[{"3", ",", "1"}], "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"Green", ",", 
       RowBox[{"Opacity", "[", ".4", "]"}]}], "}"}]}]}], "]"}], 
  "\n"}]], "Input",
 CellChangeTimes->{{3.6098167011682024`*^9, 3.6098167997948437`*^9}, {
   3.609816865372595*^9, 3.6098169849714355`*^9}, {3.609817087804317*^9, 
   3.6098171001240215`*^9}, {3.609817172053136*^9, 3.609817178644513*^9}, {
   3.6098175673657465`*^9, 3.6098175700919023`*^9}, 3.6148618522183266`*^9, 
   3.6149177842141476`*^9, {3.61794697485802*^9, 3.617946978024825*^9}, {
   3.696826732346602*^9, 3.696826786225284*^9}, {3.696826853396709*^9, 
   3.696826855488241*^9}, 3.696826937613297*^9, 
   3.7074853324887037`*^9},ExpressionUUID->"2c072070-c313-4b5f-aacc-\
45d5e9c0e323"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"cubic", ",", "%"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6098174162581034`*^9, 3.6098174565804095`*^9}, 
   3.707485332488923*^9},ExpressionUUID->"ba5ead92-14af-46ec-8765-\
929961a16909"],

Cell[TextData[{
 "As  shown at the beginning of this subsection, the curve itself consists of \
singularities of the surface; in German such a singular curve is named the ",
 StyleBox["R\[UDoubleDot]ckkehrkante",
  FontColor->RGBColor[0, 0, 1]],
 " of the tangent surface."
}], "Text",
 CellChangeTimes->{{3.609818220856124*^9, 3.6098183795682015`*^9}, 
   3.615264200418622*^9, 3.6277457031922183`*^9, 
   3.707485332489094*^9},ExpressionUUID->"95f153aa-19b2-4fb9-9c0e-\
a73db804ea5c"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.7. Developable Surfaces 1", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, {3.5875506376928062`*^9, 
   3.58755065084363*^9}, {3.5875621007464747`*^9, 3.5875621112900777`*^9}, {
   3.5881675117713223`*^9, 3.5881675315864553`*^9}, {3.590039110793*^9, 
   3.590039112899004*^9}, 3.609818829057911*^9, 3.6098201375367517`*^9, 
   3.617947335801561*^9, 3.6179498973303094`*^9, 3.627745769523535*^9, 
   3.627812689599845*^9, 3.6968275703788233`*^9, 3.6968296698980093`*^9, 
   3.7074857960600023`*^9, 
   3.707544476747713*^9},ExpressionUUID->"e24ecd5a-e553-4a81-94fa-\
9a78657502e9"],

Cell[TextData[{
 "The surfaces considered in Subsections 2.1.3 - 6 have the following common \
properties:\n1. Locally, in a neighborhood of its regular points, they are \
isometric to open sets in the Euclidean plane. \n2. They are ruled surfaces \
whose tangent planes are constant along the rulings; the tangent planes form \
a 1-parameter family, and the surface is the ",
 StyleBox["envelope",
  FontColor->RGBColor[0, 0, 1]],
 " of this family. Such surfaces are named ",
 StyleBox["developable",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 StyleBox["surfaces",
  FontColor->RGBColor[0, 0, 1]],
 " (also ",
 StyleBox["torses",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[").",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.588167702162212*^9, 3.588167785762994*^9}, {
   3.5881678992664857`*^9, 3.5881680912674675`*^9}, {3.588168243835194*^9, 
   3.5881683815790725`*^9}, {3.5881684601945686`*^9, 
   3.5881684888672085`*^9}, {3.5881685413312097`*^9, 
   3.5881685562750645`*^9}, {3.5881687263187904`*^9, 
   3.5881687325821486`*^9}, {3.588313711952491*^9, 3.5883137251212435`*^9}, {
   3.617947741961583*^9, 3.617947772433326*^9}, {3.6179478375380497`*^9, 
   3.617947840217203*^9}, 
   3.627809399644973*^9},ExpressionUUID->"373e8b78-bcfe-41d2-b200-\
f5f6fc689c34"],

Cell[TextData[{
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 ". Sometimes the surfaces having the property 1 are called developable. We \
shall see that both properties are equivalent."
}], "Text",
 CellChangeTimes->{{3.588168501626939*^9, 3.5881685296505413`*^9}, {
   3.588168564514536*^9, 3.588168628546198*^9}, 3.588168834290966*^9, 
   3.588168905955065*^9},ExpressionUUID->"f160d7f4-b602-4c67-8f57-\
b9a14436d273"],

Cell[TextData[{
 "We specify the concept of the ",
 StyleBox["envelope",
  FontColor->RGBColor[0, 0, 1]],
 " of a 1-parametric family of planes. Consider this family as defined by the \
Hesse normal form of the plane equation"
}], "Text",
 CellChangeTimes->{{3.5881689795302734`*^9, 3.58816911077878*^9}, 
   3.588223189320817*^9, {3.627809545158792*^9, 
   3.6278095461259937`*^9}},ExpressionUUID->"52f28d38-12ff-41c1-9abe-\
67a37989f60f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.696827950559848*^9, 
  3.696827972454968*^9}},ExpressionUUID->"6ea03828-01af-4c0a-9255-\
a906b56ba231"],

Cell[BoxData[
 RowBox[{"    ", 
  RowBox[{
   RowBox[{"H", "[", "v", "]"}], ":", "   ", 
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"p", "[", "v", "]"}], "                      ", 
     RowBox[{"(", "1", ")"}], "     "}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.58816914451871*^9, 3.588169184516998*^9}, {
  3.588169223453225*^9, 3.5881692616134076`*^9}, {3.588169784484314*^9, 
  3.588169790045632*^9}, {3.588170630071679*^9, 3.588170636168028*^9}, {
  3.5882232147176614`*^9, 3.5882232961654043`*^9}, {3.7075372608657722`*^9, 
  3.7075372961137238`*^9}},ExpressionUUID->"e4eb1902-f7a6-4fb4-b6ee-\
f6bed6856197"],

Cell[BoxData[
 RowBox[{"         ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}]}], "\[Equal]", " ", "1", 
   "                              "}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.58816914451871*^9, 3.588169184516998*^9}, {
   3.588169223453225*^9, 3.5881692616134076`*^9}, {3.588169784484314*^9, 
   3.588169790045632*^9}, {3.588170630071679*^9, 3.588170636168028*^9}, {
   3.5882232147176614`*^9, 3.5882232961654043`*^9}, 
   3.707537324666053*^9},ExpressionUUID->"bc4abd46-9c9c-400f-b9b3-\
83e14de712ee"],

Cell["\<\
vec[n[v]] is the unit normal vector of the plane  H[v], and p[v] is its \
oriented distance to the origin. We assume that in general two neighbored \
planes of the family are not parallel. Then the neighbored plane\
\>", "Text",
 CellChangeTimes->{{3.5881692817635603`*^9, 3.588169296634411*^9}, {
   3.5881693277151885`*^9, 3.5881693600910397`*^9}, {3.5881694707303686`*^9, 
   3.5881694890984187`*^9}, {3.588169563994703*^9, 3.5881696304745054`*^9}, 
   3.5882233336678705`*^9, 3.6151891048899174`*^9, {3.6278096679774113`*^9, 
   3.627809669428214*^9}},ExpressionUUID->"e9bc822a-0641-45ee-b9a2-\
090c18903365"],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}], ":", "   ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", 
      RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}], "]"}], ".", 
    RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{"p", "[", 
    RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}]}]}]], "Input",
 Evaluatable->False,ExpressionUUID->"69900bd0-3246-4d5a-a247-fe33a2070dee"],

Cell["\<\
and the plane (1) intersect in a line. Subtracting (1) from the last equation \
we get the equivalent system with (1) and\
\>", "Text",
 CellChangeTimes->{{3.588169817044176*^9, 
  3.5881699449544926`*^9}},ExpressionUUID->"3ea0a10c-ae75-459f-8176-\
f1b1c8a21ed7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", 
       RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}], "]"}], "-", 
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", "v", "]"}], "]"}]}], ")"}], ".", 
   RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"p", "[", 
    RowBox[{"v", "+", "\[CapitalDelta]v"}], "]"}], " ", "-", 
   RowBox[{"p", "[", "v", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5881696746290307`*^9, 3.5881697198396163`*^9}, {
   3.5881699584912663`*^9, 3.5881700206618223`*^9}, 
   3.5881709190392065`*^9},ExpressionUUID->"3f4afe91-b076-4ff4-9cc5-\
0ff13d567172"],

Cell["\<\
Dividing by \[CapitalDelta]v and considering the limit for \[CapitalDelta]v \
-> 0 we obtain\
\>", "Text",
 CellChangeTimes->{{3.5881701424827905`*^9, 3.5881702165230255`*^9}, {
  3.5882235164354544`*^9, 
  3.588223517291504*^9}},ExpressionUUID->"15ee78f5-8540-4361-ac57-\
e4aff5a999bb"],

Cell[BoxData[
 RowBox[{"               ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "'"}], "[", "v", "]"}], "                      ", 
    RowBox[{"(", "2", ")"}], "  "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5881703486705837`*^9, 3.5881704729966946`*^9}, {
  3.5882233724339385`*^9, 3.5882233992659855`*^9}, {3.588249351418147*^9, 
  3.588249351418147*^9}, {3.707537512577929*^9, 
  3.707537541904242*^9}},ExpressionUUID->"1f30f94a-fda4-4523-a90e-\
287572c62ac1"],

Cell[TextData[{
 "The linear system (1), (2) defines the limit of the intersection line of \
two neighbored planes; it is a line L[v] \[Subset] H[v].  The family of these \
lines  describes a surface, called the ",
 StyleBox["envelope",
  FontColor->RGBColor[0, 0, 1]],
 " of the plane family. We will find a parameter representation of this \
surface. \n First we exclude the trivial case: vec[n[v]] = constant  Then by \
(2)  there exists a solution only iff also p[v)== constant, and the solution \
is the whole plane given by (1).  Now we assume"
}], "Text",
 CellChangeTimes->{{3.588170493386861*^9, 3.588170564282916*^9}, 
   3.5881706131627116`*^9, {3.5881707202988396`*^9, 3.5881708395146585`*^9}, 
   3.588223422057626*^9, {3.588223503955741*^9, 3.588223504307761*^9}, 
   3.5882235387797327`*^9, 3.588223578346996*^9, {3.588223678451721*^9, 
   3.588223703267141*^9}, {3.5882237384271517`*^9, 3.5882239335233107`*^9}, {
   3.588223980171979*^9, 3.588224014403937*^9}, {3.588224092035377*^9, 
   3.5882240997228165`*^9}, {3.707537581037348*^9, 
   3.7075375954300537`*^9}},ExpressionUUID->"6c461306-7524-48e6-b993-\
8d3a56bf4477"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{
    RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], "\[NotEqual]", " ", 
  RowBox[{"null", "[", "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.588224154310939*^9, 3.5882241641175003`*^9}, 
   3.588249351418147*^9},ExpressionUUID->"2c5f8f67-0edf-4ada-8941-\
d961efdbb786"],

Cell[TextData[{
 "for all values of v; that means we exclude the",
 StyleBox[" singular planes",
  FontColor->RGBColor[0, 0, 1]],
 " of the family not satisfying this assumption. Further we assume that v is \
the arc length of the curve vec[n[v]] on the unit sphere. It follows"
}], "Text",
 CellChangeTimes->{{3.588224215228423*^9, 3.5882242746508217`*^9}, {
  3.5882243074997005`*^9, 3.588224418731063*^9}, {3.6152642253870506`*^9, 
  3.6152642280992055`*^9}},ExpressionUUID->"e55d9215-cbca-43c0-b035-\
27da7f346270"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}], "\[Equal]", "1"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.588224458469336*^9, 3.5882244813016415`*^9}, {
  3.588249351418147*^9, 
  3.5882493514337473`*^9}},ExpressionUUID->"f0f45a04-8571-445a-8c26-\
eac2ef6d1c6d"],

Cell["and by derivation", "Text",
 CellChangeTimes->{{3.588224538131892*^9, 
  3.5882245496755524`*^9}},ExpressionUUID->"ef9fb1aa-4137-4b29-8dce-\
7c811c5b9a3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
  "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882245658614783`*^9, 3.588224670981491*^9}, 
   3.588249351464947*^9},ExpressionUUID->"9ac6a751-fd01-4c84-afbd-\
89787733315c"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "''"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
   "0"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882245658614783`*^9, 3.588224670981491*^9}, {
  3.588249351480547*^9, 
  3.588249351480547*^9}},ExpressionUUID->"553da768-09af-436c-aa85-\
2123e33d2c05"],

Cell["\<\
Since vec[n[v]], vec[n'[v]] are orthogonal unit vectors the lines L[v] as \
solutions of the system (1), (2) exist and are uniquely defined. We choose an \
arbitrary smooth curve of solution points vec[x[v]] \[Element] L[v]. Then the \
difference vector with any solution vector\
\>", "Text",
 CellChangeTimes->{{3.588224756027355*^9, 3.588225057963625*^9}, {
   3.5882250974998865`*^9, 3.588225159196415*^9}, 3.5882493515117474`*^9, {
   3.5883143728092895`*^9, 
   3.5883144417842345`*^9}},ExpressionUUID->"7eb3f55a-00ab-4940-ab28-\
245c8ce78de3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", "x", "]"}], "-", 
  RowBox[{"vec", "[", 
   RowBox[{"x", "[", "v", "]"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.588225162159585*^9, 
  3.5882251621605844`*^9}},ExpressionUUID->"4aba4406-30af-4030-b587-\
e1d05dd1b2e9"],

Cell["satisfies", "Text",
 CellChangeTimes->{{3.5882251698270235`*^9, 
  3.588225182027721*^9}},ExpressionUUID->"ab94206f-6cde-4319-b6ec-\
3419979ae13c"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"vec", "[", "x", "]"}], "-", 
      RowBox[{"vec", "[", 
       RowBox[{"x", "[", "v", "]"}], "]"}]}], ")"}]}], "\[Equal]", " ", 
   "0"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882252507816534`*^9, 
  3.588225301341545*^9}},ExpressionUUID->"caba0849-7dc2-4672-b5ed-\
52016afa9001"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"vec", "[", "x", "]"}], "-", 
      RowBox[{"vec", "[", 
       RowBox[{"x", "[", "v", "]"}], "]"}]}], ")"}]}], "\[Equal]", " ", 
   "0"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882252507816534`*^9, 3.588225337870635*^9}, 
   3.5882493515273476`*^9},ExpressionUUID->"9be19bfa-655d-4f09-885b-\
571b8f7fb2d2"],

Cell[" and with", "Text",
 CellChangeTimes->{{3.588225361011958*^9, 
  3.588225364643166*^9}},ExpressionUUID->"a9a0f273-aab2-4030-860a-\
65ddc99c2044"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "n", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"cr3", "[", "n_", "]"}], "[", "v_", "]"}], ":=", " ", 
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", "v", "]"}], "]"}], ",", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5882253883235207`*^9, 3.588225509749466*^9}, 
   3.5882493515273476`*^9, {3.707538624130794*^9, 3.707538652784959*^9}, {
   3.7075392158877172`*^9, 3.707539224623166*^9}, 
   3.7075392614075813`*^9},ExpressionUUID->"10aa39cc-0134-49a7-8be1-\
08632fea304b"],

Cell["\<\
we obtain the wanted parameter representation of the envelope as the ruled \
surface\
\>", "Text",
 CellChangeTimes->{{3.5882255299016185`*^9, 3.588225543363388*^9}, {
  3.588225639010859*^9, 
  3.5882256690675783`*^9}},ExpressionUUID->"2557d460-e119-457f-b4e4-\
db71bd9c100d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "solsf", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"solsf", "[", "n_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"x", "[", "v", "]"}], "]"}], " ", "+", " ", 
    RowBox[{"u", "*", 
     RowBox[{
      RowBox[{"cr3", "[", "n", "]"}], "[", "v", "]"}]}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5882255749011917`*^9, 3.588225629869336*^9}, {
  3.588227285079009*^9, 3.5882272865500927`*^9}, {3.7075387144424753`*^9, 
  3.7075387494199657`*^9}, {3.707539295054448*^9, 
  3.707539317117642*^9}},ExpressionUUID->"0f17fe1b-f8f8-48a4-9525-\
1bd4d6a5d4c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solsf", "[", "n", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5882256864725733`*^9, 3.5882256943570247`*^9}, {
  3.5882272973097086`*^9, 3.588227298808794*^9}, {3.707538768571986*^9, 
  3.707538786348866*^9}, {3.707538818877864*^9, 3.707538839437079*^9}, {
  3.707538922166243*^9, 3.707538974205863*^9}, {3.70753917599203*^9, 
  3.70753918531859*^9}},ExpressionUUID->"d17651a0-cc08-4b9e-9ff1-\
aee5ad935fc5"],

Cell["\<\
Regard that (vec[n[v]] ,vec[n'[v]], cr3[n][v]) form a family of positively \
oriented orthonormal frames of the Euclidean vector space.\
\>", "Text",
 CellChangeTimes->{{3.588226562763695*^9, 3.5882266954272823`*^9}, 
   3.5882493515741477`*^9, {3.5883145374247046`*^9, 3.5883145665123687`*^9}, 
   3.615264263011202*^9, {3.707542545678287*^9, 
   3.707542550877887*^9}},ExpressionUUID->"61da3f40-5e6d-4ec4-aaa3-\
366cecbb8597"],

Cell["\<\
We will specify the choice of the up to now arbitrary point vec[x[v]] \
\[Element] L[v]. The lines L(v) \[Subset] solsf form a 1-parameter family of \
lines on solsf and this family may have an envelope being a curve in solsf. \
Considering the intersection point of two neighbored lines and forming the \
limit as before for the planes we obtain the new equation\
\>", "Text",
 CellChangeTimes->{{3.5882270884837637`*^9, 3.588227163644063*^9}, {
  3.5882272044033947`*^9, 3.5882272723632812`*^9}, {3.5882273138996572`*^9, 
  3.588227314427687*^9}, {3.5882273797874255`*^9, 3.5882274552117395`*^9}, {
  3.588227606035366*^9, 3.588227705715068*^9}, {3.5882277412511005`*^9, 
  3.5882277753560505`*^9}, {3.588314581137205*^9, 3.5883146185293436`*^9}, {
  3.5896240502636294`*^9, 3.589624065926525*^9}, {3.627810895632959*^9, 
  3.6278108972397614`*^9}},ExpressionUUID->"c41209e0-95df-48f3-a1ab-\
d6f8677d74d0"],

Cell[BoxData[
 RowBox[{"        ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "''"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"p", "''"}], "[", "v", "]"}], "                                ", 
    RowBox[{"(", "3", ")"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882277882617893`*^9, 3.588227862166016*^9}, {
  3.588227911814856*^9, 3.5882279124458923`*^9}, {3.5882493515897474`*^9, 
  3.5882493515897474`*^9}, {3.588249855162869*^9, 3.588249862274276*^9}, {
  3.7075426086918087`*^9, 
  3.7075426351876383`*^9}},ExpressionUUID->"ce8aed26-12bc-4e65-8a23-\
464c24c5a9eb"],

Cell["\<\
Now considering the system (1), (2), (3) we assume that the vectors \
vec[n[v]],  vec[n\[CloseCurlyQuote][v]], vec[n\[CloseCurlyQuote]\
\[CloseCurlyQuote][v]] are linearly independent. Then for any value of v \
there exists a uniquely defined solution of the system, say vec[z[v]]. \
Inserting this solution and differentiating (1) we obtain using (2):\
\>", "Text",
 CellChangeTimes->{{3.5882507314879923`*^9, 3.5882508650476313`*^9}, {
   3.588250898919568*^9, 3.588250988743706*^9}, {3.588251026695877*^9, 
   3.5882510652160797`*^9}, {3.5882515321277857`*^9, 3.5882515797755113`*^9}, 
   3.5882544666876335`*^9, {3.588314657265559*^9, 3.588314702873168*^9}, 
   3.617948569314351*^9},ExpressionUUID->"4a6a3499-5025-453b-acb2-\
fb38ca05139b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"z", "'"}], "[", "v", "]"}], "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{"z", "[", "v", "]"}], "]"}]}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"p", "'"}], "[", "v", "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.588251647891407*^9, 3.5882517007304296`*^9}, {
  3.588252009659099*^9, 
  3.5882520141383553`*^9}},ExpressionUUID->"f3a84eed-6836-4cac-bdc5-\
ebe9bb12a5d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"z", "'"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
  "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882517374495296`*^9, 
  3.5882517400336776`*^9}},ExpressionUUID->"b2636f6d-cfcc-4559-b598-\
97a0ca1b5e7d"],

Cell["Analogously, differentiating (2) and using (3) we obtain", "Text",
 CellChangeTimes->{{3.588251764577081*^9, 
  3.588251813207863*^9}},ExpressionUUID->"c9a299f5-6916-4418-95b3-\
bb20cc8c6369"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "''"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{"z", "[", "v", "]"}], "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"z", "'"}], "[", "v", "]"}], "]"}]}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"p", "''"}], "[", "v", "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.588251647891407*^9, 3.5882517007304296`*^9}, {
   3.5882519593002186`*^9, 3.588252024290936*^9}, 
   3.6968290365351*^9},ExpressionUUID->"2858ed6b-2686-40b0-81dd-d0e57b372457"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"z", "'"}], "[", "v", "]"}], "]"}]}], "\[Equal]", " ", 
  "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882517374495296`*^9, 3.5882517400336776`*^9}, 
   3.588252071458634*^9},ExpressionUUID->"a50ebd78-c1a8-4f3d-aeed-\
d0bc209567e6"],

Cell["\<\
Remembering that vec[n[v]], vec[n\[CloseCurlyQuote][v]],  cr3[n][v] form an \
orthonormal frame we conclude\
\>", "Text",
 CellChangeTimes->{{3.5882520842993684`*^9, 3.588252111823943*^9}, {
  3.588252162215825*^9, 3.5882522530560207`*^9}, {3.7075430183191023`*^9, 
  3.707543025582921*^9}},ExpressionUUID->"003ec908-8bf6-4ef6-b202-\
16d7444d5b0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{
    RowBox[{"z", "'"}], "[", "v", "]"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"h", "[", "v", "]"}], "*", 
   RowBox[{
    RowBox[{"cr3", "[", "n", "]"}], "[", "v", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.588252291249205*^9, 3.5882523068100953`*^9}, {
  3.707543107405404*^9, 
  3.707543112694378*^9}},ExpressionUUID->"5ca9aa97-8528-4489-96d1-\
4f8f97d1fa1e"],

Cell["\<\
 for a certain function h[v]. If vec[z\[CloseCurlyQuote][v]] \[NotEqual] \
null[], the tangents of the curve vec[z[v]] coincide with L[v], we may take \
x[v].= z[v] in the description of the envelope and see that the envelope is \
the tangent surface of the solution vec[z[v]]. If, on the other hand, vec[z\
\[CloseCurlyQuote][v]] == null[] the solution vec[z[v]] ==  vec[z] is \
constant, and the envelope is a conical surface with the vertex vec[z].  It \
remains to consider the case that vec[n[v]], vec[n\[CloseCurlyQuote][v]], \
vec[n\[CloseCurlyQuote]\[CloseCurlyQuote][v]] are linearly dependent. Since \
vec[n[v]], vec[n\[CloseCurlyQuote][v]] are linearly independent there exist \
two functions h[v], f[v] such that\
\>", "Text",
 CellChangeTimes->{{3.5882523323675575`*^9, 3.5882523659594784`*^9}, {
   3.588252403119604*^9, 3.5882525301118674`*^9}, {3.588252562376713*^9, 
   3.588252669647848*^9}, {3.588252736247658*^9, 3.5882527644802723`*^9}, {
   3.5882527968651247`*^9, 3.5882528233836412`*^9}, {3.588252933663949*^9, 
   3.588252998519659*^9}, {3.5882537708398333`*^9, 3.5882538299282126`*^9}, {
   3.588254100159669*^9, 3.5882541141364684`*^9}, {3.58825416206621*^9, 
   3.588254201264452*^9}, {3.588254344448642*^9, 3.588254427728405*^9}, 
   3.588254475112115*^9, {3.588254820552873*^9, 3.588254859344092*^9}, 
   3.5882558381370754`*^9, {3.5883147947924256`*^9, 
   3.5883148574810114`*^9}},ExpressionUUID->"3ee3da6e-1ec9-4f8f-b500-\
d5053cbab388"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "''"}], "[", "v", "]"}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "v", "]"}], "*", 
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", "v", "]"}], "]"}]}], "+", " ", 
    RowBox[{
     RowBox[{"h", "[", "v", "]"}], "*", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], "        ", 
     RowBox[{"(", "4", ")"}]}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882548846685405`*^9, 3.588254949778264*^9}, {
  3.5882554002110276`*^9, 3.5882554059073534`*^9}, {3.707543722613051*^9, 
  3.70754374132393*^9}, {3.707543796557316*^9, 
  3.707543798861006*^9}},ExpressionUUID->"e1f4d4dc-10cf-4c33-86aa-\
a95440ba4648"],

Cell["\<\
The Dot product with vec[n\[CloseCurlyQuote][v]] yields h[v] == 0.  Deriving 
vec[n[v]].vec[n\[CloseCurlyQuote][v]] == 0 we obtain\
\>", "Text",
 CellChangeTimes->{{3.588254991015623*^9, 3.5882551163277903`*^9}, {
  3.5882552475522957`*^9, 3.588255277408004*^9}, {3.696829422836177*^9, 
  3.6968294368358517`*^9}},ExpressionUUID->"427dc223-e0e9-43b1-b431-\
a793246256ab"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}], ".", 
    RowBox[{"vec", "[", 
     RowBox[{
      RowBox[{"n", "''"}], "[", "v", "]"}], "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}]}], " ", "\[Equal]", " ", 
   RowBox[{"-", "1"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.58825529726814*^9, 3.5882553831390514`*^9}, 
   3.588255433762947*^9},ExpressionUUID->"946e745a-389f-4c10-a569-\
5af9566ae11e"],

Cell["\<\
and the Dot product of  (4) with vec[n[v]]  yields f[v] == -1, thus we have \
\>", "Text",
 CellChangeTimes->{{3.588255445336609*^9, 3.58825551791176*^9}, {
  3.588255961705143*^9, 
  3.5882559648163214`*^9}},ExpressionUUID->"b3a70a80-7146-4697-831b-\
fb112aecdc27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{
    RowBox[{"n", "''"}], "[", "v", "]"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}]}], "                                    ", 
   RowBox[{"(", "5", ")"}], "       "}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882556594018526`*^9, 3.588255677505888*^9}, {
  3.5882559714417*^9, 3.5882559760659647`*^9}, {3.707543881283786*^9, 
  3.707543890634756*^9}},ExpressionUUID->"0ec418f0-aa1b-4a25-851b-\
2dcd627ecbe7"],

Cell["Now we consider the tangent vector ", "Text",
 CellChangeTimes->{{3.5882557291788435`*^9, 3.588255736385256*^9}, {
  3.588255779688732*^9, 3.58825579258447*^9}, {3.5882560164642754`*^9, 
  3.5882560741835766`*^9}, {3.5882561426084905`*^9, 3.588256154536173*^9}, {
  3.588256323640845*^9, 3.5882563745037537`*^9}, {3.5883149684323573`*^9, 
  3.588315003656372*^9}, {3.7075440574771*^9, 3.7075440643977127`*^9}, {
  3.707544125876256*^9, 
  3.707544132163123*^9}},ExpressionUUID->"9852d936-5ff7-46cd-8807-\
0c7a38822219"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m", "[", "v_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"cr3", "[", "n", "]"}], "[", "v", "]"}], " ", "=", " ", 
   RowBox[{"Cross", "[", 
    RowBox[{"vec", "[", 
     RowBox[{"n", "[", "v", "]"}], "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.7075441390185843`*^9, 
  3.707544201034326*^9}},ExpressionUUID->"a02eae72-70dc-4dd3-8220-\
8c94b1348bb0"],

Cell["\<\
 vec[n'[v]]] of the line L[v]. We derive this equation and obtain \
\>", "Text",
 CellChangeTimes->{{3.5882557291788435`*^9, 3.588255736385256*^9}, {
  3.588255779688732*^9, 3.58825579258447*^9}, {3.5882560164642754`*^9, 
  3.5882560741835766`*^9}, {3.5882561426084905`*^9, 3.588256154536173*^9}, {
  3.588256323640845*^9, 3.5882563745037537`*^9}, {3.5883149684323573`*^9, 
  3.588315003656372*^9}, {3.7075440574771*^9, 3.7075440643977127`*^9}, {
  3.707544125876256*^9, 
  3.707544132163123*^9}},ExpressionUUID->"49f62e1b-853e-44a9-be2a-\
2ae34bb4fc1e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"m", "'"}], "[", "v", "]"}], " ", "==", " ", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], ",", " ", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "'"}], "[", "v", "]"}], "]"}]}], "]"}], "  ", "+", " ", 
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"n", "[", "v", "]"}], "]"}], ",", " ", 
     RowBox[{"vec", "[", 
      RowBox[{
       RowBox[{"n", "''"}], "[", "v", "]"}], "]"}]}], "]"}]}], " ", 
  "\[Equal]", " ", 
  RowBox[{"null", "[", "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5882561811636953`*^9, 3.5882562189628572`*^9}, {
   3.5882562738379965`*^9, 3.5882563086289864`*^9}, 3.5883150319099874`*^9, 
   3.707486039650179*^9},ExpressionUUID->"fe741ef3-c313-4890-b5a4-\
765708a25b36"],

Cell["\<\
Therefore m[v] is constant, and the envelope is a cylindrical surface.  \
Summarizing we proved:\
\>", "Text",
 CellChangeTimes->{{3.5882567953318243`*^9, 3.58825682305641*^9}, {
   3.5882568771925063`*^9, 3.588256903752025*^9}, 3.588315098768812*^9, {
   3.5883151461535225`*^9, 
   3.5883151633765073`*^9}},ExpressionUUID->"b4c32918-ea6d-4302-8bac-\
d8aef3c0cd22"],

Cell[TextData[{
 StyleBox["Proposition 1",
  FontColor->RGBColor[0, 0, 1]],
 ". The envelope of a family of planes (1) is the set of  all solutions of \
the system (1), (2).  If vec[n[v]] is constant the envelope is a plane. \
Otherwise the envelope is locally, in the neighborhood of a plane with "
}], "Text",
 CellChangeTimes->{{3.5883151680647755`*^9, 3.588315182672611*^9}, {
   3.5883152262491035`*^9, 3.588315279185131*^9}, {3.5883153113609715`*^9, 
   3.588315350529212*^9}, {3.5883153994650106`*^9, 3.588315515048622*^9}, {
   3.5883159339855833`*^9, 3.588315946921324*^9}, 3.6152643301310415`*^9, {
   3.69682954046737*^9, 
   3.696829542403263*^9}},ExpressionUUID->"20560a13-be1b-41f6-ba4f-\
bc60e48f307f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{
     RowBox[{"n", "'"}], "[", "v", "]"}], "]"}], " ", "\[NotEqual]", " ", 
   RowBox[{"null", "[", "]"}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5883155376899166`*^9, 
  3.588315562603342*^9}},ExpressionUUID->"1242e88e-d0a8-4953-b3b2-\
eaf63eb42809"],

Cell["\<\
a developable surface, namely a tangent surface, a conical or a cylindrical \
surface. Any such surface is the envelope of a 1-parametric family of planes, \
namely its tangent planes. Thus its spherical image is a curve. These \
surfaces are locally isometric to plane regions.\[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.5883155891288586`*^9, 3.5883156337204094`*^9}, {
   3.588315687208469*^9, 3.588315892569215*^9}, 3.589624400446659*^9, {
   3.609820118876684*^9, 
   3.6098201188846846`*^9}},ExpressionUUID->"b075029b-fdf9-4a85-aec7-\
cb61d12e787c"],

Cell["\<\
The last statement has been proved for each of the three types in subsections \
2.1.4-6.\
\>", "Text",
 CellChangeTimes->{{3.589624420686816*^9, 3.589624461254137*^9}, {
  3.5896244950710707`*^9, 
  3.589624519638476*^9}},ExpressionUUID->"6a25e849-6ef1-4e28-a778-\
e26b37281c95"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.8. One-Sheeted Hyperboloids", "Subsubsection",
 CellChangeTimes->{{3.587201518412738*^9, 3.587201527076234*^9}, {
   3.587272835342759*^9, 3.58727283885396*^9}, {3.587272981302108*^9, 
   3.5872730078536263`*^9}, 3.5872731046621633`*^9, 3.587278763622837*^9, {
   3.5875395682098494`*^9, 3.58753958547908*^9}, {3.5875506376928062`*^9, 
   3.58755065084363*^9}, {3.5875621007464747`*^9, 3.5875621112900777`*^9}, {
   3.5881675117713223`*^9, 3.5881675315864553`*^9}, {3.58831735340977*^9, 
   3.588317395129156*^9}, 3.6098201445611534`*^9, 3.6098236513987246`*^9, 
   3.6179500274097495`*^9, 3.617951459497492*^9, 3.627812925363861*^9, 
   3.6278137765121903`*^9, 3.696829677586822*^9, 3.696924897067626*^9, 
   3.7075444836073647`*^9, 
   3.707544992499278*^9},ExpressionUUID->"c9ac43cd-9774-4091-8469-\
2a2ccb7832a9"],

Cell[TextData[{
 "One-sheeted hyperboloids are the standard examples of  ruled, non \
developable surfaces, see ",
 ButtonBox["MathWorld",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/One-SheetedHyperboloid.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/One-SheetedHyperboloid.html"],
 ". We consider the surface generated by rotating a hyperbola in the x, z- \
plane around the z-axis. A parameter representation is"
}], "Text",
 CellChangeTimes->{{3.588317415403316*^9, 3.5883175018172584`*^9}, {
   3.5883175511190786`*^9, 3.5883175511240788`*^9}, {3.5883175887452307`*^9, 
   3.5883175964246693`*^9}, {3.5883176462165174`*^9, 
   3.5883176956253433`*^9}, {3.5883177767289824`*^9, 3.5883178420087166`*^9}, 
   3.588336208915674*^9, 3.589624589599478*^9, {3.6278132508740597`*^9, 
   3.627813260858077*^9}},ExpressionUUID->"303554f6-a4cb-4727-84ef-\
139e39feb8b9"],

Cell[BoxData[
 RowBox[{"?", "hyperboloid"}]], "Input",
 CellChangeTimes->{{3.5883362179324903`*^9, 
  3.5883362240945005`*^9}},ExpressionUUID->"ffa94cb6-e369-435e-a9f7-\
89d2d8683b28"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyperboloid", "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5883403874176536`*^9, {3.5883404244667726`*^9, 
   3.5883404263938828`*^9}},ExpressionUUID->"72ecc2cd-6cc2-4e56-8511-\
0a531ac93c0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyperboloid", "[", 
   RowBox[{"1", ",", "2", ",", "3"}], "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"3", 
    RowBox[{"Pi", "/", "2"}]}], ",", 
   RowBox[{"-", "2"}], ",", "2"}], "]"}]], "Input",ExpressionUUID->"c015320a-\
460c-43db-a7ec-2e13bb391076"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyperboloid", "[", 
   RowBox[{"1", ",", "1", ",", "1"}], "]"}], "[", 
  RowBox[{"0", ",", 
   RowBox[{"2", "*", "Pi"}], ",", 
   RowBox[{"-", "2"}], ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.5883386193385253`*^9, 3.58833863724955*^9}, {
  3.707544636733068*^9, 
  3.707544650071525*^9}},ExpressionUUID->"0dcc9586-f1a0-48e6-a535-\
f4459c015d48"],

Cell["We consider", "Text",
 CellChangeTimes->{{3.6151958465297346`*^9, 
  3.6151958510249915`*^9}},ExpressionUUID->"e6e11b81-5214-4531-b4cd-\
71cc087e2c7b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypsf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"hyperboloid", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.588318033245654*^9, 3.5883180445303*^9}, {
   3.588318457179902*^9, 3.5883184740108647`*^9}, {3.588336256043357*^9, 
   3.588336269974181*^9}, 
   3.707544678911763*^9},ExpressionUUID->"3a3486ef-072f-4750-8abb-\
b1048806f710"],

Cell[BoxData[
 RowBox[{"hypsf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.588336161585191*^9, 3.5883361828948283`*^9}, {
  3.588336306119445*^9, 
  3.588336306805846*^9}},ExpressionUUID->"c95677cf-beba-42b8-9323-\
ac9119dc25f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hyp", " ", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"hypsf", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"Opacity", "[", ".6", "]"}]}], ",", " ", 
     RowBox[{"Mesh", " ", "\[Rule]", " ", "None"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5883386948088417`*^9, 3.5883387920834055`*^9}, {
   3.5883388681147547`*^9, 3.588338902323711*^9}, {3.5883389574828663`*^9, 
   3.588338974385833*^9}, 3.5883404603178234`*^9, 3.5883414040037985`*^9, 
   3.707544726361741*^9, 
   3.7075447600807333`*^9},ExpressionUUID->"ab13559f-995b-4db8-a916-\
5c35b0c99488"],

Cell["It is the quadric defined by the equation", "Text",
 CellChangeTimes->{{3.5883182455697985`*^9, 
  3.588318261936735*^9}},ExpressionUUID->"c467a908-2d25-430a-ba40-\
a2ff4044d56f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"x", "^", "2"}], " ", "+", " ", 
    RowBox[{"y", "^", "2"}], " ", "-", 
    RowBox[{"z", "^", "2"}]}], " ", "\[Equal]", " ", "1"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "->", 
     RowBox[{
      RowBox[{"Cos", "[", "u", "]"}], " ", 
      RowBox[{"Cosh", "[", "v", "]"}]}]}], ",", 
    RowBox[{"y", "->", 
     RowBox[{
      RowBox[{"Cosh", "[", "v", "]"}], " ", 
      RowBox[{"Sin", "[", "u", "]"}]}]}], ",", 
    RowBox[{"z", "->", 
     RowBox[{"Sinh", "[", "v", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5883182820748863`*^9, 3.5883183021390343`*^9}, {
  3.5883926010801964`*^9, 3.588392611438615*^9}, {3.6969237764126453`*^9, 
  3.696923804260386*^9}, {3.696923840414103*^9, 
  3.6969238650843773`*^9}},ExpressionUUID->"59fd9cf1-417b-4899-a532-\
2a2027f2cf39"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.696923907361925*^9, 
  3.696923928107462*^9}},ExpressionUUID->"522b9bab-a81b-4de2-b345-\
95e6b4eb67ec"],

Cell["The normal vector field is", "Text",
 CellChangeTimes->{{3.5883183493287334`*^9, 
  3.588318360512373*^9}},ExpressionUUID->"c32bf396-1759-4cfe-bcf1-\
98234cf9ec0d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"nhyp", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", ">", "0"}], ",", 
      RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.588318365192641*^9, 3.588318372047033*^9}, {
   3.5883184180426636`*^9, 3.58831842515207*^9}, {3.5883184870836124`*^9, 
   3.5883185219316053`*^9}, {3.5883188504443955`*^9, 3.588318860715983*^9}, 
   3.588392645727475*^9, 3.614861852249527*^9, 3.614917784229748*^9, 
   3.6151813598587375`*^9},ExpressionUUID->"b6bb6dd6-d4f1-491c-919b-\
23c3cf084527"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"Cos", "[", "u", "]"}], " ", 
     RowBox[{"Cosh", "[", "v", "]"}]}], 
    SqrtBox[
     RowBox[{"Cosh", "[", 
      RowBox[{"2", " ", "v"}], "]"}]]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"Cosh", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "u", "]"}]}], 
    SqrtBox[
     RowBox[{"Cosh", "[", 
      RowBox[{"2", " ", "v"}], "]"}]]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Sinh", "[", "v", "]"}], 
     SqrtBox[
      RowBox[{"Cosh", "[", 
       RowBox[{"2", " ", "v"}], "]"}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.70832185085191*^9},ExpressionUUID->"bc910bcb-7ee2-4329-bd12-dd30a4cd9836"]
}, Open  ]],

Cell["\<\
We fix a point {u,v} and consider the tangent plane of the hyperboloid at \
this point with the variable point vec[x]. Its equation is \
\>", "Text",
 CellChangeTimes->{{3.588318711689459*^9, 
  3.5883187975213685`*^9}},ExpressionUUID->"fcd38a50-6006-421f-a838-\
e9b5daba8417"],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{"u_", ",", " ", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"nhyp", "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"vec", "[", "x", "]"}]}], " ", "==", " ", 
   RowBox[{
    RowBox[{"nhyp", "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], ".", 
    RowBox[{"hypsf", "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.58833644559929*^9, 3.58833644559929*^9}, {
  3.5883368501704006`*^9, 3.588336863664424*^9}, {3.5883926475838785`*^9, 
  3.588392650391883*^9}},ExpressionUUID->"a47033ea-f16b-4c7f-a9e9-\
3cf33b63ccb1"],

Cell["\<\
The intersection of the hyperboloid with the tangent plane at {u,v} = {0,0} \
is the solution of\
\>", "Text",
 CellChangeTimes->{{3.588336386537586*^9, 3.588336413541233*^9}, {
  3.588336480340551*^9, 3.588336555641883*^9}, {3.609822617083565*^9, 
  3.6098226359956465`*^9}},ExpressionUUID->"0ffe573d-63c0-4249-9656-\
eaa0c34cbf36"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"0", ",", "0"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], "^", "2"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"x", "[", "2", "]"}], "^", "2"}], " ", "-", 
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "^", "2"}]}], "\[Equal]", " ", "1"}]}], 
    "}"}], ",", " ", 
   RowBox[{"vec", "[", "x", "]"}], ",", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.5883189765386076`*^9, 3.588319000498978*^9}, {
   3.5883190488517437`*^9, 3.5883191283982935`*^9}, {3.588319186566621*^9, 
   3.588319199897383*^9}, {3.588319458461172*^9, 3.58831946104532*^9}, 
   3.6148618522651267`*^9, 
   3.614917784245348*^9},ExpressionUUID->"f7b4917d-ea61-4f2f-b1b6-\
3276d9967fd1"],

Cell["The solution consists of two lines intersecting in the point", "Text",
 CellChangeTimes->{{3.5883368982808847`*^9, 3.588336928685338*^9}, {
   3.5883370207430906`*^9, 3.5883370393991575`*^9}, 
   3.615264421498866*^9},ExpressionUUID->"631d0c09-e983-493e-b959-\
18fa6c00d932"],

Cell[BoxData[
 RowBox[{"hypsf", "[", 
  RowBox[{"0", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.588337052581912*^9, 3.5883370617754374`*^9}, 
   3.58833711234533*^9},ExpressionUUID->"f0d57486-9fe7-44a3-b79d-\
b7f30dbf580e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lines", " ", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "t", ",", "t"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "t", ",", 
         RowBox[{"-", "t"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", "Thick"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Thick"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5883391787715225`*^9, 3.588339406986576*^9}, 
   3.588340016380431*^9, 
   3.5883400791880236`*^9},ExpressionUUID->"c94f567d-6296-46c2-b768-\
348818558270"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hpl", " ", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"u", "+", "v"}], ",", 
       RowBox[{"u", "-", "v"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Opacity", "[", "0.3", "]"}]}], "}"}]}], ",", " ", 
     RowBox[{"Mesh", "\[Rule]", " ", "False"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5883395599233236`*^9, 3.588339574290145*^9}, {
   3.58833960514691*^9, 3.588339605156911*^9}, {3.588339682473333*^9, 
   3.588339886557006*^9}, 3.5883400673403463`*^9, 
   3.6969240417930517`*^9},ExpressionUUID->"efefff18-14ec-47f8-9f52-\
457b14c71ca6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt", " ", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.015", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.588340740746863*^9, 3.5883407765549107`*^9}, {
   3.5883408387954707`*^9, 3.5883408522202387`*^9}, {3.5883409048192472`*^9, 
   3.588341005627013*^9}, {3.5883410445882416`*^9, 3.5883410657394514`*^9}, 
   3.588341104810686*^9, 3.614861852280727*^9, 
   3.6149177842609477`*^9},ExpressionUUID->"a27163fe-216c-426b-966d-\
882fe2f08d41"],

Cell["\<\
The next figure shows the hyperboloid and the intersection with its tangent \
plane at the point pt:\
\>", "Text",
 CellChangeTimes->{{3.5883405593284864`*^9, 3.5883406616313376`*^9}, {
  3.5883411405207286`*^9, 
  3.588341154064503*^9}},ExpressionUUID->"5939c4af-ded6-4bb5-8802-\
e8891467e8d5"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"hyp", ",", "lines", ",", "hpl", ",", "pt"}], "}"}], ",", " ", 
   RowBox[{"Axes", "\[Rule]", " ", "None"}], ",", 
   RowBox[{"Boxed", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883394200973263`*^9, 3.588339474577442*^9}, {
   3.588339905786106*^9, 3.588339907934229*^9}, {3.588339937962946*^9, 
   3.588339947194474*^9}, {3.588341018018722*^9, 3.5883410194828053`*^9}, 
   3.696924062999917*^9},ExpressionUUID->"de68b114-34d5-4483-b5ca-\
801a03486d1e"],

Cell["\<\
Through any point of hypsf  two lines belong to the surface, for example\
\>", "Text",
 CellChangeTimes->{{3.5883377675518055`*^9, 3.5883378334235735`*^9}, {
  3.5883390557674875`*^9, 
  3.588339089159397*^9}},ExpressionUUID->"f9aaf7ca-a0a1-42f1-8812-\
144d13c139fc"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "1", "]"}], "^", "2"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"x", "[", "2", "]"}], "^", "2"}], " ", "-", 
       RowBox[{
        RowBox[{"x", "[", "3", "]"}], "^", "2"}]}], "\[Equal]", " ", "1"}]}], 
    "}"}], ",", " ", 
   RowBox[{"vec", "[", "x", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883189765386076`*^9, 3.588319000498978*^9}, {
   3.5883190488517437`*^9, 3.5883191283982935`*^9}, {3.588319186566621*^9, 
   3.588319199897383*^9}, {3.588319458461172*^9, 3.58831946104532*^9}, {
   3.588319535468577*^9, 3.58831954670922*^9}, {3.588319614765112*^9, 
   3.588319619853403*^9}, {3.588336590819945*^9, 3.5883366074651737`*^9}, 
   3.5883368036823187`*^9, {3.5883371369567375`*^9, 3.588337149963482*^9}, {
   3.5896249832169914`*^9, 3.5896249944856358`*^9}, {3.58962515837101*^9, 
   3.5896251697996635`*^9}, 3.6148618522963266`*^9, 
   3.6148646598800583`*^9},ExpressionUUID->"4f776b99-5396-4322-a2e9-\
9ac68a4679de"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883371576409206`*^9, 
  3.5883371965681477`*^9}},ExpressionUUID->"ee9d6c95-916d-4084-8cb5-\
a999f0cae0fb"],

Cell[TextData[{
 "Surfaces being ruled in a twofold way are said to be ",
 StyleBox["doubly ruled",
  FontColor->RGBColor[0, 0, 1]],
 ", see ",
 ButtonBox["MathWorld",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/DoublyRuledSurface.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/DoublyRuledSurface.html"],
 ". The spherical image of the surface hypsf is given by its normal vector \
nhyp[u,v] defined above. We have"
}], "Text",
 CellChangeTimes->{{3.588337859712077*^9, 3.588337952823403*^9}, {
   3.588338081911786*^9, 3.588338171823929*^9}, 3.588338215392421*^9, 
   3.5896254035730343`*^9, {3.589625489598955*^9, 3.589625585046414*^9}, {
   3.609822804716297*^9, 
   3.609822809275558*^9}},ExpressionUUID->"bb3bdf39-ca75-4c6d-be48-\
2105af3a8d47"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "nhyp", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5896256072246823`*^9, 
  3.5896256187763433`*^9}},ExpressionUUID->"23b6d536-1c3d-4e36-aad4-\
2bf88d262e1d"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6969242739179363`*^9, 
  3.6969242883371162`*^9}},ExpressionUUID->"23e1d4c7-1587-40cf-9250-\
fee7f1c9f43a"],

Cell[BoxData[
 RowBox[{"%%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", " ", 
     RowBox[{"Random", "[", "]"}]}], ",", 
    RowBox[{"v", "\[Rule]", " ", 
     RowBox[{"Random", "[", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5896256589816427`*^9, 3.58962570072103*^9}, 
   3.696924317683856*^9},ExpressionUUID->"f61c5b93-735a-4b3e-8941-\
5ed2c61554c9"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.5896257130727367`*^9, 
  3.5896257222002587`*^9}},ExpressionUUID->"5f975c97-ea54-491a-866d-\
45e105bea7fa"],

Cell["\<\
Indeed, the spherical image of the surface covers a whole open region of the \
sphere. Therefore the surface may not be developable; remember that the \
spherical image of a developable surface is a curve or a point only.\
\>", "Text",
 CellChangeTimes->{{3.5896257957964683`*^9, 3.589625951590379*^9}, 
   3.6151962208821464`*^9},ExpressionUUID->"a36ef925-01d7-40c3-a3df-\
44592c430296"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"nhyp", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", " ", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "7"}], ",", "7"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5896259599918594`*^9, 3.589626106817258*^9}, {
  3.5896265303224807`*^9, 3.589626550265621*^9}, {3.69692446534778*^9, 
  3.696924470839943*^9}, {3.696924520400576*^9, 3.696924553422757*^9}, {
  3.6969246283482943`*^9, 
  3.696924637206933*^9}},ExpressionUUID->"612d1605-8710-4ada-97c9-\
dbf4104e34e0"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"nhyp", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"[", "3", "]"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Rule]", " ", 
    RowBox[{"-", "Infinity"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5896261379230366`*^9, 3.589626182777602*^9}, 
   3.589626268130484*^9, {3.615196311548332*^9, 
   3.6151963255081306`*^9}},ExpressionUUID->"9592fd8d-de38-4234-8b8c-\
97fb55ee179f"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.696924600552039*^9, 
  3.696924609110457*^9}},ExpressionUUID->"88cc5db3-7cae-4d29-8edf-\
a6c870e0c99e"],

Cell[TextData[{
 "Thus the spherical image of the whole hyperboloid hypsf consists of the \
points of the unit sphere whose third coordinate  satisfies -",
 Cell[BoxData[
  FractionBox["1", 
   SqrtBox["2"]]],
  CellChangeTimes->{{3.58962617067691*^9, 3.5896261837426577`*^9}, 
    3.5896262696565714`*^9},ExpressionUUID->
  "ea407557-4e18-4dec-a25e-e5723543a7ec"],
 "< x[3] < ",
 Cell[BoxData[
  FractionBox["1", 
   SqrtBox["2"]]],
  CellChangeTimes->{{3.58962617067691*^9, 3.5896261837426577`*^9}, 
    3.5896262696565714`*^9},ExpressionUUID->
  "b4752842-2aa9-4cde-8a83-6add201362fd"],
 "."
}], "Text",
 CellChangeTimes->{{3.58962632295862*^9, 
  3.589626485630924*^9}},ExpressionUUID->"809633f8-138a-4c7d-8e9d-\
4029c7d455b5"],

Cell[TextData[{
 "Another doubly ruled surface is the ",
 StyleBox["hyperbolic paraboloid",
  FontColor->RGBColor[0, 0, 1]],
 ", see ",
 ButtonBox["MathWorld",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/HyperbolicParaboloid.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/HyperbolicParaboloid.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.588337859712077*^9, 3.588337952823403*^9}, {
   3.588338081911786*^9, 3.588338171823929*^9}, 3.588338215392421*^9, {
   3.5896254035730343`*^9, 
   3.589625428646468*^9}},ExpressionUUID->"97b66e1d-5fa9-409c-9486-\
f6c6daa09d1c"],

Cell[BoxData[
 RowBox[{"?", "hyperbolicparaboloid"}]], "Input",
 CellChangeTimes->{
  3.5883384595453854`*^9},ExpressionUUID->"6ceac543-213f-4f42-8ac6-\
54eb9f4e5a81"],

Cell[BoxData[
 RowBox[{"hyperbolicparaboloid", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.588338474241226*^9, 
  3.5883384780094414`*^9}},ExpressionUUID->"fc31c219-5c00-4ff2-b67c-\
4220c0e492d9"],

Cell[BoxData[
 RowBox[{"hyperbolicparaboloid", "[", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "1", ",", 
   RowBox[{"-", "1"}], ",", "1"}], "]"}]], "Input",ExpressionUUID->"92511048-\
92a8-4a23-b370-c30ad335a3bc"],

Cell["\<\
As an exercise find  the line families contained in this surface, calculate \
its first fundamental form and plot its spherical image.\
\>", "Text",
 CellChangeTimes->{{3.5896266873664627`*^9, 
  3.589626792142456*^9}},ExpressionUUID->"ea9fc978-83af-43f1-b945-\
9f8716122e2c"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2. The Gaussian Curvature", "Subsection",
 CellChangeTimes->{{3.5872730558623724`*^9, 3.58727307645455*^9}, {
   3.5883415613617992`*^9, 3.5883415766636744`*^9}, {3.5883416340959597`*^9, 
   3.5883416520479865`*^9}, 3.6151964340823407`*^9, 3.6152119753114877`*^9, 
   3.6179516333704367`*^9, 
   3.61795637897787*^9},ExpressionUUID->"175144be-5d87-4e95-bb00-\
fa6b50cbd9c6"],

Cell[CellGroupData[{

Cell["\<\
2.2.1. Integral Curvature and Curvature Integral. Orientation\
\>", "Subsubsection",
 CellChangeTimes->{{3.589779006964474*^9, 3.5897790435933385`*^9}, {
   3.5897790965554314`*^9, 3.589779110049455*^9}, 3.609823738997735*^9, 
   3.6098312806720943`*^9, 3.6278139692135315`*^9, 3.62789661193079*^9, 
   3.6969249052766743`*^9, 3.696948961261662*^9, 3.707545000939609*^9, 
   3.707572102122958*^9},ExpressionUUID->"6adce1bc-258c-40c5-8f0d-\
1325230a46a0"],

Cell["Here is the unit sphere:", "Text",
 CellChangeTimes->{{3.588487873500686*^9, 
  3.5884878829387026`*^9}},ExpressionUUID->"4f176d2f-1b06-4792-b3ec-\
a36fc9963639"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sph1", " ", "=", " ", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sphero", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{
        RowBox[{"-", "Pi"}], "/", "2"}], ",", 
       RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"Green", ",", 
        RowBox[{"Opacity", "[", ".4", "]"}]}], "}"}]}], ",", " ", 
     RowBox[{"Mesh", "\[Rule]", " ", "False"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5884876724319334`*^9, 3.588487820210993*^9}, 
   3.5896342644259577`*^9, {3.696925107387542*^9, 
   3.69692513616295*^9}},ExpressionUUID->"87717148-1472-45f9-a007-\
59dbf7638214"],

Cell["The spherical image of the part hyp of the hyperboloid is", "Text",
 CellChangeTimes->{{3.588393319929459*^9, 
  3.5883933833435707`*^9}},ExpressionUUID->"fc30f74d-dfe6-4e62-beaa-\
5b2b4b9ef9ac"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"nhyp", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883416562532268`*^9, 3.588341656255227*^9}, {
   3.5883416876340218`*^9, 3.588341775107025*^9}, 3.5883418201235995`*^9, 
   3.588392652560287*^9, {3.5883932721777754`*^9, 
   3.588393273675378*^9}},ExpressionUUID->"c9c6a163-159e-4b2c-88c5-\
3fd1f1588180"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", " ", "%"}], "}"}], ",", " ", 
   RowBox[{"Axes", " ", "\[Rule]", " ", "None"}], ",", " ", 
   RowBox[{"Boxed", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588487907992347*^9, 
  3.588487947772417*^9}},ExpressionUUID->"d24df62d-0fce-47cb-91db-\
3f483cfc85b8"],

Cell[TextData[{
 "The area of the spherical image of a surface region is a measure  for the \
curvature of the surface in this region; it is called its",
 StyleBox[" integral curvature",
  FontColor->RGBColor[0, 0, 1]],
 ". For developable surfaces the integral curvature is zero since the \
spherical image is a point (in case of a plane) or a curve. "
}], "Text",
 CellChangeTimes->{{3.5883934642453127`*^9, 3.588393512823798*^9}, {
   3.5883935504978642`*^9, 3.5883936377488174`*^9}, {3.588393710195345*^9, 
   3.588393869144024*^9}, 
   3.5883939316533337`*^9},ExpressionUUID->"a1c7a072-e955-4528-8b91-\
1e087f071e89"],

Cell[BoxData[
 RowBox[{"?", "Integrate"}]], "Input",
 CellChangeTimes->{{3.5883419502820444`*^9, 
  3.5883419756504955`*^9}},ExpressionUUID->"340d5efd-89fc-4ea5-acf8-\
7b44e37dd58e"],

Cell["\<\
The integration of the area element of the spherical image nhyp[u,v] yields \
for the region hyp:\
\>", "Text",
 CellChangeTimes->{{3.588394687349861*^9, 3.5883947193611174`*^9}, {
  3.588394751699974*^9, 3.588394762619993*^9}, {3.588394847452942*^9, 
  3.588394860198165*^9}},ExpressionUUID->"959cc0fa-f032-4098-983a-\
320ff2d5abb0"],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dA", "[", "nhyp", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588342032832766*^9, 3.5883420805934973`*^9}, {
   3.5883422997950354`*^9, 3.588342314618883*^9}, 3.588394079635194*^9, {
   3.5883947964096527`*^9, 3.588394797220854*^9}, 3.614861852327527*^9, 
   3.614865446121439*^9},ExpressionUUID->"4e17c684-cb00-4f1e-abf3-\
b3670d715e1a"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.588342444491311*^9, 
  3.5883424563769913`*^9}},ExpressionUUID->"579312d2-6546-46ad-a299-\
12a6349faaa5"],

Cell["The area of the spherical image of the whole hyperboloid is", "Text",
 CellChangeTimes->{{3.588394955373932*^9, 
  3.5883949821591787`*^9}},ExpressionUUID->"1bad84ad-83a3-471e-9e14-\
fde4ab165ad5"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dA", "[", "nhyp", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"-", "x"}], ",", "x"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"x", "\[Rule]", " ", "Infinity"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5883426748503556`*^9, 3.5883427271728477`*^9}, 
   3.5883940826303988`*^9, {3.5883948978722305`*^9, 3.588394899385433*^9}, 
   3.614861852327527*^9, 
   3.614865446137039*^9},ExpressionUUID->"572ea39a-1411-46ee-abea-\
35ded8aace74"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.5883427886993556`*^9, 
  3.588342798730173*^9}},ExpressionUUID->"0398027d-76ab-4e2f-90e1-\
09fb2a820ff2"],

Cell["and this is less than the area 4\[DoubledPi] of the whole unit sphere. \
", "Text",
 CellChangeTimes->{{3.588395009084826*^9, 3.588395145163865*^9}, {
   3.588395195895154*^9, 3.5883951978139577`*^9}, 
   3.69692536354557*^9},ExpressionUUID->"6ed34ea4-dc80-49fd-9698-\
42a94d6e8b22"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"4", "*", "Pi"}], "]"}]], "Input",
 CellChangeTimes->{{3.696925368739212*^9, 
  3.696925379744165*^9}},ExpressionUUID->"2e7619d0-054a-4b81-b826-\
00ba41729ff1"],

Cell["\<\
 Indeed, the spherical image is the region on the unit sphere between the two \
limit circles\
\>", "Text",
 CellChangeTimes->{{3.588395009084826*^9, 3.588395145163865*^9}, {
  3.588395195895154*^9, 
  3.5883951978139577`*^9}},ExpressionUUID->"cb63d3b1-d743-4781-81d2-\
fe0d5c2d1667"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"nhyp", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Rule]", " ", "Infinity"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588342841177848*^9, 3.5883428656074905`*^9}, 
   3.58839265435429*^9},ExpressionUUID->"3bfe53c3-1d98-433f-84bd-\
4cc059a5fee4"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"nhyp", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Rule]", " ", 
    RowBox[{"-", "Infinity"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.588342841177848*^9, 3.5883428656074905`*^9}, 
   3.58839265435429*^9, {3.588395162370695*^9, 
   3.5883951674563046`*^9}},ExpressionUUID->"9ef5bfaa-7ee6-4941-978b-\
c748b13fbbf0"],

Cell["\<\
Since the area element of any surface by its definition is always  positive, \
the integral curvature is always non negative. For a finer consideration of \
the curvature the orientation of the spherical image has to be considered, \
and a finer integration on the surface must be introduced, namely the \
integration of 2-forms (alternating biforms).
As has been shown at the end  of subsection 1.4.1 we have the equation 
dA[sf][u,v] ==Det[{\[Sigma][1][sf][u,v], \[Sigma][2][sf][u,v]}]], and this is \
the strict coordinate of the2-form \
\[Sigma][1][sf][u,v]\[And]\[Sigma][2][sf][u,v]. The left hand side of this \
equation is always positive, whereas the sign of the right side depends on \
the signs of the basic vectors and on their order. The ordered cobasis 
{\[Sigma][1][sf][u,v], \[Sigma][2][sf][u,v]}], or equivalently the ordered \
basis  {amf[1][sf][u,v], amf[2][sf][u,v]}] represents the orientation of the \
tangent planes; in the natural order this orientation is considered to be \
positive or counter clockwise. \
\>", "Text",
 CellChangeTimes->{{3.5883956383758087`*^9, 3.5883958423764772`*^9}, {
   3.588395877112464*^9, 3.5883959244321704`*^9}, {3.5884149596021376`*^9, 
   3.5884151284880342`*^9}, {3.5884152076581736`*^9, 
   3.5884152696526823`*^9}, {3.588415339525205*^9, 3.5884153419276094`*^9}, {
   3.5884154774918475`*^9, 3.588415512420309*^9}, {3.588415721613336*^9, 
   3.588415786285035*^9}, {3.588415925629005*^9, 3.5884159356215763`*^9}, {
   3.58841620247784*^9, 3.5884162121253915`*^9}, {3.5884162594771*^9, 
   3.588416445276727*^9}, {3.5884236681491313`*^9, 3.5884236686571603`*^9}, {
   3.588488086924661*^9, 3.5884880975326796`*^9}, {3.5884882789641457`*^9, 
   3.588488288460689*^9}, {3.58848868499737*^9, 3.5884886898446465`*^9}, 
   3.609823956908199*^9, 3.6098240272362213`*^9, {3.614861852405527*^9, 
   3.614861852483527*^9}, {3.6149177843389482`*^9, 3.6149177844169483`*^9}, 
   3.6152107773853836`*^9, {3.615210839067892*^9, 3.615210881359566*^9}, 
   3.6152644556048174`*^9, {3.6278271307136235`*^9, 3.627827140479241*^9}, {
   3.6969255442715883`*^9, 
   3.6969256113758373`*^9}},ExpressionUUID->"79cbec79-6954-4c79-bbc2-\
a179c3525cb7"],

Cell["\<\
Consider the sequence of colors (Red, Green, Blue, Black) and the sequence of \
points in the parameter neighborhood of the point {0,0}:\
\>", "Text",
 CellChangeTimes->{{3.5884285649172106`*^9, 3.5884286217354603`*^9}, {
  3.5884286562264333`*^9, 3.5884287192820396`*^9}, {3.588488460204512*^9, 
  3.5884884633086896`*^9}},ExpressionUUID->"30126741-7e4e-4e0d-871d-\
27db30fe3d8a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{".3", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", ".3"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", ".3"}]}], "}"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.5884287354409637`*^9, 3.5884288748109355`*^9}, {
  3.589634138656764*^9, 
  3.589634151975526*^9}},ExpressionUUID->"a2b25571-189e-4dd0-b2ea-\
a6ecea005534"],

Cell["\<\
Running on the hyperboloid through these points in the given order is a \
positive or counter clockwise turn:\
\>", "Text",
 CellChangeTimes->{{3.588428907825824*^9, 3.5884289947457952`*^9}, {
  3.588488794187615*^9, 
  3.5884888100045195`*^9}},ExpressionUUID->"71922a85-c8dc-42b5-8a80-\
cc9a89604dfd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt1", " ", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"hypsf", "[", 
        RowBox[{".3", ",", "0"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5884290046673627`*^9, 3.5884291367649183`*^9}, 
   3.5884295120143814`*^9, 3.5884883695753284`*^9, 3.6148618524991274`*^9, 
   3.6149177844169483`*^9},ExpressionUUID->"c0578f4a-f2e1-4746-b281-\
9d3153d89443"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt2", " ", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"hypsf", "[", 
        RowBox[{"0", ",", ".3"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5884290046673627`*^9, 3.58842918871689*^9}, 
   3.5884295183647447`*^9, 3.5884883917355957`*^9, 3.614861852514727*^9, 
   3.614917784432548*^9},ExpressionUUID->"6d058f6d-600b-4522-b1d9-\
a04ad4bd41dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt3", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"hypsf", "[", 
        RowBox[{
         RowBox[{"-", ".3"}], ",", "0"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5884290046673627`*^9, 3.5884292509564495`*^9}, 
   3.5884295237650537`*^9, 3.588488417024042*^9, 3.614861852514727*^9, 
   3.614917784432548*^9},ExpressionUUID->"54575c93-ceda-4201-9729-\
9df1a4215eea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt4", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"hypsf", "[", 
        RowBox[{"0", ",", 
         RowBox[{"-", ".3"}]}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5884290046673627`*^9, 3.5884293145250854`*^9}, 
   3.5884295299654083`*^9, 3.588488430007785*^9, 3.614861852514727*^9, 
   3.614917784448148*^9},ExpressionUUID->"6667d4c1-dd9f-4a7a-8add-\
0f377e35311b"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"hyp", ",", "pt1", ",", "pt2", ",", "pt3", ",", "pt4"}], "}"}], 
   ",", 
   RowBox[{"Axes", "\[Rule]", "None"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.58842939432465*^9, 
  3.5884294656937323`*^9}},ExpressionUUID->"4507cae9-c0cf-4d50-8187-\
ba652e4fe25c"],

Cell["Now we consider the spherical images of these points:", "Text",
 CellChangeTimes->{{3.588488839700218*^9, 
  3.5884888813005977`*^9}},ExpressionUUID->"ed423329-7cb1-4045-98c8-\
f01235c907ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"arr1", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"nhyp", "[", 
          RowBox[{"0.3", ",", "0"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.588427392477151*^9, 3.5884274494664106`*^9}, {
   3.5884275184193544`*^9, 3.5884275979879055`*^9}, {3.588427688125061*^9, 
   3.5884276984686527`*^9}, {3.588427772996915*^9, 3.58842777378096*^9}, {
   3.5884280016129913`*^9, 3.5884280146927395`*^9}, {3.5884280699088974`*^9, 
   3.5884280748041773`*^9}, 3.588429567725568*^9, 
   3.588488547303494*^9},ExpressionUUID->"66e3108e-8bae-4439-a337-\
690e8cd659ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"arr2", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"nhyp", "[", 
          RowBox[{"0", ",", "0.3"}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.588427392477151*^9, 3.5884274494664106`*^9}, {
   3.5884275184193544`*^9, 3.5884275979879055`*^9}, {3.588427688125061*^9, 
   3.5884276984686527`*^9}, {3.588427772996915*^9, 3.58842777378096*^9}, {
   3.5884280016129913`*^9, 3.5884280146927395`*^9}, {3.5884280699088974`*^9, 
   3.588428119556737*^9}, 3.588429575366005*^9, 
   3.5884885668076096`*^9},ExpressionUUID->"30cddc7f-566d-403a-be1a-\
ae2b7e0fd2b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"arr3", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"nhyp", "[", 
          RowBox[{
           RowBox[{"-", ".3"}], ",", "0"}], "]"}]}], "}"}], "]"}]}], "}"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.588427392477151*^9, 3.5884274494664106`*^9}, {
   3.5884275184193544`*^9, 3.5884275979879055`*^9}, {3.588427688125061*^9, 
   3.5884276984686527`*^9}, {3.588427772996915*^9, 3.58842777378096*^9}, {
   3.5884280016129913`*^9, 3.5884280146927395`*^9}, {3.5884280699088974`*^9, 
   3.5884281805252247`*^9}, {3.5884282118210144`*^9, 3.588428289323447*^9}, 
   3.588429582853433*^9, 
   3.5884885870717688`*^9},ExpressionUUID->"7ab77189-ca5a-4bd3-b79c-\
3df0ae26b651"],

Cell[BoxData[
 RowBox[{
  RowBox[{"arr4", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"nhyp", "[", 
          RowBox[{"0", ",", 
           RowBox[{"-", ".3"}]}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.588427392477151*^9, 3.5884274494664106`*^9}, {
   3.5884275184193544`*^9, 3.5884275979879055`*^9}, {3.588427688125061*^9, 
   3.5884276984686527`*^9}, {3.588427772996915*^9, 3.58842777378096*^9}, {
   3.5884280016129913`*^9, 3.5884280146927395`*^9}, {3.5884280699088974`*^9, 
   3.5884281805252247`*^9}, {3.5884282118210144`*^9, 3.5884283493828826`*^9}, 
   3.588429589597819*^9, 
   3.588488601991622*^9},ExpressionUUID->"bd679612-3146-4bc4-8e49-\
e520372297e4"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", "arr1", ",", "arr2", ",", "arr3", ",", "arr4"}], 
    "}"}], ",", " ", 
   RowBox[{"Axes", "\[Rule]", " ", "None"}], ",", " ", 
   RowBox[{"Boxed", " ", "\[Rule]", " ", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5884283602025013`*^9, 3.588428386155986*^9}, {
  3.5884886535505705`*^9, 3.5884886580278273`*^9}, {3.5884889416150475`*^9, 
  3.588488975566989*^9}},ExpressionUUID->"a8126e46-402e-4659-a02e-\
87b16beb1147"],

Cell["\<\
The order of the colors  (Red, Green, Blue, Black)  shows that the sequence \
of the corresponding arrows induce the clockwise, i. e. negative, orientation \
on the unit sphere:  in case of the hyperboloid the Gauss map inverses the \
natural orientations. The reason is that the curvature of the hyperboloid is \
negative, as we shall see now.
The space of 2-forms on a two-dimensional vector space is one-dimensional; \
the strict coordinate \[CapitalOmega][[1,2]] of the2-form \[CapitalOmega] \
serves as a Cartesian coordinate. The integral of the2-iform \[CapitalOmega] \
is defined to be\
\>", "Text",
 CellChangeTimes->{{3.5884893334124565`*^9, 3.5884893557247334`*^9}, {
  3.588489422220536*^9, 3.5884897365085125`*^9}, {3.588489801484229*^9, 
  3.588489872100268*^9}, {3.5884899097884235`*^9, 3.588489962276426*^9}, {
  3.5884900049308653`*^9, 3.588490046281231*^9}, {3.588490080052162*^9, 
  3.5884900844844155`*^9}, {3.5884901378524685`*^9, 3.5884902140368257`*^9}, {
  3.5884995387898827`*^9, 3.588499554920311*^9}, {3.615211108371165*^9, 
  3.615211113316374*^9}, {3.696925972996399*^9, 3.69692600777122*^9}, {
  3.696926041442137*^9, 
  3.696926044442813*^9}},ExpressionUUID->"49e2ff9f-2449-417a-ac68-\
1bb9157b445a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Integral]", "\[CapitalOmega]"}], " ", ":=", " ", 
  RowBox[{"\[Integral]", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
     RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.588500380185361*^9},ExpressionUUID->"c0ee0eb9-a63d-42ab-b3e4-\
e6404a75ad2b"],

Cell["\<\
As in any 1-dimensional vector spaces the ratio of two elements can be \
defined as the ratio of its coordinates with respect to an arbitrary basis, \
e.g.  we have .\
\>", "Text",
 CellChangeTimes->{
  3.5884998191067753`*^9, {3.5884998502368298`*^9, 3.5884999423861914`*^9}, {
   3.588500051430383*^9, 3.588500125826914*^9}, 
   3.6098243018919306`*^9},ExpressionUUID->"852e5f88-12cc-4e62-a514-\
8a8689282bb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalOmega]", " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
     RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}], ",", " ", 
  RowBox[{
   RowBox[{"or", "  ", 
    RowBox[{"\[CapitalOmega]", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "/", 
     RowBox[{"\[Sigma]", "[", "1", "]"}]}], "\[Wedge]", 
    RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}]], "Input",
 Evaluatable->False,ExpressionUUID->"760e13e2-9ae1-4c6b-b317-ae2b7b192945"],

Cell["\<\
Since dA = \[Sigma][1]\[Wedge]\[Sigma][2]   the integral can be written as a \
surface integral over the ratio, which is a function on the surface\
\>", "Text",
 CellChangeTimes->{{3.5885013705531*^9, 
  3.5885014825768967`*^9}},ExpressionUUID->"9e017ee6-0969-41cd-af60-\
c07285884639"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Integral]", "\[CapitalOmega]"}], "=", 
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[CapitalOmega]", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
          RowBox[{"\[Sigma]", "[", "2", "]"}]}], ")"}]}], ")"}], 
      RowBox[{
       RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
       RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}], "  ", "=", " ", 
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[CapitalOmega]", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "\[Wedge]", 
          RowBox[{"\[Sigma]", "[", "2", "]"}]}], ")"}]}], ")"}], "dA"}]}]}]}],
   TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.5885011117954454`*^9, {3.588501145444705*^9, 3.5885011624331346`*^9}, {
   3.588501272460128*^9, 
   3.588501317419407*^9}},ExpressionUUID->"57339234-e4e2-4a95-a5f6-\
0a55ac694458"],

Cell[TextData[{
 "Now we apply this to the oriented area element of the spherical image \
amf[3][sf][u,v]. By the third derivation equation this area element is   \n\
\[Omega][1] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Wedge]", " "}], TraditionalForm]],ExpressionUUID->
  "30894d71-53b8-46b8-a22e-fc731a8d97ee"],
 "\[Omega][2]. The ratio \[Omega][1] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Wedge]", " "}], TraditionalForm]],ExpressionUUID->
  "4128b5a9-c12d-4b2c-b356-9ce284f1c6f7"],
 "\[Omega][2]/\[Sigma][1] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Wedge]", " "}], TraditionalForm]],ExpressionUUID->
  "8756c7cd-a5fd-40be-8097-226cfe310332"],
 "\[Sigma][2], or equivalently"
}], "Text",
 CellChangeTimes->{{3.5885016075799165`*^9, 3.5885016542863984`*^9}, {
   3.588501705220488*^9, 3.5885019030600357`*^9}, {3.5896350200141745`*^9, 
   3.589635126429261*^9}, 3.6148618526083274`*^9, 3.6149177845261483`*^9, {
   3.615211292326688*^9, 3.615211294042691*^9}, {3.69717579263557*^9, 
   3.697175804155596*^9}, {3.697175838923287*^9, 
   3.69717590237101*^9}},ExpressionUUID->"66a28ffd-e72c-4413-a863-\
fe773f0cec0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gauss", "[", "ff_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fd2", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "/", 
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.697094606090253*^9, 3.6970946571155376`*^9}, {
   3.69709483581002*^9, 3.6970950315538397`*^9}, 
   3.6971749852716703`*^9},ExpressionUUID->"11c6a640-57e6-401b-b151-\
0ab7bde8d29f"],

Cell[BoxData[
 RowBox[{"?", "gauss"}]], "Input",
 CellChangeTimes->{{3.6152113763484354`*^9, 3.615211448826163*^9}, {
   3.615211504674261*^9, 3.6152115152822795`*^9}, 3.61521155540555*^9, {
   3.622781860423489*^9, 3.6227818755399156`*^9}, {3.6227822926690483`*^9, 
   3.622782302122665*^9}},ExpressionUUID->"594a6f3d-8a01-4e7b-bae8-\
2b8545b09902"],

Cell[TextData[{
 "Is named the ",
 StyleBox["Gaussian curvature",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface at the point  ff[u,v].  Remark that the Gaussian curvature \
doesn\[CloseCurlyQuote]t depend on the orientation of the surface: A change \
of the orientation would cause the change of signs of the numerator and the \
denominator in the same way.\nWe will calculate it for our example:"
}], "Text",
 CellChangeTimes->{{3.5885022915319176`*^9, 3.588502353635627*^9}, {
   3.5896344813413644`*^9, 3.5896344946851273`*^9}, {3.5896352910086946`*^9, 
   3.589635419818121*^9}, 
   3.615264508027816*^9},ExpressionUUID->"0ecdf3a7-eb19-4602-9ef0-\
23faef60d02a"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", "hypsf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5885023564748316`*^9, 
  3.588502394772899*^9}},ExpressionUUID->"397330b7-9dad-4e2e-806f-\
d83726f8a7c8"],

Cell["\<\
Remember Sech[x] == 1/Cosh[x].  Since hypsf is a surface of revolution the \
Gaussian curvature does not depend on u.  It reflects very well the visual \
impression of the curvature of the hyperboloid:\
\>", "Text",
 CellChangeTimes->{{3.588502593392448*^9, 3.58850274255991*^9}, 
   3.615264540124651*^9},ExpressionUUID->"ee8a127a-c30a-4417-a453-\
da154b95d468"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"Sech", "[", 
      RowBox[{"2", " ", "v"}], "]"}], "^", "2"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5884250453039*^9, 3.5884250954547687`*^9}, 
   3.588425134172983*^9, 
   3.588502546139965*^9},ExpressionUUID->"a2bf6ea5-5bb5-4d22-9313-\
925890c1356b"],

Cell["\<\
For a sphere of radius r the Gaussian curvature is constant, namely\
\>", "Text",
 CellChangeTimes->{{3.627827807484621*^9, 
  3.627827884538557*^9}},ExpressionUUID->"6f772419-77b8-4ee9-ae0b-\
91f872efa4fe"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6278275913456373`*^9, 3.6278276071796656`*^9}, {
  3.627827637682719*^9, 
  3.627827647699937*^9}},ExpressionUUID->"238142e1-2b03-42f1-ae40-\
5cf35cb1f95a"],

Cell["\<\
Mathematica also calculates the Gaussian curvature for a general surface:\
\>", "Text",
 CellChangeTimes->{{3.588502870776535*^9, 
  3.5885029205094223`*^9}},ExpressionUUID->"10cbc832-26ff-484e-a54d-\
12b265479a46"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.697176314752637*^9, 
  3.6971763256740427`*^9}},ExpressionUUID->"aa8386c1-0a9c-4418-bca9-\
796e97b7c1e9"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Together", "[", "%", "]"}], ",", 
    RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6098262724436398`*^9, 3.6098262802690873`*^9}, {
   3.6098268413811812`*^9, 3.6098268828225517`*^9}, 3.6098309235986705`*^9, {
   3.627827986394537*^9, 3.6278280029345665`*^9}, {3.627882451248157*^9, 
   3.6278824652413816`*^9}, 
   3.6278958180536346`*^9},ExpressionUUID->"1316e4ed-fe72-438a-99f9-\
2b47c8dea9c2"],

Cell[TextData[{
 "Evaluating with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " version 9.0.1.0 he needed processing time was 12708 s =3 h,32min, \
(2017.06.27.: 11925.628000s = 3 h, 18 min). We used the result to define a \
Module which calculates the Gauss curvature directly from the component \
functions, see the subnotebook Gausscurvature.nb."
}], "Text",
 CellChangeTimes->{{3.6098309366054144`*^9, 3.6098310648917522`*^9}, 
   3.615211712373026*^9, 3.6278958350888643`*^9, {3.6278958679893227`*^9, 
   3.6278959661602945`*^9}, {3.627896520991829*^9, 3.6278965538328867`*^9}, 
   3.697176108121933*^9, {3.707547255260909*^9, 3.707547274021665*^9}, {
   3.70755968210112*^9, 3.707559733419697*^9}, {3.707559910987542*^9, 
   3.7075599695545063`*^9}, {3.707571954772488*^9, 
   3.707572078299535*^9}},ExpressionUUID->"de053423-9387-40a5-b69d-\
f82e81d89935"],

Cell[TextData[{
 "We define the ",
 StyleBox["curvature integral ",
  FontColor->RGBColor[0, 0, 1]],
 "as the integral of K(u,v)*dA[sf][u,v]  (K[u,v]== Gaussian Curvature); for \
surfaces with K(u,v)\[NotEqual]0  it coincides up to sign with the integral \
curvature. "
}], "Text",
 CellChangeTimes->{{3.588502989586344*^9, 3.5885031522946296`*^9}, {
   3.588503185959489*^9, 3.5885032187663465`*^9}, {3.6098311102523465`*^9, 
   3.6098311450603375`*^9}, 3.615264590355524*^9, {3.617954311481616*^9, 
   3.6179544126024*^9}},ExpressionUUID->"8e6c2090-d64f-44d9-a8a8-\
83834674bcb2"],

Cell["\<\
The Gaussian curvature of any developable surface is zero. Examples:\
\>", "Text",
 CellChangeTimes->{{3.5885081700865965`*^9, 3.5885082334071083`*^9}, 
   3.588508375289357*^9},ExpressionUUID->"7496c0f3-5fdd-426e-a485-\
3616fed64810"],

Cell[BoxData[
 RowBox[{"?", "plane"}]], "Input",
 CellChangeTimes->{{3.5899584114106817`*^9, 3.589958414279846*^9}, {
  3.615211799577179*^9, 
  3.615211819997615*^9}},ExpressionUUID->"15617742-9832-4be5-ad88-\
dc52712a270b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pl", "[", 
   RowBox[{"u_", ",", "v_"}], " ", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"plane", "[", 
    RowBox[{"1", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0"}], "]"}], 
   "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5899581112285123`*^9, 3.589958113401637*^9}, {
   3.5899581556930556`*^9, 3.5899582483363543`*^9}, {3.589958278543082*^9, 
   3.589958359030686*^9}, 3.6148618527175274`*^9, 
   3.614862652983333*^9},ExpressionUUID->"14fda5fa-7b76-48ab-bdd1-\
1ce89cfdc271"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", "pl", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.589958375121606*^9, 
  3.589958385221184*^9}},ExpressionUUID->"ffb0d4a2-a4b9-4a91-93d0-\
111255cda229"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"tangsf", "[", "curve", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588502749330322*^9, 3.5885027917311964`*^9}, {
  3.5885080347251587`*^9, 3.588508057048798*^9}, {3.696948809460506*^9, 
  3.696948815728108*^9}},ExpressionUUID->"b59acb2f-6bc7-4876-a158-\
792eba1cd584"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"conesf", "[", "y", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588502749330322*^9, 3.5885027917311964`*^9}, {
   3.5885080347251587`*^9, 3.588508057048798*^9}, 3.5885082818295927`*^9, {
   3.588508346647707*^9, 
   3.588508358332127*^9}},ExpressionUUID->"dae82264-8b40-4350-b97a-\
89c3c729adb0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"cylindersf", "[", 
     RowBox[{"c", ",", "y"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588502749330322*^9, 3.5885027917311964`*^9}, {
   3.5885080347251587`*^9, 3.588508057048798*^9}, 3.5885082818295927`*^9, {
   3.588508346647707*^9, 3.5885083677857437`*^9}, {3.5885084318706565`*^9, 
   3.588508443430277*^9}},ExpressionUUID->"10cfb3e7-5779-4565-90a3-\
442a06f561ac"],

Cell[TextData[{
 "The Gaussian curvature of a sphere of radius r equals ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    SuperscriptBox["r", "2"]], TraditionalForm]],ExpressionUUID->
  "23ee01d2-bc49-4781-8d01-4f02c7c7a55a"],
 ":"
}], "Text",
 CellChangeTimes->{{3.5885086629246006`*^9, 3.588508697213562*^9}, {
   3.588508729758423*^9, 3.5885088016285343`*^9}, 
   3.615264594986789*^9},ExpressionUUID->"42fc14b8-5e56-4a69-b933-\
488bb5c2e663"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.588502749330322*^9, 3.5885027917311964`*^9}, {
   3.5885080347251587`*^9, 3.588508057048798*^9}, 3.5885082818295927`*^9, {
   3.588508346647707*^9, 3.5885083677857437`*^9}, {3.5885084318706565`*^9, 
   3.588508443430277*^9}, {3.5885088284560685`*^9, 
   3.5885088477761736`*^9}},ExpressionUUID->"8e01c861-0ce5-442e-b390-\
2dfd1464cfed"],

Cell["\<\
Clearly, for the unit sphere the Gauss map is the identity; it is orientation \
preserving, and the Gaussian curvature is positive.\
\>", "Text",
 CellChangeTimes->{{3.5885090527488976`*^9, 
  3.5885091182126417`*^9}},ExpressionUUID->"9b8b0813-77eb-43f0-9f1c-\
616f99630994"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2.2. Theorema Egregium", "Subsubsection",
 CellChangeTimes->{{3.5897791459451184`*^9, 3.5897791554299345`*^9}, {
   3.589779201169215*^9, 3.5897792115588336`*^9}, 3.609831296628007*^9, 
   3.6112105016421847`*^9, 3.6152119829399014`*^9, 3.615212872250663*^9, 
   3.6179564158099766`*^9, 3.617965383514293*^9, 3.6278966188572016`*^9, 
   3.6278967271093955`*^9, 3.696948973954958*^9, 3.696951207264122*^9, 
   3.707572109987679*^9, 
   3.707630620440662*^9},ExpressionUUID->"d71a64ac-9501-4a27-b7e4-\
52e433dcfdba"],

Cell["\<\
The Gaussian curvature has been defined by the normal vector and the \
spherical image  of the surface. This is a construction using the embedding \
of the surface into the Euclidean space. It is an surprising result, found by \
Gauss in the year 1816,  that this curvature doesn\[CloseCurlyQuote]t depend \
on the embedding but on the metric of the surface only. Gauss named this \
result the\
\>", "Text",
 CellChangeTimes->{{3.589779294238979*^9, 3.589779629748768*^9}, {
   3.589780134955655*^9, 3.5897801705861177`*^9}, {3.5898648454159813`*^9, 
   3.589864846336383*^9}, 
   3.589864883526848*^9},ExpressionUUID->"b0ac3a37-7b82-4fdf-bec9-\
5b3af4250075"],

Cell[TextData[{
 StyleBox["Theorema egregium",
  FontColor->RGBColor[0, 0, 1]],
 ". If F[sf[u,v]] = sh[f[u,v]] is an isometry then the Gaussian curvatures at \
corresponding points coincide:"
}], "Text",
 CellChangeTimes->{{3.589779644319194*^9, 3.5897796537572103`*^9}, {
  3.58977983591873*^9, 
  3.589779957817344*^9}},ExpressionUUID->"ff7a5fe4-0194-4524-8aa0-\
cdadf754008c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"sh", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", " ", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"gauss", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589779962700153*^9, 3.5897800217150564`*^9}, {
  3.61795650503608*^9, 3.6179565144676194`*^9}, {3.6179565867477536`*^9, 
  3.6179565931711206`*^9}},ExpressionUUID->"03feef42-6651-46ff-811a-\
ffcbc0cd2456"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ".  In subsection 1.4.1, 2. we expressed the first fundamental form as the \
sum of the squares of the basis forms \[Sigma][1], \[Sigma][2]. Therefore it \
suffices to show that the Gaussian curvature may be expressed through these \
basis forms and their exterior derivatives. From the last integrability \
condition ",
 ButtonBox["1.5.1",
  BaseStyle->"Hyperlink",
  ButtonData->"intcond"],
 " it follows"
}], "Text",
 CellChangeTimes->{{3.5897802415506425`*^9, 3.589780247556653*^9}, {
   3.589781031988431*^9, 3.5897811125001726`*^9}, {3.589781144308628*^9, 
   3.5897811764446845`*^9}, {3.5897813023213053`*^9, 3.589781390586261*^9}, {
   3.5898649435557537`*^9, 3.589864944928556*^9}, {3.589865042054326*^9, 
   3.589865062708763*^9}, {3.589865161098136*^9, 3.589865165263343*^9}, {
   3.5898652061666145`*^9, 3.589865238209071*^9}, 
   3.589868621090613*^9},ExpressionUUID->"572af91b-db96-4992-b0a9-\
ee51c422e60a"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"gauss", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], " ", "+", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"dd", "[", 
          RowBox[{
           RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
       RowBox[{
        RowBox[{"extprod", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ")"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
      RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5898653290948305`*^9, 3.5898654271098027`*^9}, {
   3.589865496529925*^9, 3.5898655792100697`*^9}, 3.589865737519148*^9, {
   3.5898682853312235`*^9, 3.589868290292032*^9}, {3.5898683717241745`*^9, 
   3.589868393626613*^9}, {3.58986851160962*^9, 3.5898685574737015`*^9}, 
   3.6096737157884865`*^9, 3.6099111290994644`*^9, 3.609911671609494*^9, {
   3.696949346957603*^9, 3.69694936770571*^9}, {3.696949400000704*^9, 
   3.696949413768005*^9}},ExpressionUUID->"a86625c1-a199-4210-999b-\
98921ac36032"],

Cell["\<\
Thus it suffices to show that  \[Omega][3] may be expressed by \[Sigma][1], \
\[Sigma][2]. This follows from the first two integrability conditions. \
Indeed, inserting for the basis representation of  \[Omega][3]:\
\>", "Text",
 CellChangeTimes->{{3.589865870649782*^9, 3.589866048770895*^9}, {
   3.589866265190075*^9, 3.589866267186878*^9}, 
   3.6152646117317467`*^9},ExpressionUUID->"7c97200b-3e49-4d73-864d-\
0b41680b9105"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Omega]", "[", "3", "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"cg", "[", "1", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{"cg", "[", "2", "]"}], "*", 
    RowBox[{"\[Sigma]", "[", "2", "]"}], " "}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589866097895381*^9, 3.589866168033104*^9}, {
  3.6179744737467556`*^9, 
  3.6179744768909354`*^9}},ExpressionUUID->"c625027e-e58a-43ba-9427-\
a326b2ce24ff"],

Cell[TextData[{
 "into the integrability conditions we obtain the formulas ",
 ButtonBox["[B-R]",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 ", (46.5-8),used  as definitions in eudiffgeov3,m"
}], "Text",
 CellChangeTimes->{{3.5898662781068974`*^9, 3.589866329103387*^9}, {
   3.5898673198299274`*^9, 3.5898673426683674`*^9}, {3.589867391465253*^9, 
   3.589867431931724*^9}, {3.6226157712134523`*^9, 3.622615791384288*^9}, 
   3.6862890145568037`*^9},ExpressionUUID->"9fa9afc7-c442-4e66-b13e-\
778da8f60352"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cg", "[", "1", "]"}], "[", "ff_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dd", "[", 
      RowBox[{
       RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5898663353121977`*^9, 3.5898664498007994`*^9}, {
   3.589866942293664*^9, 3.5898669583616924`*^9}, {3.5898669907161493`*^9, 
   3.589867004756174*^9}, 3.5898681119369183`*^9, {3.5898682177831044`*^9, 
   3.589868228796724*^9}, 3.6096737250530167`*^9, 3.6179744789150515`*^9, {
   3.696949827308291*^9, 3.696949873228683*^9}, 
   3.696950380115798*^9},ExpressionUUID->"b794af7e-82e8-4133-87fd-\
d3f9190e373c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cg", "[", "2", "]"}], "[", "ff_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dd", "[", 
      RowBox[{
       RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
   RowBox[{
    RowBox[{"extprod", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589866492544874*^9, 3.5898665075833006`*^9}, {
   3.589866902544794*^9, 3.5898669300476427`*^9}, 3.5898689735732317`*^9, {
   3.589869375273937*^9, 3.58986938255915*^9}, 3.609911786091042*^9, 
   3.609911905885894*^9, 3.6179744802981305`*^9, 
   3.696949885957165*^9},ExpressionUUID->"24c529e3-c341-422d-b66e-\
f38eed701c21"],

Cell[BoxData[
 RowBox[{"?", "cg"}]], "Input",
 CellChangeTimes->{{3.6179750758591948`*^9, 3.617975187419575*^9}, {
   3.6179752579396086`*^9, 3.617975284484127*^9}, 3.6179754698357286`*^9, 
   3.617976052148035*^9, {3.6179762354295177`*^9, 3.6179763154430943`*^9}, 
   3.617976361330719*^9, {3.6226158991336765`*^9, 
   3.622615913142502*^9}},ExpressionUUID->"4cd9216e-68ad-405e-8f69-\
05195aa356ee"],

Cell[BoxData[
 RowBox[{"Context", "[", "cg", "]"}]], "Input",
 CellChangeTimes->{{3.6226159252169228`*^9, 
  3.6226159541861734`*^9}},ExpressionUUID->"639698cb-63c6-442f-86b5-\
d4838f7b5b39"],

Cell["and this shows", "Text",
 CellChangeTimes->{{3.5898665879858418`*^9, 
  3.589866602790268*^9}},ExpressionUUID->"7bbd5a89-515a-4b27-91ee-\
2ba892b47478"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "-", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cg", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cg", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "*", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.589866608874278*^9, 3.5898667830485845`*^9}, {
   3.589867075549098*^9, 3.5898671069051533`*^9}, {3.5898676092260356`*^9, 
   3.5898676576329203`*^9}, {3.589869404633189*^9, 3.5898694693577027`*^9}, 
   3.609911828578472*^9, {3.617974482131235*^9, 3.6179744835703173`*^9}, {
   3.696949659654914*^9, 
   3.6969496615005503`*^9}},ExpressionUUID->"9f663417-1abd-4b9b-b28d-\
71b85ac6fbfe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"dd", "[", 
         RowBox[{
          RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
      RowBox[{
       RowBox[{"extprod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "+", " ", 
     RowBox[{
      RowBox[{"gauss", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
      RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{
  3.589893961196463*^9, 3.6179587350616302`*^9, {3.617958812949085*^9, 
   3.617958909461605*^9}, 
   3.696949977591147*^9},ExpressionUUID->"bd760cdf-38a5-42d2-94c8-\
e0d2b0696267"],

Cell["Here is the Gaussian curvature of the hyperboloid:", "Text",
 CellChangeTimes->{{3.696950620352941*^9, 3.696950730387664*^9}, {
  3.707630057069676*^9, 
  3.707630064067976*^9}},ExpressionUUID->"b47be714-9036-4f9b-b73f-\
3adfaf73d481"],

Cell[BoxData[
 RowBox[{"hypsf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.696950759876495*^9},ExpressionUUID->"bda99c54-030c-41a6-9d2b-\
74a5dea2b5e4"],

Cell["it is negative:", "Text",
 CellChangeTimes->{{3.696950770659457*^9, 
  3.696950778931282*^9}},ExpressionUUID->"f01ab482-916e-4401-9913-\
223d0cf4ebd6"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", "hypsf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.696950588886504*^9},ExpressionUUID->"da1c1f3b-f23f-4387-a355-\
7dae3f03928c"],

Cell["\<\
Also in this concrete case the theorema egregium is confirmed\
\>", "Text",
 CellChangeTimes->{{3.6969508038591213`*^9, 
  3.6969508376589203`*^9}},ExpressionUUID->"0028e747-9330-4741-ac17-\
eae7b8c23bd7"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{
        RowBox[{"dd", "[", 
         RowBox[{
          RowBox[{"\[Omega]", "[", "3", "]"}], "[", "hypsf", "]"}], "]"}], 
        "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "/", 
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5898707934412284`*^9, {3.5898708344381003`*^9, 3.5898708579785414`*^9}, {
   3.5898940993971057`*^9, 3.5898941417199802`*^9}, 3.609911786284053*^9, 
   3.6099119062469144`*^9, {3.617964848782708*^9, 3.617964872742079*^9}, 
   3.6969505303114157`*^9},ExpressionUUID->"20506d76-c93e-4725-a591-\
d6e564a35cae"],

Cell["The traditional form of the proved identity is", "Text",
 CellChangeTimes->{{3.696950869019631*^9, 
  3.6969509250099983`*^9}},ExpressionUUID->"a83be79c-a562-4719-a46c-\
f11f31321e75"],

Cell[BoxData[
 RowBox[{"K", "\[Equal]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     SubscriptBox["d\[Omega]", "3"], 
     RowBox[{
      SubscriptBox["\[Sigma]", "1"], "\[Wedge]", " ", 
      SubscriptBox["\[Sigma]", "2"]}]]}], "                                            ", 
   RowBox[{"(", "1", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.696950930941003*^9, 3.696950947546885*^9}, {
  3.6969509813121643`*^9, 3.696951113689837*^9}, {3.697001060642606*^9, 
  3.697001072170199*^9}},ExpressionUUID->"87801be3-8e53-4009-bcd4-\
db7475e1d804"],

Cell["\<\
Thee third integrability condition of Subsection 1.5.3 yields\
\>", "Text",
 CellChangeTimes->{{3.696999657605947*^9, 3.696999734300722*^9}, {
   3.696999780732122*^9, 3.6969998083637114`*^9}, 
   3.696999843427561*^9},ExpressionUUID->"b6147f70-24f6-4572-9a8c-\
b267d5d3c6ce"],

Cell[BoxData[
 RowBox[{"K", "\[Equal]", 
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Wedge]", 
     SubscriptBox["\[Omega]", "2"]}], 
    RowBox[{
     SubscriptBox["\[Sigma]", "1"], "\[Wedge]", " ", 
     SubscriptBox["\[Sigma]", "2"]}]], "                                            ", 
   RowBox[{"(", "2", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.696950930941003*^9, 3.696950947546885*^9}, {
   3.6969509813121643`*^9, 3.696951113689837*^9}, {3.696999902747821*^9, 
   3.696999944243189*^9}, 3.6969999778663073`*^9, {3.6970000496663322`*^9, 
   3.697000123793149*^9}, {3.697001083202124*^9, 
   3.697001095578064*^9}},ExpressionUUID->"1442864b-d2fd-49c5-bfe1-\
c94102a8865f"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2.3. Developable Surfaces 2", "Subsubsection",
 CellChangeTimes->{{3.58995791782845*^9, 3.5899579288990836`*^9}, {
   3.58995796082791*^9, 3.589957970067438*^9}, {3.5900391023377857`*^9, 
   3.5900391053953905`*^9}, 3.611210506158443*^9, 3.6112125836092663`*^9, 
   3.6152128786622744`*^9, 3.615263576317348*^9, 3.6179654195943565`*^9, 
   3.617973709425148*^9, 3.6278967582042503`*^9, 3.6279023898942275`*^9, 
   3.696951213857129*^9, 3.697002895710759*^9, 3.707630627919808*^9, 
   3.707630818703182*^9},ExpressionUUID->"e848cc0d-d980-4daa-821f-\
7be6a39aa3ae"],

Cell["\<\
In Subsection 2.2.1 we have seen that all developable surfaces have Gaussian \
curvature zero. From the theorema egregium it follows that any surface \
isometric to the plane has this property. Now we will prove the converse: \
\>", "Text",
 CellChangeTimes->{{3.5899580312989407`*^9, 3.5899580758994913`*^9}, {
   3.5899585563559723`*^9, 3.5899586364995565`*^9}, {3.589958678715971*^9, 
   3.589958706467558*^9}, {3.589978337180153*^9, 3.5899783553853855`*^9}, {
   3.590039159901887*^9, 3.590039159901887*^9}, {3.590039354761829*^9, 
   3.590039368786254*^9}, 
   3.696998831154541*^9},ExpressionUUID->"1d1b83ee-da99-4bb4-a925-\
cb9afa616498"],

Cell[TextData[{
 StyleBox["Proposition 2",
  FontColor->RGBColor[0, 0, 1]],
 ". Let sf[u,v] be a surface with Gaussian curvature zero. Then the rank \
rk[u,v] of the differential of the Gauss map  d[amf[3][sf]][u,v] is less than \
2. If this rank for all points sf[u,v] equals zero, the surface is a part of \
a plane. If the rank  for all points sf[u,v] equals one, the surface is \
developable."
}], "Text",
 CellChangeTimes->{{3.5899587166831427`*^9, 3.5899587244515867`*^9}, {
   3.5899588196920342`*^9, 3.589958880251498*^9}, {3.589958924227013*^9, 
   3.589958945747244*^9}, {3.5899589894277425`*^9, 3.5899590581636744`*^9}, {
   3.5899590896194735`*^9, 3.5899591359231215`*^9}, 3.589978431482319*^9, {
   3.589979743507023*^9, 3.589979771041072*^9}, {3.5899800276459227`*^9, 
   3.5899800708423977`*^9}, 3.614861852826728*^9, 3.6149177846821485`*^9, 
   3.615261926990012*^9, {3.6969993213517523`*^9, 3.696999323287668*^9}, {
   3.696999421063678*^9, 
   3.69699942198291*^9}},ExpressionUUID->"ef80dd7b-d40d-4759-a032-\
9549e4d2ecee"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ".  The differential of the Gauss map is \nd[amf[3] ]== amf[1] \[Omega][2] - \
 amf[2] \[Omega][1]. \nThe rank  rk[u,v] of this differential at a point \
sf[u,v] is less than 2 iff \n\[Omega][1] ",
 Cell[BoxData[
  FormBox["\[And]", TraditionalForm]],ExpressionUUID->
  "8ae3f19c-6656-4896-8aef-e6f72d46fc68"],
 " \[Omega][2] == 0, and this is the case iff gauss[sf][u,v]== 0. see \
2.2.2.(2). If the rank equals 0 for the whole connected surface  the normal \
vector amf[3] is constant, and the statement follows from",
 ButtonBox[" Lemma 1",
  BaseStyle->"Hyperlink",
  ButtonData->"lem2.1.1"],
 ".  If the rank of the Gauss map is less than two then the set of all points \
sf[u,v] of the surface with \nrk[u,v] = 1 is open. We assume that rk[u,v] == \
1 for all points of the surface. Then the kernel ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{
         RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ")"}], 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"null", "[", " ", "]"}]}], TraditionalForm]],ExpressionUUID->
  "15a8b952-1b3f-4629-9fa3-983404be9291"],
 "] of d[amf[3][sf]][u,v]  is one-dimensional. We put the vector \
amf[1][sf][u,v] into the kernel. Then the frame is uniquely defined since \
amf[2] == amf[3] \[Times] amf[1]. The integral curves of the Pfaffian \
equation \[Sigma][2] == 0 have the tangent vector amf[1]=d[sf][u, v].vt, \
where vt is the corresponding vector in the parameter space. Thus \
d[amf[3][sf]][u, v].vt== 0, and the normal vector is constant along the \
integral curves. We will show that also amf[1] is constant along these \
curves: d[amf[1][sf]][u,v].vt == 0 if \[Sigma][2](vt) = 0. To this aim we \
consider the basis decompositions of \[Omega][1], \[Omega][2] with the \
notations [B-R] (61.9) p. 87:"
}], "Text",
 CellChangeTimes->{{3.589978656980715*^9, 3.589978703499996*^9}, {
   3.5899787359636536`*^9, 3.589978816974596*^9}, {3.5899788639306784`*^9, 
   3.589979198488866*^9}, {3.5899796086915865`*^9, 3.589979638050838*^9}, {
   3.589979676146105*^9, 3.5899797209025836`*^9}, 3.5899800551799707`*^9, {
   3.589980091294034*^9, 3.5899801718057756`*^9}, {3.589980202428629*^9, 
   3.5899802665915422`*^9}, {3.5899803831008573`*^9, 
   3.5899805423809676`*^9}, {3.5899805879755754`*^9, 
   3.5899807208211737`*^9}, {3.589980760477442*^9, 3.58998077250113*^9}, {
   3.589980874364956*^9, 3.5899809564446507`*^9}, 3.5899811643895445`*^9, 
   3.589981878013362*^9, {3.589981948653402*^9, 3.589981996293127*^9}, {
   3.589982186453003*^9, 3.589982221292996*^9}, {3.5899822553059416`*^9, 
   3.5899823342284555`*^9}, {3.590039496051277*^9, 3.5900394960668774`*^9}, {
   3.590039566969002*^9, 3.590039575065416*^9}, {3.590039605189069*^9, 
   3.590039677604396*^9}, 3.59003973123729*^9, {3.5900397746677666`*^9, 
   3.5900397784741735`*^9}, {3.5900398450082903`*^9, 3.590039878158348*^9}, {
   3.5900399682641068`*^9, 3.590040111987159*^9}, {3.5900407431174674`*^9, 
   3.59004083581283*^9}, {3.590040875140499*^9, 3.590040965620658*^9}, {
   3.59004100086112*^9, 3.590041048722004*^9}, {3.614861853481929*^9, 
   3.6148618583803377`*^9}, {3.6149177853529496`*^9, 
   3.6149177902357583`*^9}, {3.6152619289561243`*^9, 3.615261948601248*^9}, {
   3.615262603651715*^9, 3.615262646526167*^9}, {3.615262816362881*^9, 
   3.6152628196860714`*^9}, {3.627900345151836*^9, 3.6279003527802496`*^9}, {
   3.6279012717154636`*^9, 3.627901321385951*^9}, {3.627901352398805*^9, 
   3.6279014732834177`*^9}, {3.6970001930614023`*^9, 3.697000216794722*^9}, {
   3.69700112202345*^9, 3.6970011280312634`*^9}, {3.697001183439184*^9, 
   3.69700120638767*^9}, {3.6970015337359324`*^9, 3.6970015365026712`*^9}, 
   3.697001657650729*^9},ExpressionUUID->"c110000f-ffd1-4450-8eb8-\
8341dfbc793a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"\[Omega]", "[", "1", "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}], ";", " ", 
  RowBox[{
   RowBox[{"\[Omega]", "[", "2", "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "1", "]"}]}], " ", "+", "  ", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "2", "]"}]}]}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5899823839693003`*^9, 
  3.589982562800529*^9}},ExpressionUUID->"b2a024a6-7736-4623-a355-\
d785c7d7b569"],

Cell[TextData[{
 "leading to the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " definitions of the coefficients cf defined in eudiffgeov3.m."
}], "Text",
 CellChangeTimes->{{3.589982622308933*^9, 3.5899826449002247`*^9}, {
   3.6226135412863355`*^9, 3.622613608160453*^9}, 3.627901605961651*^9, 
   3.686289015650693*^9},
 CellTags->"cij",ExpressionUUID->"a2fd810c-c835-4380-ae90-2d98cf5c806f"],

Cell[BoxData[
 RowBox[{"?", "cf"}]], "Input",
 CellChangeTimes->{{3.622613719685049*^9, 
  3.622613721900253*^9}},ExpressionUUID->"968354ef-538a-476e-ae1b-\
3faf80a46995"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "[", "ff_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"extprod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Omega]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "/", 
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "[", "ff_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
    RowBox[{
     RowBox[{"+", 
      RowBox[{
       RowBox[{"extprod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Omega]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "/", 
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "[", "ff_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Omega]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
     RowBox[{
      RowBox[{"extprod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Omega]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", 
    RowBox[{
     RowBox[{"extprod", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5899830368256416`*^9, 3.589983216612925*^9}, 
   3.589983350955609*^9, 3.589983976627395*^9, {3.59221330302858*^9, 
   3.5922133147682514`*^9}, 3.592315502531618*^9, {3.609911786486065*^9, 
   3.609911786498065*^9}, {3.609911906425925*^9, 3.6099119064319253`*^9}, 
   3.6179720239937468`*^9, {3.6257282958419447`*^9, 
   3.6257283174635825`*^9}},ExpressionUUID->"726aba45-a446-4e9f-bcd4-\
010f255da41f"],

Cell["For this coefficients one has ", "Text",
 CellChangeTimes->{{3.5900401716884637`*^9, 
  3.590040188489693*^9}},ExpressionUUID->"8c0ca9db-b3e4-491f-a599-\
ab91c1aaf13b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "==", 
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5899837285372057`*^9, 3.589983810223878*^9}, {
  3.5900402150409403`*^9, 3.5900402169441433`*^9}, {3.617972032119211*^9, 
  3.6179720334632883`*^9}, {3.625726673503094*^9, 3.625726701817144*^9}, {
  3.6279017111838355`*^9, 
  3.6279017345370765`*^9}},ExpressionUUID->"d286a6bb-4ccf-4d74-9ac7-\
ffe577475d75"],

Cell["\<\
 for all surfaces; it is a consequence of the third integrability condition \
in Subsection 1.5.2. We conclude, since 
\[Sigma][1][sf][u,v][vt] ==1 and \[Sigma][2][sf][u,v][vt] == 0,\
\>", "Text",
 CellChangeTimes->{{3.589984123908819*^9, 3.589984178348933*^9}, {
   3.589984231596979*^9, 3.5899843220211506`*^9}, {3.5899843621814475`*^9, 
   3.5899843678207703`*^9}, {3.5899843991745634`*^9, 3.5899844344285803`*^9}, 
   3.590040616492045*^9, {3.5900406549929123`*^9, 3.590040669547738*^9}, 
   3.5900411030413*^9, {3.590041232427927*^9, 3.5900412522711616`*^9}, {
   3.697002382896254*^9, 3.697002397015781*^9}, 
   3.697002435255797*^9},ExpressionUUID->"a27148b6-ccce-4028-a584-\
8e93d353d104"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}], " ", "\[Equal]", " ", "0", " ", "\[Equal]", 
  " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "*", 
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}]}], " ", "+", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "*", 
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589984447519329*^9, 3.5899845634239583`*^9}, {
   3.589984611100685*^9, 3.589984633600972*^9}, {3.589984668727981*^9, 
   3.589984696433566*^9}, 3.589984851882457*^9, 3.5899848983511147`*^9, {
   3.6148618584115376`*^9, 3.6148618584271374`*^9}, {3.6149177902513585`*^9, 
   3.614917790266958*^9}, {3.61526194986032*^9, 3.615261953404523*^9}, {
   3.6179720352323895`*^9, 3.617972036935487*^9}, {3.6279019504258556`*^9, 
   3.6279019720630937`*^9}},ExpressionUUID->"1a2dc900-efc2-4b74-b447-\
5dba66e573e9"],

Cell["\<\
We conclude cf[1,1] == cf[2,1] ==cf[1,2] ==0, and therefore \
\[Omega][2][sf][u,v] == 0 is the null form. Furthermore we have that the \
assumption implies \
\>", "Text",
 CellChangeTimes->{{3.589984961956753*^9, 3.589984971221283*^9}, {
  3.589985019637052*^9, 3.5899851567168922`*^9}, {3.5899852224376516`*^9, 
  3.5899852821410666`*^9}, {3.61797203839657*^9, 
  3.617972045323967*^9}},ExpressionUUID->"3e7b8d49-858a-4bed-9f23-\
bb908f2f6b08"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Omega]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "*", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5899852947197857`*^9, 3.5899853374092274`*^9}, {
   3.5899853776785307`*^9, 3.589985379710647*^9}, {3.589985414166618*^9, 
   3.5899855089280376`*^9}, 
   3.617972047079067*^9},ExpressionUUID->"0e090342-b6a2-4509-bbb5-\
ed356c0aa98f"],

Cell["We conclude from the derivation equations", "Text",
 CellChangeTimes->{{3.5899857875329733`*^9, 3.589985865828451*^9}, 
   3.5899859187814803`*^9, {3.5899859747406807`*^9, 3.5899859794209485`*^9}, {
   3.5900414890483775`*^9, 
   3.5900415027764015`*^9}},ExpressionUUID->"007966ac-1f66-44db-8408-\
8f8afd39ebfc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "*", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "3", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589985616280178*^9, 3.5899857305607147`*^9}, {
  3.6148618584271374`*^9, 3.6148618584427376`*^9}, {3.6149177902825584`*^9, 
  3.6149177902825584`*^9}, {3.615261954652594*^9, 
  3.6152619562126837`*^9}},ExpressionUUID->"e1bd2ed4-b381-4516-bfcc-\
6b65e8f4a8fe"],

Cell["\<\
since \[Omega][2] == 0. The last equation implies. since \[Sigma][1][vt]== 1, \
\[Sigma][2][vt]==0:\
\>", "Text",
 CellChangeTimes->{
  3.589985928237021*^9, {3.5899860674129815`*^9, 3.5899861255893087`*^9}, 
   3.590041447006304*^9},ExpressionUUID->"08063ed8-afc5-49e9-94cb-\
a9d8d13e27ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "*", 
   RowBox[{
    RowBox[{
     RowBox[{"cg", "[", "1", "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5899860290237856`*^9, 3.589986048991928*^9}, {
   3.6148618584427376`*^9, 3.6148618584427376`*^9}, {3.6149177902825584`*^9, 
   3.6149177902981586`*^9}, {3.6152619573567486`*^9, 3.6152619587168264`*^9}, 
   3.6179744883795924`*^9},ExpressionUUID->"4fbdfe5a-98bf-4710-ae5f-\
01403fc123e9"],

Cell["Now we apply the fifth integrability condition :", "Text",
 CellChangeTimes->{{3.5899861640295076`*^9, 
  3.5899861937332067`*^9}},ExpressionUUID->"0c14c6c2-7cae-455d-87d5-\
2ae1d98bc7de"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dd", "[", 
     RowBox[{"\[Omega]", "[", "2", "]"}], "]"}], " ", "\[Equal]", " ", 
    RowBox[{"-", " ", 
     RowBox[{"\[Omega]", "[", "3", "]"}]}]}], "\[And]", " ", 
   RowBox[{"\[Omega]", "[", "1", "]"}]}], " ", "=", " ", 
  RowBox[{"0", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cg", "[", "1", "]"}], "*", " ", 
     RowBox[{"cf", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "*", 
     RowBox[{"\[Sigma]", "[", "1", "]"}]}], "\[And]", 
    RowBox[{
     RowBox[{"\[Sigma]", "[", "2", "]"}], "."}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.589986244895133*^9, 3.5899863882873344`*^9}, {
   3.5899864285356364`*^9, 3.589986483231765*^9}, {3.5899865213349447`*^9, 
   3.589986633432356*^9}, 3.6179720482881365`*^9, 
   3.617974492023801*^9},ExpressionUUID->"2a33ed0d-c691-40a6-a05f-\
8ec3770835b1"],

Cell["\<\
Since MatrixRank[{\[Omega][1], \[Omega][2]}] == 1 we have \
cf[2,2]\[NotEqual]0, and thus cg[1] == 0. It follows\
\>", "Text",
 CellChangeTimes->{{3.5899866745767093`*^9, 3.589986807629319*^9}, {
   3.589986839149122*^9, 3.5899868475086*^9}, 3.61797204974422*^9, 
   3.617974494186925*^9},ExpressionUUID->"1ca1a501-f2bb-4e86-8736-\
32c025db13af"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], 
   RowBox[{"(", "vt", ")"}]}], " ", "\[Equal]", " ", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5899868535589466`*^9, 3.589986858447226*^9}, 
   3.6148618584427376`*^9, 3.6149177902981586`*^9, 
   3.6152619598278904`*^9},ExpressionUUID->"46ec8ea0-42fd-49fd-b5fd-\
ae1ea287d885"],

Cell["\<\
amf[1] is constant along the integral curves of \[Sigma][2]== 0, and thus \
these curves must be lines. Since the normal vector of the surface is also \
constant along these lines, the surface is developable. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.5899869117332735`*^9, 3.5899870684532375`*^9}, 
   3.6148618584739375`*^9, 3.614917790329358*^9, 3.615261961097963*^9, {
   3.6152634663810596`*^9, 3.6152634704812946`*^9}, {3.617972839882413*^9, 
   3.617972846952817*^9}},ExpressionUUID->"d5aebf1d-e97b-4912-aff3-\
a12d321058b8"],

Cell[TextData[{
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 ". Generally, a surface may have singularities. Furthermore, the subset of \
points at which the rank of the Gauss map is zero, is a closed set. The \
points of the last set not being interior points of the set are not \
considered in the proposition.  Having in mind this, one often formulates - \
with a grain of salt:\n",
 StyleBox["Corollary",
  FontColor->RGBColor[0, 0, 1]],
 ". A surface in the Euclidean 3-space is locally isometric to an Euclidean \
plane iff its Gauss curvature is zero."
}], "Text",
 CellChangeTimes->{{3.589959160829546*^9, 3.5899591830038147`*^9}, {
   3.5899592232671175`*^9, 3.5899593889235926`*^9}, {3.5899594189633102`*^9, 
   3.58995943381116*^9}, {3.589959612019353*^9, 3.589959622683963*^9}, 
   3.5899785101376567`*^9, {3.5900420955373964`*^9, 3.590042246961057*^9}, 
   3.617972882304839*^9},ExpressionUUID->"451b1fe0-2519-4d4f-b784-\
6a911b427759"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. The Second Fundamental Form", "Section",
 CellChangeTimes->{{3.590213457675046*^9, 3.5902135002631207`*^9}, 
   3.5902137672731895`*^9, {3.5905025808142767`*^9, 3.5905025824834795`*^9}, 
   3.5907394960471115`*^9, {3.6112125916717277`*^9, 3.6112126039264283`*^9}, {
   3.611212757083188*^9, 3.6112127596153336`*^9}, 3.6152635866689405`*^9, 
   3.61527332575016*^9},ExpressionUUID->"9fed42b2-58ec-4f2a-877b-\
e970f669a20b"],

Cell[CellGroupData[{

Cell["3.1. The Definition ", "Subsection",
 CellChangeTimes->{{3.5906466020506277`*^9, 3.590646615061051*^9}, {
   3.5906466475091076`*^9, 3.5906466547319202`*^9}, {3.6112127683308315`*^9, 
   3.6112127708729773`*^9}, 3.611213166180588*^9, {3.6179741428428288`*^9, 
   3.617974156080586*^9}, 3.6180341576632977`*^9, 3.6279029363281584`*^9, {
   3.6279070864876823`*^9, 3.627907086968285*^9}, {3.6279073204952974`*^9, 
   3.62790733313132*^9}, 3.6279079091849365`*^9, 3.697002914704033*^9, 
   3.697003492946286*^9, 3.7076308264558697`*^9, 
   3.7076332729721537`*^9},ExpressionUUID->"c0982fd6-08da-40be-b6f7-\
3ea69d1025f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.6180338973768406`*^9, 
  3.6180339102624636`*^9}},ExpressionUUID->"90999149-5787-4f0d-8a76-\
9f111c99b7de"],

Cell[TextData[{
 "Following ",
 ButtonBox["[B-R]",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 ",(61..8) we introduce now the ",
 StyleBox["second fundamental form",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5906404910830946`*^9, 3.590640514810736*^9}, {
  3.5906405514552007`*^9, 3.590640594776477*^9}, {3.5906406796562257`*^9, 
  3.5906406796562257`*^9}},ExpressionUUID->"94bdbdea-4076-42b7-be29-\
64406ffea269"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fund2", "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], "[", 
   RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "ff", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", "x"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", "y"}], ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.590214197740346*^9, 3.590214224307193*^9}, {
   3.5902142903889084`*^9, 3.590214400400302*^9}, {3.590218010839443*^9, 
   3.590218051961116*^9}, {3.5902180860783753`*^9, 3.5902181389780684`*^9}, {
   3.5904956764293494`*^9, 3.5904956764293494`*^9}, {3.5905011101060934`*^9, 
   3.5905011431313515`*^9}, {3.5907157938532677`*^9, 3.59071579522607*^9}, 
   3.6148618585051374`*^9, 3.6149177903449583`*^9, 3.6152619715185585`*^9, 
   3.622699047316374*^9},ExpressionUUID->"760d19fc-2101-4d4f-8e96-\
83f4b6ca868f"],

Cell[BoxData[
 RowBox[{"?", "fund2"}]], "Input",
 CellChangeTimes->{{3.618026345918378*^9, 3.618026378569235*^9}, {
   3.6180264185365047`*^9, 3.6180265050698566`*^9}, 3.618026535786311*^9, {
   3.618026569950371*^9, 3.618026638153691*^9}, {3.622699083212036*^9, 
   3.622699098281663*^9}},ExpressionUUID->"a1e34954-9dfb-45c9-a189-\
2aa60cf9937c"],

Cell[BoxData[
 RowBox[{"Context", "[", "fund2", "]"}]], "Input",
 CellChangeTimes->{{3.6226991761414*^9, 
  3.622699201304244*^9}},ExpressionUUID->"6551b6be-749c-4793-93d4-\
02ff395cacb1"],

Cell[TextData[{
 "Clearly, fund2 is invariant with respect to orientation preserving \
Euclidean motions. It changes the sign if the orientation of the space or the \
orientation of the surface (direction of amf[3][sf])  changes.  It is a field \
of bilinear forms with  linear transformation under parameter \
transformations. Thus, as well as the first fundamental form, it defines a \
field of twofold covariant tensors on the surface. The coordinates of this \
tensor with respect to the local cobasis \[Sigma][1], \[Sigma][2]  are the \
coefficients cf[i,j], considered already in subsection ",
 ButtonBox["2.2.3",
  BaseStyle->"Hyperlink",
  ButtonData->"cij"],
 ":"
}], "Text",
 CellChangeTimes->{{3.590640970830737*^9, 3.5906414247915344`*^9}, {
   3.5906420395730143`*^9, 3.590642063846657*^9}, {3.5907159302287073`*^9, 
   3.5907160598961353`*^9}, {3.5907161361179314`*^9, 3.5907161917331123`*^9}, 
   3.6112129366894617`*^9, 3.6148618585987377`*^9, 3.6149177904385586`*^9, 
   3.6152619732326565`*^9, {3.61526726018423*^9, 3.615267267071624*^9}, 
   3.617972051489319*^9, 3.6180344092752137`*^9, {3.622613841349663*^9, 
   3.6226138600696955`*^9}, {3.62790750892583*^9, 3.627907528646265*^9}, 
   3.6279075760139484`*^9},ExpressionUUID->"d621d18d-5708-442d-8492-\
d0e068c5cb52"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "=", " ", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], ";", " ", 
  RowBox[{"yy", "=", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund2", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"xx", ",", "yy"}], "]"}], "-", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"cf", "[", 
           RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[Sigma]", "[", "i", "]"}], "[", "sf", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], ".", "xx"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[Sigma]", "[", "j", "]"}], "[", "sf", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], ".", "yy"}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
      RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5902162888928185`*^9, 3.5902165073244023`*^9}, {
   3.5902167767524757`*^9, 3.590216796829711*^9}, {3.590217454916867*^9, 
   3.590217511061365*^9}, {3.5902175775954823`*^9, 3.5902176033823276`*^9}, 
   3.5902178500811605`*^9, {3.590218591566063*^9, 3.590218738206321*^9}, 
   3.5902188211048665`*^9, 3.5902198527502785`*^9, 3.590220631597246*^9, 
   3.59049567686615*^9, {3.5904994302171426`*^9, 3.5904995144260902`*^9}, {
   3.5904995882298203`*^9, 3.5904996219258795`*^9}, {3.5904996601615467`*^9, 
   3.5904996603643465`*^9}, {3.5904997007840176`*^9, 3.590499704403224*^9}, 
   3.5905023971551538`*^9, {3.590502450304447*^9, 3.590502485420109*^9}, {
   3.5906415477197504`*^9, 3.5906415910566263`*^9}, {3.590818432344045*^9, 
   3.5908184468832707`*^9}, 
   3.6179720537374477`*^9},ExpressionUUID->"c98d2445-57e5-4646-b50d-\
7911f1aba5ff"],

Cell[BoxData[
 RowBox[{"?", "cf"}]], "Input",
 CellChangeTimes->{{3.6226140882668962`*^9, 
  3.6226140906693*^9}},ExpressionUUID->"fbce4d84-290f-45e3-b434-35da5316d0ce"],

Cell[TextData[{
 "The bilinear form fund2 is ",
 StyleBox["symmetric",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5906417309108725`*^9, 3.590641761923727*^9}, 
   3.5906418653519087`*^9, 
   3.5907162291482525`*^9},ExpressionUUID->"f1ca0199-3e85-4629-aeee-\
fd6c6b255102"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund2", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{"xx", ",", "yy"}], "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"fund2", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{"yy", ",", "xx"}], "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590214680093193*^9, 3.5902147816961718`*^9}, {
  3.5904956764449496`*^9, 3.5904956764449496`*^9}, {3.590641834853855*^9, 
  3.5906418500950813`*^9}},ExpressionUUID->"6f07c39a-6018-492f-a334-\
463a9c045f54"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590214680093193*^9, 3.5902147816961718`*^9}, {
  3.5904956764449496`*^9, 3.5904956764449496`*^9}, {3.590641834853855*^9, 
  3.5906418500950813`*^9}, {3.6226141555186143`*^9, 
  3.6226142522699842`*^9}},ExpressionUUID->"61b3fb9b-09e3-4c84-ba3f-\
2be23efefa45"],

Cell[TextData[{
 "We remark that very often the second fundamental form is defined with the \
opposite sign, see e.g. Alfred  Gray [",
 ButtonBox["G06",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray"],
 "], or Erwin Kreyszig [",
 ButtonBox["Kr",
  BaseStyle->"Hyperlink",
  ButtonData->"Kr"],
 "], formula (38.6), p 146."
}], "Text",
 CellChangeTimes->{{3.590642754147869*^9, 3.59064281138437*^9}, {
   3.590643336512492*^9, 3.5906434798299437`*^9}, {3.5906435852705293`*^9, 
   3.590643647140238*^9}, 3.590644042975333*^9, {3.5991973443311057`*^9, 
   3.5991973496114078`*^9}},ExpressionUUID->"25078d7a-fb7c-437b-aaf6-\
606700e40b6e"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2. Gaussian Curvature and Second Fundamental Form", "Subsection",
 CellChangeTimes->{{3.5906466724535513`*^9, 3.5906467470684824`*^9}, 
   3.590671674118125*^9, 3.6112131733619986`*^9, 3.6114693957095017`*^9, 
   3.6152733312304735`*^9, 3.6152757102455454`*^9, 3.6180344955531483`*^9, 
   3.6180373458971786`*^9, 3.627907951651211*^9, 3.6279130329859734`*^9, 
   3.697003525266947*^9, 3.69700583401054*^9, 3.707633293923863*^9, 
   3.70763384281643*^9},ExpressionUUID->"26107c3f-f1b2-4f63-8834-\
527a9bcf8704"],

Cell["\<\
For the Gaussian curvature we obtain the formula, see [B-R], (61.12):\
\>", "Text",
 CellChangeTimes->{{3.590644144063511*^9, 3.5906441679783525`*^9}, {
  3.5906444821005044`*^9, 
  3.590644503784542*^9}},ExpressionUUID->"9be3c6e7-e97c-492b-98b2-\
0649f4716b24"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"gauss", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], " ", "-", " ", 
     RowBox[{"Det", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"cf", "[", 
           RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
      RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}], ",", 
    RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5906441721591597`*^9, 3.59064420053561*^9}, {
   3.590644236665273*^9, 3.5906442773657446`*^9}, 3.5906443350702457`*^9, {
   3.6114672135436893`*^9, 3.611467262235474*^9}, 3.614861858629938*^9, 
   3.6148635015936236`*^9, 3.617972055328539*^9, {3.69700363069575*^9, 
   3.6970036429698257`*^9}},ExpressionUUID->"ea6dfd5d-2b96-4939-85d2-\
ae1efaea4d4f"],

Cell[TextData[{
 "Mathematica needed 73.688,0 s for this calculation.\nRemember that the \
definition of the Gaussian curvature is the ratio of two \n2-orms, invariant \
under Euclidean motions and parameter transformations. In the local basis \
\[Sigma][1], \[Sigma][2] the strict coordinate of  \[Sigma][1] \[And] \
\[Sigma][2] is 1, and the formula just calculated follows immediately from \
the ",
 ButtonBox["definition",
  BaseStyle->"Hyperlink",
  ButtonData->"gaussK"],
 "."
}], "Text",
 CellChangeTimes->{{3.590738951294155*^9, 3.5907390645503535`*^9}, {
   3.59073910233362*^9, 3.590739262452301*^9}, {3.590739416346572*^9, 
   3.5907394544574385`*^9}, {3.618034565778165*^9, 3.6180345719545183`*^9}, 
   3.6180373847834024`*^9, {3.6970045139624166`*^9, 3.697004577529921*^9}, {
   3.6970047093453493`*^9, 3.697004726808612*^9}, 3.697176604556756*^9, {
   3.697176703196575*^9, 
   3.697176707837142*^9}},ExpressionUUID->"0b0db3d5-1fe9-4122-87ff-\
c03ee2f709c3"],

Cell[TextData[{
 "The coordinates of the second fundamental form with respect to the local ",
 "cobasis",
 " ",
 ButtonBox["du, dv",
  BaseStyle->"Hyperlink",
  ButtonData->"dudv"],
 " are"
}], "Text",
 CellChangeTimes->{{3.5907165401090384`*^9, 3.5907165927970514`*^9}, {
   3.5907167704052105`*^9, 3.5907168262464046`*^9}, 
   3.618034459904109*^9},ExpressionUUID->"f17ef8ab-99c7-4843-8489-\
69098655f39a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fd2", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fd2", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fd2", "[", 
      RowBox[{"2", ",", "2"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fd2", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5906718894921036`*^9, 3.5906720131535206`*^9}, {
   3.590719635842104*^9, 3.590719636032115*^9}, 3.5907196778325057`*^9, 
   3.618035398484793*^9, 
   3.6180354370499988`*^9},ExpressionUUID->"fd7bdd75-0d0f-4d2f-a2f0-\
aaf28aff5a1f"],

Cell[BoxData[
 RowBox[{"?", "fd2"}]], "Input",
 CellChangeTimes->{{3.6180354694598527`*^9, 3.6180357108316584`*^9}, 
   3.6180359090899982`*^9, {3.6226953261836953`*^9, 
   3.6226953478989334`*^9}},ExpressionUUID->"c838c03e-492b-448e-8bea-\
c070608e1261"],

Cell[TextData[StyleBox["The determinant of the matrix {fd2[i,j]} is the \
product of determinants",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.590716987076603*^9, 3.590717076748732*^9}, {
  3.592113156600597*^9, 
  3.5921131570841975`*^9}},ExpressionUUID->"3a619a79-8460-429d-9c95-\
3bcb8838e240"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Det", "[", 
   RowBox[{"{", 
    RowBox[{"fd2", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "}"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{"cf", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "}"}], "]"}], "*", 
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{"rgT", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "}"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5907170998510537`*^9, 3.5907171567763095`*^9}, {
   3.590719718049806*^9, 3.5907197185128326`*^9}, 3.617628080916442*^9, 
   3.6179720574146585`*^9},ExpressionUUID->"f0f843a3-9ba6-41d0-9c46-\
9dab3889b31d"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5907172529178085`*^9, 
  3.5907172560609884`*^9}},ExpressionUUID->"34b5a835-0b08-4cb4-b620-\
e59aaa9fcd4e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fd2", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "==", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"cf", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "*", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5906723438117013`*^9, 3.5906724411714725`*^9}, {
   3.590672471809926*^9, 3.5906725129315987`*^9}, {3.59071972720533*^9, 
   3.59071972808438*^9}, {3.5907368705001*^9, 3.5907368707185*^9}, {
   3.614861858629938*^9, 3.6148618586455383`*^9}, {3.6148635016092234`*^9, 
   3.6148635016092234`*^9}, 3.6176280830785656`*^9, 
   3.617972058857741*^9},ExpressionUUID->"e6fb09ea-1b5b-4431-a3b2-\
48c8756185e0"],

Cell["\<\
Thus it follows the general formula, see [B-R], (61.12), which I used as the \
definition of the function gauss in eudiffgeov3.m:\
\>", "Text",
 CellChangeTimes->{{3.5909099752525454`*^9, 3.590909987588251*^9}, {
   3.5909888126325254`*^9, 3.590988812960126*^9}, {3.5909889041422863`*^9, 
   3.59098893481194*^9}, 3.5909890097856717`*^9, {3.697176846026053*^9, 
   3.697176903617559*^9}},ExpressionUUID->"25e84c2e-9c7d-49ce-a2af-\
ba9a9e1a8979"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "-", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"fd2", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "/", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.59091000400919*^9, 3.590910046910644*^9}, {
   3.590910117662691*^9, 3.5909101521126614`*^9}, 3.6114690139486666`*^9, {
   3.6148618586455383`*^9, 3.614861858661138*^9}, {3.614863501640424*^9, 
   3.614863501640424*^9}, 
   3.617628084765662*^9},ExpressionUUID->"000ea092-f0f0-4b67-9ae2-\
a540875c1955"],

Cell[TextData[{
 StyleBox["Example 1",
  FontColor->RGBColor[0, 0, 1]],
 ".",
 StyleBox[" The sphere of radius r",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{{3.590645549360779*^9, 3.5906455664584093`*^9}, {
   3.697005032784369*^9, 3.697005035024167*^9}, 
   3.697005110280025*^9},ExpressionUUID->"55593cff-0ae8-4ff4-9d0a-\
f849ecaafab0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fd2", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "-", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"cf", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "*", 
    RowBox[{"Det", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5906723438117013`*^9, 3.5906724411714725`*^9}, {
   3.590672471809926*^9, 3.5906725129315987`*^9}, {3.5906725949253426`*^9, 
   3.5906726627230616`*^9}, {3.590673581970276*^9, 3.5906735987247057`*^9}, {
   3.5907197413651395`*^9, 3.5907197418371663`*^9}, {3.5907368468192587`*^9, 
   3.5907368597516813`*^9}, {3.590738130810714*^9, 3.5907381619795685`*^9}, {
   3.614861858661138*^9, 3.614861858661138*^9}, {3.614863501656024*^9, 
   3.6148635016716237`*^9}, 3.6176280865107617`*^9, 
   3.617972060681845*^9},ExpressionUUID->"61faa36c-12c3-41b6-9202-\
2f2706a19848"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cf", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5906720266943445`*^9, 3.5906720991096716`*^9}, {
   3.5906721323533297`*^9, 3.590672139934943*^9}, 3.5906722123658705`*^9, {
   3.5907382355024977`*^9, 3.590738290320994*^9}, 3.614861858676738*^9, 
   3.614863501687224*^9, 3.6179720618959146`*^9, {3.697176992981797*^9, 
   3.697176998665697*^9}},ExpressionUUID->"f846740d-b0af-4707-b886-\
bd5a2b47e3ff"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", 
      RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "xx"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590220048343422*^9, 3.5902200805418787`*^9}, {
   3.590220507904629*^9, 3.590220528902266*^9}, 3.5902205880731697`*^9, {
   3.5902221438171024`*^9, 3.5902221985575986`*^9}, 3.5904956768973503`*^9, 
   3.5906439031210876`*^9, 
   3.5906439367703466`*^9},ExpressionUUID->"48c07c99-ffaa-429f-928b-\
91a5f81c5c6f"],

Cell["Thus we see", "Text",
 CellChangeTimes->{{3.5906455044951*^9, 
  3.59064551025151*^9}},ExpressionUUID->"fae269db-2f9c-4126-91d8-\
b3d324dd3fc6"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund2", "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{"xx", ",", "xx"}], "]"}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "r"}], ")"}], "*", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"xx", ",", "xx"}], "]"}]}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590220048343422*^9, 3.5902200805418787`*^9}, {
   3.590220507904629*^9, 3.590220528902266*^9}, 3.5902205880731697`*^9, {
   3.5902221438171024`*^9, 3.5902221985575986`*^9}, 3.5904956768973503`*^9, 
   3.5906439031210876`*^9, 3.5906439367703466`*^9, {3.5906453634084525`*^9, 
   3.590645369289663*^9}, {3.590645419552951*^9, 
   3.590645467944236*^9}},ExpressionUUID->"0bf8feb8-6f49-4578-96fe-\
ef3613ca83b1"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.697005151847084*^9, 
  3.6970051518493156`*^9}},ExpressionUUID->"79950f28-be2d-43a4-904e-\
8e94d64e68e9"],

Cell[TextData[{
 StyleBox["Example 2",
  FontColor->RGBColor[0, 0, 1]],
 ". The second fundamental forms for all ",
 StyleBox["developable surfaces",
  FontColor->RGBColor[0, 0, 1]],
 " degenerate. For the ",
 StyleBox["circular cones",
  FontColor->RGBColor[0, 0, 1]],
 " we have"
}], "Text",
 CellChangeTimes->{{3.5906456117920885`*^9, 3.590645688778224*^9}, {
  3.5906459738999243`*^9, 3.5906459850383444`*^9}, {3.697005165079277*^9, 
  3.697005166975494*^9}},ExpressionUUID->"82266dab-3401-4ef2-b29e-\
d8438bc90c53"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", 
      RowBox[{"cone", "[", "a", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t1", ",", "t2"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"a", "/", "2"}], "]"}], ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590214476700036*^9, 3.590214562578187*^9}, 
   3.5904956764449496`*^9, {3.5904958754076986`*^9, 3.590495889354123*^9}, {
   3.5906437534388247`*^9, 3.590643762767641*^9}, {3.5906447896394444`*^9, 
   3.5906448165806923`*^9}, {3.590644867826782*^9, 3.590644932863296*^9}, 
   3.614861858676738*^9, 
   3.6148647317181845`*^9},ExpressionUUID->"04d5b3e0-97d9-48f6-acf0-\
04e7ae061ae1"],

Cell["For the plane we have ", "Text",
 CellChangeTimes->{{3.5907384391608553`*^9, 
  3.590738465088101*^9}},ExpressionUUID->"d1f017d1-1906-4dd6-a9db-\
d755b449afbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pl", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"plane", "[", 
    RowBox[{"a1", ",", "a2", ",", "b1", ",", "b2", ",", "c1", ",", "c2"}], 
    "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.5907384667573037`*^9, 3.5907384667573037`*^9}, {
   3.5907385125277843`*^9, 3.5907385253198066`*^9}, 3.590738675891271*^9, 
   3.614861858692338*^9, 
   3.6148626542469354`*^9},ExpressionUUID->"2f831146-32e7-40b9-9367-\
56e8300e54df"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund2", "[", "pl", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5907385438214393`*^9, 3.5907385878915167`*^9}, 
   3.5907386904304967`*^9},ExpressionUUID->"e886b2d3-2f4d-4bec-8230-\
85fbf9b6d66b"],

Cell["For a tangent surface one obtains", "Text",
 CellChangeTimes->{{3.697005918117157*^9, 
  3.6970059453851013`*^9}},ExpressionUUID->"48e8495c-9ccb-47a3-a41a-\
5f016386cb4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sft", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"tangsf", "[", "curve", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], ";", 
  RowBox[{"sft", "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6970054799356117`*^9, 3.697005541660707*^9}, {
   3.697005636681006*^9, 3.69700564077801*^9}, 
   3.6970057765279512`*^9},ExpressionUUID->"385577db-a1ad-4114-87dc-\
9b92cd02e423"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund2", "[", "sft", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t1", ",", "t2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.697005561349249*^9, 3.697005596589919*^9}, {
  3.697005668950631*^9, 
  3.697005685036481*^9}},ExpressionUUID->"f9dcd69d-a1f9-4597-9dc3-\
1ea8bdb95ce7"],

Cell["\<\
\[FilledSmallSquare]
Since the plane and the cones are locally isometric surfaces it is clear that \
the second fundamental form is not invariant under isometries; it doesn\
\[CloseCurlyQuote]t belong to the inner geometry of the surfaces.\
\>", "Text",
 CellChangeTimes->{{3.590738712442135*^9, 3.590738740100984*^9}, {
  3.590738784498662*^9, 3.5907388582555914`*^9}, {3.611469357789333*^9, 
  3.611469360549491*^9}, {3.697005799195034*^9, 
  3.697005808608849*^9}},ExpressionUUID->"1391a0bf-92ae-498a-bc93-\
79c94e557e4e"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.3.  An Equivalent Definition of the Second Fundamental Form\
\>", "Subsection",
 CellChangeTimes->{{3.590818296109006*^9, 3.590818381035555*^9}, 
   3.590910415997754*^9, 3.611469400327766*^9, 3.611471134269942*^9, 
   3.615275717765976*^9, 3.615276391918535*^9, 3.618037428649912*^9, 
   3.6180379274334407`*^9, 3.6279130679888353`*^9, 3.627913632095426*^9, 
   3.697005850154871*^9, 3.697007056828423*^9, 3.707633856672741*^9, 
   3.7076351582864733`*^9},ExpressionUUID->"3f61b789-94cc-4600-872d-\
0cc816942bc2"],

Cell["\<\
The following definition is often used as the primary. We start with the  \
identity\
\>", "Text",
 CellChangeTimes->{{3.590818477116124*^9, 3.590818522715004*^9}, {
  3.590818558439067*^9, 3.590818570607088*^9}, {3.5908187338572936`*^9, 
  3.5908187527853765`*^9}, {3.590820605355337*^9, 
  3.590820657793337*^9}},ExpressionUUID->"0f72a80d-5d0e-4750-903e-\
64c082ab01cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "=", " ", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], ";", " ", 
  RowBox[{"yy", "=", 
   RowBox[{"{", 
    RowBox[{"u1", ",", "u2"}], "}"}]}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "xx"}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", 
         RowBox[{
          RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "yy"}], ")"}]}], "\[Equal]", " ", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"d", "[", "sf", "]"}], "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], ".", "xx"}], ")"}], ".", "yy"}], 
       ")"}], ".", 
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6152760579194317`*^9, 3.6152760614466333`*^9}, {
   3.6180375677928705`*^9, 3.6180375998537045`*^9}, 
   3.697006039853467*^9},ExpressionUUID->"82f2e695-a65f-46fe-b48c-\
694150f6da27"],

Cell["\<\
and it follows the new expression for the second fundamental form\
\>", "Text",
 CellChangeTimes->{{3.5909086612622857`*^9, 
  3.5909086901379366`*^9}},ExpressionUUID->"1074fda9-ab75-404e-9234-\
0a257e541ce7"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"d", "[", "sf", "]"}], "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ".", "xx"}], ")"}], ".", "yy"}], 
      ")"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5908231690709734`*^9, 3.590823267325593*^9}, 
   3.590823302446602*^9, {3.5908233571987333`*^9, 3.5908233692144213`*^9}, {
   3.590823756951598*^9, 3.590823799359024*^9}, {3.5908238384552603`*^9, 
   3.590823914906633*^9}, {3.590905864085401*^9, 3.5909059654855795`*^9}, {
   3.5909082182371073`*^9, 3.590908268110395*^9}, {3.590908312008872*^9, 
   3.5909083780749884`*^9}, 3.614861858707938*^9, 3.6149177904853587`*^9, 
   3.6152622106372356`*^9},ExpressionUUID->"3b3c9b66-d277-4f98-8be0-\
d74c14c226c5"],

Cell["For the coefficients fd2[i,j][sf][u,v] we obtain", "Text",
 CellChangeTimes->{{3.5909087665624704`*^9, 
  3.590908833970189*^9}},ExpressionUUID->"74564876-5855-440d-b704-\
fd9d4f4c5252"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "2"}], "}"}]}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"fd2", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590837626280514*^9, 3.5908376661217923`*^9}, {
   3.5908379583135047`*^9, 3.5908380325077486`*^9}, 3.614861858707938*^9, 
   3.6149177905009584`*^9, 
   3.6152622119333096`*^9},ExpressionUUID->"b9cc2952-15f7-41ff-bd96-\
d01012d56495"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"fd2", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590837626280514*^9, 3.5908376661217923`*^9}, {
   3.5908379583135047`*^9, 3.5908380517038465`*^9}, {3.5908381960561028`*^9, 
   3.5908382285549617`*^9}, 3.614861858723538*^9, 3.6149177905165586`*^9, 
   3.6152622130683746`*^9},ExpressionUUID->"de435c1e-a5ed-4541-bd8c-\
caaa393e5938"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", "v", ",", "u"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"fd2", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590837626280514*^9, 3.5908376661217923`*^9}, {
   3.5908379583135047`*^9, 3.5908380517038465`*^9}, {3.5908381960561028`*^9, 
   3.590838288707402*^9}, 3.614861858723538*^9, 3.6149177905165586`*^9, 
   3.6152622141574373`*^9},ExpressionUUID->"2c9c490b-d7e3-4866-9d89-\
4a824f576077"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"sf", "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"v", ",", "2"}], "}"}]}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{
      RowBox[{"fd2", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590837626280514*^9, 3.5908376661217923`*^9}, {
   3.5908379583135047`*^9, 3.5908380517038465`*^9}, {3.5908381960561028`*^9, 
   3.5908383295867405`*^9}, 3.614861858723538*^9, 3.614917790532159*^9, 
   3.6152622154055085`*^9},ExpressionUUID->"eefeaf51-870d-4d7d-a727-\
b9340dfc5435"],

Cell["Using the cobasis du, dv we may write", "Text",
 CellChangeTimes->{{3.590909029266932*^9, 
  3.590909052214572*^9}},ExpressionUUID->"71a6953a-61b4-45c8-a029-\
745f9c5fdea6"],

Cell[BoxData[
 RowBox[{"??", "du"}]], "Input",
 CellChangeTimes->{{3.697006259621188*^9, 
  3.697006261927515*^9}},ExpressionUUID->"aeac584b-8eb2-4a60-a04f-\
4ce3864dbd0c"],

Cell[BoxData["xx"], "Input",
 CellChangeTimes->{{3.697006359991543*^9, 
  3.697006360126955*^9}},ExpressionUUID->"b8bc20ee-c3fa-4d94-9d86-\
86a820f0fb2b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "u", ",", "u"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "*", 
    RowBox[{"(", 
     RowBox[{"du", ".", "xx"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"du", ".", "yy"}], ")"}]}], "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "u", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "*", 
    RowBox[{"(", 
     RowBox[{"du", ".", "xx"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"dv", ".", "yy"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "v", ",", "u"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "*", 
    RowBox[{"(", 
     RowBox[{"dv", ".", "xx"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"du", ".", "yy"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", "v", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "*", 
    RowBox[{"(", 
     RowBox[{"dv", ".", "xx"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{"dv", ".", "yy"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.590838820986847*^9, 3.5908389558845625`*^9}, {
   3.590838990723555*^9, 3.5908390265996075`*^9}, {3.5908390586154385`*^9, 
   3.5908390676709566`*^9}, {3.5908391213030243`*^9, 
   3.5908391710558696`*^9}, {3.5908392565527596`*^9, 3.590839257639822*^9}, {
   3.590839445520568*^9, 3.59083947264812*^9}, 3.5908415910502853`*^9, {
   3.611470519818797*^9, 3.61147052284297*^9}, {3.611470586316601*^9, 
   3.6114705918189154`*^9}, {3.6114708904849977`*^9, 
   3.6114708942192116`*^9}, {3.611470943300019*^9, 3.6114709523105345`*^9}, {
   3.6148618587391376`*^9, 3.614861858754738*^9}, {3.614917790547759*^9, 
   3.614917790563359*^9}, {3.615262216609577*^9, 3.615262220241785*^9}, 
   3.6970063219019823`*^9, {3.6970063536162977`*^9, 3.697006666566745*^9}, {
   3.697006801664214*^9, 
   3.697006942679441*^9}},ExpressionUUID->"30586e71-5c42-4ad2-abab-\
b804b97155ff"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}], " ", "-", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fd2", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", 
      RowBox[{"xx", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "*", 
      RowBox[{"yy", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5908401746002693`*^9, 3.5908402249931517`*^9}, {
   3.5908402920429864`*^9, 3.5908403707404876`*^9}, {3.5908404013022356`*^9, 
   3.5908404929334764`*^9}, 3.590840842709483*^9, 3.5908409435162487`*^9, {
   3.5908411319660273`*^9, 3.59084131367642*^9}, {3.590841362764228*^9, 
   3.590841376276001*^9}},ExpressionUUID->"fb8117dd-f974-44a2-9aaf-\
4d48f51af928"],

Cell["For possible future applications we define", "Text",
 CellChangeTimes->{{3.5909091109174757`*^9, 
  3.590909168762377*^9}},ExpressionUUID->"e6330301-07ec-4cc0-b882-\
ce967fe12fa1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "fund2a", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2a", "[", "ff_", "]"}], "[", 
     RowBox[{"u_", ",", "v_"}], "]"}], "[", 
    RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"d", "[", "ff", "]"}], "]"}], "[", 
           RowBox[{"u1", ",", "v1"}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"u1", "\[Rule]", "u"}], ",", 
            RowBox[{"v1", "\[Rule]", "v"}]}], "}"}]}], ")"}], ".", "x"}], 
       ")"}], ".", "y"}], ")"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5908418218494864`*^9, 3.590841851618189*^9}, {
   3.590845349630325*^9, 3.590845703112543*^9}, {3.590907786584349*^9, 
   3.590907800437174*^9}, {3.590907905596958*^9, 3.5909079379046154`*^9}, {
   3.614057154177955*^9, 3.6140572705541596`*^9}, 3.614861858754738*^9, 
   3.6149177905789585`*^9, 
   3.615262223526973*^9},ExpressionUUID->"84314282-3cda-4ce2-8672-\
8645768fbe04"],

Cell["Regard that fund2 and fund2a differ by the sign only:", "Text",
 CellChangeTimes->{{3.5909093606603928`*^9, 
  3.590909391316146*^9}},ExpressionUUID->"249fb1e5-fb0f-4886-8dcc-\
47d015e3bdd6"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2a", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
    RowBox[{"xx", ",", "yy"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5908457241747475`*^9, 3.5908458264865994`*^9}, {
   3.5908458587194433`*^9, 3.59084586740694*^9}, 3.590846092119793*^9, {
   3.5908461398635235`*^9, 3.590846173752462*^9}, {3.59090782689482*^9, 
   3.5909078458800535`*^9}, 3.590907989353505*^9, 3.61803783090792*^9, 
   3.6180378859720693`*^9},ExpressionUUID->"566c24cf-40b1-4984-a378-\
868111178e43"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4. The Curvature Vector", "Subsection",
 CellChangeTimes->{{3.5911636991239314`*^9, 3.591163726106475*^9}, 
   3.6114711409343233`*^9, 3.611640870360384*^9, 3.615276399973996*^9, 
   3.615434797034876*^9, 3.618037933137767*^9, 3.618406755097189*^9, {
   3.6246867791918316`*^9, 3.624686781531836*^9}, 3.6251124003687673`*^9, {
   3.6254878485050135`*^9, 3.6254878765266633`*^9}, {3.627917374326639*^9, 
   3.6279173763234425`*^9}, 
   3.6279748461554165`*^9},ExpressionUUID->"59ab247d-c4d7-4e63-9cce-\
3edd86fce9ff"],

Cell[CellGroupData[{

Cell["3.4.1. Curves on Surfaces", "Subsubsection",
 CellChangeTimes->{{3.625112377592727*^9, 3.6251123907903504`*^9}, 
   3.697007070908992*^9, 3.697009955065786*^9, 3.7076351696193743`*^9, 
   3.707635393403564*^9},ExpressionUUID->"9b385e5f-a03c-484a-995c-\
41aaaca403c4"],

Cell["\<\
Consider a general curve on the surface (or a two-dimensional manifold) with \
parameter s\
\>", "Text",
 CellChangeTimes->{{3.591163790323148*^9, 3.5911637979785852`*^9}, {
   3.5911638677065735`*^9, 3.591163893043023*^9}, 3.615276463125608*^9, {
   3.618293875822893*^9, 
   3.6182939377394023`*^9}},ExpressionUUID->"88dca62f-37f3-422e-b2ce-\
853eb0aeea38"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hu", "[", "s", "]"}], ",", 
    RowBox[{"hv", "[", "s", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5911640806537533`*^9, 
  3.5911641202370176`*^9}},ExpressionUUID->"191093a0-066e-4765-93f7-\
34acd65b66b9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6254682628083925`*^9, 
  3.625468273322811*^9}},ExpressionUUID->"c1762897-db47-4d41-a08f-\
7e1f0e6d29aa"],

Cell["Such a curve on the surface ff[u,v] is given by", "Text",
 CellChangeTimes->{{3.6182945196204243`*^9, 
  3.6182945562960887`*^9}},ExpressionUUID->"d68fa1bb-8a14-42b2-a7dd-\
fa2ed0440b15"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cxx", "[", "ff_", "]"}], "[", "s_", "]"}], " ", ":=", 
  RowBox[{"ff", "[", 
   RowBox[{
    RowBox[{"hu", "[", "s", "]"}], ",", 
    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.618294110182105*^9, 3.6182941903194456`*^9}, 
   3.618294366069354*^9, 
   3.6246953556850033`*^9},ExpressionUUID->"2a53cb12-056c-4858-b4b2-\
2a8405c170f2"],

Cell["For the non specified general surface we set", "Text",
 CellChangeTimes->{{3.618294651565456*^9, 
  3.618294677352301*^9}},ExpressionUUID->"c854b9a1-45ed-4b68-bcb4-\
d656a3fffdfe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cx", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"cxx", "[", "sf", "]"}], "[", "s", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5911639056057415`*^9, 3.5911639586847773`*^9}, 
   3.5911644865179677`*^9, 3.611471276833096*^9, {3.6182942572903633`*^9, 
   3.6182943057128487`*^9}, 
   3.618294381731782*^9},ExpressionUUID->"55045566-5be6-42e5-92d3-\
f522ca076110"],

Cell[BoxData[
 RowBox[{"cx", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6182943281612883`*^9, 
  3.6182943327788963`*^9}},ExpressionUUID->"9d7793a4-4665-4dd1-8f7d-\
ecf0d87cd48f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cx", "'"}], "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6182943281612883`*^9, 3.6182943327788963`*^9}, {
  3.6254683143508835`*^9, 
  3.6254683271585054`*^9}},ExpressionUUID->"f539bf3c-99cc-4392-82ab-\
e926ecb70e31"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cx", "'"}], "[", "s", "]"}], ".", 
    RowBox[{
     RowBox[{"cx", "'"}], "[", "s", "]"}]}], " ", "==", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591164184167674*^9, 3.5911642643002577`*^9}, {
   3.5911643068696923`*^9, 3.591164405895356*^9}, 3.5911644724711647`*^9, {
   3.5911646118721375`*^9, 3.5911646213996825`*^9}, {3.5911647404074893`*^9, 
   3.59116474548778*^9}, {3.611471280412301*^9, 
   3.611471281483362*^9}},ExpressionUUID->"7d066540-094c-4a9e-83e8-\
7de48e952971"],

Cell["\<\
A parameter s is  the arc length parameter,  if the following condition is \
satisfied\
\>", "Text",
 CellChangeTimes->{{3.5911640248865643`*^9, 3.5911640470268307`*^9}, {
   3.6152764886770697`*^9, 3.615276498893654*^9}, {3.618294718099573*^9, 
   3.618294723200782*^9}, {3.6182948073161297`*^9, 3.6182949029754972`*^9}, 
   3.6250336541598353`*^9, {3.6252310696115417`*^9, 
   3.6252310712651443`*^9}},ExpressionUUID->"3a27f9d7-93bd-4dad-9b61-\
c8fc4b89b43e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "\[Equal]", "1"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6252309845717916`*^9, 
  3.6252310031046247`*^9}},ExpressionUUID->"c6cf71f7-0222-43ad-9849-\
ec72a3a5d03c"],

Cell["\<\
A general test for  a curve parameter to be the arc length is defined in the \
package eudiffgeov3.m:\
\>", "Text",
 CellChangeTimes->{{3.5911647999228935`*^9, 3.591164817426895*^9}, 
   3.61719839476588*^9, 3.6250336697286625`*^9, {3.62523110835041*^9, 
   3.6252311933121595`*^9}, {3.6252312302570243`*^9, 3.625231240039242*^9}, 
   3.6252363978051243`*^9, 3.62523643468559*^9, 
   3.6862890168272657`*^9},ExpressionUUID->"f8f4b736-9efb-4cbd-8006-\
154b8ab60b96"],

Cell[BoxData[
 RowBox[{"?", "assu"}]], "Input",
 CellChangeTimes->{{3.6252312475740547`*^9, 
  3.6252312495396585`*^9}},ExpressionUUID->"3ed3c576-d9d8-46ba-a874-\
ece6b562e664"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"assu", "[", "x", "]"}], "[", "s", "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.625231297750744*^9},ExpressionUUID->"35ee83e7-f362-496a-a3bc-\
07febfd931d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"assu", "[", "cx", "]"}], "[", "s", "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6251520146981506`*^9, 
  3.6251520764118586`*^9}},ExpressionUUID->"1004233b-eaa7-4501-a695-\
959a92a6c607"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cspherx", "[", "s_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"sphero", "[", "1", "]"}], "[", 
   RowBox[{
    RowBox[{"hu", "[", "s", "]"}], ",", 
    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.625223954903874*^9, 
  3.625224005323162*^9}},ExpressionUUID->"d6e8055b-bf7f-4621-9e3b-\
786b315fcb53"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"assu", "[", "cspherx", "]"}], "[", "s", "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",ExpressionUUID->"6ecef551-d8f2-\
49e0-8c37-e377ea9f4025"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"assu", "[", "cspherx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"Element", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}], ",", 
        RowBox[{
         RowBox[{"hu", "'"}], "[", "s", "]"}], ",", 
        RowBox[{
         RowBox[{"hv", "'"}], "[", "s", "]"}], ",", "s"}], "}"}], ",", 
      "Reals"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6251526255172234`*^9, 3.6251527012865562`*^9}, {
   3.625221223261076*^9, 3.6252212246494784`*^9}, {3.625221359230915*^9, 
   3.625221392817774*^9}, 3.6252229737245502`*^9, {3.625224027724802*^9, 
   3.6252240326232104`*^9}, 3.625230376260124*^9, {3.625231401152725*^9, 
   3.625231404959132*^9}, {3.627973783169549*^9, 3.627973835913242*^9}, {
   3.627973904272562*^9, 
   3.6279739211361914`*^9}},ExpressionUUID->"b0d2e69a-3eb1-42ed-bd44-\
646b7eb531f4"],

Cell["\<\
after waiting a long time.  assu has difficulties to be evaluated for \
symbolically defined  curves on certain specified surfaces. Thus we try \
another more direct definition of an arc length condition better adapted to \
general curves on surfaces:\
\>", "Text",
 CellChangeTimes->{{3.625234093019863*^9, 3.625234116065104*^9}, {
   3.625234164473989*^9, 3.625234315217455*^9}, {3.6252364755012617`*^9, 
   3.625236490524088*^9}, 
   3.6254684356566963`*^9},ExpressionUUID->"d055f38d-37fd-40e2-a121-\
04013e04f25d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "scond", "]"}], ";", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"scond", "[", "ff_", "]"}], "[", "s_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "ff", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "\[Equal]", " ", 
    "1"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.625234324405871*^9, 3.6252343731639566`*^9}, {
  3.6252344399848747`*^9, 
  3.6252344762433386`*^9}},ExpressionUUID->"0343cda6-0873-4fcc-8919-\
ccd206169dc3"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"scond", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.598944128504306*^9, 3.5989441321885166`*^9}, {
  3.6136199311429863`*^9, 3.613619945604212*^9}, {3.613620401281012*^9, 
  3.6136204109530287`*^9}, {3.61728282398886*^9, 3.617282859771202*^9}, {
  3.6252345050731893`*^9, 
  3.62523453399564*^9}},ExpressionUUID->"9a602179-89ea-4151-9c13-\
0049be835db7"],

Cell["\<\
The  condition scond evaluates immediately, also for an unspecified general \
surface\
\>", "Text",
 CellChangeTimes->{{3.6252305236803837`*^9, 3.6252305403724127`*^9}, {
   3.6252306316723647`*^9, 3.6252306713286343`*^9}, {3.6252345876969347`*^9, 
   3.6252346438182335`*^9}, {3.6252347187687654`*^9, 3.6252347214675703`*^9}, 
   3.625468519803244*^9},ExpressionUUID->"156fdcfe-40ef-4c06-8599-\
671d74513fb6"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"scond", "[", "sf", "]"}], "[", "s", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6251526255172234`*^9, 3.6251527012865562`*^9}, {
   3.625221223261076*^9, 3.6252212246494784`*^9}, {3.625221359230915*^9, 
   3.625221392817774*^9}, 3.6252229737245502`*^9, {3.625224027724802*^9, 
   3.6252240326232104`*^9}, {3.625230376260124*^9, 3.625230469735489*^9}, {
   3.6252346718710833`*^9, 
   3.625234672963085*^9}},ExpressionUUID->"caa79482-681e-49ec-89c5-\
d30b42cf9be8"],

Cell[TextData[{
 "Now the derivation of this equation must be zero; this is an analytic \
consequence not recognized automatically by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ":"
}], "Text",
 CellChangeTimes->{{3.599025515164632*^9, 
  3.5990256061127915`*^9}},ExpressionUUID->"f3337602-c2fc-4d50-9d5d-\
7c17514eacde"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", 
        RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
    "]"}], ",", 
   RowBox[{
    RowBox[{"scond", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", "s", "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5989442396766644`*^9, 3.5989442862613287`*^9}, {
   3.6136206379490275`*^9, 3.6136206408506327`*^9}, {3.617282881985641*^9, 
   3.617282884887246*^9}, {3.618217879816814*^9, 3.6182178831708198`*^9}, 
   3.618218489091484*^9, {3.618295111095543*^9, 3.6182951433683887`*^9}, {
   3.6252348254029536`*^9, 
   3.625234827493357*^9}},ExpressionUUID->"c1056541-f443-4f2b-a99a-\
91ff23dad4f9"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "sf", "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
    "]"}], ",", 
   RowBox[{
    RowBox[{"scond", "[", "sf", "]"}], "[", "s", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5989442396766644`*^9, 3.5989442862613287`*^9}, {
   3.6136206379490275`*^9, 3.6136206408506327`*^9}, {3.617282881985641*^9, 
   3.617282884887246*^9}, {3.618217879816814*^9, 3.6182178831708198`*^9}, 
   3.618218489091484*^9, {3.618295111095543*^9, 3.6182951433683887`*^9}, {
   3.618295278430114*^9, 3.6182952966481557`*^9}, {3.6252348547964053`*^9, 
   3.6252348855928593`*^9}},ExpressionUUID->"ded0067a-af4a-47ff-ae78-\
cd96098a59b0"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"scond", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", "s", "]"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "sf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
     "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5989442396766644`*^9, 3.5989442862613287`*^9}, {
   3.6136206379490275`*^9, 3.6136206408506327`*^9}, {3.617282881985641*^9, 
   3.617282884887246*^9}, {3.618217879816814*^9, 3.6182178831708198`*^9}, 
   3.618218489091484*^9, {3.618295111095543*^9, 3.6182951433683887`*^9}, {
   3.618295278430114*^9, 3.6182952966481557`*^9}, {3.625061428050082*^9, 
   3.62506154631389*^9}, {3.6252349137705092`*^9, 
   3.625234916110513*^9}},ExpressionUUID->"04db162b-4d10-468c-ba3e-\
6ec443446eb8"],

Cell["\<\
Therefore we have to formulate the condition for the derivative explicitly \
and join it to the condition scond:\
\>", "Text",
 CellChangeTimes->{{3.5990256677016993`*^9, 3.599025684378129*^9}, 
   3.61728290995649*^9, 3.617441777844398*^9, {3.6252349592641892`*^9, 
   3.625235026054907*^9}, {3.625468841733322*^9, 
   3.6254688427785244`*^9}},ExpressionUUID->"8fab39fd-c74c-4539-b401-\
3120ef120e38"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "scond2", "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"scond2", "[", "ff_", "]"}], "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"scond", "[", "ff", "]"}], "[", "s", "]"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"fund1", "[", "ff", "]"}], "[", 
            RowBox[{
             RowBox[{"hu", "[", "t", "]"}], ",", 
             RowBox[{"hv", "[", "t", "]"}]}], "]"}], "[", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], ",", 
            RowBox[{
             RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}]}], "]"}], ",", "t"}], 
         "]"}], "/.", 
        RowBox[{"t", "->", "s"}]}], " ", "]"}], ")"}], "==", " ", "0"}]}], 
   "}"}]}], "\n", 
 RowBox[{"  "}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5989444311036134`*^9, 3.598944452091814*^9}, {
   3.598944491622075*^9, 3.5989445892626595`*^9}, {3.613620483305956*^9, 
   3.613620520215621*^9}, {3.6136205570784855`*^9, 3.6136205617428937`*^9}, {
   3.6173372915542564`*^9, 3.6173373145675726`*^9}, 3.618208860062937*^9, {
   3.6182090179508142`*^9, 3.6182090390576515`*^9}, {3.618209092534545*^9, 
   3.6182090956701508`*^9}, 3.6182091600046635`*^9, {3.6182091936227226`*^9, 
   3.6182092224515734`*^9}, {3.61820972123125*^9, 3.618209830852642*^9}, {
   3.6182099255604086`*^9, 3.618209961814872*^9}, {3.618211324789266*^9, 
   3.6182113780477595`*^9}, {3.6182114114942183`*^9, 3.618211437405864*^9}, 
   3.618211471148723*^9, {3.6182164338814745`*^9, 3.618216468357535*^9}, {
   3.6182165257656355`*^9, 3.618216533191249*^9}, {3.6182185538627977`*^9, 
   3.618218577262839*^9}, 3.6182186344057393`*^9, {3.618218786227606*^9, 
   3.6182187922804165`*^9}, {3.6182217002815247`*^9, 
   3.6182217279247727`*^9}, {3.618221842928175*^9, 3.6182218524753914`*^9}, {
   3.625235042468136*^9, 
   3.6252350593805656`*^9}},ExpressionUUID->"f1c1168e-4f8c-48a0-b665-\
0f531794081b"],

Cell["Now we obtain the expected result:", "Text",
 CellChangeTimes->{{3.6180604278910885`*^9, 3.618060462419063*^9}, {
   3.6182196402511063`*^9, 3.6182196579103374`*^9}, {3.61829593994195*^9, 
   3.6182959707107096`*^9}, 
   3.6184068236311083`*^9},ExpressionUUID->"9a24ba3e-5d7f-45a1-9fb5-\
fd1561e62111"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "sf", "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
    "]"}], ",", 
   RowBox[{
    RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5989442396766644`*^9, 3.5989442862613287`*^9}, {
  3.6136206379490275`*^9, 3.6136206408506327`*^9}, {3.617282881985641*^9, 
  3.617282884887246*^9}, {3.618059910127474*^9, 3.618059926725423*^9}, {
  3.6182186201629143`*^9, 3.6182186312857337`*^9}, {3.6182187056510644`*^9, 
  3.618218714121879*^9}, {3.6252351518841286`*^9, 
  3.62523515798374*^9}},ExpressionUUID->"01e4e01c-8bb5-4f95-b721-\
70005d11a403"],

Cell[TextData[{
 StyleBox["Example 3",
  FontColor->RGBColor[0, 0, 1]],
 ". The unit sphere"
}], "Text",
 CellChangeTimes->{{3.6180604278910885`*^9, 3.618060462419063*^9}, {
  3.6182196402511063`*^9, 3.6182196579103374`*^9}, {3.61829593994195*^9, 
  3.618296005188682*^9}, {3.618296062100937*^9, 3.6182960712054577`*^9}, {
  3.6970094770404778`*^9, 
  3.697009478352388*^9}},ExpressionUUID->"2765aba1-01c4-41df-ba14-\
807e36619e4d"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund1", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
    RowBox[{
     RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.618220361128372*^9, 
  3.6182203959788337`*^9}},ExpressionUUID->"9cf36f17-cd83-4715-aad8-\
650ede844138"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "s"}], "]"}]], "Input",
 CellChangeTimes->{{3.618220420798477*^9, 
  3.618220429269292*^9}},ExpressionUUID->"3dc886df-d5d9-4a35-b2f7-\
28069dfdee9e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", 
        RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
    "]"}], ",", 
   RowBox[{
    RowBox[{"scond2", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", "s", "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5989442396766644`*^9, 3.5989442862613287`*^9}, {
   3.6136206379490275`*^9, 3.6136206408506327`*^9}, {3.617282881985641*^9, 
   3.617282884887246*^9}, {3.6182102141921153`*^9, 3.618210263519402*^9}, 
   3.6182116456038294`*^9, 3.618220220603326*^9, {3.6182360303187585`*^9, 
   3.618236096026074*^9}, {3.6252357283153443`*^9, 
   3.625235730156148*^9}},ExpressionUUID->"7004f4c7-93a0-43cd-9f72-\
0cf3f9154999"],

Cell["\<\
Unexpectedly, scond2[sphero[1]][s] has not been applied. 
First we have to evaluate and to simplify the specialized condition:\
\>", "Text",
 CellChangeTimes->{{3.618236148270566*^9, 3.6182362271599045`*^9}, {
  3.618296137309239*^9, 3.6182961587914677`*^9}, {3.618296206613203*^9, 
  3.6182962413651905`*^9}, {3.6252358055152807`*^9, 
  3.6252358079332848`*^9}},ExpressionUUID->"ac48817d-caec-4d68-b77f-\
750e49fd6ef1"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Evaluate", "[", 
   RowBox[{
    RowBox[{"scond2", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", "s", "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6182358571116543`*^9, 3.6182358646152678`*^9}, {
  3.61823632717168*^9, 3.6182363467965145`*^9}, {3.6252357642336082`*^9, 
  3.6252357678996143`*^9}},ExpressionUUID->"b1987f18-94b8-43e1-bd11-\
0ea3e60f0f01"],

Cell["Now we get the expected result:", "Text",
 CellChangeTimes->{{3.618236269311178*^9, 
  3.6182362919936185`*^9}},ExpressionUUID->"7b4d172f-bff7-4112-9f57-\
3e7825d71e0a"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{"%", ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", 
         RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
     "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618217765187813*^9, 3.618217802393878*^9}, {
   3.6182179873790026`*^9, 3.6182180275178733`*^9}, 3.6182181114772205`*^9, 
   3.6182182611126833`*^9, 3.6182183126707745`*^9, 3.6182188601405363`*^9, {
   3.6182200229821787`*^9, 3.6182200436834145`*^9}, {3.618235708989394*^9, 
   3.6182357770055137`*^9}, 3.61823583762722*^9, {3.6182358763308883`*^9, 
   3.618235921149767*^9}, {3.61823636102374*^9, 
   3.618236386326984*^9}},ExpressionUUID->"ebf9e4f4-7a13-4696-bf72-\
05794e600a78"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.61822320072336*^9, 
  3.61822320072336*^9}},ExpressionUUID->"0d82751a-e91f-459c-8739-\
dd4e341f4921"],

Cell[TextData[{
 StyleBox["Example 4",
  FontColor->RGBColor[0, 0, 1]],
 ". The  hyperboloid"
}], "Text",
 CellChangeTimes->{{3.6182368296017623`*^9, 3.618236847713394*^9}, {
  3.697009639009397*^9, 
  3.697009641161677*^9}},ExpressionUUID->"945cfe3a-1350-40b3-b68a-\
33b880397e52"],

Cell["\<\
The same situation we meet with other explicitly given surfaces, e. g.\
\>", "Text",
 CellChangeTimes->{{3.61829635272456*^9, 
  3.618296403549467*^9}},ExpressionUUID->"e445c97f-1e2a-4446-aaa7-\
cf5c4edf2e99"],

Cell[BoxData[
 RowBox[{"hypsf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.618236856090609*^9, 
  3.618236874139841*^9}},ExpressionUUID->"c641bb28-d7a2-4766-ae7d-\
bf42be76e068"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "hypsf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "s", "]"}], ",", 
       RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], "]"}],
   "]"}]], "Input",
 CellChangeTimes->{
  3.618296326096037*^9},ExpressionUUID->"fcb5a6ca-8056-4016-9909-\
d3b4a38e66b0"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"scond2", "[", "hypsf", "]"}], "[", "s", "]"}], "]"}], "]"}], 
   ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "hypsf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", "s"}], 
     "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618217765187813*^9, 3.618217802393878*^9}, {
   3.6182179873790026`*^9, 3.6182180275178733`*^9}, 3.6182181114772205`*^9, 
   3.6182182611126833`*^9, 3.6182183126707745`*^9, 3.6182188601405363`*^9, {
   3.6182200229821787`*^9, 3.6182200436834145`*^9}, {3.618235708989394*^9, 
   3.6182357770055137`*^9}, 3.61823583762722*^9, {3.6182358763308883`*^9, 
   3.618235921149767*^9}, {3.61823636102374*^9, 3.618236386326984*^9}, {
   3.6182369218915243`*^9, 3.6182369801108265`*^9}, {3.6252358876710253`*^9, 
   3.6252358922886333`*^9}},ExpressionUUID->"01adaf9d-8ee8-4eb3-a7de-\
f575078dd526"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}], " ", 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}]}], 
   ",", 
   RowBox[{
    RowBox[{"scond2", "[", "hypsf", "]"}], "[", "s", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6182370761445956`*^9, 3.6182371296214895`*^9}, {
  3.6252359178620787`*^9, 
  3.625235920919684*^9}},ExpressionUUID->"35f46b79-ebaf-43fc-ad4e-\
a73b77d79bc4"],

Cell["\<\
The same as before: First evaluate and simplify the specialized condition:\
\>", "Text",
 CellChangeTimes->{{3.6182372867293653`*^9, 3.618237333201847*^9}, {
  3.6182964786051564`*^9, 
  3.618296480141244*^9}},ExpressionUUID->"4b6ca26f-5786-487d-9de7-\
c93b7f31ac2e"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"scond2", "[", "hypsf", "]"}], "[", "s", "]"}], "]"}], "]"}], 
   ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}], " ",
      "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
         RowBox[{
          RowBox[{"hu", "[", "s", "]"}], ",", 
          RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
        RowBox[{
         RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}]}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6182370761445956`*^9, 3.6182371296214895`*^9}, {
   3.6182371678259563`*^9, 3.6182371946892037`*^9}, 3.618237242128887*^9, {
   3.6252359480823317`*^9, 
   3.6252359500811357`*^9}},ExpressionUUID->"cae14a07-1e19-428e-af3e-\
d0e00cc7d3cb"],

Cell["\<\
\[FilledSquare]

The following general formula is obtained directly:\
\>", "Text",
 CellChangeTimes->{{3.6182373795027285`*^9, 3.6182374399996347`*^9}, {
  3.624696435316099*^9, 
  3.624696438716905*^9}},ExpressionUUID->"0a09f08d-57dd-4eb0-8750-\
54788a1ab08e"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}], " ", 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "sf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}]}], 
   ",", 
   RowBox[{
    RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591164978147087*^9, 3.59116512593254*^9}, 
   3.6180441542132874`*^9, {3.6252359797377872`*^9, 
   3.6252359858217983`*^9}},ExpressionUUID->"49237436-328b-4312-ad4c-\
633d077a666f"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4.2. Angles", "Subsubsection",
 CellChangeTimes->{{3.625112340729862*^9, 3.6251123601050963`*^9}, 
   3.69700996729928*^9, 3.6970161908916817`*^9, 3.707635399227957*^9, 
   3.707638619322872*^9},ExpressionUUID->"6b93a2cd-97cf-4e30-bd71-\
ad4a072f3978"],

Cell[TextData[{
 "There exists a uniquely defined ",
 StyleBox["angle",
  FontColor->RGBColor[0, 0, 1]],
 " \[Tau] between two tangent vectors  with coordinates {s1,s2}, {t1,t2} \
defined by"
}], "Text",
 CellChangeTimes->{{3.591165792643674*^9, 3.591165861738626*^9}, {
   3.5911660657072926`*^9, 3.5911660947709546`*^9}, 3.618296655345346*^9, {
   3.6182972690779467`*^9, 3.6182973948131385`*^9}, 3.618298044670308*^9, {
   3.618298078357235*^9, 
   3.6182980826774817`*^9}},ExpressionUUID->"33867a8e-77f8-416d-b6ab-\
3ef69a641dbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"angle", "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", " ", "v_"}], "]"}], "[", 
   RowBox[{"s_List", ",", " ", "t_List"}], "]"}], " ", ":=", " ", 
  RowBox[{"ArcCos", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "ff", "]"}], "[", 
      RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
     RowBox[{"s", ",", " ", "t"}], "]"}], "/", " ", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
       RowBox[{"s", ",", " ", "s"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", " ", "v"}], "]"}], "[", 
       RowBox[{"t", ",", " ", "t"}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6182985837181396`*^9, 
  3.61829858371914*^9}},ExpressionUUID->"c335bed9-8602-4eb1-bafc-\
747d9d2a8a62"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"angle", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6183113497195683`*^9, 
  3.6183114408887825`*^9}},ExpressionUUID->"f93d9dab-62f2-45da-8602-\
4c1ecd37f6bb"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6183114751387415`*^9, 
  3.618311485000306*^9}},ExpressionUUID->"dd445856-e708-401f-a663-\
110829c6d4ff"],

Cell["\<\
The direction angle between the tangent vector of a curve on the surface with \
the tangent   vector amf[1]{ff][u,v] of the surface is defined as the \
solution of the equations\
\>", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.6182974023185673`*^9, 3.618297482128133*^9}, {
   3.6182975428396053`*^9, 3.6182977356406326`*^9}, {3.618297912209732*^9, 
   3.618297956537267*^9}, {3.6182979883630877`*^9, 3.6182979985366697`*^9}, {
   3.6182980955372176`*^9, 3.61829810676186*^9}, {3.6182981910096784`*^9, 
   3.6182982298669004`*^9}, {3.618298282223895*^9, 3.6182983847377586`*^9}, 
   3.6182984255310917`*^9, 3.6182985196004725`*^9, {3.6182985972059116`*^9, 
   3.618298654213172*^9}, {3.6182986943974705`*^9, 
   3.618298766141574*^9}},ExpressionUUID->"b9db2bb8-fbe4-4765-8c9c-\
410a62457a21"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dirangle", "[", 
    RowBox[{"ff_", ",", "hu_", ",", "hv_"}], "]"}], "[", "s_", "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cu", ",", "t"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"cu", "[", "t_", "]"}], "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"hu", "[", "t", "]"}], ",", 
        RowBox[{"hv", "[", "t", "]"}]}], "}"}]}], ";", 
     RowBox[{"Assuming", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"scond2", "[", "ff", "]"}], "[", "s", "]"}], "]"}], "]"}], 
       ",", 
       RowBox[{"FullSimplify", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", "\[Tau]", "]"}], " ", "\[Equal]", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "ff", "]"}], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
            RowBox[{
             RowBox[{"cu", "'"}], "[", "s", "]"}]}]}], ",", " ", 
          RowBox[{
           RowBox[{"Sin", "[", "\[Tau]", "]"}], " ", "\[Equal]", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "ff", "]"}], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], ".", 
            RowBox[{
             RowBox[{"cu", "'"}], "[", "s", "]"}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"0", "\[LessEqual]", " ", "\[Tau]"}], ",", " ", 
          RowBox[{"\[Tau]", " ", "<", " ", 
           RowBox[{"2", "*", "Pi"}]}]}], "}"}], "]"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5911658904282665`*^9, 3.591166056496765*^9}, {
   3.5911664298171177`*^9, 3.591166476456786*^9}, {3.5911665164810753`*^9, 
   3.5911665297628345`*^9}, 3.5911673587612505`*^9, 3.6148618587859383`*^9, 
   3.614917790610159*^9, {3.615262227734214*^9, 3.6152622420480323`*^9}, 
   3.6152757802705507`*^9, {3.6152765968182545`*^9, 3.6152765992253923`*^9}, {
   3.6181181173599977`*^9, 3.618118117952799*^9}, {3.6182375175941706`*^9, 
   3.6182376369811807`*^9}, {3.618298818994597*^9, 3.618298822635805*^9}, {
   3.6250340281548924`*^9, 3.6250340517421336`*^9}, {3.625236692271044*^9, 
   3.6252366944550476`*^9}, {3.6993371630368*^9, 3.6993372890967703`*^9}, {
   3.6993373234974937`*^9, 3.699337340296753*^9}, 3.699337415799883*^9, {
   3.699337988032735*^9, 
   3.699337988906534*^9}},ExpressionUUID->"68cd01a5-f007-4a24-b51e-\
fb12b506d140"],

Cell["It is the angle ", "Text",
 CellChangeTimes->{{3.618296717043454*^9, 
  3.6182967229246645`*^9}},ExpressionUUID->"c6237e8d-10d5-4b2b-821a-\
8e7f763cae8d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirangle", "[", 
   RowBox[{
    RowBox[{"sphero", "[", "r", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
  "s", "]"}]], "Input",
 CellChangeTimes->{{3.6116354915177364`*^9, 3.6116355074453645`*^9}, {
   3.611635948395739*^9, 3.611635961468562*^9}, 3.6148618587859383`*^9, 
   3.614917790610159*^9, {3.6180442929732237`*^9, 3.618044310582231*^9}, 
   3.61804546640534*^9, {3.6180605496920547`*^9, 3.61806057566054*^9}, 
   3.61811479371176*^9, {3.618117354035057*^9, 3.6181173736598916`*^9}, {
   3.6181174175271683`*^9, 3.618117436574802*^9}, {3.618118143271643*^9, 
   3.618118149449254*^9}, {3.618237684498864*^9, 3.6182376950132823`*^9}, {
   3.6183189630340247`*^9, 3.618319022601432*^9}, {3.625034125311863*^9, 
   3.6250341303038716`*^9}},ExpressionUUID->"d2c16a62-94aa-47c4-8d08-\
876bbe70f3f6"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"r", "\[Rule]", "1"}]}], ",", "\[Tau]", ",", "Reals"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.611635580391093*^9, 3.611635587114704*^9}, {
   3.6116356236031685`*^9, 3.6116356431344028`*^9}, 3.6148618588015385`*^9, 
   3.6149177906413593`*^9, {3.618119717361208*^9, 3.618119726877225*^9}, {
   3.618320086843303*^9, 3.618320092458624*^9}, 
   3.618375224935257*^9},ExpressionUUID->"8d5a54b0-6118-4347-afbf-\
9447ed343075"],

Cell[BoxData[
 RowBox[{"solangle", " ", "=", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"scond2", "[", 
       RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", "s", "]"}], "]"}], ",", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], "\[Element]", " ", "Reals"}], ",", 
        RowBox[{
         RowBox[{"hv", "[", "s", "]"}], "\[Element]", " ", "Reals"}]}], 
       "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6183191347148447`*^9, 3.6183191944412603`*^9}, 
   3.618319228977236*^9, {3.6183193357953453`*^9, 3.6183193716903987`*^9}, {
   3.6183194292416906`*^9, 3.61831947505031*^9}, 3.61837523803928*^9, {
   3.6250342829189396`*^9, 3.625034296178963*^9}, {3.6252367505295467`*^9, 
   3.6252367540239525`*^9}},ExpressionUUID->"b22f2ed4-76a1-42c8-aad6-\
b4fd0ff27f22"],

Cell[BoxData[
 RowBox[{"solangle", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], " ", "\[Rule]", " ", "0"}], ",", 
    RowBox[{
     RowBox[{"hv", "[", "s", "]"}], " ", "\[Rule]", " ", "1"}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "\[Rule]", " ", "0"}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "\[Rule]", "1"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.611635580391093*^9, 3.611635587114704*^9}, {
   3.6116356236031685`*^9, 3.6116356431344028`*^9}, 3.6148618588015385`*^9, 
   3.6149177906413593`*^9, 3.618118629384097*^9, {3.61811879586759*^9, 
   3.618118838892465*^9}, {3.618119433066309*^9, 3.618119489522808*^9}, {
   3.6181195503005147`*^9, 3.618119577226162*^9}, 3.61811986070986*^9, {
   3.6181199797380686`*^9, 3.618120032622162*^9}, 3.6182378003914676`*^9, {
   3.618320127722641*^9, 3.618320133946997*^9}, {3.618320467129054*^9, 
   3.6183204861621428`*^9}, {3.627978129901374*^9, 3.627978159120225*^9}, 
   3.699338724977191*^9, 3.707635614515294*^9, 3.707635700904294*^9, 
   3.7076364215246773`*^9},ExpressionUUID->"b771107f-68bd-4561-a7f8-\
c53d6713fc96"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirangle", "[", 
   RowBox[{
    RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
  "s", "]"}]], "Input",ExpressionUUID->"188c15ce-9af9-477b-b16e-fcb7836a45ce"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dirangle", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
   "s", "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["hu", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "\[Rule]", " ", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]], "*", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], ")"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["hv", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], "\[Rule]", 
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.627977400818494*^9, 3.6279774178381233`*^9}, 
   3.6279774628130026`*^9, {3.6279775345887284`*^9, 3.627977568643588*^9}, {
   3.627977801302397*^9, 3.627977876151328*^9}, 3.699338725721106*^9, 
   3.707638493286509*^9},ExpressionUUID->"b0923a05-a830-4ba1-99e0-\
9392828b0afd"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Reduce", "[", 
   RowBox[{"%", ",", "\[Tau]", ",", "Reals"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.611635580391093*^9, 3.611635587114704*^9}, {
   3.6116356236031685`*^9, 3.6116356431344028`*^9}, 3.6148618588015385`*^9, 
   3.6149177906413593`*^9, 3.618118629384097*^9, {3.61811879586759*^9, 
   3.618118838892465*^9}, {3.618119433066309*^9, 3.618119489522808*^9}, {
   3.6181195503005147`*^9, 3.618119577226162*^9}, 3.61811986070986*^9, 
   3.618119948070013*^9, 3.618120040656176*^9, {3.618120115208707*^9, 
   3.6181201569699802`*^9}, 3.618237828970718*^9, {3.6183201627306433`*^9, 
   3.618320166970886*^9}, {3.618320507146343*^9, 3.6183205123936434`*^9}, {
   3.6183206598570776`*^9, 3.6183207264948893`*^9}, {3.618320972341951*^9, 
   3.6183209890159044`*^9}, {3.618321068420446*^9, 3.6183210771309443`*^9}, 
   3.618321121093459*^9, {3.618321162740841*^9, 3.6183211834050226`*^9}, {
   3.625237028674836*^9, 3.625237032374043*^9}, 
   3.6279776359109063`*^9},ExpressionUUID->"93a78175-57c2-4926-b8d8-\
317764b053cf"],

Cell[" \[FilledSquare]", "Text",
 CellChangeTimes->{{3.591168964923118*^9, 3.5911689898665447`*^9}, {
   3.598367986622035*^9, 3.5983680078382483`*^9}, 3.611471327168975*^9, {
   3.611636294653947*^9, 3.6116363786600947`*^9}, {3.6181209493889723`*^9, 
   3.618120953039378*^9}, {3.6181215261999855`*^9, 3.61812154033361*^9}, {
   3.6182378794368067`*^9, 3.6182379036012487`*^9}, {3.6250617487710457`*^9, 
   3.625061750159448*^9}, 
   3.627977948894256*^9},ExpressionUUID->"6b15e58e-7028-44b7-a1cc-\
d4a275128e45"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4.3. Curvature", "Subsubsection",
 CellChangeTimes->{{3.6251124466228485`*^9, 3.6251124651400805`*^9}, 
   3.6254886914533005`*^9, {3.6279789572020273`*^9, 3.6279789586840296`*^9}, 
   3.6280013306607757`*^9, 3.628001365312437*^9, {3.628051487277828*^9, 
   3.628051497012245*^9}, 3.697016198476405*^9, 3.69703415662895*^9, 
   3.707638628163496*^9, 
   3.708335066825547*^9},ExpressionUUID->"6040c043-8f26-493d-98d0-\
4f55b0f4fe0b"],

Cell["We consider the curvature vector of the curve cx[s] ", "Text",
 CellChangeTimes->{{3.591168964923118*^9, 3.5911689898665447`*^9}, {
   3.598367986622035*^9, 3.5983680078382483`*^9}, 3.611471327168975*^9, {
   3.611636294653947*^9, 3.6116363786600947`*^9}, {3.6181209493889723`*^9, 
   3.618120953039378*^9}, {3.6181215261999855`*^9, 3.61812154033361*^9}, {
   3.6182378794368067`*^9, 3.6182379036012487`*^9}, 3.625040520855096*^9, 
   3.6280013867176743`*^9},ExpressionUUID->"b08cdfb0-c15f-4639-9b4e-\
10103c89c165"],

Cell[BoxData[
 RowBox[{"?", "curvaturevector"}]], "Input",
 CellChangeTimes->{{3.6251386786559267`*^9, 
  3.6251387118683853`*^9}},ExpressionUUID->"889d06fd-f8c1-447a-8c75-\
1ad2da12e711"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"curvaturevector", "[", "curve_", "]"}], "[", "t_", "]"}], " ", ":=",
   "  ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"tangent", "[", "curve", "]"}], "[", "t", "]"}], ",", "t"}], 
    "]"}], "/", 
   RowBox[{"norm", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"curve", "[", "t", "]"}], ",", "t"}], "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,ExpressionUUID->"ef57b82a-190e-4c36-a2b0-927a151dfa0c"],

Cell[BoxData[
 RowBox[{"?", "tangent"}]], "Input",
 CellChangeTimes->{{3.6279836598943963`*^9, 
  3.6279836633108025`*^9}},ExpressionUUID->"87da1504-b67c-4bf7-806f-\
8784ee0ebcb6"],

Cell["\<\
Now we define the curvature vector of a general curve on the surface ff[u,v]\
\>", "Text",
 CellChangeTimes->{{3.6279837558345647`*^9, 
  3.6279838478123264`*^9}},ExpressionUUID->"b06d7b60-b3cd-4880-a8a4-\
4d8e86c78497"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"curvaturevec", "[", "f_", "]"}], "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"curvaturevector", "[", 
    RowBox[{"cxx", "[", "f", "]"}], "]"}], "[", "t", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6279839265924644`*^9, 3.627983933503277*^9}, {
  3.6279839852329674`*^9, 
  3.627984040769065*^9}},ExpressionUUID->"3f568a4b-9212-4464-8f02-\
f8650e18f53d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"curvaturevec", "[", "sf", "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{
  3.5983684150655403`*^9, {3.611471358282755*^9, 3.6114713598908463`*^9}, {
   3.61147376236126*^9, 3.611473789919836*^9}, {3.611477071370826*^9, 
   3.6114770742179885`*^9}, {3.6181290507857103`*^9, 3.618129058819724*^9}, {
   3.6181309876539125`*^9, 3.6181309895883155`*^9}, {3.618323987210391*^9, 
   3.618323997915004*^9}, {3.618380132688277*^9, 3.61838013449788*^9}, {
   3.6250364470327406`*^9, 3.6250364807911997`*^9}, {3.625036525251278*^9, 
   3.6250365334724927`*^9}, {3.6279836978024626`*^9, 
   3.6279837038708735`*^9}, {3.6279843682604403`*^9, 
   3.6279843800072613`*^9}},ExpressionUUID->"f3fc4473-6238-46f9-a94a-\
2009a6bfd7be"],

Cell["\<\
The result  is contained in the following definition giving the curvature \
vector of the curve  cx[t], t an arbitrary parameter, on the arbitrary \
surface sf[u,v]:\
\>", "Text",
 CellChangeTimes->{{3.62503661705744*^9, 3.6250366330318675`*^9}, {
   3.6250367671921034`*^9, 3.6250368411362333`*^9}, 3.6251126016715207`*^9, {
   3.627984579406811*^9, 
   3.6279846420565214`*^9}},ExpressionUUID->"1f779dbd-ec80-47bb-8422-\
bc9a79000ef8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"curvatvec", "[", "t_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"curvaturevec", "[", "sf", "]"}], "[", "t", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6250366399270797`*^9, 3.6250367196744194`*^9}, 
   3.6251126527460103`*^9, {3.6279844774918323`*^9, 3.62798449348186*^9}, {
   3.628051575402383*^9, 
   3.628051599270425*^9}},ExpressionUUID->"ce9680d3-de75-4af5-b7df-\
cd301169a29e"],

Cell[TextData[{
 "Now we test the power of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " simplifying large symbolic expressions. Sometimes this power is great, but \
sometimes the simplification remains without success,"
}], "Text",
 CellChangeTimes->{{3.5984278441866727`*^9, 3.5984278488354807`*^9}, {
   3.6253017820189505`*^9, 3.625301782252951*^9}, 3.6279993615091743`*^9, {
   3.62799939308363*^9, 3.6279993938948317`*^9}, {3.6279994710910797`*^9, 
   3.6279996145557337`*^9}, 
   3.6279996744812546`*^9},ExpressionUUID->"3aca8ea8-0934-4976-b5d9-\
3c468574a320"],

Cell[BoxData[
 RowBox[{"?", "norm"}]], "Input",
 CellChangeTimes->{{3.6280598655856256`*^9, 
  3.6280598690176315`*^9}},ExpressionUUID->"56914e55-a614-4d03-820d-\
de3ffc00ae87"],

Cell[BoxData[
 RowBox[{"Context", "[", "norm", "]"}]], "Input",
 CellChangeTimes->{{3.628059906785298*^9, 
  3.628059920606922*^9}},ExpressionUUID->"bf89b53b-b36d-4dce-bdd5-\
43f99e607940"],

Cell[BoxData[
 RowBox[{"norm", "[", 
  RowBox[{
   RowBox[{"tangent", "[", "cx", "]"}], "[", "s", "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.627998951961655*^9},ExpressionUUID->"081f35b6-a6ea-4b2b-90f6-\
c02fcb382cb4"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hu", "[", "t", "]"}], ",", 
       RowBox[{"hv", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"hu", "'"}], "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"hv", "'"}], "[", "t", "]"}], ",", "t"}], "}"}], ",", 
     "Reals"}], "]"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6279982036283407`*^9, 
  3.6279982443444123`*^9}},ExpressionUUID->"2e3ed331-7012-496b-81c4-\
9b74b166db07"],

Cell["Try the same with the built-in function ", "Text",
 CellChangeTimes->{{3.627999692158086*^9, 
  3.627999724639343*^9}},ExpressionUUID->"460f976d-f051-4a0d-b139-\
8de9e63e246e"],

Cell[BoxData[
 RowBox[{"?", "Norm"}]], "Input",
 CellChangeTimes->{{3.6279997278061485`*^9, 
  3.627999729958952*^9}},ExpressionUUID->"79ec81ca-2855-4a2d-a351-\
48555702b7d1"],

Cell[BoxData[
 RowBox[{"Context", "[", "Norm", "]"}]], "Input",
 CellChangeTimes->{{3.6280599391241546`*^9, 
  3.6280599483125706`*^9}},ExpressionUUID->"d0be88e5-bacb-4285-81c7-\
1474ca7298d9"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Norm", "[", 
    RowBox[{
     RowBox[{"tangent", "[", "cx", "]"}], "[", "s", "]"}], "]"}], ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hu", "[", "t", "]"}], ",", 
       RowBox[{"hv", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"hu", "'"}], "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"hv", "'"}], "[", "t", "]"}], ",", "t"}], "}"}], ",", 
     "Reals"}], "]"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6279982036283407`*^9, 3.6279982443444123`*^9}, {
   3.6279997912312603`*^9, 3.627999802980081*^9}, 
   3.627999845012555*^9},ExpressionUUID->"abe6ab54-29ab-4ba2-b478-\
146f404838d6"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " doesn\[CloseCurlyQuote]t confirm that this expression equals 1."
}], "Text",
 CellChangeTimes->{{3.627999943493929*^9, 
  3.6279999750567846`*^9}},ExpressionUUID->"ef97f27d-ca95-4b47-a58b-\
33ecafa6c5ca"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}], ",", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"curvatvec", "[", "s", "]"}], ",", 
      RowBox[{"Element", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"hu", "[", "t", "]"}], ",", 
          RowBox[{"hv", "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"hu", "'"}], "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"hv", "'"}], "[", "t", "]"}], ",", "t"}], "}"}], ",", 
        "Reals"}], "]"}], ",", 
      RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.625036910712355*^9, 3.6250369422556105`*^9}, {
  3.62503698740209*^9, 3.625037006075323*^9}, {3.625040832060043*^9, 
  3.625040833573245*^9}, {3.6252914589882417`*^9, 3.6252914910618978`*^9}, {
  3.625301652476323*^9, 3.625301662694341*^9}, {3.6254739705053406`*^9, 
  3.6254739930473804`*^9}, {3.6254740463646746`*^9, 3.6254740667267103`*^9}, {
  3.627984731288678*^9, 
  3.6279847685259438`*^9}},ExpressionUUID->"843161db-1d35-47cd-8e5b-\
c0f59adcbca7"],

Cell[TextData[{
 "Needed 3644.08 s = 61 min (",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v. 9.0.1.0). The simplification of large symbolic expressions is \
difficult. Sometimes impossible, also if using the condition scond2[sf][s]. \
We shall tests such simplifications for general curves on specified surfaces, \
e.g..(and later)"
}], "Text",
 CellChangeTimes->{{3.6250401786840954`*^9, 3.625040182303302*^9}, 
   3.62547825758156*^9, {3.625478369673415*^9, 3.6254784676571875`*^9}, 
   3.6254785007760453`*^9, {3.625478534924505*^9, 3.6254785805077853`*^9}, {
   3.6254899430977087`*^9, 3.6254900201894445`*^9}, {3.707645225148753*^9, 
   3.707645232203265*^9}, {3.707645302628724*^9, 3.70764531109192*^9}, {
   3.7076453785395927`*^9, 
   3.7076454383943367`*^9}},ExpressionUUID->"4873f77c-6f7a-4ecc-b64d-\
e624f55178e4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cxx", "[", 
   RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.627983866532359*^9, 
  3.6279838862507935`*^9}},ExpressionUUID->"c3403b72-ac52-4dec-8846-\
67f3cd2433b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"curvaturevec", "[", 
   RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.627984075463526*^9, 
  3.6279841041675763`*^9}},ExpressionUUID->"8fc9b4d7-c222-4ab4-9a0a-\
40c2021d41f0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hu", "[", "t", "]"}], ",", 
       RowBox[{"hv", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"hu", "'"}], "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"hv", "'"}], "[", "t", "]"}], ",", "t"}], "}"}], ",", 
     "Reals"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.627984133979229*^9, 
  3.6279842634906564`*^9}},ExpressionUUID->"0a75fb1b-68a4-4f80-9bf9-\
e7fcd1dc04ca"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"%", ".", "%"}], "-", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"curvature", "[", 
       RowBox[{"cxx", "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "]"}], "[", "t", "]"}], "^",
      "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.625489561092635*^9, 3.625489636030567*^9}, {
  3.6280003079555717`*^9, 3.628000350797247*^9}, {3.628001243087821*^9, 
  3.6280012547098417`*^9}, {3.707645772525861*^9, 
  3.7076457756614122`*^9}},ExpressionUUID->"00324bdc-4985-4837-8a7b-\
60e857694c2e"],

Cell["\<\
The norm of the curvature vector equals the curvature of the curve:\
\>", "Text",
 CellChangeTimes->{{3.6254877745060835`*^9, 3.6254878051797376`*^9}, {
   3.6280000900429873`*^9, 3.628000090292588*^9}, 3.628000276487316*^9, 
   3.6280014229001384`*^9},ExpressionUUID->"802a5a64-61a1-4972-9433-\
a0b47277689e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"curvatvec", "[", "s", "]"}], ".", 
    RowBox[{"curvatvec", "[", "s", "]"}]}], "-", 
   RowBox[{
    RowBox[{
     RowBox[{"curvature", "[", "cx", "]"}], "[", "s", "]"}], "^", "2"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.625037026838959*^9, 3.6250370385077796`*^9}, {
  3.625041055468035*^9, 3.625041065467653*^9}, {3.6252915316999693`*^9, 
  3.6252915382363806`*^9}, {3.6252955519362307`*^9, 3.625295571295864*^9}, {
  3.6252956122771363`*^9, 3.6252957028664956`*^9}, {3.6252957379041567`*^9, 
  3.6252957399009604`*^9}},ExpressionUUID->"d7c101d4-d96a-4491-b0f4-\
9d5ffde41000"],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6254900729889383`*^9, 
  3.6254900744885406`*^9}},ExpressionUUID->"bce152ba-84cf-40d6-ba57-\
05343926c697"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.5. Normal and Principal Curvatures", "Subsection",
 CellChangeTimes->{{3.6253019673316765`*^9, 3.62530196942208*^9}, {
   3.625487887886483*^9, 3.6254878944560947`*^9}, {3.6254955731301117`*^9, 
   3.6254955894477406`*^9}, 3.6258042239622874`*^9, 3.628001374908454*^9, 
   3.628085057551937*^9, 3.697034208739292*^9, 3.697194183570907*^9, {
   3.7076458690548973`*^9, 3.70764587094304*^9}, 
   3.7076604129244204`*^9},ExpressionUUID->"7bc79ead-3373-41d2-9b8e-\
7ff3403c767b"],

Cell["The curvature vector of a curve ", "Text",
 CellChangeTimes->{{3.6256503633483934`*^9, 
  3.625650415327685*^9}},ExpressionUUID->"8003fa90-4f33-4d5c-9c81-\
d3fb4b63b3d2"],

Cell[BoxData[
 RowBox[{"cx", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6256504203040934`*^9, 
  3.6256504203040934`*^9}},ExpressionUUID->"dc889922-1127-4617-8862-\
f51e04707191"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]], "Input",ExpressionUUID->\
"c719dd0e-c1e5-45ef-9ef3-ffef86bad2a7"],

Cell["on the surface ", "Text",
 CellChangeTimes->{{3.6256504346561184`*^9, 
  3.62565045821216*^9}},ExpressionUUID->"76f8902b-c7ab-4b33-8331-\
4257a9dbe1fa"],

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6256504686329784`*^9, 
  3.625650474607789*^9}},ExpressionUUID->"487337da-e9b9-4f88-8019-\
e2bd55937210"],

Cell["\<\
decomposes orthogonally into two components: the normal and the tangential \
component. The normal component is the projection of the second derivative of \
the curve  cx\[CloseCurlyQuote]\[CloseCurlyQuote][s], s its arc length, to \
the normal amf[3][sf] of the surface. We calculate for an arbitrary parameter \
s\
\>", "Text",
 CellChangeTimes->{{3.6256505100978513`*^9, 3.6256505142474585`*^9}, {
   3.62565070715102*^9, 3.6256507566967072`*^9}, {3.625650795868376*^9, 
   3.6256508451556644`*^9}, 3.625650879445525*^9, {3.6256509102897797`*^9, 
   3.6256509309286156`*^9}, {3.6256509643906746`*^9, 3.625650999289936*^9}, 
   3.6258042728995733`*^9},ExpressionUUID->"e9b97843-3103-40ca-93c6-\
1696c7438d30"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cx", "''"}], "[", "s", "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
   RowBox[{
    RowBox[{
     RowBox[{"fund2a", "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591167006058077*^9, 3.591167099582426*^9}, {
   3.5911671805020547`*^9, 3.5911672617777033`*^9}, 3.6114713759407644`*^9, 
   3.6148618589731383`*^9, 3.6149177907973595`*^9, 3.615262266573435*^9, 
   3.6180441624927607`*^9, {3.625041188676669*^9, 3.625041192171075*^9}, 
   3.6250412242915316`*^9, 3.6250413414477377`*^9, 3.6253020700578566`*^9, {
   3.6253021015543118`*^9, 3.6253021613024173`*^9}, {3.6253022616885934`*^9, 
   3.6253022634045963`*^9}, {3.6253023696407833`*^9, 3.6253023712787857`*^9}, 
   3.625303907085883*^9, {3.6256418568786397`*^9, 3.6256419171415453`*^9}, {
   3.6256419513836055`*^9, 
   3.6256419649868293`*^9}},ExpressionUUID->"cdb76891-8a24-44a2-bf8b-\
0b86efa3f5fa"],

Cell["In particular, we obtain for the curvature vector:", "Text",
 CellChangeTimes->{{3.625645256701811*^9, 3.625645335341549*^9}, {
  3.6256510287593875`*^9, 
  3.625651085137887*^9}},ExpressionUUID->"892bdf76-6c39-4a9e-a2dd-\
4523687927bb"],

Cell[BoxData[
 RowBox[{"?", "curvatvec"}]], "Input",
 CellChangeTimes->{{3.628051466108591*^9, 
  3.6280514715530005`*^9}},ExpressionUUID->"acdae391-0d95-4825-bc92-\
5b1e17f03f4f"],

Cell[BoxData[
 RowBox[{"??", "curvaturevec"}]], "Input",
 CellChangeTimes->{{3.697034565418627*^9, 
  3.697034588390244*^9}},ExpressionUUID->"0392826c-2948-4b85-9783-\
60e825158521"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"curvatvec", "[", "t", "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "t", "]"}], ",", 
      RowBox[{"hv", "[", "t", "]"}]}], "]"}]}], "-", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund2a", "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "t", "]"}], ",", 
       RowBox[{"hv", "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}]}], "]"}], "/", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "sf", "]"}], "[", 
      RowBox[{
       RowBox[{"hu", "[", "t", "]"}], ",", 
       RowBox[{"hv", "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Gamma]", "'"}], "[", "t", "]"}]}], "]"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591167006058077*^9, 3.591167099582426*^9}, {
   3.5911671805020547`*^9, 3.5911672617777033`*^9}, 3.6114713759407644`*^9, 
   3.6148618589731383`*^9, 3.6149177907973595`*^9, 3.615262266573435*^9, 
   3.6180441624927607`*^9, {3.625041188676669*^9, 3.625041192171075*^9}, 
   3.6250412242915316`*^9, 3.6250413414477377`*^9, 3.6253020700578566`*^9, {
   3.6253021015543118`*^9, 3.6253021613024173`*^9}, {3.6253022616885934`*^9, 
   3.6253022634045963`*^9}, {3.6253023696407833`*^9, 3.6253023712787857`*^9}, 
   3.625303907085883*^9, {3.6256418568786397`*^9, 3.6256419171415453`*^9}, {
   3.6256419513836055`*^9, 3.6256419649868293`*^9}, 3.6256438308593063`*^9, {
   3.6256438615133605`*^9, 3.6256439269866753`*^9}, {3.628051718719835*^9, 
   3.628051768483922*^9}},ExpressionUUID->"48c3e669-b1a4-4cc2-8cd3-\
06cb2f73f86f"],

Cell[TextData[{
 "This formula is valid for an arbitrary parameter t. We conclude\n",
 StyleBox["Proposition 1",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["All curves ",
  FontSlant->"Italic"],
 "cx",
 StyleBox[" on the surface through the point sf[u,v] with the same tangent  \
at this point have the same ",
  FontSlant->"Italic"],
 StyleBox["normal curvature",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" defined by",
  FontSlant->"Italic"],
 " fund2a[sf][u,v][\[Gamma]\[CloseCurlyQuote][s],\[Gamma]\[CloseCurlyQuote][s]\
], s  ",
 StyleBox["the arc length of the curve.  ",
  FontSlant->"Italic"],
 "\[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.59117015034192*^9, 3.591170175986387*^9}, {
   3.5911702324906187`*^9, 3.5911703699304795`*^9}, {3.591170402012315*^9, 
   3.591170414571033*^9}, {3.5983664215985203`*^9, 3.598366434774274*^9}, {
   3.598428209586115*^9, 3.5984282141101227`*^9}, {3.5984287710467005`*^9, 
   3.5984287755863085`*^9}, {3.598443070436406*^9, 3.598443070450407*^9}, 
   3.6114713772008367`*^9, 3.6152810347747393`*^9, {3.6256511613908205`*^9, 
   3.625651224758132*^9}, {3.625651318217896*^9, 3.6256513230383043`*^9}, 
   3.6280517867827544`*^9, {3.697034766257358*^9, 
   3.697034768409307*^9}},ExpressionUUID->"f4f2bd22-64eb-436d-aa14-\
0a532f5167d0"],

Cell["\<\
We defined the normal curvature for a curve {h1[t],h2[t]}  with an arbitrary \
parameter t on the surface ff[u,v] in eudiffgeov3.m by\
\>", "Text",
 CellChangeTimes->{{3.614310317474022*^9, 3.6143103199232264`*^9}, {
   3.6143104210818157`*^9, 3.6143106065544243`*^9}, 3.6152810492845693`*^9, {
   3.625651367825983*^9, 3.625651386062415*^9}, {3.6256514204448757`*^9, 
   3.6256514532517333`*^9}, {3.7076462003962517`*^9, 3.707646202051504*^9}, 
   3.707646240811563*^9},ExpressionUUID->"f84f6e86-d5a3-4c23-9c38-\
2faddc07625e"],

Cell[BoxData[
 RowBox[{"?", "normalcurvature"}]], "Input",
 CellChangeTimes->{{3.6256514626741495`*^9, 
  3.625651470708164*^9}},ExpressionUUID->"a1ef92d8-f86b-492b-b332-\
31a5431ca830"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normalcurvature", "[", 
    RowBox[{"ff_", ",", "h1_", ",", "h2_"}], "]"}], "[", "t_", "]"}], ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cvx", ",", "tt", ",", "vt", ",", "tx", ",", "aa", ",", "bb"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"cvx", "[", "tt_", "]"}], " ", ":=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"h1", "[", "tt", "]"}], ",", 
        RowBox[{"h2", "[", "tt", "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vt", "[", "tt_", "]"}], " ", ":=", " ", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"cvx", "[", "tx", "]"}], ",", "tx"}], "]"}], "/.", 
       RowBox[{"tx", "\[Rule]", "tt"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"aa", " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{
          RowBox[{"fund2", "[", "ff", "]"}], "[", 
          RowBox[{
           RowBox[{"h1", "[", "tt", "]"}], ",", 
           RowBox[{"h2", "[", "tt", "]"}]}], "]"}], "[", 
         RowBox[{
          RowBox[{"vt", "[", "tt", "]"}], ",", 
          RowBox[{"vt", "[", "tt", "]"}]}], "]"}]}], "/.", 
       RowBox[{"tt", "\[Rule]", "t"}]}]}], ";", 
     RowBox[{"bb", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"fund1", "[", "ff", "]"}], "[", 
         RowBox[{
          RowBox[{"h1", "[", "tt", "]"}], ",", 
          RowBox[{"h2", "[", "tt", "]"}]}], "]"}], "[", 
        RowBox[{
         RowBox[{"vt", "[", "tt", "]"}], ",", 
         RowBox[{"vt", "[", "tt", "]"}]}], "]"}], "/.", 
       RowBox[{"tt", "\[Rule]", "t"}]}]}], ";", 
     RowBox[{"aa", "/", "bb"}]}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6143106214582767`*^9, 3.614310705541086*^9}, {
   3.6143107438282757`*^9, 3.6143107815564337`*^9}, {3.614310816436429*^9, 
   3.614310915165076*^9}, {3.614310967790086*^9, 3.614311041454299*^9}, {
   3.614311075774262*^9, 3.614311217126347*^9}, {3.6143112637990165`*^9, 
   3.6143112898545065`*^9}, {3.614311337239217*^9, 3.6143113487278743`*^9}, {
   3.614311448903604*^9, 3.614311576977929*^9}, {3.6148618589731383`*^9, 
   3.6148618589731383`*^9}, 3.6148631365217824`*^9, 3.614917790812959*^9, {
   3.618395996020481*^9, 3.6183960036020947`*^9}, {3.618396341607888*^9, 
   3.6183963564903145`*^9}},ExpressionUUID->"d7f01bd1-6917-4b28-ab40-\
949ea5e0ceef"],

Cell[BoxData[
 RowBox[{"Context", "[", "normalcurvature", "]"}]], "Input",
 CellChangeTimes->{{3.7076461677322474`*^9, 
  3.7076461907027893`*^9}},ExpressionUUID->"2415bad7-cfb5-4cee-a4fa-\
ef44d884cb78"],

Cell["Indeed, we have", "Text",
 CellChangeTimes->{{3.6256515285530653`*^9, 3.6256515378662815`*^9}, {
  3.625651572825943*^9, 
  3.6256515747135468`*^9}},ExpressionUUID->"5237c9af-e899-4987-b6d5-\
2da857033ae6"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"curvatvec", "[", "s", "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", " ", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{"sf", ",", "hu", ",", "hv"}], "]"}], "[", "s", "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.625303629467796*^9, 
  3.625303731413975*^9}},ExpressionUUID->"1c750e85-85cd-4fc9-88c1-\
d1ec50b197c4"],

Cell["\<\
The expression aa/bb in the Module  is invariant under a parameter \
transformation, and it coincides with the result of proposition 1 if t = s is \
the arc length parameter.\
\>", "Text",
 CellChangeTimes->{{3.6143128012499533`*^9, 3.6143129209067974`*^9}, 
   3.615281888172551*^9, 3.6184068592621465`*^9, {3.6256516497964783`*^9, 
   3.625651666394908*^9}, {3.628051900054553*^9, 3.628051901817356*^9}, {
   3.697034944639941*^9, 
   3.69703495243228*^9}},ExpressionUUID->"ec54893c-1e30-403f-aebf-\
8c8b9d706abb"],

Cell[TextData[{
 StyleBox["Example 5.",
  FontColor->RGBColor[0, 0, 1]],
 " Normal curvature of a general curve on the sphere of radius r"
}], "Text",
 CellChangeTimes->{{3.61431205516628*^9, 3.6143121144266696`*^9}, {
   3.6143125946581373`*^9, 3.614312626209942*^9}, 3.615281900524257*^9, {
   3.697035013560124*^9, 
   3.69703501491193*^9}},ExpressionUUID->"fdcb9ddc-49f7-47f4-8200-\
e55b17ffae82"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
    "t", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"hu", "[", "t", "]"}], "\[Element]", "Reals"}], ",", 
     RowBox[{
      RowBox[{"hv", "[", "t", "]"}], "\[Element]", "Reals"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614311584076335*^9, 3.614311620931443*^9}, {
   3.614312164300522*^9, 3.6143122685814867`*^9}, 3.6148618589887385`*^9, 
   3.614863136537382*^9},ExpressionUUID->"6bbc4cbc-7168-4935-ba1d-\
232f5a72209e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sign", "[", 
       RowBox[{"Cos", "[", 
        RowBox[{"hv", "[", "t", "]"}], "]"}], "]"}]}], "/", "r"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"hv", "[", "t", "]"}], "\[Element]", "Reals"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6143116405155635`*^9, 3.614311725388418*^9}, {
  3.614312338661495*^9, 
  3.614312447581725*^9}},ExpressionUUID->"5d5d9415-53ca-4191-a731-\
677959e8fc04"],

Cell[TextData[{
 "All curves through  a given point of the sphere have at this point the same \
normal curvature! A point on a surface with this property is said to be ",
 StyleBox["umbilic",
  FontColor->RGBColor[0, 0, 1]],
 ". On a general surface umbilic points don\[CloseCurlyQuote]t need to exist. \
On a sphere all points are umbilic. \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.6183972736471252`*^9, 3.618397349026458*^9}, {
   3.6183975386560383`*^9, 3.6183975462724743`*^9}, {3.6256519947920847`*^9, 
   3.625652012154915*^9}, {3.6256520442753716`*^9, 3.625652138889538*^9}, {
   3.625652231788701*^9, 3.6256522402283154`*^9}, {3.625652273955575*^9, 
   3.6256522761239786`*^9}, 
   3.6256599037945337`*^9},ExpressionUUID->"ba47ce0c-12e7-4aee-81fd-\
4a23d3a21b7f"],

Cell["\<\
The sign of the normal curvature as well as the sign of the second \
fundamental form depends on the orientation of the surface: it is reversed if \
the orientation is changed.\
\>", "Text",
 CellChangeTimes->{{3.614312497097557*^9, 3.614312497099557*^9}, 
   3.6256522687763653`*^9, {3.6256523066844325`*^9, 
   3.625652402703601*^9}},ExpressionUUID->"e81c7b05-f87f-4219-aa1c-\
1da3b758a696"],

Cell["\<\
Now we consider the normal plane of the curve at the point cx[s]. It can be \
spanned by the normal vector of the curve belonging to the tangent plane of \
the surface:\
\>", "Text",
 CellChangeTimes->{{3.591182851545838*^9, 3.5911830541589937`*^9}, {
   3.5913402274775476`*^9, 3.5913402300671525`*^9}, 3.6114713785929165`*^9, 
   3.6116379545436625`*^9},ExpressionUUID->"65de680c-fd93-4e4c-b534-\
f571cf9db11e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "[", "2", "]"}], " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "  ", 
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", "sf", "]"}]}], "*", 
    RowBox[{"Sin", "[", "\[Tau]", "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "2", "]"}], "[", "sf", "]"}], "*", 
    RowBox[{"Cos", "[", "\[Tau]", "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5911830364997625`*^9, 3.5911830411173706`*^9}, {
  3.591183096435068*^9, 3.5911832179904814`*^9}, {3.6148618589887385`*^9, 
  3.6148618589887385`*^9}, {3.614917790828559*^9, 3.614917790828559*^9}, {
  3.6152622786691265`*^9, 3.615262279580179*^9}, {3.6280521694826264`*^9, 
  3.628052224971924*^9}},ExpressionUUID->"9c356f53-34df-4f38-8a53-\
b39f016dbdfc"],

Cell["\<\
and the normal vector amf[3][sf] of the surface; here \[Tau] denotes the \
angle between the tangent of the curve and the vector amf[1][sf][u,v]. We \
decompose the curvature vector cx\[CloseCurlyQuote]\[CloseCurlyQuote][s]  \
lying in the normal plane of the curve into its normal and its tangential \
components:\
\>", "Text",
 CellChangeTimes->{{3.5911833479543095`*^9, 3.591183380074766*^9}, {
   3.59118341636043*^9, 3.591183463690913*^9}, {3.591183535118173*^9, 
   3.5911835543982763`*^9}, {3.591415122160385*^9, 3.591415157112384*^9}, 
   3.611471379982996*^9, 3.6148618590199385`*^9, 3.6149177908597593`*^9, 
   3.6152622808812532`*^9, {3.6256525658360877`*^9, 3.6256526363326116`*^9}, {
   3.697037020033699*^9, 
   3.697037028041527*^9}},ExpressionUUID->"16ce51f8-2e49-4bbf-a37f-\
10bd56a434e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cx", "''"}], "[", "s", "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["k", "n"], "[", "s", "]"}], "*", 
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["k", "g"], "[", "s", "]"}], " ", "*", 
    RowBox[{"a", "[", "2", "]"}]}]}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"k", "[", "s", "]"}], "*", 
   RowBox[{
    RowBox[{
     RowBox[{"frenet", "[", "cx", "]"}], "[", "s", "]"}], "[", "2", 
    "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5911839809576735`*^9, 3.5911840523367567`*^9}, {
   3.59118409034593*^9, 3.5911842270017467`*^9}, {3.591184262162758*^9, 
   3.591184277106612*^9}, {3.59118467761052*^9, 3.5911846817297554`*^9}, {
   3.591247611926702*^9, 3.5912476277139297`*^9}, {3.6114713820901165`*^9, 
   3.6114713829871674`*^9}, 3.6148618590199385`*^9, 3.6149177908753595`*^9, 
   3.615262281932314*^9},ExpressionUUID->"2721bd9f-aadf-4adb-a597-\
f6772ce1b191"],

Cell[TextData[{
 "Here ",
 Cell[BoxData[
  SubscriptBox["k", "n"]],
  Evaluatable->False,
  CellChangeTimes->{{3.5911839809576735`*^9, 3.5911840523367567`*^9}, {
   3.59118409034593*^9, 3.5911842270017467`*^9}, {3.591184262162758*^9, 
   3.591184277106612*^9}},ExpressionUUID->
  "f51dd45d-a842-489e-8095-3597c935f39a"],
 " denotes the normal curvature defined above, ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["k", "g"], " "}]],
  Evaluatable->False,
  CellChangeTimes->{{3.5911839809576735`*^9, 3.5911840523367567`*^9}, {
   3.59118409034593*^9, 3.5911842270017467`*^9}, {3.591184262162758*^9, 
   3.591184277106612*^9}},ExpressionUUID->
  "6d797af3-5335-4079-a702-0ceb147370b3"],
 " the so called ",
 StyleBox["geodesic  curvature",
  FontColor->RGBColor[0, 0, 1]],
 ", and k = k[s] the curvature of the curve. A trivial but remarkable \
consequence of this formula is"
}], "Text",
 CellChangeTimes->{{3.5911844346546235`*^9, 3.5911845590627394`*^9}, {
   3.5911846124467926`*^9, 3.5911846528151016`*^9}, {3.5911846911002913`*^9, 
   3.591184738406997*^9}, 3.591184783935601*^9, {3.591184882295227*^9, 
   3.591184892598817*^9}, {3.591184945407837*^9, 3.5911850142957773`*^9}, 
   3.5912474146331553`*^9, {3.591247670036804*^9, 3.5912477102692747`*^9}, {
   3.624771935816691*^9, 3.6247719464403095`*^9}, {3.697037226008998*^9, 
   3.697037230889188*^9}},
 CellTags->"geodc",ExpressionUUID->"1c91ffc1-fe35-4dfb-9a57-8d400a598305"],

Cell[TextData[{
 StyleBox["Lemma 1.",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" The geodesic curvature satisfies the formula",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.591247751796548*^9, 3.5912479321172647`*^9}, {
   3.5912479914753685`*^9, 3.5912480101954017`*^9}, 3.611471384289242*^9, {
   3.6116387366198363`*^9, 3.61163878415312*^9}, {3.6116388403912187`*^9, 
   3.611638846319229*^9}, {3.69703734179998*^9, 
   3.697037342976013*^9}},ExpressionUUID->"11396394-b7a1-47f3-8314-\
654cfa6b8e77"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SubscriptBox["k", "g"], "(", "s", ")"}], "2"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"k", "(", "s", ")"}], "2"], "-", 
    SuperscriptBox[
     RowBox[{
      SubscriptBox["k", "n"], "(", "s", ")"}], "2"]}]}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6116388736348767`*^9, 
  3.611638942649398*^9}},ExpressionUUID->"bdaa981d-35b1-4bf7-ad26-\
9f1fbd568436"],

Cell[TextData[{
 StyleBox["A point ",
  FontSlant->"Italic"],
 "cx",
 StyleBox["[s] is a",
  FontSlant->"Italic"],
 StyleBox[" flat point of the curve",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" (what means",
  FontSlant->"Italic"],
 " k[s] = 0) ",
 StyleBox["iff ",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.591247751796548*^9, 3.5912479321172647`*^9}, {
   3.5912479914753685`*^9, 3.5912480101954017`*^9}, 3.611471384289242*^9, {
   3.6116387366198363`*^9, 3.61163878415312*^9}, 
   3.611638959684628*^9},ExpressionUUID->"6f442ff2-a647-408f-bf4f-\
9e647f20a80a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["k", "n"], "[", "s", "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    SubscriptBox["k", "g"], "[", "s", "]"}], "=", " ", "0.", 
   "  "}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5912479532553015`*^9, 3.5912479532553015`*^9}, 
   3.5912480620186925`*^9, {3.5984431524080944`*^9, 3.598443158216427*^9}, 
   3.61839774271371*^9},ExpressionUUID->"ee0d5d12-0ba1-4cca-9f14-\
791e91212550"],

Cell["\<\
In particular, any line lying in the surface has vanishing normal and \
geodesic curvatures. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.5912480764175177`*^9, 3.5912480831255293`*^9}, {
   3.591248205517848*^9, 3.5912482771579456`*^9}, 3.598429103155684*^9, {
   3.618397761840804*^9, 
   3.618397761842804*^9}},ExpressionUUID->"3b34c3bb-61e7-4eb8-bd35-\
dfc4cb56118d"],

Cell["\<\
 The angle \[Theta] between cx''[s] and a[2] equals the angle between the \
tangent plane of the surface and the osculating plane of the curve. By \
Pythagoras it follows\
\>", "Text",
 CellChangeTimes->{{3.5911844346546235`*^9, 3.5911845590627394`*^9}, {
   3.5911846124467926`*^9, 3.5911846528151016`*^9}, {3.5911846911002913`*^9, 
   3.591184738406997*^9}, 3.591184783935601*^9, {3.591184882295227*^9, 
   3.591184892598817*^9}, {3.591184945407837*^9, 3.5911850142957773`*^9}, 
   3.5912474146331553`*^9, {3.591247670036804*^9, 3.5912477102692747`*^9}, 
   3.611471385545314*^9, 
   3.628052596321707*^9},ExpressionUUID->"41aae714-89ab-49d1-9c41-\
8071420cca86"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["k", "n"], "=", 
    RowBox[{"k", " ", 
     RowBox[{"sin", "(", "\[Theta]", ")"}]}]}], ",", "      ", 
   RowBox[{
    RowBox[{"or", "   ", 
     FractionBox["1", 
      SubscriptBox["r", "n"]]}], "=", 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"sin", "(", "\[Theta]", ")"}]}], "r"]}], ","}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.591185108512166*^9, 3.591185329658815*^9}, {
   3.591185370764166*^9, 3.591185390363287*^9}, {3.5911854204750094`*^9, 
   3.5911854560440435`*^9}, 
   3.591185489753972*^9},ExpressionUUID->"a82dc26d-003a-49f0-8be3-\
822534e5ab83"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "n"], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.591185108512166*^9, 3.591185329658815*^9}, {
    3.591185370764166*^9, 3.591185390363287*^9}, {3.5911854204750094`*^9, 
    3.5911854560440435`*^9}, 3.591185489753972*^9},ExpressionUUID->
  "a47ac652-a6b9-4b89-bcd4-5983e7e44fda"],
 " = 1/",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "n"], TraditionalForm]],ExpressionUUID->
  "691b40bf-d1f7-42f0-b5b4-6b9afa44dbd4"],
 " and r = 1/k are the corresponding curvature radii. This formula is the \
content of \n\n",
 StyleBox["Proposition 2 (Meusnier)",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["All curves ",
  FontSlant->"Italic"],
 "cx",
 StyleBox[" on the surface sf whose osculating plane at the point ",
  FontSlant->"Italic"],
 "cx",
 StyleBox["[s] has an angle \[Theta] \[NotEqual] 0, \[Pi]   with the tangent \
plane have at this point the same curvature, namely\n ",
  FontSlant->"Italic"],
 "k = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "n"], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.591185108512166*^9, 3.591185329658815*^9}, {
    3.591185370764166*^9, 3.591185390363287*^9}, {3.5911854204750094`*^9, 
    3.5911854560440435`*^9}, 3.591185489753972*^9},
  FontSlant->"Plain",ExpressionUUID->"cd33c48b-cd7f-4f13-8e0c-44a5c8f79a16"],
 "/sin(\[Theta]). \[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.5911854976874256`*^9, 3.5911855165425043`*^9}, {
  3.5911855569068127`*^9, 3.591185646350929*^9}, {3.59118578763901*^9, 
  3.59118583029445*^9}, {3.591186005119449*^9, 3.591186281990285*^9}, {
  3.598429373769359*^9, 3.5984293827549753`*^9}, {3.5984432845576525`*^9, 
  3.598443288191861*^9}, {3.611471386802386*^9, 3.6114713884584804`*^9}, {
  3.6280526662750316`*^9, 3.6280526713606405`*^9}, {3.697037570726842*^9, 
  3.697037601990212*^9}},ExpressionUUID->"3897dbdd-caf5-4f44-bdc2-\
ab15d2906e82"],

Cell[TextData[{
 "In particular one obtains such a curve intersecting the surface with a \
plane containing the point x = sf[u,v]: a ",
 StyleBox["plane section",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface. The curvature of the plane section through x containing \
the tangent vector"
}], "Text",
 CellChangeTimes->{{3.5911866587728357`*^9, 3.591186787255185*^9}, {
   3.591186817454912*^9, 3.5911868375110593`*^9}, {3.5911868704389424`*^9, 
   3.5911871717431765`*^9}, 
   3.6116396765994873`*^9},ExpressionUUID->"05290ce3-edbc-4748-95b2-\
15a00041ec9d"],

Cell[" tt[\[Tau]]  = amf[1][sf]*Cos[\[Tau]] + amf[2][sf]*Sin[\[Tau]] ", "Text",
 CellChangeTimes->{{3.5911866587728357`*^9, 3.591186787255185*^9}, {
  3.591186817454912*^9, 3.5911868375110593`*^9}, {3.5911868704389424`*^9, 
  3.5911871717431765`*^9}, {3.6116396765994873`*^9, 3.611639688003107*^9}, {
  3.6153607884512267`*^9, 
  3.6153608190829787`*^9}},ExpressionUUID->"db715ab1-e16e-493a-9c8b-\
6311b7b778e4"],

Cell["is defined by the normal curvature ", "Text",
 CellChangeTimes->{{3.5911866587728357`*^9, 3.591186787255185*^9}, {
  3.591186817454912*^9, 3.5911868375110593`*^9}, {3.5911868704389424`*^9, 
  3.5911871717431765`*^9}, {3.6116396765994873`*^9, 
  3.611639688003107*^9}},ExpressionUUID->"c10e5d36-078b-4a1a-b2b1-\
64b2fc448649"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["k", "n"], "[", "\[Tau]", "]"}], "=", " ", 
   RowBox[{"-", 
    RowBox[{"fund2", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"sf", "[", 
        RowBox[{"u", ",", "v"}], "]"}], 
       RowBox[{"tt", "[", "\[Tau]", "]"}]}], ",", 
      RowBox[{"tt", "[", "\[Tau]", "]"}]}], "]"}], " "}]}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5911872243951874`*^9, 3.591187294696209*^9}, 
   3.5911873290491734`*^9, {3.6183982560420704`*^9, 
   3.618398263809515*^9}},ExpressionUUID->"4ca2bc6f-91d8-4782-bcca-\
c3f91ffb0585"],

Cell[TextData[{
 "and the angle \[Theta] by Meusnier\[CloseCurlyQuote]s formula. The case  \
\[Theta] = 0, \[Pi]  is excluded since the intersection of the tangent plane \
with the surface yields a curve  (or a point) being singular at this point. \
The special sections containing the normal of the surface (corresponding to  \
\[Theta] = \[Pi]/2) at a considered point are called ",
 StyleBox["normal sections ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["at this point.",
  FontColor->GrayLevel[0]],
 " For the normal sections the curvature at this point coincides with the \
normal curvature. This property is an appropriate geometric interpretation of \
the second fundamental form."
}], "Text",
 CellChangeTimes->{{3.591187367878394*^9, 3.5911875588153152`*^9}, {
   3.5911875983665776`*^9, 3.591187677583109*^9}, {3.591187709710946*^9, 
   3.591187782231094*^9}, {3.5911878983987384`*^9, 3.591187971934944*^9}, 
   3.5913413340342913`*^9, {3.611639842490179*^9, 3.611639889290261*^9}, {
   3.611639940676751*^9, 
   3.611639947384763*^9}},ExpressionUUID->"9ce02a27-05a0-41ed-a50f-\
758f30cb2555"],

Cell["\<\
By the last formula the normal curvature of curves through a point sf[u,v] on \
the surface is a quadratic form of the tangent vectors tt at this point. Its \
extreme values under the condition\
\>", "Text",
 CellChangeTimes->{{3.591255092426669*^9, 3.5912552697677803`*^9}, 
   3.591255317035863*^9, {3.591255404676817*^9, 3.5912554445504875`*^9}, 
   3.5914189635761013`*^9, {3.5914191306166553`*^9, 3.591419151610856*^9}, 
   3.618406972686634*^9, 3.6256531094878626`*^9, {3.628052873575998*^9, 
   3.6280528741063986`*^9}},ExpressionUUID->"5995f792-e5d5-4ea5-a8e1-\
f5b13e94be31"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"tt", ",", "tt"}], "]"}], " ", "\[Equal]", " ", "1"}], 
  ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5914192915048575`*^9, 3.591419294121007*^9}, {
  3.5914193733635397`*^9, 
  3.591419415121928*^9}},ExpressionUUID->"02f9702f-4fc6-4913-a7c3-\
d25d85683fd5"],

Cell[TextData[{
 " i.e. with tt =tt[\[Tau]] varying \[Tau], are called the ",
 StyleBox["principal curvatures",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface at this point. They are the eigenvalues of the second \
fundamental form"
}], "Text",
 CellChangeTimes->{{3.591255092426669*^9, 3.5912552697677803`*^9}, 
   3.591255317035863*^9, {3.591255404676817*^9, 3.5912554445504875`*^9}, 
   3.5914189635761013`*^9, {3.5914191306166553`*^9, 3.591419151610856*^9}, {
   3.5914194705841007`*^9, 3.591419508504269*^9}, 3.59150772294116*^9, {
   3.697087166548215*^9, 
   3.697087218923952*^9}},ExpressionUUID->"576a8221-365b-4209-a6df-\
11cb26aa6a1c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "prcurvatures", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
   RowBox[{"Eigenvalues", "[", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cf", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5912555454202642`*^9, 3.591255666928878*^9}, 
   3.5912557322461925`*^9, {3.5923133603434553`*^9, 3.5923135255321455`*^9}, {
   3.592313755554549*^9, 3.5923137596573563`*^9}, {3.592313883084773*^9, 
   3.5923138845043755`*^9}, {3.5923139232080436`*^9, 
   3.5923139658897185`*^9}, {3.5923140976943502`*^9, 3.59231414305923*^9}, {
   3.5923141935877185`*^9, 3.592314214320155*^9}, {3.592314548823943*^9, 
   3.592314676946968*^9}, 3.614861859051139*^9, 3.614863501734024*^9, 
   3.6179720955858417`*^9, 
   3.62565314221672*^9},ExpressionUUID->"d89bd026-168b-4445-ae4a-\
3121e9749f21"],

Cell[BoxData[
 RowBox[{"?", "prcurvatures"}]], "Input",
 CellChangeTimes->{{3.6153610380975056`*^9, 3.6153611275666227`*^9}, {
  3.6227207800409913`*^9, 
  3.622720789713008*^9}},ExpressionUUID->"4a2c917c-612b-4959-8436-\
4802c28628e0"],

Cell["For a sphere of radius r we obtain ", "Text",
 CellChangeTimes->{{3.591419571946898*^9, 3.591419599568478*^9}, {
   3.591419672176631*^9, 3.591419681112142*^9}, 
   3.5914215436806746`*^9},ExpressionUUID->"4c557173-558b-43e1-bb68-\
07b6ef2b018f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"cf", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.625660071276428*^9, 3.625660086439655*^9}, 
   3.625660132771736*^9, {3.625728855734329*^9, 3.625728862379941*^9}, {
   3.6257288999916067`*^9, 3.6257289195580416`*^9}, {3.62572896420532*^9, 
   3.6257290078113966`*^9}},ExpressionUUID->"8af11eb3-a8ea-4628-b28e-\
beeeb5db711b"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5912556786912985`*^9, 3.59125568522771*^9}, {
  3.591255752541828*^9, 3.5912558042715187`*^9}, {3.591419629908213*^9, 
  3.5914196592438912`*^9}, {3.592314726508255*^9, 3.5923147697359304`*^9}, {
  3.611640033496914*^9, 
  3.611640064338168*^9}},ExpressionUUID->"ddf09840-5ecf-4bab-b28d-\
324480008a6f"],

Cell["\<\
As expected by symmetry reasons, the normal curvature on a sphere is \
constant. In general the principal curvatures  differ and vary; e. g. for the \
hyperbolic paraboloid one has\
\>", "Text",
 CellChangeTimes->{{3.591419786766185*^9, 3.591419851071863*^9}, {
  3.5914200225206695`*^9, 3.591420025927864*^9}, {3.591420094999815*^9, 
  3.591420137944271*^9}, {3.591420194544509*^9, 3.5914202251602592`*^9}, {
  3.5914202937611837`*^9, 
  3.591420296000312*^9}},ExpressionUUID->"52ffc1e3-b448-45f4-af1e-\
8d9b72864a95"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", "hypsf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5912556786912985`*^9, 3.59125568522771*^9}, {
  3.591255752541828*^9, 3.5912558042715187`*^9}, {3.5913414958377757`*^9, 
  3.5913415065081944`*^9}, {3.5914198948743687`*^9, 
  3.591419913586439*^9}},ExpressionUUID->"f7a92ab0-a912-492e-85cd-\
f4aa4146d3b9"],

Cell[TextData[{
 "A point sf[u, v]  is  an ",
 StyleBox["umbilic",
  FontColor->RGBColor[0, 0, 1]],
 " (or an umbilic point) if the principal curvatures at this point coincide. \
Special umbilic points are the",
 StyleBox[" flat points",
  FontColor->RGBColor[0, 0, 1]],
 " defined by the property that both principal curvatures at this point are \
zero, or that the second fundamental form is zero at this point. On a sphere \
all points are umbilic, and all points of a plane are flat points.as shown at \
the end of Section 3.2. "
}], "Text",
 CellChangeTimes->{{3.5914206128734355`*^9, 3.591420717416415*^9}, 
   3.5914207584237604`*^9, {3.591421160424754*^9, 3.591421316560684*^9}, {
   3.591421360529199*^9, 3.5914214038246756`*^9}, {3.591421572585328*^9, 
   3.5914215837359657`*^9}, {3.5914216161288185`*^9, 3.5914216186169605`*^9}, 
   3.5914216810255303`*^9, {3.5914417174874754`*^9, 3.5914417322295017`*^9}, {
   3.6153612636999826`*^9, 3.6153612654830847`*^9}, {3.618398779056985*^9, 
   3.6183988121208763`*^9}, 3.6183988661469665`*^9, 
   3.6257294760404215`*^9},ExpressionUUID->"20122e30-7722-4088-b89b-\
c820849eafe7"],

Cell[TextData[{
 "The directions in the tangent plane defined by the eigenvectors of the \
second fundamental form are called ",
 StyleBox["principal directions",
  FontColor->RGBColor[0, 0, 1]],
 ". At an umbilic the principal directions are not defined, or any direction \
can be considered as a principal direction. For a non umbilic point there \
exist exactly two principal directions orthogonal to each other. Curves on \
the surface  whose tangents at each point have principal directions are \
called ",
 StyleBox["principal curves",
  FontColor->RGBColor[0, 0, 1]],
 ". Outside the set of the umbilic points there exist two families of \
principal curves orthogonal to each other, namely the integral curves of the \
principal  directions. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has two functions admitting the calculation of the principal directions:"
}], "Text",
 CellChangeTimes->{{3.591421836304412*^9, 3.5914220785842695`*^9}, {
   3.5914222012562857`*^9, 3.591422254088308*^9}, {3.591422290704402*^9, 
   3.5914223437044334`*^9}, {3.5914223746402025`*^9, 
   3.5914223980085397`*^9}, {3.5914224586890106`*^9, 3.5914225164723153`*^9}, 
   3.5914418208220572`*^9, {3.5984546613739953`*^9, 3.5984546967180166`*^9}, {
   3.6116402144728317`*^9, 3.611640215564834*^9}, 
   3.618406981744152*^9},ExpressionUUID->"5a4d1909-5844-42ce-950d-\
f00cffc43b1e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Eigenvectors", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cf", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "hypsf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591186146479534*^9, 3.591186166391673*^9}, {
   3.5914225738175955`*^9, 3.591422608636587*^9}, 3.614861859051139*^9, 
   3.6148635017496243`*^9, 
   3.617972096893916*^9},ExpressionUUID->"52e1b976-74c5-4ecd-8ae8-\
863e20c2ee1e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Eigensystem", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cf", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "hypsf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, 
   3.614861859066739*^9, 3.614863501765224*^9, 
   3.6179720982649946`*^9},ExpressionUUID->"7598e849-4a02-4672-9e8c-\
cb9daaa357c9"],

Cell["\<\
From this result it follows that on the parabolic hyperboloid hypsf[u,v]  \
there don\[CloseCurlyQuote]t exist umbilic points, and that the parameter \
lines {u ,t} and {t,v} are the principal curves.\
\>", "Text",
 CellChangeTimes->{{3.5914229744565105`*^9, 3.591423241632792*^9}, {
  3.6183990352646394`*^9, 3.6183990356326604`*^9}, {3.6258043878023934`*^9, 
  3.6258043903295975`*^9}},ExpressionUUID->"08f6ab03-84ed-48cb-9d20-\
3c5a935bb2e1"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, {
  3.5914420245290146`*^9, 
  3.5914421216703854`*^9}},ExpressionUUID->"6447fe08-5fb2-4a31-a0ae-\
fc5c71caa097"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, {
  3.5914420245290146`*^9, 3.5914421216703854`*^9}, {3.591442168205267*^9, 
  3.5914421830252934`*^9}},ExpressionUUID->"6565f9fb-a299-4325-ba51-\
96242f84106d"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "1", "]"}], "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, {
   3.5914420245290146`*^9, 3.5914421216703854`*^9}, {3.591442168205267*^9, 
   3.5914421830252934`*^9}, 3.5914423088239145`*^9, {3.5914427746251326`*^9, 
   3.591442808165191*^9}, {3.59144284725886*^9, 
   3.591442868974098*^9}},ExpressionUUID->"6df857a4-8b5c-4954-b905-\
c853a214ebd6"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "2", "]"}], "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], ",", " ", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5913416993869333`*^9, 3.5913417963723035`*^9}, {
   3.5914420245290146`*^9, 3.5914421216703854`*^9}, {3.591442168205267*^9, 
   3.5914421830252934`*^9}, 3.5914423088239145`*^9, {3.5914427746251326`*^9, 
   3.591442808165191*^9}, {3.59144284725886*^9, 
   3.5914429074437656`*^9}},ExpressionUUID->"441386f9-60bf-4d2e-bd88-\
687f99ee4064"],

Cell[TextData[{
 "The product of the eigenvalues is the determinant of the matrix Table[",
 "cf[",
 "i,j][sf][u,v] ], and this is the Gaussian curvature, see Section 3.2. Using \
a long working time ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " verified"
}], "Text",
 CellChangeTimes->{{3.591345466125239*^9, 3.591345517773193*^9}, {
   3.5914233072975483`*^9, 3.5914233377202883`*^9}, {3.5914233679840193`*^9, 
   3.5914234270003943`*^9}, {3.5914235564968014`*^9, 3.591423599200244*^9}, {
   3.5915079289499435`*^9, 3.5915079404446006`*^9}, 3.5984298919242697`*^9, 
   3.614861859082339*^9, 3.614863501812024*^9, 
   3.617972099835085*^9},ExpressionUUID->"7b4a8747-b274-4cf3-8c2f-\
19b3b5cf2c63"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"gauss", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.697108269866621*^9, 3.697108270946472*^9}, 
   3.697108342210733*^9, 
   3.6971771506482143`*^9},ExpressionUUID->"2ca7ee59-2827-4b63-a6c1-\
63545a9fa635"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"gauss", "[", "hypsf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6971198090260563`*^9, 3.6971198201536427`*^9}, {
  3.6971773469979486`*^9, 
  3.697177358074236*^9}},ExpressionUUID->"55198388-2507-4dba-bbfd-\
de47e26a1a0a"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"gauss", "[", "hypsf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"prcurvatures", "[", "hypsf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{"prcurvatures", "[", "hypsf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], ",", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"v", "\[Element]", " ", "Reals"}], ",", " ", 
      RowBox[{"v", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5913423152136145`*^9, 3.5913424135873876`*^9}, {
   3.59134244879665*^9, 3.591342507515153*^9}, 3.5913425460004206`*^9, {
   3.6970878296951933`*^9, 3.697087846632094*^9}, 3.697095054812228*^9, 
   3.697108163747311*^9, {3.697169600357793*^9, 3.6971696354534388`*^9}, {
   3.697174491302249*^9, 3.697174514315812*^9}, 3.6971773821142273`*^9, 
   3.697177432313869*^9},ExpressionUUID->"9cbd8a3b-b4cb-43bc-8c55-\
5a3b98c3ae19"],

Cell[TextData[{
 "If amf[1][sf][u,v], ",
 "amf[",
 "2][sf][u,v] have principal directions and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]],ExpressionUUID->
  "d215071d-65f0-4819-8679-a56513cef189"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]],ExpressionUUID->
  "ebad3b1a-89f4-4f69-94de-68026634d076"],
 " denote the principal curvature radii,  the normal form of the second \
fundamental form gives ",
 StyleBox["Euler\[CloseCurlyQuote]s formula",
  FontColor->RGBColor[0, 0, 1]],
 " for the normal curvature"
}], "Text",
 CellChangeTimes->{{3.591508114652565*^9, 3.5915083854050508`*^9}, 
   3.5984299357759466`*^9, {3.6148618591135387`*^9, 3.614861859144739*^9}, {
   3.6149177909221597`*^9, 3.6149177909533596`*^9}, {3.615262300306364*^9, 
   3.6152623012024155`*^9}},ExpressionUUID->"2ea9f86a-eead-47fe-af39-\
90df5f324f7b"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    SubscriptBox["r", "n"]], "\[LongEqual]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["cos", "2"], "(", "\[Tau]", ")"}], 
     SubscriptBox["r", "1"]], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["sin", "2"], "(", "\[Tau]", ")"}], 
      SubscriptBox["r", "2"]], "."}]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.591508404647152*^9, 3.5915084060942345`*^9}, {
   3.5915084395291467`*^9, 3.5915084509828014`*^9}, {3.5915084879509163`*^9, 
   3.5915086366044188`*^9}, 3.591508698468957*^9, {3.5915087375851946`*^9, 
   3.5915087569603024`*^9}},
 TextAlignment->Center,ExpressionUUID->"59217326-9883-433b-8888-935dda0f9a5d"],

Cell["\<\
where \[Tau] denotes the angle of the tangent vector of the curve with the \
first principal direction.\
\>", "Text",
 CellChangeTimes->{{3.5914236744605484`*^9, 3.591423751543957*^9}, {
   3.5914243571205945`*^9, 3.591424357792633*^9}, {3.598451012192274*^9, 
   3.5984510125012918`*^9}, {3.615362094107479*^9, 3.615362161155314*^9}, 
   3.628060562329649*^9},ExpressionUUID->"b5a950ab-0366-4e9d-8ddc-\
1bed321c5312"],

Cell[TextData[{
 " A curve on the surface is said to be an ",
 StyleBox["asymptotic curve",
  FontColor->RGBColor[0, 0, 1]],
 " if its normal curvature at all points is identically zero. An implicit \
differential equation for the asymptotic curves is"
}], "Text",
 CellChangeTimes->{{3.5912513948692684`*^9, 3.5912515055345984`*^9}, {
   3.5912515441348057`*^9, 3.5912516055903206`*^9}, 3.591341039365374*^9, {
   3.6183978275525627`*^9, 3.61839783503199*^9}, 
   3.6184068933910985`*^9},ExpressionUUID->"f59895a3-9f82-4ff5-a0ee-\
1e3cd01ffb61"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "\[Equal]", " ", 
   "0"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], " ", "\[NotEqual]", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5912516204781723`*^9, 3.591251639128239*^9}, {
   3.591251688890085*^9, 3.5912517049450035`*^9}, 3.591251797316287*^9, {
   3.5912544370822725`*^9, 
   3.5912544610826454`*^9}},ExpressionUUID->"77e6c7c7-fa98-4a0a-9cad-\
4135f9a8baf3"],

Cell["\<\
Any line contained in a surface is an asymptotic curve. Asymptotic curves \
exist only at points with an indefinite second fundamental form, that means \
with non positive Gaussian curvature; therefore a ruled surface has \
non-positive Gaussian curvature at all of its points. On  spheres there don\
\[CloseCurlyQuote]t exist  asymptotic curves since the second fundamental \
form is definite:\
\>", "Text",
 CellChangeTimes->{{3.591254508871379*^9, 3.5912545339588137`*^9}, {
   3.5912545724790173`*^9, 3.5912546562148066`*^9}, {3.5915138824234624`*^9, 
   3.5915139679813557`*^9}, 3.598429175227811*^9, {3.615359907563843*^9, 
   3.6153599694273815`*^9}, {3.6153600463797827`*^9, 3.615360088875213*^9}, {
   3.615360418947092*^9, 3.615360511867407*^9}, {3.615360549322549*^9, 
   3.615360598043336*^9}, 3.618406903278664*^9, {3.628060652201407*^9, 
   3.6280607016066937`*^9}, {3.628062123564791*^9, 3.628062170895274*^9}, {
   3.6971776058912687`*^9, 
   3.697177656514532*^9}},ExpressionUUID->"2ae82fbc-a5d8-498e-b8a4-\
61cb87ebd316"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fund2", "[", 
          RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"s1", ",", "s2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}], "\[Equal]", " ", 
      "0"}], ")"}], "&&", "  ", 
    RowBox[{"(", 
     RowBox[{"v", "<", 
      RowBox[{"Pi", "/", "2"}]}], ")"}], "&&", "  ", 
    RowBox[{"(", 
     RowBox[{"v", ">", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}]}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"r", ">", "0"}], ")"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2", ",", "v"}], "}"}], ",", "Reals"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591251918655227*^9, 3.591251930794922*^9}, {
   3.5912519649228735`*^9, 3.591252048466652*^9}, {3.591252241953719*^9, 
   3.5912522623128834`*^9}, {3.5912522937856836`*^9, 3.591252347257742*^9}, 
   3.591252871539729*^9, {3.5912537907793064`*^9, 3.591253941118905*^9}, 
   3.591253983300318*^9, {3.591254121708235*^9, 3.591254134867987*^9}, {
   3.611639104484082*^9, 3.6116391257157197`*^9}, 3.6148618590355387`*^9, 
   3.6149177908909597`*^9},ExpressionUUID->"258def1c-9fea-462c-b41a-\
ca1ab991f6c6"],

Cell[TextData[{
 "Another important invariant of the surface is the ",
 StyleBox["mean curvature",
  FontColor->RGBColor[0, 0, 1]],
 " defined as the trace of the second fundamental form"
}], "Text",
 CellChangeTimes->{{3.5914236744605484`*^9, 3.591423751543957*^9}, {
   3.5914243571205945`*^9, 3.591424357792633*^9}, {3.598451012192274*^9, 
   3.5984510125012918`*^9}, {3.615362094107479*^9, 3.615362161155314*^9}, 
   3.628060562329649*^9, 
   3.6280622939638906`*^9},ExpressionUUID->"65ad470d-7e72-436e-bd86-\
ba154b3199dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"fd2", "[", 
          RowBox[{"1", ",", "1"}], "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"2", ",", "2"}], "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", "*", 
       RowBox[{
        RowBox[{
         RowBox[{"fd2", "[", 
          RowBox[{"1", ",", "2"}], "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", "2"}], "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "+", "\n", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"fd2", "[", 
          RowBox[{"2", ",", "2"}], "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"1", ",", "1"}], "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "*", 
      RowBox[{"Det", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"rgT", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}]}], ")"}]}]}], 
  ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.591453039732647*^9, 3.591453186263705*^9}, 
   3.591453315572332*^9, 3.614861859144739*^9, 3.614863136537382*^9, {
   3.617972101448177*^9, 3.6179721027672524`*^9}, 3.697519925255453*^9, 
   3.6975200559792013`*^9, 
   3.697520113103002*^9},ExpressionUUID->"bb1384a3-4f99-43f5-bad9-\
845804a7cb75"],

Cell["(function so defined by A. Gray.)", "Text",
 CellChangeTimes->{{3.6975201459115877`*^9, 3.6975201652061567`*^9}, {
  3.697520196867942*^9, 
  3.6975202481232033`*^9}},ExpressionUUID->"c467c619-ed91-4db7-bd73-\
1e3af3836d25"],

Cell[BoxData[
 RowBox[{"?", "meancurvature"}]], "Input",
 CellChangeTimes->{{3.6153650924458*^9, 3.6153652075853853`*^9}, 
   3.615365241170306*^9, {3.6226994759115267`*^9, 
   3.622699487720747*^9}},ExpressionUUID->"2ea55f6b-b427-46c6-b948-\
ed87cdc1655f"],

Cell[BoxData[
 RowBox[{"Context", "[", "meancurvature", "]"}]], "Input",
 CellChangeTimes->{{3.6153650924458*^9, 3.6153652075853853`*^9}, 
   3.615365241170306*^9, {3.6226994759115267`*^9, 3.622699487720747*^9}, {
   3.62269954043324*^9, 
   3.6226995583264713`*^9}},ExpressionUUID->"689eae28-c15c-4948-8cb5-\
a03b9e4d92c6"],

Cell[TextData[{
 StyleBox["Remark,",
  FontColor->RGBColor[0, 0, 1]],
 " The signs of the mean curvature, of  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.591508404647152*^9, 3.5915084060942345`*^9}, {
    3.5915084395291467`*^9, 3.5915084509828014`*^9}, {3.5915084879509163`*^9, 
    3.5915086366044188`*^9}, 3.591508698468957*^9, {3.5915087375851946`*^9, 
    3.5915087569603024`*^9}},
  TextAlignment->Center,ExpressionUUID->
  "76fd7263-146d-4d0b-9cb3-05d2f8ca07f8"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.591508404647152*^9, 3.5915084060942345`*^9}, {
    3.5915084395291467`*^9, 3.5915084509828014`*^9}, {3.5915084879509163`*^9, 
    3.5915086366044188`*^9}, 3.591508698468957*^9, {3.5915087375851946`*^9, 
    3.5915087569603024`*^9}},
  TextAlignment->Center,ExpressionUUID->
  "0b3ce195-aa0a-4970-a929-143c84d37638"],
 ", are opposite to the definitions in [B-R], see (61.26), p. 89."
}], "Text",
 CellChangeTimes->{{3.5915132001654396`*^9, 3.5915133912293673`*^9}, {
   3.615365277023357*^9, 3.6153652880139856`*^9}, {3.6154345328328114`*^9, 
   3.6154345703196774`*^9}, 3.6184070924544845`*^9, 
   3.6257307007247796`*^9},ExpressionUUID->"c4ff1100-04e5-49f5-9c68-\
e712298b84da"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"meancurvature", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "-", 
  RowBox[{
   RowBox[{"Tr", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cf", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.591424392201601*^9, 3.591424478700548*^9}, {
   3.5914245920050287`*^9, 3.5914246060768337`*^9}, 3.5914432841844273`*^9, {
   3.591443426487877*^9, 3.5914434841143785`*^9}, {3.591443521382844*^9, 
   3.5914435245496497`*^9}, 3.591444524511406*^9, 3.591452112560619*^9, 
   3.591453529043107*^9, {3.5914535906632147`*^9, 3.5914535921140175`*^9}, {
   3.591509215258516*^9, 3.591509217562648*^9}, {3.614861859160339*^9, 
   3.614861859160339*^9}, 3.6148631365529823`*^9, 3.614863501843224*^9, 
   3.617972104512352*^9, {3.6280625047202606`*^9, 
   3.6280625121926737`*^9}},ExpressionUUID->"2ae18368-4edb-4fbb-8116-\
f49c17615a89"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", "%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.628062670064951*^9, 
  3.6280626859769793`*^9}},ExpressionUUID->"3e838ec4-09c5-4abd-95be-\
5ad16c35c830"],

Cell[TextData[{
 "Also the following general equation has been confirmed by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", using about 20 min  of evaluating time:"
}], "Text",
 CellChangeTimes->{{3.5914271254729347`*^9, 3.5914271808651032`*^9}, {
   3.591453651908922*^9, 3.5914536546389275`*^9}, 3.5914579284684405`*^9, {
   3.615365395470132*^9, 3.615365402398528*^9}, {3.6971849444724216`*^9, 
   3.6971849640322247`*^9}, 
   3.6975203160431423`*^9},ExpressionUUID->"b9527c03-994c-4a38-a154-\
22a78a116ca3"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"prcurvatures", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", "+", 
      RowBox[{
       RowBox[{
        RowBox[{"prcurvatures", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.591425022610658*^9, {3.5914250548025*^9, 3.5914251408384204`*^9}, {
   3.591425286552755*^9, 3.5914253533975782`*^9}, 3.591453535875919*^9, 
   3.614861859160339*^9, 3.6148631365685825`*^9, 3.615365573002286*^9, {
   3.6153732193236303`*^9, 3.6153732221637926`*^9}, {3.628062711670224*^9, 
   3.6280627217790422`*^9}, {3.6280728281519146`*^9, 3.628072872974794*^9}, {
   3.697177854187038*^9, 
   3.697177953056663*^9}},ExpressionUUID->"8895a8e1-61eb-4045-a81c-\
ebf1ffc54274"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", "hypsf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"prcurvatures", "[", "hypsf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", "+", 
      RowBox[{
       RowBox[{
        RowBox[{"prcurvatures", "[", "hypsf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.591425022610658*^9, {3.5914250548025*^9, 3.5914251408384204`*^9}, {
   3.591425286552755*^9, 3.5914253533975782`*^9}, 3.591453535875919*^9, 
   3.614861859160339*^9, 3.6148631365685825`*^9, 3.615365573002286*^9, {
   3.6153732193236303`*^9, 3.6153732221637926`*^9}, {3.628062711670224*^9, 
   3.6280627217790422`*^9}, {3.6280728281519146`*^9, 3.628072872974794*^9}, {
   3.6971850310097933`*^9, 3.697185051762089*^9}, {3.6975172342665663`*^9, 
   3.697517242620028*^9}, 3.697517301746578*^9, {3.697519162389678*^9, 
   3.697519163333118*^9}, {3.6975198018089323`*^9, 
   3.697519803615288*^9}},ExpressionUUID->"cf59f3fe-5a30-4e3a-92a7-\
5779b6e3fbbb"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"meancurvature", "[", "hypsf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", ",", 
    RowBox[{"v", "\[Element]", "Reals"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.697517318385954*^9, 3.697517319545681*^9}, {
  3.697517675155126*^9, 3.697517682557415*^9}, {3.697518902019449*^9, 
  3.697518930839113*^9}, {3.6975208414002867`*^9, 3.69752088590314*^9}, {
  3.697520938672173*^9, 
  3.697520955102517*^9}},ExpressionUUID->"67e409a5-b1b3-4b8d-b340-\
abbe3e909a4d"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"meancurvature", "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.697517318385954*^9, 3.697517319545681*^9}, {
   3.697517675155126*^9, 3.697517682557415*^9}, {3.697518902019449*^9, 
   3.697518930839113*^9}, 3.697520520850308*^9, {3.697520557257413*^9, 
   3.697520595777156*^9}},ExpressionUUID->"b844827a-3c68-46c0-be8c-\
dab6ec964d70"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"Cos", "[", "v", "]"}], ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697520696836646*^9, 
  3.697520742344118*^9}},ExpressionUUID->"4a5b974b-f059-40d2-ac6d-\
189287a82359"],

Cell["\<\
The traditional notations of the Gaussian and the mean curvature are\
\>", "Text",
 CellChangeTimes->{{3.591510504133235*^9, 3.5915105337009263`*^9}, 
   3.6280631605828657`*^9},ExpressionUUID->"2d657d41-db0e-4370-a5e2-\
614cc317c461"],

Cell[BoxData[
 RowBox[{
  RowBox[{"K", "=", 
   RowBox[{
    RowBox[{"gauss", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], ";", 
  RowBox[{"H", "=", " ", 
   RowBox[{
    RowBox[{"meancurvature", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.591509404812358*^9, 3.5915094861910124`*^9}, {
   3.5915098286475997`*^9, 3.591509840613284*^9}, 3.591510578280476*^9, 
   3.6148618591759386`*^9, 
   3.6148631365841827`*^9},ExpressionUUID->"13a66f39-ca05-4428-93c1-\
43a54af0942d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tt", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.591509404812358*^9, 3.5915094861910124`*^9}, {
  3.5915098286475997`*^9, 3.591509840613284*^9}, {3.591510578280476*^9, 
  3.5915105854378853`*^9}, {3.615365503896333*^9, 
  3.6153655065834866`*^9}},ExpressionUUID->"e5802d6e-8f33-4df5-bc46-\
34746a7ec002"],

Cell["\<\
We verify the well known relation, proved e.g. in [B-R], (62.19), p.93:\
\>", "Text",
 CellChangeTimes->{{3.591512624125492*^9, 3.5915126308448763`*^9}, {
  3.591512932918154*^9, 3.5915129927415752`*^9}, {3.591514476205425*^9, 
  3.591514484732912*^9}},ExpressionUUID->"d1981c60-6e0a-44cb-8cd4-\
aa4eb1fe0904"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"K", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"tt", ",", "tt"}], "]"}]}], " ", "+", " ", 
    RowBox[{"2", "*", "H", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"fund2a", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "[", 
      RowBox[{"tt", ",", "tt"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", 
         RowBox[{
          RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "tt"}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"d", "[", 
         RowBox[{
          RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "tt"}], ")"}]}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5915095082782755`*^9, 3.591509568263706*^9}, {
  3.591509610320112*^9, 3.591509645545127*^9}, {3.591509733351149*^9, 
  3.591509753367294*^9}, {3.5915098645436525`*^9, 3.591509870040967*^9}, {
  3.591510188080158*^9, 3.591510252920867*^9}, {3.591510335568594*^9, 
  3.5915103952670083`*^9}, {3.5915125071888037`*^9, 3.59151253055614*^9}, {
  3.6148618591759386`*^9, 3.6148618591759386`*^9}, {3.6149177909533596`*^9, 
  3.61491779096896*^9}, {3.61526232208561*^9, 
  3.6152623239587173`*^9}},ExpressionUUID->"c4c007b8-d99e-4fd1-90fa-\
4fb7ce16d4aa"],

Cell[TextData[{
 "The result is zero. The time needed to verify this identity was  1594.328 s \
= 26 min, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v.9.0.1.0. "
}], "Text",
 CellChangeTimes->{{3.6280847273149567`*^9, 3.6280848058454947`*^9}, {
   3.628084868074004*^9, 3.628084885717635*^9}, {3.6971938608617764`*^9, 
   3.6971938622861643`*^9}, 3.707660175166201*^9, {3.707660239814887*^9, 
   3.707660241877556*^9}, {3.707660274862639*^9, 
   3.7076603087424793`*^9}},ExpressionUUID->"34050b5e-b2f8-41bb-acef-\
88730b1ebc05"],

Cell[TextData[{
 "The last Dot product is named the",
 StyleBox[" third fundamental form",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface:"
}], "Text",
 CellChangeTimes->{{3.591510744132962*^9, 
  3.591510787156423*^9}},ExpressionUUID->"6d079d3e-a2f5-4860-90ab-\
a5f91b0d38de"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fund3", "[", "ff_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], "[", 
   RowBox[{"x_List", ",", "y_List"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", "x"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", "y"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.5915107902566004`*^9, 3.591510920463048*^9}, {
  3.5915111307120733`*^9, 3.591511134304279*^9}, {3.614861859191539*^9, 
  3.614861859191539*^9}, {3.61491779096896*^9, 3.6149177909845595`*^9}, {
  3.6152623260058346`*^9, 
  3.615262327597925*^9}},ExpressionUUID->"ded4a181-f01f-435a-8e91-\
9db86b353557"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund3", "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{"tt", ",", "tt"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5915135006626267`*^9, 
  3.591513610408904*^9}},ExpressionUUID->"c51e036d-af99-46de-b576-\
6375f226919e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{"tt", ",", "tt"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915136280619135`*^9, 3.591513662912907*^9}, 
   3.5915136981689234`*^9},ExpressionUUID->"6452f4aa-341e-4857-b824-\
43b0a1736936"],

Cell["\<\
It degenerates if K = 0, and it is the first fundamental form of the unit \
sphere under the parameter representation of the Gauss map otherwise.\
\>", "Text",
 CellChangeTimes->{{3.5915109744131336`*^9, 3.5915110763489637`*^9}, {
  3.6154347044799128`*^9, 
  3.6154347134031286`*^9}},ExpressionUUID->"b35e8035-c0aa-4495-b177-\
60b3e3253fee"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"K", ",", "H", ",", "cx", ",", "tt", ",", " ", "\[Gamma]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591511821736598*^9, 3.5915118333552628`*^9}, 
   3.5915119055813932`*^9, {3.5915119646777735`*^9, 3.591511972552224*^9}, {
   3.591513428718512*^9, 3.591513460286318*^9}, {3.591513764215701*^9, 
   3.5915137673668814`*^9}, 
   3.6114713927527266`*^9},ExpressionUUID->"4b877a18-df9a-415b-afaa-\
f8eb519de928"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.6. Graphs of Functions", "Subsection",
 CellChangeTimes->{{3.591592516559106*^9, 3.591592541566536*^9}, 
   3.611640876709595*^9, 3.6116416079920797`*^9, 3.615434814350906*^9, 
   3.6154364406381626`*^9, {3.6184074755410967`*^9, 3.618407498629137*^9}, {
   3.628085165379326*^9, 3.6280851714945374`*^9}, 3.6280860846577406`*^9, 
   3.6971941928281097`*^9, 3.697210635007815*^9, 3.707660443020914*^9, 
   3.7077067572239523`*^9},ExpressionUUID->"aeac7398-b3de-4405-8e75-\
5edec592cb85"],

Cell["\<\
In this section we consider surfaces as graphs of functions of two variables: \
We shall calculate the invariants of the graphs and apply the results to \
visualize the relation of the curvature with the local shape of a surface.\
\>", "Text",
 CellChangeTimes->{{3.5915973790152225`*^9, 3.591597457390705*^9}, {
  3.5916065041192923`*^9, 
  3.5916066114464307`*^9}},ExpressionUUID->"122b4519-9c32-47d2-82d9-\
e27f38f57fe4"],

Cell[BoxData[
 RowBox[{"?", "graph"}]], "Input",
 CellChangeTimes->{{3.5915926925891743`*^9, 
  3.5915926960793734`*^9}},ExpressionUUID->"c777c63a-6b3a-41d1-a26b-\
8da41187fc65"],

Cell[BoxData[
 RowBox[{
  RowBox[{"graph", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5915927300373163`*^9, 3.591592744128122*^9}, 
   3.5984303193338203`*^9},ExpressionUUID->"25caf269-b02f-45d5-a5af-\
8ef93e97a5b4"],

Cell["The moving frame of the surface graph[f] is", "Text",
 CellChangeTimes->{{3.5915977489033785`*^9, 3.5915978063746657`*^9}, {
  3.5915982482159376`*^9, 
  3.591598249815029*^9}},ExpressionUUID->"659a003c-b41d-4362-bcf8-\
ff1ee7db0b2f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "1", "]"}], "[", 
   RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.591592810221902*^9, 3.5915928362723923`*^9}, {
   3.5915975202423*^9, 3.5915975270816913`*^9}, {3.591597567498003*^9, 
   3.5915975708171926`*^9}, 3.614861859207139*^9, 3.6149177909845595`*^9, 
   3.615275815323556*^9},ExpressionUUID->"9e493249-3658-45cf-9f67-\
d984d9d3aa00"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "2", "]"}], "[", 
   RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.591592810221902*^9, 3.5915928362723923`*^9}, {
   3.5915975202423*^9, 3.5915975270816913`*^9}, {3.591597567498003*^9, 
   3.591597605425172*^9}, 3.614861859207139*^9, 3.6149177910001593`*^9, 
   3.615275816315613*^9},ExpressionUUID->"99996f48-763b-4235-9446-\
8865c3e2fe59"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amf", "[", "3", "]"}], "[", 
   RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.591592810221902*^9, 3.5915928362723923`*^9}, {
   3.5915975202423*^9, 3.5915975270816913`*^9}, {3.591597567498003*^9, 
   3.591597605425172*^9}, {3.5915976544389753`*^9, 3.5915976736180725`*^9}, 
   3.614861859207139*^9, 3.6149177910157595`*^9, 
   3.6152758172926683`*^9},ExpressionUUID->"5b178c1f-2091-46fd-a07b-\
09dd3a6eef93"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Together", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"amf", "[", "i", "]"}], "[", 
         RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], ".", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"amf", "[", "j", "]"}], "[", 
         RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.6280854466478205`*^9, 3.6280855191255474`*^9}, {
  3.628085564958428*^9, 
  3.628085661070197*^9}},ExpressionUUID->"cd57f2a2-b261-46c9-9599-\
6ac477f0672a"],

Cell["\<\
We consider the special position that the tangent plane of the surface at the \
point {u, v}={0, 0}  is the u, v-plane z = 0 and the point graph[f][0,0] is \
the origin. These conditions are\
\>", "Text",
 CellChangeTimes->{{3.5915982913974075`*^9, 3.5915985371594644`*^9}, 
   3.5915987400710697`*^9, 
   3.59168583181394*^9},ExpressionUUID->"f52464d1-de9b-425d-a3ca-\
ae2dc4e8e7ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "tcond", "]"}], ";", 
  RowBox[{
   RowBox[{"tcond", "[", "ff_", "]"}], ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ff", "[", 
         RowBox[{"u", ",", "v"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", "\[Rule]", "0"}], ",", 
          RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ")"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["ff", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", "\[Rule]", "0"}], ",", 
          RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ")"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["ff", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"u", "\[Rule]", "0"}], ",", 
          RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ")"}], "\[Equal]", 
      "0"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5915929268945756`*^9, 3.5915930649064693`*^9}, {
  3.591593102353611*^9, 3.5915931751407747`*^9}, {3.591593263948854*^9, 
  3.5915933381660986`*^9}},ExpressionUUID->"9d64924d-1f1c-4471-a87f-\
eebd7751560d"],

Cell[BoxData[
 RowBox[{"tcond", "[", "f", "]"}]], "Input",
 CellChangeTimes->{{3.5915931846653194`*^9, 
  3.591593224104575*^9}},ExpressionUUID->"42bee4d2-060d-496a-bd33-\
5f88060ec9cc"],

Cell["\<\
Each surface sf locally, in the neighborhood of an arbitrary regular point,  \
can be represented in this way. The function f is the distance of the point \
sf[u,v] from the tangent plane at the point sf[0,0]. The frame at the point \
{0,0} then is the standard basis:\
\>", "Text",
 CellChangeTimes->{{3.591598628758703*^9, 3.591598711359428*^9}, {
  3.591598745871402*^9, 3.59159889951919*^9}, {3.5915991083351336`*^9, 
  3.591599135631695*^9}},ExpressionUUID->"30e0a42d-37a5-4c03-9446-\
aa7d22a86b9a"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "1", "]"}], "[", 
        RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "2", "]"}], "[", 
        RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"amf", "[", "3", "]"}], "[", 
        RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "}"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", 
   RowBox[{"tcond", "[", "f", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915989328190947`*^9, 3.5915990016440315`*^9}, {
  3.591599046445594*^9, 3.591599054701066*^9}, {3.614861859222739*^9, 
  3.614861859222739*^9}, {3.6149177910313597`*^9, 3.6149177910313597`*^9}, {
  3.6152758184227333`*^9, 
  3.6152758205978575`*^9}},ExpressionUUID->"d4bbac51-0a08-4c87-a986-\
5273a0e0fd90"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ss", "=", 
   RowBox[{"{", 
    RowBox[{"s1", ",", "s2"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5915944041560698`*^9, 3.5915944155127196`*^9}, 
   3.591599225201818*^9},ExpressionUUID->"c157f3bb-9f58-488b-aa26-\
abef244f99e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund1", "[", 
    RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{"ss", ",", "ss"}], "]"}]], "Input",
 CellChangeTimes->{{3.5915942364314766`*^9, 3.591594247940135*^9}, {
   3.591594278312872*^9, 3.591594297073945*^9}, {3.5915944248652544`*^9, 
   3.5915944299525456`*^9}, 
   3.5915993268266306`*^9},ExpressionUUID->"479582ec-a09c-4d54-8393-\
994056c132ae"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", 
   RowBox[{"tcond", "[", "f", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915944688857727`*^9, 3.591594505640875*^9}, {
  3.591599368362006*^9, 
  3.5915993755534177`*^9}},ExpressionUUID->"82b446fc-0a7e-4a8e-b1e6-\
ff878997632e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund2a", "[", 
    RowBox[{"graph", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{"ss", ",", "ss"}], "]"}]], "Input",
 CellChangeTimes->{{3.5915945394578085`*^9, 3.59159454052787*^9}, {
   3.591594591249771*^9, 3.5915946618878117`*^9}, {3.591594739650259*^9, 
   3.591594762532568*^9}, 3.5916053890825157`*^9, 
   3.5916054716252365`*^9},ExpressionUUID->"e17a099e-1326-44a1-82fc-\
7c68cb562416"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", 
   RowBox[{"tcond", "[", "f", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915944688857727`*^9, 3.591594505640875*^9}, {
  3.591599368362006*^9, 
  3.5915993755534177`*^9}},ExpressionUUID->"a4148577-a2c8-419f-9cc5-\
2ec93c548d32"],

Cell["\<\
We will compare this expression with the first non vanishing term of the \
Taylor series of f at {0,0}:\
\>", "Text",
 CellChangeTimes->{{3.5916010136001086`*^9, 3.5916010984949646`*^9}, {
  3.591605432806016*^9, 
  3.5916054543502483`*^9}},ExpressionUUID->"38ca1005-9287-4baf-887b-\
1e89623f91c2"],

Cell[BoxData[
 RowBox[{"?", "Series"}]], "Input",
 CellChangeTimes->{{3.5915936651197996`*^9, 
  3.5915936737732944`*^9}},ExpressionUUID->"b3d458f5-f751-4916-9458-\
5fd3e7f38b90"],

Cell["The first term of this series along an arbitrary line is", "Text",
 CellChangeTimes->{{3.591601114977907*^9, 
  3.5916011479037905`*^9}},ExpressionUUID->"0a52f071-8bff-4ea7-9ce4-\
c809a447786c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"s1", "*", "t"}]}], ";", 
  RowBox[{
   RowBox[{"v", "[", "t_", "]"}], " ", ":=", 
   RowBox[{"s2", "*", "t"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5916003676521626`*^9, 3.5916004260495024`*^9}, {
  3.591600594235122*^9, 3.591600630105174*^9}, {3.6184687864831133`*^9, 
  3.618468807839551*^9}},ExpressionUUID->"90f5b357-1a67-4e33-bf7d-\
3cd5fa7a79f8"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], ",", 
       RowBox[{"v", "[", "t", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "2"}], "}"}]}], "]"}], ",", 
   RowBox[{"tcond", "[", "f", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5915937069431915`*^9, 3.591593725240238*^9}, {
  3.59159376058526*^9, 3.5915937987624435`*^9}, {3.591593849634353*^9, 
  3.591593853378567*^9}, {3.591594000297971*^9, 3.591594019612075*^9}, {
  3.5915998108033123`*^9, 3.591599837041813*^9}, {3.5916003026874466`*^9, 
  3.5916003256267586`*^9}, {3.5916004415553894`*^9, 3.5916004544021244`*^9}, {
  3.5916006394597087`*^9, 
  3.591600644394991*^9}},ExpressionUUID->"74e6c3f5-e092-45dc-80a7-\
785b85710959"],

Cell["\<\
This is the half of the second fundamental form of graph[f] at the point \
{0,0}. We consider simple test functions with given principal curvatures of \
their graphs:\
\>", "Text",
 CellChangeTimes->{{3.591601196950596*^9, 3.5916012447353287`*^9}, {
  3.591601283679556*^9, 3.5916013527195053`*^9}, {3.6154352752225156`*^9, 
  3.615435283849331*^9}},ExpressionUUID->"fc8aeb7f-24b8-40fb-b553-\
aca9a1b84ef8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"testf", "[", 
    RowBox[{"k1_", ",", "k2_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"k1", "*", 
       RowBox[{"u", "^", "2"}]}], "+", 
      RowBox[{"k2", "*", 
       RowBox[{"v", "^", "2"}]}]}], ")"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.5915953083397865`*^9, 3.591595409400567*^9}, {
   3.591596024913772*^9, 3.5915960290890107`*^9}, 
   3.591686360140068*^9},ExpressionUUID->"bbedc7e2-b5ea-41e5-95ee-\
992c25487614"],

Cell[BoxData[
 RowBox[{"tcond", "[", 
  RowBox[{"testf", "[", 
   RowBox[{"k1", ",", "k2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.591595419727157*^9, 
  3.5915954602054725`*^9}},ExpressionUUID->"11963e89-27ee-4692-8f80-\
deaa063acbf8"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"prcurvatures", "[", 
      RowBox[{"graph", "[", 
       RowBox[{"testf", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", " ", 
   RowBox[{"k1", "\[GreaterEqual]", " ", "k2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591601370840542*^9, 3.591601405881546*^9}, 
   3.591604992271819*^9, {3.591605166785801*^9, 3.5916051749442673`*^9}, 
   3.591605221897953*^9, {3.5916055418982563`*^9, 
   3.5916055638985147`*^9}},ExpressionUUID->"93e037ff-24f2-41e3-b0b0-\
0934491c6e71"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", 
      RowBox[{"graph", "[", 
       RowBox[{"testf", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", " ", 
   RowBox[{"k1", "\[GreaterEqual]", " ", "k2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591601370840542*^9, 3.591601405881546*^9}, 
   3.591604992271819*^9, {3.591605166785801*^9, 3.5916051749442673`*^9}, 
   3.591605221897953*^9, {3.5916055418982563`*^9, 3.5916055638985147`*^9}, {
   3.5916056076470165`*^9, 
   3.5916056199587207`*^9}},ExpressionUUID->"f3c584b1-3517-4f48-b0d4-\
50472202a53b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"meancurvature", "[", 
      RowBox[{"graph", "[", 
       RowBox[{"testf", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "0"}], ",", 
      RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}], ",", " ", 
   RowBox[{"k1", "\[GreaterEqual]", " ", "k2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591601370840542*^9, 3.591601405881546*^9}, 
   3.591604992271819*^9, {3.591605166785801*^9, 3.5916051749442673`*^9}, 
   3.591605221897953*^9, {3.5916055418982563`*^9, 3.5916055638985147`*^9}, {
   3.5916056076470165`*^9, 3.591605642184992*^9}, 3.614861859238339*^9, 
   3.6148631365841827`*^9, 3.615275821972936*^9, 
   3.615275880248269*^9},ExpressionUUID->"9b3f6f01-f5bc-45c7-b3f5-\
087a34d52058"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fund2", "[", 
     RowBox[{"graph", "[", 
      RowBox[{"testf", "[", 
       RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{"ss", ",", "ss"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", "0"}], ",", 
    RowBox[{"v", "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.591596189028159*^9, 3.5915962745710516`*^9}, 
   3.5916064079967937`*^9},ExpressionUUID->"c2ba13e7-40e0-4051-af3b-\
57bf3a4516f8"],

Cell[TextData[{
 "In the near of  an ",
 StyleBox["elliptic point",
  FontColor->RGBColor[0, 0, 1]],
 ", i.e. K[u,v] >0, the shape of the surface is similar to"
}], "Text",
 CellChangeTimes->{{3.5916056834863544`*^9, 
  3.591605780221887*^9}},ExpressionUUID->"ce2aca4b-e2b2-4902-89cc-\
477e2532a69a"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", 
     RowBox[{"testf", "[", 
      RowBox[{"1", ",", "3"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591595505721076*^9, 3.591595605058758*^9}, 
   3.5915957711872597`*^9},ExpressionUUID->"31ca92df-e238-403c-8427-\
2c5368c1ca7a"],

Cell["\<\
In particular, for an umbilic point with K > 0 we have the shape nearly to a \
spherical surface\
\>", "Text",
 CellChangeTimes->{{3.591605792010562*^9, 3.5916059000707426`*^9}, {
  3.5916860947056017`*^9, 3.591686125422056*^9}, {3.618469149698551*^9, 
  3.6184691517889547`*^9}},ExpressionUUID->"a0d03a3e-bdad-4834-aca0-\
c59a2c19b988"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", 
     RowBox[{"testf", "[", 
      RowBox[{"3", ",", "3"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591595505721076*^9, 3.591595605058758*^9}, {
  3.591595742887641*^9, 3.591595750138056*^9}, {3.591605870594056*^9, 
  3.5916058715061083`*^9}},ExpressionUUID->"f8dc5bdb-8837-403d-85d6-\
25496ad27db2"],

Cell[TextData[{
 "Near an",
 StyleBox[" hyperbolic point",
  FontColor->RGBColor[0, 0, 1]],
 ", K<0, the shape of the surface is near to"
}], "Text",
 CellChangeTimes->{{3.5916060217467017`*^9, 
  3.5916060856463566`*^9}},ExpressionUUID->"838c3b50-dccd-40bb-8ba3-\
d07b34192d44"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", 
     RowBox[{"testf", "[", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "3"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591595505721076*^9, 3.591595645378064*^9}, {
  3.591596110219651*^9, 3.5915961157469673`*^9}, {3.591686418702571*^9, 
  3.591686425004982*^9}},ExpressionUUID->"5f558daf-b3ba-4817-9216-\
d2c7557dff17"],

Cell[TextData[{
 "This is a ",
 StyleBox["saddle point",
  FontColor->RGBColor[0, 0, 1]],
 " of the function ftest.  For a ",
 StyleBox["parabolic point",
  FontColor->RGBColor[0, 0, 1]],
 ", i.e. k1>k2 = 0, (or k1<k2 = 0) , the shape of the surface is of type"
}], "Text",
 CellChangeTimes->{{3.591606125706648*^9, 3.591606367550481*^9}, 
   3.591686581754058*^9},ExpressionUUID->"89b2100f-4e09-4389-9088-\
97312973fc51"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", 
     RowBox[{"testf", "[", 
      RowBox[{"0", ",", "3"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", ".3"}], ",", ".3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591595505721076*^9, 3.591595645378064*^9}, {
   3.5915956756417947`*^9, 3.591595686778432*^9}, 3.5916064444268775`*^9, 
   3.591686453256632*^9},ExpressionUUID->"1d43cd84-7716-49db-b804-\
971d23e08807"],

Cell["\<\
As an exercise plot the intersection of the surface with its tangent plane at \
the point {0,0}  in each of the cases:\
\>", "Text",
 CellChangeTimes->{{3.5916867209219017`*^9, 3.5916868015584435`*^9}, {
   3.5916868490917273`*^9, 3.591686866766558*^9}, 
   3.5916875684089904`*^9},ExpressionUUID->"8523c61d-c0a6-4c95-829b-\
a31dd4178e25"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"graph", "[", 
        RowBox[{"testf", "[", 
         RowBox[{"k1", ",", "k2"}], "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
     RowBox[{"stb", "[", "3", "]"}]}], " ", "\[Equal]", "0"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", " ", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.591687035543255*^9, 3.591687042812867*^9}, {
   3.591687140562639*^9, 3.5916871955839357`*^9}, 3.6148618592539387`*^9, 
   3.6149177910625596`*^9, {3.618469330019268*^9, 
   3.618469340970487*^9}},ExpressionUUID->"f96dbddb-468f-44b7-85f4-\
0cde8491d54e"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"u", ",", "v", ",", "ss", ",", "testf"}], "]"}]], "Input",
 CellChangeTimes->{{3.5916885145818524`*^9, 3.5916885328650846`*^9}, {
  3.618470302669377*^9, 
  3.6184703062573833`*^9}},ExpressionUUID->"d18dd8df-0985-427e-bd68-\
7cfa214ba855"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.7. Ruled Surfaces: Criterion  of Developability", "Subsection",
 CellChangeTimes->{{3.591771408757987*^9, 3.5917714528555093`*^9}, {
   3.594270351054023*^9, 3.5942703667164507`*^9}, 3.611641617461296*^9, 
   3.611667344308116*^9, 3.6154364525565834`*^9, 3.6154517959096875`*^9, {
   3.6184703670506897`*^9, 3.6184703699678946`*^9}, 3.618561968272961*^9, 
   3.628085177921748*^9, 3.6280861398350377`*^9, 3.628176382410313*^9, 
   3.697210643272819*^9, 3.6972688276108837`*^9, 3.699338727418528*^9, {
   3.699338790258765*^9, 3.6993388270901127`*^9}, 3.707706763303423*^9, 
   3.707721991008863*^9},ExpressionUUID->"6e036f36-2043-4f2f-8ea5-\
cd3da5d42425"],

Cell["Ruled surface have been introduced in Subsection 2.1.2;", "Text",
 CellChangeTimes->{{3.59202391500099*^9, 
  3.592023996339533*^9}},ExpressionUUID->"f819541d-e3e9-4bf0-a971-\
ecd7f9ede225"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruled", "[", 
   RowBox[{"x", ",", "y"}], "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5920228263062778`*^9, 
  3.5920228604391375`*^9}},ExpressionUUID->"b42f1235-ccab-4b4d-a7a1-\
73db839713df"],

Cell["\<\
For  shortness we set for a general, not specified ruled surface\
\>", "Text",
 CellChangeTimes->{{3.6280868843463454`*^9, 
  3.6280869280888224`*^9}},ExpressionUUID->"249a9828-4742-4583-ab8b-\
5dc5c258c093"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf", "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"ruled", "[", 
    RowBox[{"x", ",", " ", "y"}], "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5917723210491667`*^9, 3.591772332008794*^9}, {
   3.591772366105744*^9, 3.591772383985767*^9}, {3.591971789454519*^9, 
   3.5919717908585215`*^9}, 3.5919720609641957`*^9, {3.5920231716284847`*^9, 
   3.592023191643319*^9}, {3.5920234488097715`*^9, 3.592023471414211*^9}, 
   3.5920240269935865`*^9},ExpressionUUID->"e605dd84-3bc2-4358-9a86-\
72538771d0d7"],

Cell[BoxData[
 RowBox[{"rsf", "[", 
  RowBox[{"s", ",", " ", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.591772390090116*^9, 3.591772396432479*^9}, 
   3.5919717922625237`*^9, 3.591972063741001*^9, 
   3.592023652046928*^9},ExpressionUUID->"63fa7479-50c2-4f23-aff9-\
6f8a472e5756"],

Cell["Furthermore we set", "Text",
 CellChangeTimes->{{3.592024050081627*^9, 3.59202405156363*^9}, {
  3.6280869500068607`*^9, 
  3.628086963656885*^9}},ExpressionUUID->"b3bb31db-8e1d-4731-92c9-\
6be21f126ed3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"xx", "[", "t_", "]"}], " ", "=", 
   RowBox[{"vec", "[", 
    RowBox[{"x", "[", "t", "]"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"yy", "[", "t_", "]"}], " ", "=", 
   RowBox[{"vec", "[", 
    RowBox[{"y", "[", "t", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rsf", "[", 
   RowBox[{"s", ",", "t"}], "]"}], " ", "==", 
  RowBox[{
   RowBox[{"xx", "[", "t", "]"}], "+", 
   RowBox[{"s", "*", 
    RowBox[{"yy", "[", "t", "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.591771503590411*^9, 3.5917715096997604`*^9}, {
   3.591771552281196*^9, 3.5917715868411727`*^9}, {3.591771626377434*^9, 
   3.591771658025244*^9}, {3.5917719866660414`*^9, 3.5917720404511175`*^9}, {
   3.591772073435004*^9, 3.5917722000862484`*^9}, {3.591772279558794*^9, 
   3.591772307915416*^9}, {3.5919717709996862`*^9, 3.5919717880817165`*^9}, 
   3.591971995686881*^9, {3.592023012071404*^9, 3.5920230840655303`*^9}, {
   3.6975213991074963`*^9, 3.697521462058413*^9}, {3.6975215669380293`*^9, 
   3.69752158424131*^9}},ExpressionUUID->"180c8802-7a56-4803-b7df-\
713ded432850"],

Cell["\<\
and assume that the following three conditions are satisfied:\
\>", "Text",
 CellChangeTimes->{{3.592024086991292*^9, 3.5920240913905*^9}, {
  3.5920241521058064`*^9, 
  3.592024182026659*^9}},ExpressionUUID->"1696c0ac-8b43-4231-aeb0-\
5fa04967cd81"],

Cell["Conditions. 1. t is the arc length of the curve xx[t]: ", "Text",
 CellChangeTimes->{{3.5917724731278653`*^9, 3.5917725324312572`*^9}, 
   3.591971800358938*^9, 3.591972152161956*^9, {3.6154366314108973`*^9, 
   3.615436634546503*^9}, 
   3.6184912621753073`*^9},ExpressionUUID->"33e13320-2f3b-4c6b-8ee9-\
1798e0b309a6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xx", "'"}], "[", "t", "]"}], ".", 
   RowBox[{
    RowBox[{"xx", "'"}], "[", "t", "]"}]}], "\[Equal]", " ", "1"}]], "Input",
 CellChangeTimes->{{3.5917725466500707`*^9, 3.5917725635370364`*^9}, 
   3.5917727670656776`*^9, {3.5919718012949395`*^9, 
   3.5919718020593405`*^9}},ExpressionUUID->"137e5ed0-5c40-43aa-af6c-\
6d4d047b801d"],

Cell["2.s is the arc length of the rulings (the generating lines)", "Text",
 CellChangeTimes->{{3.5917726476638484`*^9, 3.5917727400471325`*^9}, 
   3.5919721589635677`*^9, {3.592024220246726*^9, 3.5920242610719976`*^9}, 
   3.6184912986169715`*^9},ExpressionUUID->"d9dafea3-91fd-4579-a191-\
afe02fc702c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"yy", "[", "t", "]"}], ".", 
   RowBox[{"yy", "[", "t", "]"}]}], "\[Equal]", " ", "1"}]], "Input",
 CellChangeTimes->{{3.5917727481735973`*^9, 3.591772758993216*^9}, {
  3.5919718461606183`*^9, 
  3.5919718469562197`*^9}},ExpressionUUID->"c6d3f359-73ec-42f0-b3d3-\
67edb07cc161"],

Cell["3. The directrix intersects the rulings orthogonal :", "Text",
 CellChangeTimes->{{3.5917728253350105`*^9, 
  3.5917728708076115`*^9}},ExpressionUUID->"5dadb41c-dfd8-41ac-8a14-\
6858ce16d895"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xx", "'"}], "[", "t", "]"}], ".", 
   RowBox[{"yy", "[", "t", "]"}]}], "\[Equal]", " ", "0"}]], "Input",
 CellChangeTimes->{{3.5917728840893707`*^9, 3.5917728999052753`*^9}, {
  3.5919718565346365`*^9, 
  3.5919718575018387`*^9}},ExpressionUUID->"97fa2253-4826-4340-9f16-\
daa53a0fd344"],

Cell["\<\
These conditions mean that t is the arc length of the directrix and that the \
rulings  are a family of normals of the directrix spanned by unit normal \
vectors of the directrix.
We collect the conditions and their derivatives into\
\>", "Text",
 CellChangeTimes->{{3.591772976055631*^9, 3.5917730201351523`*^9}, 
   3.6281472022053223`*^9, {3.628147237792985*^9, 3.628147262928629*^9}, {
   3.628147298422692*^9, 3.6281474116636915`*^9}, 
   3.707707943782529*^9},ExpressionUUID->"fe3a3539-4922-4b04-9e23-\
fd56dd086d42"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruledcond", "[", 
   RowBox[{"f_", ",", "g_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "t", "]"}], ".", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "t", "]"}]}], "\[Equal]", " ", "1"}], ",", 
    " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "t", "]"}], ".", 
      RowBox[{
       RowBox[{"f", "''"}], "[", "t", "]"}]}], "\[Equal]", " ", "0"}], ",", 
    " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g", "[", "t", "]"}], ".", 
      RowBox[{"g", "[", "t", "]"}]}], "\[Equal]", " ", "1"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"g", "'"}], "[", "t", "]"}], ".", 
      RowBox[{"g", "[", "t", "]"}]}], "\[Equal]", "  ", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "t", "]"}], ".", 
      RowBox[{"g", "[", "t", "]"}]}], " ", "\[Equal]", " ", "0"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f", "''"}], "[", "t", "]"}], ".", 
       RowBox[{"g", "[", "t", "]"}]}], " ", "+", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], "[", "t", "]"}], ".", 
       RowBox[{
        RowBox[{"g", "'"}], "[", "t", "]"}]}]}], " ", "\[Equal]", " ", 
     "0"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5917730578503094`*^9, 3.591773257268716*^9}, {
  3.591773294164826*^9, 3.5917733554303303`*^9}, {3.5917734069742785`*^9, 
  3.5917734221761475`*^9}, {3.5917735277751875`*^9, 3.5917735384467983`*^9}, {
  3.5919718795134773`*^9, 
  3.5919719042083206`*^9}},ExpressionUUID->"f19b588b-f4be-415d-be48-\
ec947651c567"],

Cell[BoxData[
 RowBox[{"ruledcond", "[", 
  RowBox[{"xx", ",", "yy", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5917734434103622`*^9, 
  3.5917734747451544`*^9}},ExpressionUUID->"581b1a88-6515-4330-8e69-\
0251ccff7dc2"],

Cell["\<\
Now we calculate the \[OpenCurlyDoubleQuote]fundamental\
\[CloseCurlyDoubleQuote] invariants of the ruled surface and express them by \
the defining vectors. For the first fundamental form we obtain\
\>", "Text",
 CellChangeTimes->{{3.592024910672739*^9, 3.5920249298295727`*^9}, {
   3.5920258232431417`*^9, 3.592025891040861*^9}, 
   3.618491368785895*^9},ExpressionUUID->"7e2ff632-70a3-4f14-9007-\
78fa76c1c10c"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", "rsf", "]"}], "[", 
      RowBox[{"s", ",", " ", "t"}], "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"u1", ",", "u2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"u1", ",", "u2"}], "}"}]}], "]"}], ",", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592024567659336*^9, {3.6184922379570217`*^9, 3.6184923055051403`*^9}, {
   3.61849235670443*^9, 3.61849236233604*^9}, 3.618493122774976*^9, {
   3.6280871721356506`*^9, 3.6280871832740707`*^9}, 3.6280872203085356`*^9, {
   3.707712067587089*^9, 3.707712123303204*^9}, {3.7077121807368107`*^9, 
   3.707712194173908*^9}, {3.707712240263216*^9, 
   3.7077122684398527`*^9}},ExpressionUUID->"c532b2f0-f4a2-4d8f-aec8-\
bbb0f53c604f"],

Cell["Needed 113.736 s (v. 9.0.1.0). The coefficients are", "Text",
 CellChangeTimes->{{3.707712470184966*^9, 3.707712518006377*^9}, 
   3.70771499267785*^9},ExpressionUUID->"c4d3620e-94ea-4919-9456-\
b1df4d882e1b"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "[", "rsf", "]"}], "[", 
       RowBox[{"s", ",", " ", "t"}], "]"}], "\[Equal]", " ", "1"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592024567659336*^9, {3.592024950874009*^9, 3.5920250921166573`*^9}, 
   3.5920251260467167`*^9, 3.5920257017501283`*^9, 3.6176282336851797`*^9, 
   3.6184923352699924`*^9},ExpressionUUID->"9a1ddc35-ff68-4d66-8481-\
12e564945470"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"1", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
       RowBox[{"s", ",", " ", "t"}], "]"}], "\[Equal]", " ", "0"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592024567659336*^9, {3.592024950874009*^9, 3.5920250784978333`*^9}, 
   3.5920251338467307`*^9, 3.5920251948428383`*^9, 
   3.6176282415886316`*^9},ExpressionUUID->"04bf0e4b-4e00-4d4f-9911-\
2fa477049e2b"],

Cell["Regarding", "Text",
 CellChangeTimes->{{3.707715084375223*^9, 3.707715089038516*^9}, 
   3.7077152143592453`*^9},ExpressionUUID->"f5ffaeb6-586d-41f0-820d-\
228e70b56e5f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
     ")"}], "\[Equal]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}], "[", "2", "]"}], " ", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}], "[", "3", "]"}], " ", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}], "[", "3", "]"}]}]}], ")"}]}]}],
    ",", 
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6184932156419387`*^9, 3.618493233987571*^9}, {
   3.618493313578911*^9, 3.6184933488349724`*^9}, 3.6184959796391935`*^9, 
   3.6184960168452587`*^9, 3.6184960623505383`*^9, {3.6280875750375586`*^9, 
   3.6280875828687725`*^9}, {3.628088359812537*^9, 
   3.6280884551443043`*^9}},ExpressionUUID->"f62fb5f9-7c0e-4353-8ed5-\
f0134f840aba"],

Cell["we confirm", "Text",
 CellChangeTimes->{{3.7077152329162483`*^9, 
  3.707715239460764*^9}},ExpressionUUID->"6acd6922-94b1-465b-bcd1-\
91c35b8bdb80"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"2", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
       RowBox[{"s", ",", " ", "t"}], "]"}], "\[Equal]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"xx", "'"}], "[", "t", "]"}], "+", " ", 
         RowBox[{"s", "*", 
          RowBox[{
           RowBox[{"yy", "'"}], "[", "t", "]"}]}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"xx", "'"}], "[", "t", "]"}], "+", " ", 
         RowBox[{"s", "*", 
          RowBox[{
           RowBox[{"yy", "'"}], "[", "t", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5917889229130664`*^9, 3.5917890378886423`*^9, {
   3.59178994401447*^9, 3.5917900186787405`*^9}, 3.5917933838012147`*^9, {
   3.591793669191538*^9, 3.5917937009843564`*^9}, {3.5917951837611666`*^9, 
   3.5917952037283087`*^9}, {3.591795236712195*^9, 3.591795257680394*^9}, {
   3.5917967300736103`*^9, 3.59179673880011*^9}, 3.5919455581142216`*^9, 
   3.591945593588684*^9, {3.5919476014838104`*^9, 3.5919476613255157`*^9}, {
   3.5919499489159336`*^9, 3.59195003789849*^9}, 3.5920236628265467`*^9, 
   3.592024567659336*^9, {3.592024950874009*^9, 3.5920250784978333`*^9}, 
   3.5920251338467307`*^9, {3.5920251948428383`*^9, 3.5920252157780743`*^9}, {
   3.5920254784357357`*^9, 3.5920255461554546`*^9}, 
   3.6176282474619675`*^9},ExpressionUUID->"cc045246-eaee-49dd-bf96-\
e3698ca80836"],

Cell["The Gaussian curvature is", "Text",
 CellChangeTimes->{{3.5920274989668846`*^9, 3.5920275363757505`*^9}, {
  3.6154383312678833`*^9, 3.615438345729109*^9}, {3.7077153156761913`*^9, 
  3.7077153184435177`*^9}},ExpressionUUID->"012c7565-503f-43d2-b48a-\
89a5c478d7c6"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", "rsf", "]"}], "[", 
     RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, 3.591945531859376*^9, 
   3.5919662569712014`*^9, {3.591966314535302*^9, 3.5919663241605196`*^9}, 
   3.5920236574601374`*^9, {3.62808877711327*^9, 3.628088801464913*^9}, {
   3.628088837953377*^9, 3.6280888486081953`*^9}, {3.6280890791454*^9, 
   3.6280890878658156`*^9}, {3.6280894318464203`*^9, 3.628089467274082*^9}, {
   3.628091090318059*^9, 3.628091101238078*^9}, {3.7077154345124273`*^9, 
   3.7077154473120403`*^9}},ExpressionUUID->"090eb5fb-7866-435a-8353-\
2305f2f611ee"],

Cell["\<\
Needed 258.492 s (v. 9.0.1.0). The result is inserted into the following \
definition:\
\>", "Text",
 CellChangeTimes->{{3.615440149154676*^9, 3.6154401960015583`*^9}, 
   3.6184976289988904`*^9, {3.6281430842494893`*^9, 3.6281430990383153`*^9}, {
   3.6281435810479617`*^9, 3.6281435826703644`*^9}, {3.628143657542761*^9, 
   3.6281436783591976`*^9}, {3.6281442165307493`*^9, 3.628144221602758*^9}, {
   3.6972615536997833`*^9, 3.697261584388329*^9}, {3.70771608327769*^9, 
   3.707716105733922*^9}},ExpressionUUID->"b19ef9a2-2977-4266-b9d5-\
1de554cacae3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "gaussrsf", "]"}], ";", 
  RowBox[{
   RowBox[{"gaussrsf", "[", 
    RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}]}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}],
           ")"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
       ")"}], "2"]}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
           "2"]}], ")"}]}], "-", 
       RowBox[{"2", " ", "s", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}]}], ")"}], "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.697261946198826*^9, 3.697261946210739*^9}, 
   3.697262002817379*^9, {3.707709279101985*^9, 3.7077092904476967`*^9}, {
   3.7077161252672462`*^9, 
   3.707716155829514*^9}},ExpressionUUID->"3f3d5774-ac9d-45d9-b57f-\
b48eda20606e"],

Cell["\<\
Clearly, the Gaussian curvature of a ruled surface is ever non-positive. 
We  calculate the coefficients of the second fundamental form with respect to \
the cobasis \[Sigma][1], \[Sigma][2]:\
\>", "Text",
 CellChangeTimes->{{3.591971612569808*^9, 3.591971643707463*^9}, {
   3.5920275682310066`*^9, 3.592027618712695*^9}, {3.5920276500999503`*^9, 
   3.592027688772418*^9}, 3.592046285230348*^9, {3.6154383708919525`*^9, 
   3.6154383797527685`*^9}, {3.628144104260951*^9, 
   3.628144171317869*^9}},ExpressionUUID->"00d4d11b-9e24-4a93-94a7-\
06eeead1525f"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cf", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "[", "rsf", "]"}], "[", 
    RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5919455433721952`*^9, 3.59202365875494*^9, 
   3.5920277181784697`*^9, 3.5920277515937285`*^9, 3.617972115784997*^9, {
   3.69726217126197*^9, 
   3.697262216079939*^9}},ExpressionUUID->"1e61fb05-5377-45be-928d-\
6ae4d93e6dec"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsfc", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.5917888627836275`*^9, 3.591788891982297*^9}, 
   3.592027795305005*^9, {3.5920463146675997`*^9, 3.592046340828846*^9}, 
   3.592046432603807*^9, 
   3.592046856191351*^9},ExpressionUUID->"63157f28-34c6-45ea-a2ae-\
42d239625133"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
     RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
    RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5919455433721952`*^9, 3.59202365875494*^9, 
   3.5920277181784697`*^9, 3.5920277515937285`*^9, 3.617972115784997*^9, {
   3.69726217126197*^9, 3.697262216079939*^9}, 3.697262319577402*^9, {
   3.707716605657151*^9, 
   3.7077166349108887`*^9}},ExpressionUUID->"692290b7-b679-4ecf-b467-\
c1f8bf2bf44a"],

Cell["The result is entered in the following definition:", "Text",
 CellChangeTimes->{{3.615440149154676*^9, 3.6154401960015583`*^9}, 
   3.6184976289988904`*^9, {3.6281430842494893`*^9, 3.6281430990383153`*^9}, {
   3.6281435810479617`*^9, 3.6281435826703644`*^9}, {3.628143657542761*^9, 
   3.6281436783591976`*^9}, {3.6281442165307493`*^9, 
   3.628144221602758*^9}},ExpressionUUID->"b1ceedcb-427d-4d22-a979-\
82797ad57530"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rsfc", "[", 
     RowBox[{"1", ",", " ", "2"}], "]"}], "[", 
    RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "-", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
          " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "-", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
          "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}]}]}], "\n"}]], "Input",
 CellChangeTimes->{{3.592046383806921*^9, 3.592046453539044*^9}, {
   3.614861859285139*^9, 3.614861859347539*^9}, {3.6149177910937595`*^9, 
   3.6149177911561604`*^9}, {3.615439089538415*^9, 3.615439122516873*^9}, {
   3.615439153966528*^9, 3.6154392339010687`*^9}, {3.628144258159622*^9, 
   3.628144268689641*^9}, 3.697262416214381*^9, 3.697262470566272*^9, 
   3.707716923020482*^9},ExpressionUUID->"5cdf5ff3-5e50-45cd-8349-\
2a81288f2871"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsfc", "[", 
    RowBox[{"2", ",", "1"}], "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"rsfc", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "[", 
   RowBox[{"s", ",", " ", "t"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.5920285948376093`*^9, 3.5920286219348574`*^9}, {
  3.5920464791854887`*^9, 
  3.5920465062983365`*^9}},ExpressionUUID->"52a90903-10a1-49f4-a1b7-\
9113a01ee7e3"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "[", "rsf", "]"}], "[", 
     RowBox[{"s", ",", " ", "t"}], "]"}], ",", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
    RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.591773629631014*^9, 3.591773714170849*^9}, {
   3.5917737484678106`*^9, 3.5917737560822463`*^9}, {3.591773808723257*^9, 
   3.591773814242573*^9}, {3.591775768244335*^9, 3.5917757816751037`*^9}, {
   3.5917786327132173`*^9, 3.591778658722705*^9}, {3.591788739317565*^9, 
   3.591788759352711*^9}, 3.5919455433721952`*^9, 3.59202365875494*^9, 
   3.5920277181784697`*^9, 3.5920277515937285`*^9, 3.617972115784997*^9, {
   3.69726217126197*^9, 3.697262216079939*^9}, 3.697262319577402*^9, 
   3.697262545584474*^9, {3.70770948461515*^9, 
   3.7077095010720263`*^9}},ExpressionUUID->"5aa51158-97ac-4bde-93f8-\
eaf13d6965ed"],

Cell["\<\
Needed 2344.532 s = 39 min (v. 9.0,1,0).
The result is inserted into the following definition:\
\>", "Text",
 CellChangeTimes->{{3.707719563751473*^9, 3.707719565679947*^9}, {
  3.707719596870851*^9, 3.7077196153865833`*^9}, {3.70771966077185*^9, 
  3.707719721859477*^9}},ExpressionUUID->"0119b3be-c224-4615-93f4-\
a85a5f30221e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsfc", "[", 
    RowBox[{"2", ",", " ", "2"}], "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
           RowBox[{"s", " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["s", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}],
           ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "-", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "+", 
           RowBox[{"s", " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["s", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "+", 
           RowBox[{"s", " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{"s", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["s", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
           "-", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
            " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"],
          "+", 
         SuperscriptBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
          "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", "s", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
        ")"}]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]}]], "Input",
 CellChangeTimes->{{3.618548391200186*^9, 3.61854839374299*^9}, 
   3.6185484318850574`*^9, {3.69726298905584*^9, 
   3.69726302393178*^9}},ExpressionUUID->"3d7ac983-5996-4834-aea0-\
ae2da64728a6"],

Cell["\<\
 The Gaussian curvature is the determinant of these coefficients, see Section \
3.2\
\>", "Text",
 CellChangeTimes->{{3.5920281482400255`*^9, 3.592028194182106*^9}, {
  3.5920282896542735`*^9, 
  3.5920282970642867`*^9}},ExpressionUUID->"3e22ef9d-d97e-401d-b36f-\
317214820c74"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Krsf", "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], ":=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{
     RowBox[{"rsfc", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.7077107368936367`*^9, 3.7077107944956207`*^9}, 
   3.707719824438579*^9},ExpressionUUID->"0bfbc56d-d24d-4012-8c25-\
8449aaab9617"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Krsf", "[", 
     RowBox[{"s", ",", "t"}], "]"}], ",", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.707710807190404*^9, 3.707710922352151*^9}, {
  3.7077199061105824`*^9, 
  3.7077199955900173`*^9}},ExpressionUUID->"3dd92597-b7ce-4a22-8081-\
a3532c606ae8"],

Cell["\<\
Mathematica needed 336.468 s for this calculation. The result is inserted \
into the following definition:\
\>", "Text",
 CellChangeTimes->{{3.615440149154676*^9, 3.6154401960015583`*^9}, 
   3.6184976289988904`*^9, {3.6281430842494893`*^9, 3.6281430990383153`*^9}, {
   3.6281435810479617`*^9, 3.6281435826703644`*^9}, {3.628143657542761*^9, 
   3.6281436783591976`*^9}, {3.6281442165307493`*^9, 3.628144221602758*^9}, {
   3.697263355381983*^9, 3.697263368685902*^9}, {3.697264140808752*^9, 
   3.6972641528086863`*^9}, {3.69726419484968*^9, 
   3.697264216288308*^9}},ExpressionUUID->"2c3f709e-bbc1-4d3a-a712-\
c593511a87f5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Krsf", "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
       "+", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], "2"], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
         "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}]}], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
          "+", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
         ")"}], "2"]}], ")"}], "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SuperscriptBox["s", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], 
            "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], 
            "2"], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
            "2"]}], ")"}]}], "-", 
        RowBox[{"2", " ", "s", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], 
           "+", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}],
           ")"}]}]}], ")"}], "2"]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5920466545921965`*^9, 3.592046673967431*^9}, {
  3.6148618596127396`*^9, 3.61486185967514*^9}, {3.6149177914057603`*^9, 
  3.6149177914681606`*^9}, {3.618549408914773*^9, 3.618549437447223*^9}, {
  3.697263380712914*^9, 3.6972633816155157`*^9}, {3.6972642608921833`*^9, 
  3.69726429972911*^9}},ExpressionUUID->"310b1c95-3dfa-44b2-bd2b-\
be7289949438"],

Cell[TextData[{
 StyleBox["It follows the",
  FontColor->GrayLevel[0]],
 StyleBox["\nCriterion.",
  FontColor->RGBColor[0, 0, 1]],
 " The ruled surface rsf[s, t] := xx[t] + s*yy][t], where xx, yy satisfy the \
conditions "
}], "Text",
 CellChangeTimes->{{3.5919695796873407`*^9, 3.5919695872065535`*^9}, {
   3.591969771286877*^9, 3.5919698988795013`*^9}, {3.5919699317799587`*^9, 
   3.5919699517635937`*^9}, 3.592023584436409*^9, {3.592029928671152*^9, 
   3.5920299343651624`*^9}, {3.5920470783513412`*^9, 3.592047080753745*^9}, {
   3.5922183538404703`*^9, 3.592218371311469*^9}, {3.625804454478113*^9, 
   3.6258044586121206`*^9}},ExpressionUUID->"3be26655-ad43-4ed2-bb4f-\
49e6c82559e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruledcond", "[", 
   RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"xx", "'"}], ".", 
      RowBox[{"xx", "'"}]}], "\[Equal]", "1"}], ",", " ", 
    RowBox[{
     RowBox[{"yy", ".", "yy"}], " ", "\[Equal]", " ", "1"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"xx", "'"}], ".", "yy"}], "\[Equal]", " ", "0"}]}], 
   "}"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.591969981590846*^9, 3.5919701060166655`*^9}, {
   3.592047093514568*^9, 3.5920470950589705`*^9}, 
   3.6185546260787363`*^9},ExpressionUUID->"c0b7be6a-0318-4a82-97b3-\
49c390bb00cd"],

Cell["has the Gaussian curvature", "Text",
 CellChangeTimes->{{3.5920299951116695`*^9, 
  3.5920300221777163`*^9}},ExpressionUUID->"b017206b-f4c6-4658-97ea-\
9fdc2e559e3e"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Krsf", "(", 
    RowBox[{"s", ",", "t"}], ")"}], "\[LongEqual]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}], ".", 
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["xx", "\[Prime]",
           MultilineFunction->None], "(", "t", ")"}], ".", 
         RowBox[{
          SuperscriptBox["yy", "\[Prime]",
           MultilineFunction->None], "(", "t", ")"}]}], ")"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s", " ", 
           RowBox[{
            SuperscriptBox["yy", "\[Prime]",
             MultilineFunction->None], "(", "t", ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["xx", "\[Prime]",
            MultilineFunction->None], "(", "t", ")"}]}], ")"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s", " ", 
           RowBox[{
            SuperscriptBox["yy", "\[Prime]",
             MultilineFunction->None], "(", "t", ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["xx", "\[Prime]",
            MultilineFunction->None], "(", "t", ")"}]}], ")"}]}], ")"}], 
      "2"]]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.592030032660935*^9, 3.5920301076346664`*^9}, {
   3.592030144840732*^9, 3.5920302698905516`*^9}, 3.592032530350122*^9, 
   3.5920471394254484`*^9},ExpressionUUID->"6c665418-4996-4588-bb5e-\
c568d427c186"],

Cell["The surface is developable iff ", "Text",
 CellChangeTimes->{{3.591970202222034*^9, 3.591970227213278*^9}, {
  3.5919702655562363`*^9, 3.591970270403514*^9}, {3.5920303196546392`*^9, 
  3.592030324241047*^9}},ExpressionUUID->"be0c7775-6726-40ca-95bc-\
127cd77fd09b"],

Cell[BoxData[
 FormBox[
  RowBox[{"(*", 
   RowBox[{
    RowBox[{")", "                          ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["yy", "\[Prime]",
        MultilineFunction->None], "(", "t", ")"}], ".", 
      RowBox[{
       SuperscriptBox["yy", "\[Prime]",
        MultilineFunction->None], "(", "t", ")"}]}]}], "\[LongEqual]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["yy", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}], ".", 
        RowBox[{
         SuperscriptBox["xx", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}]}], ")"}], "2"], "."}]}]}],
   TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
   3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
   3.5920474186035385`*^9}, {3.6116464842946773`*^9, 
   3.611646496306698*^9}},ExpressionUUID->"404aed06-b785-4883-8593-\
9e7982f49729"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". First we check the formula for the curvature  Krsf[s,t]:"
}], "Text",
 CellChangeTimes->{{3.591970572095769*^9, 3.591970666820187*^9}, {
   3.5919707419874864`*^9, 3.591970840188103*^9}, {3.5919710737404613`*^9, 
   3.5919710961077414`*^9}, {3.591971168891904*^9, 3.591971219956825*^9}, {
   3.5919712500365453`*^9, 3.591971385892316*^9}, {3.5919714409454646`*^9, 
   3.591971459415521*^9}, {3.5919714898212605`*^9, 3.591971502003957*^9}, {
   3.592030403785587*^9, 3.5920304817545238`*^9}, {3.5920305450906353`*^9, 
   3.5920305474462395`*^9}, {3.5920326139818687`*^9, 
   3.5920326269922915`*^9}, {3.592047221075992*^9, 3.5920472221835938`*^9}, {
   3.615442227593127*^9, 3.6154423098988714`*^9}, 3.618553138569324*^9, {
   3.618553195618624*^9, 3.618553225009076*^9}, {3.61855355192325*^9, 
   3.6185535876161127`*^9}},ExpressionUUID->"c479a0de-1990-4e92-9201-\
a957eef82ee0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Krsf", "[", 
     RowBox[{"s", ",", "t"}], "]"}], " ", "\[Equal]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"yy", "'"}], "[", "t", "]"}], ".", 
         RowBox[{
          RowBox[{"yy", "'"}], "[", "t", "]"}]}], " ", "-", 
        RowBox[{
         RowBox[{"(", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"xx", "'"}], "[", "t", "]"}], ".", 
           RowBox[{
            RowBox[{"yy", "'"}], "[", "t", "]"}]}], ")"}], "^", "2"}]}], 
       ")"}]}], "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"xx", "'"}], "[", "t", "]"}], " ", "+", 
          RowBox[{"s", "*", 
           RowBox[{
            RowBox[{"yy", "'"}], "[", "t", "]"}]}]}], ")"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"xx", "'"}], "[", "t", "]"}], " ", "+", 
          RowBox[{"s", "*", 
           RowBox[{
            RowBox[{"yy", "'"}], "[", "t", "]"}]}]}], ")"}]}], ")"}], "^", 
      "2"}]}]}], ",", 
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"TimeConstraint", " ", "->", " ", "Infinity"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592030563233467*^9, 3.592030592951519*^9}, {
   3.5920314597202415`*^9, 3.5920314666778536`*^9}, {3.5920315132439356`*^9, 
   3.592031539623582*^9}, 3.592031682098632*^9, {3.592032371151842*^9, 
   3.5920323779846544`*^9}, {3.592032515015295*^9, 3.5920325452325478`*^9}, {
   3.592032592266631*^9, 3.5920325936082335`*^9}, {3.697264578079349*^9, 
   3.697264605263988*^9}, 
   3.697264813965197*^9},ExpressionUUID->"9c37259d-ac33-44e5-9a87-\
eee795318168"],

Cell["\<\
 A surface, in particular a ruled surface, is developable iff its Gaussian \
curvature equals zero, see  Subsection 2.2.3. Thus the ruled surface is \
developable iff condition (*) is valid   \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.5920326603919506`*^9, 3.5920326808747864`*^9}, {
   3.5920327676577387`*^9, 3.5920328681687155`*^9}, {3.5920473610394373`*^9, 
   3.5920473823490753`*^9}, {3.592047433064764*^9, 3.592047457588007*^9}, {
   3.5920477355725155`*^9, 3.5920477384756813`*^9}, 3.6154423422533283`*^9, {
   3.615443194014824*^9, 3.615443196276828*^9}, {3.618553735753973*^9, 
   3.6185537650040245`*^9}, 
   3.628147613802648*^9},ExpressionUUID->"23ffbc66-21f1-4eae-ba96-\
c483cb317f30"],

Cell[TextData[{
 StyleBox["Corollary.",
  FontColor->RGBColor[0, 0, 1]],
 " The condition (*) can be written in the form"
}], "Text",
 CellChangeTimes->{{3.615443353993105*^9, 3.615443453926881*^9}, 
   3.615443697817709*^9, 3.6154437382841797`*^9, 
   3.6185539467131433`*^9},ExpressionUUID->"d197ca8a-b52f-4a6b-8a49-\
35ecfbc1d27b"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(*", "*)"}], "                       ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["xx", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}], " ", ".", 
       RowBox[{
        SuperscriptBox["xx", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}], ")"}], "*", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}], ".", 
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}], ")"}]}], "\[LongEqual]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["yy", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}], ".", 
        RowBox[{
         SuperscriptBox["xx", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}]}], ")"}], "2"], "."}]}]}],
   TraditionalForm]],
 Evaluatable->False,
 CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
   3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
   3.5920474186035385`*^9}, {3.6116464842946773`*^9, 
   3.611646496306698*^9}},ExpressionUUID->"31ce42d1-1a4d-4570-8c13-\
18c29e9a1ee3"]], "Text",
 CellChangeTimes->{{3.6154435063429728`*^9, 3.615443534313822*^9}, {
  3.615443574858293*^9, 3.6154436171811676`*^9}, {3.6154436514544277`*^9, 
  3.6154436537008314`*^9}, {3.6154437181133447`*^9, 3.6154437181133447`*^9}, {
  3.615443791183873*^9, 
  3.615443791183873*^9}},ExpressionUUID->"bf0544a4-d2a3-4890-8e1a-\
693f23234f85"],

Cell["A ruled surface", "Text",
 CellChangeTimes->{{3.615444030473133*^9, 3.615444048054364*^9}, {
  3.618554659743596*^9, 
  3.6185546844384394`*^9}},ExpressionUUID->"a6c2de0d-8c75-4ba5-b1ed-\
6921a87ebd61"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruled", "[", 
   RowBox[{"xx", ",", "yy"}], "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.615444057507981*^9, 3.6154440603159857`*^9}, {
  3.6154441029508605`*^9, 
  3.615444114292081*^9}},ExpressionUUID->"af5ccf33-b708-46e7-80fc-\
c06e5aec2e98"],

Cell[TextData[{
 " satisfying  the conditions yy(t).yy(t)==1 and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"yy", "(", "t", ")"}], ".", 
    RowBox[{
     SuperscriptBox["xx", "\[Prime]",
      MultilineFunction->None], "(", "t", ")"}]}], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
    3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
    3.5920474186035385`*^9}, {3.6116464842946773`*^9, 3.611646496306698*^9}},
  ExpressionUUID->"d97f2ca6-dd99-471b-9f30-cc09fd8fb613"],
 " == 0 is developable iff condition (**) is  satisfied, t an arbitrary \
parameter.\n",
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " Remember: the conditions yy(t).yy(t)==1 and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"yy", "(", "t", ")"}], ".", 
    RowBox[{
     SuperscriptBox["xx", "\[Prime]",
      MultilineFunction->None], "(", "t", ")"}]}], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
    3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
    3.5920474186035385`*^9}, {3.6116464842946773`*^9, 3.611646496306698*^9}},
  ExpressionUUID->"54795f70-b360-4d37-a4bf-1206138f8ef0"],
 " == 0 being assumed in addition to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["xx", "\[Prime]",
      MultilineFunction->None], "(", "t", ")"}], " ", ".", 
    RowBox[{
     SuperscriptBox["xx", "\[Prime]",
      MultilineFunction->None], "(", "t", ")"}]}], TraditionalForm]],
  Evaluatable->False,
  CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
    3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
    3.5920474186035385`*^9}, {3.6116464842946773`*^9, 3.611646496306698*^9}},
  ExpressionUUID->"0deeeffb-3f07-4daf-8fb9-01d20b77fe4d"],
 " == 1 as we calculated the Gaussian curvature; the other three conditions \
in ruledcond follow by deriving those.  If t is the arc length of the curve \
xx[t] condition [**) reduces to (*) and is proved. Now condition (**) is \
invariant under a parameter transformation. Thus the criterion is valid for \
any parametrizations  of xx[t], yy[t].\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.615444168190175*^9, 3.6154444057473927`*^9}, {
   3.615444442173456*^9, 3.6154444708775067`*^9}, 3.615444591231718*^9, {
   3.6154446991215076`*^9, 3.615444904449068*^9}, {3.6154449408595324`*^9, 
   3.6154449687991815`*^9}, {3.615445015068863*^9, 3.6154450421193104`*^9}, {
   3.618554242692463*^9, 3.6185542543768835`*^9}, {3.618554289866946*^9, 
   3.6185543196317987`*^9}, {3.618554692082453*^9, 3.6185547207709026`*^9}, 
   3.618554780019807*^9, {3.6185548133258657`*^9, 3.618554836772707*^9}, {
   3.6185548901092005`*^9, 3.618554909624835*^9}, {3.6185549522753096`*^9, 
   3.6185550958111615`*^9}},ExpressionUUID->"9c2b9634-f75e-4b44-a66d-\
c8cbada5f483"],

Cell["Now we calculate the mean curvature of a ruled surface:", "Text",
 CellChangeTimes->{{3.5921135377560663`*^9, 3.592113576865335*^9}, {
  3.6185605679688683`*^9, 3.6185605756163054`*^9}, {3.697268494421253*^9, 
  3.6972685350288553`*^9}},ExpressionUUID->"37d23128-3a75-489c-89bd-\
7a3d4d61a8e1"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"meancurvature", "[", "rsf", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], ",", 
    RowBox[{"ruledcond", "[", 
     RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5919676261801605`*^9, 3.591967669766637*^9}, {
   3.591967706021101*^9, 3.5919677109039097`*^9}, {3.591967770386814*^9, 
   3.5919678540029607`*^9}, {3.5920491350405607`*^9, 
   3.5920492534233313`*^9}, {3.592049573543641*^9, 3.5920496692571154`*^9}, {
   3.592049704033105*^9, 3.5920497102974634`*^9}, 3.592050945314102*^9, {
   3.5920511461695905`*^9, 3.592051226626192*^9}, 3.592055181657555*^9, 
   3.592055268737536*^9, {3.5920553221935935`*^9, 3.592055377169738*^9}, 
   3.592058731034568*^9, {3.592112568931965*^9, 3.592112574875575*^9}, 
   3.5921126374472847`*^9, {3.592113589844558*^9, 3.592113639499445*^9}, 
   3.61486186009634*^9, 3.614863136599783*^9, {3.628160648918606*^9, 
   3.628160689917478*^9}},ExpressionUUID->"1eb4aeda-5829-47ef-a996-\
5eeb210487f6"],

Cell["The time needed was 535.804 s; 47.752 s. with v. 9.0.1.1!", "Text",
 CellChangeTimes->{{3.69726868275954*^9, 3.697268709781932*^9}, 
   3.69752223612388*^9, {3.707721868843294*^9, 
   3.7077219200178623`*^9}},ExpressionUUID->"6ae081c5-7204-46e3-9987-\
f1c99817fb08"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"rsfc", "[", 
          RowBox[{"1", ",", "1"}], "]"}], "[", 
         RowBox[{"s", ",", "t"}], "]"}], "+", 
        RowBox[{
         RowBox[{"rsfc", "[", 
          RowBox[{"2", ",", "2"}], "]"}], "[", 
         RowBox[{"s", ",", "t"}], "]"}]}], ")"}], "/", "2"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5919676261801605`*^9, 3.591967669766637*^9}, {
   3.591967706021101*^9, 3.5919677109039097`*^9}, {3.591967770386814*^9, 
   3.5919678540029607`*^9}, {3.5920491350405607`*^9, 
   3.5920492534233313`*^9}, {3.592049573543641*^9, 3.5920496692571154`*^9}, {
   3.592049704033105*^9, 3.5920497102974634`*^9}, 3.592050945314102*^9, {
   3.5920511461695905`*^9, 3.592051226626192*^9}, 3.592055181657555*^9, 
   3.592055268737536*^9, {3.5920553221935935`*^9, 3.592055377169738*^9}, 
   3.592058731034568*^9, {3.592112568931965*^9, 3.592112574875575*^9}, 
   3.5921126374472847`*^9, {3.592113589844558*^9, 3.592113639499445*^9}, {
   3.5921139773804383`*^9, 3.592114013931303*^9}, {3.5921140833046246`*^9, 
   3.592114101431856*^9}, 3.5921143285994554`*^9, {3.5921143809843473`*^9, 
   3.592114405835191*^9}, 
   3.6116650552848954`*^9},ExpressionUUID->"077e624d-5f45-4aea-83a0-\
35bb86d5971f"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"ruledcond", "[", 
    RowBox[{"xx", ",", "yy", ",", "t"}], "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"%", "-", 
     RowBox[{"%%", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6185612597444353`*^9, 3.6185613193158426`*^9}, 
   3.628164622736604*^9, 3.6281647920391026`*^9, 3.6281648369545813`*^9, {
   3.6281649802910337`*^9, 3.628165010511287*^9}, {3.6975224179861526`*^9, 
   3.697522431082242*^9}, {3.697522465574813*^9, 
   3.697522465769515*^9}},ExpressionUUID->"623f8eec-4d79-4422-b5d3-\
d59363c3a1c5"],

Cell["OK.", "Text",
 CellChangeTimes->{{3.592114541290229*^9, 
  3.592114545346236*^9}},ExpressionUUID->"e79b014f-e650-4984-9e29-\
7d90d04f8321"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.8. The Normal Congruences", "Subsection",
 CellChangeTimes->{{3.591688363105586*^9, 3.5916883848832245`*^9}, 
   3.5917714021446085`*^9, 3.5985964668405457`*^9, 3.615451802305699*^9, 
   3.615559274768277*^9, 3.6280851857685623`*^9, 3.628176387948323*^9, 
   3.629013005046713*^9, 3.697268834187353*^9, 
   3.6972703668389263`*^9},ExpressionUUID->"8b22a6db-912d-4452-9cfb-\
d188d5ba53ce"],

Cell[CellGroupData[{

Cell["3.8.1. Normal Congruence of a Regular Curve", "Subsubsection",
 CellChangeTimes->{{3.592115389572919*^9, 3.592115426638584*^9}, 
   3.5921354646825233`*^9, 3.5922182112163124`*^9, 3.5942701628864923`*^9, 
   3.598596137570768*^9, 3.6116673526853304`*^9, 3.6119986168238125`*^9, {
   3.6155592477178297`*^9, 3.615559249355833*^9}, 3.6161383195804777`*^9, 
   3.618564015369048*^9, 3.6186374644950294`*^9, 3.6280852651103015`*^9, 
   3.6282292445934086`*^9, {3.6282293236387477`*^9, 3.6282293292235575`*^9}, 
   3.6282293736836357`*^9, {3.6282294187833147`*^9, 3.6282294761602154`*^9}, 
   3.697270372712083*^9, 3.697371142906358*^9, 3.707721998363308*^9, 
   3.707727932601667*^9},
 CellTags->"helix",ExpressionUUID->"3abc168c-34a2-4447-ac4f-468453c34aa0"],

Cell[TextData[{
 "The family of all normals to a given curve forms a 2-dimensional family of \
lines: ",
 StyleBox["The normal congruence of the curve",
  FontColor->RGBColor[0, 0, 1]],
 ". Let s be the arc length of a general curve xx[s] in the Euclidean \
3-space. "
}], "Text",
 CellChangeTimes->{
  3.6282296190564666`*^9, {3.6282299000909605`*^9, 3.6282299640354724`*^9}, {
   3.628230007684349*^9, 
   3.6282300308659897`*^9}},ExpressionUUID->"85ca6593-504e-4fae-8758-\
24f0511b04e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"vec", "[", 
   RowBox[{"x", "[", "s", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.62823004226961*^9, 
  3.6282301137957354`*^9}},ExpressionUUID->"e6c511b1-7795-4518-bb5e-\
a6919415cd4e"],

Cell[BoxData[
 RowBox[{"xx", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.628230120300947*^9, 
  3.628230123873353*^9}},ExpressionUUID->"639f2f7b-c8f1-4915-a878-\
c8898cc13ca3"],

Cell[TextData[{
 " A general parameter representation of the ",
 StyleBox["normal congruence",
  FontColor->RGBColor[0, 0, 1]],
 "  of the curve x[s] is"
}], "Text",
 CellChangeTimes->{{3.628230407809452*^9, 3.6282304976812096`*^9}, {
   3.628230763240476*^9, 3.628230770603689*^9}, 
   3.707722383777554*^9},ExpressionUUID->"659830d0-3630-4925-a8cf-\
41d566933c8c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normalcongruence", "[", "x_", "]"}], "[", 
   RowBox[{"a_", ",", "s_", ",", "t_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"x", "[", "s", "]"}], " ", "+", " ", 
   RowBox[{"t", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"frenet", "[", "x", "]"}], "[", "s", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], "*", 
       RowBox[{"Cos", "[", "a", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"frenet", "[", "x", "]"}], "[", "s", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}], "*", 
       RowBox[{"Sin", "[", "a", "]"}]}]}], ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6282305071348267`*^9, 3.628230645195069*^9}, {
  3.628230675849123*^9, 
  3.628230714568391*^9}},ExpressionUUID->"b5ea359d-4713-440f-9582-\
75f3911b757f"],

Cell[TextData[{
 "Here t is the line parameter and a is the angle between the normal and the \
principal normal vector of the curve at the same point.\n\nAs an application \
we can give  a parameter representation for the ",
 StyleBox["tube of radius r ",
  FontColor->RGBColor[0, 0, 1]],
 "of the curve x[s]"
}], "Text",
 CellChangeTimes->{{3.6282323211528125`*^9, 3.6282324109777703`*^9}, {
  3.628250775620305*^9, 3.6282508493540354`*^9}, {3.697270788227778*^9, 
  3.697270822971571*^9}, {3.697270855651045*^9, 
  3.697270889235423*^9}},ExpressionUUID->"54b38af0-060d-4a6a-a9a7-\
fa27513f49f0"],

Cell[BoxData[
 RowBox[{"?", "tube"}]], "Input",
 CellChangeTimes->{{3.6282320050494576`*^9, 3.628232007249061*^9}, 
   3.6282322482070847`*^9},ExpressionUUID->"030eb3f9-ee16-49f6-ae8a-\
4e0e543c6ca5"],

Cell[BoxData[
 RowBox[{"Context", "[", "tube", "]"}]], "Input",
 CellChangeTimes->{{3.6282319533977666`*^9, 
  3.6282319788570113`*^9}},ExpressionUUID->"49490af0-31b8-4231-a8b0-\
810c0b8507cc"],

Cell["A parameter representation of the tube is", "Text",
 CellChangeTimes->{{3.628400068168715*^9, 
  3.628400082785941*^9}},ExpressionUUID->"b2c92de5-7fa4-492e-8c4c-\
dc36e57a5e9f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tubepr", "[", 
    RowBox[{"x_", ",", "r_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"normalcongruence", "[", "x", "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "r"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6282317535458155`*^9, 3.628231854462393*^9}, {
   3.628231918765706*^9, 3.628231926284919*^9}, {3.6282322056190095`*^9, 
   3.628232206711012*^9}, 
   3.6282328058924637`*^9},ExpressionUUID->"1313255f-e6dd-4a67-afdf-\
5644f61aba12"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"tubepr", "[", 
      RowBox[{
       RowBox[{"helix", "[", 
        RowBox[{"1", ",", "1"}], "]"}], ",", "0.5"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"6", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6282325317219825`*^9, 3.628232644775381*^9}, {
  3.628232735770341*^9, 3.6282327467059603`*^9}, {3.6282328547985497`*^9, 
  3.628232896965424*^9}},ExpressionUUID->"9761b552-9bf7-4c61-9d82-\
da738d80d0d3"],

Cell["The same picture can be obtained directly using tube:", "Text",
 CellChangeTimes->{{3.6282506795237355`*^9, 
  3.6282507070773845`*^9}},ExpressionUUID->"a4ff0bcb-7e7a-4f37-a130-\
47956801fe78"],

Cell[BoxData[
 RowBox[{"tube", "[", 
  RowBox[{
   RowBox[{"helix", "[", 
    RowBox[{"1", ",", "1"}], "]"}], ",", "0", ",", 
   RowBox[{"6", "*", "Pi"}], ",", "0.5"}], "]"}]], "Input",
 CellChangeTimes->{{3.6282329207554655`*^9, 3.628232939023098*^9}, {
  3.6282329695835514`*^9, 
  3.628233007320018*^9}},ExpressionUUID->"9e3a19a1-1665-46dd-a7b4-\
c97959b5d28e"],

Cell[TextData[{
 "Our aim now is to answer the following question: Choose a normal at each \
point of the curve fixing a = a[s].  For which functions a = a[s]  the ruled \
surface formed by the chosen normals is developable?  We will apply the \
criterion of Subsection 3.7 \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"(*", 
    RowBox[{
     RowBox[{")", "                          ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}], ".", 
       RowBox[{
        SuperscriptBox["yy", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}]}], "\[LongEqual]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["yy", "\[Prime]",
           MultilineFunction->None], "(", "t", ")"}], ".", 
         RowBox[{
          SuperscriptBox["xx", "\[Prime]",
           MultilineFunction->None], "(", "t", ")"}]}], ")"}], "2"], 
      "."}]}]}], TraditionalForm]], "Input",
  Evaluatable->False,
  CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
    3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
    3.5920474186035385`*^9}, {3.6116464842946773`*^9, 3.611646496306698*^9}},
  ExpressionUUID->"7ee97914-6e63-4fc5-b502-b6922718d2ee"]
}], "Text",
 CellChangeTimes->{{3.628250887457303*^9, 3.6282509321709814`*^9}, {
   3.6282509730470533`*^9, 3.628251000538302*^9}, {3.628251066394018*^9, 
   3.628251250685543*^9}, {3.6282512808599963`*^9, 3.6282513758605638`*^9}, 
   3.6282516328798175`*^9, {3.628400123018411*^9, 3.6284001464808526`*^9}, 
   3.697366424832191*^9, {3.697366495506641*^9, 3.697366520183926*^9}, 
   3.697366564310951*^9, 
   3.707722510446398*^9},ExpressionUUID->"9fd54936-98f4-49a3-8ed3-\
79fad6ce856b"],

Cell["with xx[s] and", "Text",
 CellChangeTimes->{{3.628250887457303*^9, 3.6282509321709814`*^9}, {
   3.6282509730470533`*^9, 3.628251000538302*^9}, {3.628251066394018*^9, 
   3.628251250685543*^9}, {3.6282512808599963`*^9, 3.6282513758605638`*^9}, 
   3.6282516328798175`*^9, {3.628400123018411*^9, 3.6284001464808526`*^9}, 
   3.697366424832191*^9},ExpressionUUID->"a1287af2-aab1-460b-a4c6-\
d4c8decafc6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"yy", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"frenet", "[", "xx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"a", "[", "s", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"frenet", "[", "xx", "]"}], "[", "s", "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}], "*", 
    RowBox[{"Sin", "[", 
     RowBox[{"a", "[", "s", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6282513797957706`*^9, 3.628251400372207*^9}, {
  3.6282514540599017`*^9, 
  3.62825150394119*^9}},ExpressionUUID->"09137a31-fbb7-468a-a6c0-\
69295c21490c"],

Cell["\<\
We solve the problem using the Frenet formulas of curve theory. \
\>", "Text",
 CellChangeTimes->{{3.6284026131571856`*^9, 3.6284026911573224`*^9}, {
   3.6973667918129883`*^9, 3.6973668233167*^9}, 3.6973668671980457`*^9, 
   3.697366974738091*^9},ExpressionUUID->"5490625b-4ede-4167-876d-\
0f35d065f3e4"],

Cell[BoxData[
 RowBox[{"?", "frenet"}]], "Input",
 CellChangeTimes->{{3.6288355030534844`*^9, 
  3.62883550625149*^9}},ExpressionUUID->"49763cd1-0c40-4379-90d4-\
09e266127f7e"],

Cell["For shortness we omit the arc length variable s and set", "Text",
 CellChangeTimes->{{3.6284026131571856`*^9, 3.6284026911573224`*^9}, {
   3.6973667918129883`*^9, 3.6973668233167*^9}, 3.6973668671980457`*^9, 
   3.6973669906993237`*^9},ExpressionUUID->"717849df-68c5-4abc-bb44-\
28a5c3eeec00"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fre", "[", "i_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"frenet", "[", "xx", "]"}], "[", "s", "]"}], "[", 
    RowBox[{"[", "i", "]"}], "]"}]}], ";", 
  RowBox[{"k", " ", "=", " ", 
   RowBox[{
    RowBox[{"curvature", "[", "xx", "]"}], "[", "s", "]"}]}], ";", " ", 
  RowBox[{"\[Kappa]", " ", "=", " ", 
   RowBox[{"torsion", "[", 
    RowBox[{"xx", "[", "s", "]"}], "]"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.628403621652157*^9, 3.628403775998828*^9}, 
   3.628835461027011*^9, {3.697367155546625*^9, 
   3.697367179114779*^9}},ExpressionUUID->"78dfcf1c-c173-41f8-b589-\
576372c1b1d0"],

Cell["Applying the Frenet formulas we obtain", "Text",
 CellChangeTimes->{{3.6284037918484554`*^9, 
  3.6284038282589197`*^9}},ExpressionUUID->"485db3bb-bd41-4504-9600-\
3ed18b1daaf4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"yy", "'"}], "[", "s", "]"}], " ", "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"fre", "[", "1", "]"}]}], "*", "k", "*", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", "[", "s", "]"}], "]"}]}], " ", "-", 
    RowBox[{
     RowBox[{"fre", "[", "2", "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Kappa]", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", "[", "s", "]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "s", "]"}], "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", "[", "s", "]"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"fre", "[", "3", "]"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Kappa]", "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"a", "[", "s", "]"}], "]"}]}], " ", "+", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "s", "]"}], "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"a", "[", "s", "]"}], "]"}]}]}], ")"}]}]}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.628403876431804*^9, 3.628403940735117*^9}, {
   3.6284040564561205`*^9, 3.628404065784937*^9}, {3.628404196700367*^9, 
   3.6284042602392783`*^9}, {3.6284043016417513`*^9, 3.6284043993291225`*^9}, 
   3.628404622097514*^9, {3.697367263401153*^9, 3.697367312737499*^9}, {
   3.6973673655136957`*^9, 3.697367427617725*^9}, {3.697367459705934*^9, 
   3.6973675007041693`*^9}, {3.697367555016951*^9, 3.697367605504182*^9}, {
   3.697368726561862*^9, 
   3.697368740581644*^9}},ExpressionUUID->"3327dc66-9dba-4257-872d-\
115b336f0ce4"],

Cell["\<\
Since the Frenet frame is orthonormal we get the scalar square of this vector \
by\
\>", "Text",
 CellChangeTimes->{{3.6284044139775486`*^9, 3.6284044875472775`*^9}, {
   3.628835724199473*^9, 3.628835726461477*^9}, {3.6290131026716843`*^9, 
   3.6290131068992915`*^9}, 
   3.6290131751182117`*^9},ExpressionUUID->"9312fd8e-e2cb-4c2e-a3e2-\
a19deeaaa225"],

Cell[BoxData[
 RowBox[{"sqy", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "*", 
        RowBox[{"Cos", "[", "a", "]"}]}], ")"}], "^", "2"}], " ", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Kappa]", "*", 
         RowBox[{"Sin", "[", "a", "]"}]}], "+", 
        RowBox[{
         RowBox[{"a", "'"}], "*", 
         RowBox[{"Sin", "[", "a", "]"}]}]}], ")"}], "^", "2"}], "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Kappa]", "*", 
         RowBox[{"Cos", "[", "a", "]"}]}], " ", "+", 
        RowBox[{
         RowBox[{"a", "'"}], "*", 
         RowBox[{"Cos", "[", "a", "]"}]}]}], ")"}], "^", "2"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", ">", "0"}], ",", " ", 
      RowBox[{
       RowBox[{"a", "'"}], ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.628404489918482*^9, 3.6284045923638616`*^9}, {
   3.6284046467455573`*^9, 3.6284047233572917`*^9}, 
   3.62840481358785*^9},ExpressionUUID->"e9d2d777-faa7-4bbf-bfda-\
55a3c0c46d2d"],

Cell["Obviously, this can be written as", "Text",
 CellChangeTimes->{{3.628405373675634*^9, 
  3.6284053877468586`*^9}},ExpressionUUID->"0a90c6da-b76e-43ca-8700-\
83d69ac99524"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"sqy", " ", "\[Equal]", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"k", "^", "2"}], "  ", "*", 
     RowBox[{
      RowBox[{"Cos", "[", "a", "]"}], "^", "2"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Kappa]", " ", "+", 
       RowBox[{"a", "'"}]}], ")"}], "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.628404790343809*^9, 3.6284050227998176`*^9}, {
  3.628405319449939*^9, 
  3.62840534295918*^9}},ExpressionUUID->"bede6ae6-2569-45df-92a5-\
1ab55fcf93b6"],

Cell["Since xx\[CloseCurlyQuote][s] == fre[1], we have", "Text",
 CellChangeTimes->{{3.6284050532354712`*^9, 
  3.6284051018295565`*^9}},ExpressionUUID->"a65e6822-85f9-4910-aebe-\
e522ab0802fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"xx", "'"}], "[", "s", "]"}], ".", 
     RowBox[{
      RowBox[{"yy", "'"}], "[", "s", "]"}]}], ")"}], "^", "2"}], " ", "==", 
  " ", 
  RowBox[{
   RowBox[{"k", "^", "2"}], "*", 
   RowBox[{
    RowBox[{"Cos", "[", "a", "]"}], "^", "2"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6284051121411743`*^9, 3.6284051842757015`*^9}, {
   3.6284052725250564`*^9, 3.6284052839910765`*^9}, 
   3.697369033555627*^9},ExpressionUUID->"3a15e38d-fed4-414b-80b2-\
f0d653fb54d9"],

Cell[TextData[{
 "Using the criterion of Subsection 3.7 we conclude \n",
 StyleBox["Proposition 3.",
  FontColor->RGBColor[0, 0, 1]],
 " A family of normals  of  the generally curved  curve xx[s], s its arc \
length parameter, defined by the angle a[s] of the normal with the principal \
normal at the point xx[s], is developable iff"
}], "Text",
 CellChangeTimes->{{3.6284055015334587`*^9, 3.628405719824642*^9}, {
  3.697369364296623*^9, 3.697369365328321*^9}, {3.697369431759996*^9, 
  3.697369448976112*^9}},ExpressionUUID->"a70eab01-dc33-43b8-a9c7-\
dc4217bd26fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"a", "[", "s", "]"}], ",", "s"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"torsion", "[", "xx", "]"}], "[", "s", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.62840573583027*^9, 3.6284057675607257`*^9}, 
   3.628405920986995*^9},ExpressionUUID->"5ab042f4-a545-4fe5-a88c-\
34f1c14c72ed"],

Cell["is satisfied.", "Text",
 CellChangeTimes->{{3.6284057912883673`*^9, 
  3.628405811038002*^9}},ExpressionUUID->"9fa5c3ac-f367-45db-b42c-\
cf436416c59d"],

Cell["\<\
Indeed, the criterion is satisfied iff sqy == (xx\[CloseCurlyQuote][s].yy\
\[CloseCurlyQuote][s])^2 . \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.6284058365596466`*^9, 3.62840590095656*^9}, {
  3.628405944730237*^9, 
  3.628405956648658*^9}},ExpressionUUID->"0d87a6d6-799b-4168-9125-\
1a2a1f1581b9"],

Cell[TextData[{
 StyleBox["Example 6.",
  FontColor->RGBColor[0, 0, 1]],
 " Plane curve.\nConsider a plane curve embedded into the 3-space as a space \
curve, e.g."
}], "Text",
 CellChangeTimes->{{3.628837813612527*^9, 3.628837819495737*^9}, {
   3.628837851354993*^9, 3.628837922782919*^9}, 3.6290131318437357`*^9, {
   3.697369576598771*^9, 
   3.697369579022637*^9}},ExpressionUUID->"e4e6dfed-df77-4f89-92cd-\
32558f956714"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plcurve", "[", 
    RowBox[{"f_", ",", "g_"}], "]"}], "[", "s_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", "s", "]"}], ",", 
    RowBox[{"g", "[", "s", "]"}], ",", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6288379330945377`*^9, 3.628838029202707*^9}, {
  3.697284551984477*^9, 
  3.697284569505653*^9}},ExpressionUUID->"762992d7-6675-491d-a990-\
ae26661d47b6"],

Cell["\<\
Its principal normal is the normal of the plane curve, and its binormal is \
the constant normal vector of the embedded plane, in our case \
\[PlusMinus]stb[3]:\
\>", "Text",
 CellChangeTimes->{{3.6288380721711826`*^9, 3.628838201589411*^9}, {
  3.628838433289233*^9, 
  3.628838433289233*^9}},ExpressionUUID->"78d17517-bd46-41d1-9cf6-\
c0fa6bbc9f3c"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"frenet", "[", 
      RowBox[{"plcurve", "[", 
       RowBox[{"f", ",", "g"}], "]"}], "]"}], "[", "s", "]"}], "[", 
    RowBox[{"[", "3", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["g", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], "2"]}], " ", ">", "0"}], 
     ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SuperscriptBox["g", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}]}], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "s", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], " ", 
        RowBox[{
         SuperscriptBox["g", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "s", "]"}]}]}], "<", "0"}]}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6288382088590236`*^9, 3.62883825766391*^9}, {
  3.6288383057493973`*^9, 3.628838354168291*^9}, {3.628838412258396*^9, 
  3.628838417968006*^9}, {3.6288384675664935`*^9, 
  3.6288384951669416`*^9}},ExpressionUUID->"7b0e0308-af5c-4cc9-9904-\
9636a1fdedc2"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"torsion", "[", 
     RowBox[{"plcurve", "[", 
      RowBox[{"f", ",", "g"}], "]"}], "]"}], "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["g", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], "2"]}], " ", ">", "0"}], 
     ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SuperscriptBox["g", "\[Prime]",
           MultilineFunction->None], "[", "s", "]"}]}], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "s", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], " ", 
        RowBox[{
         SuperscriptBox["g", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "s", "]"}]}]}], "<", "0"}]}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6288385166209803`*^9, 
  3.62883859589472*^9}},ExpressionUUID->"2194694e-b6e2-415c-97de-\
f4fe297b2554"],

Cell[TextData[{
 "Thus the angle between the principal normal and the normal of a developable \
normal surface of the curve must be constant. For a = 0 we obtain the region \
of the plane covered by the principal normals (the normals of the plane \
curve). The envelope of these normals is the locus of the centers of \
curvature of the curve, called its ",
 StyleBox["evolute",
  FontColor->RGBColor[0, 0, 1]],
 " (see ",
 ButtonBox["evolute",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Evolute.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/Evolute.html"],
 "). The curve itself then is called the ",
 ButtonBox["involute",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Involute.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/Involute.html"],
 " of its evolute. The developable normal surface of the involute is the \
tangent surface of the evolute. For \na[s] =Pi/2 we obtain the cylindrical \
surface generated by the curve with rulings spanned  by stb[3]. The evolute \
degenerates to an infinite point of the z-axis.\n\nUsually one considers the  \
evolute-involute relation for plane  curves in dimension 2 only. Considering \
the plane curve embedded in the 3-space  we  may consider evolutes depending \
on the angle a, as we do now; we speak about",
 StyleBox[" a-evolutes",
  FontColor->RGBColor[0, 0, 1]],
 ". Again the a-evolute is the curve whose tangent surface is the developable \
normal surface of the given involute, it is the locus of singularities, the \
\[OpenCurlyDoubleQuote]R\[UDoubleDot]ckkehrkante, of the surface, we will \
find its equation. The parameter representation of the surface is"
}], "Text",
 CellChangeTimes->{{3.628838712128925*^9, 3.628838715529731*^9}, {
   3.628838747387987*^9, 3.628838748105588*^9}, {3.628840123825511*^9, 
   3.628840370957348*^9}, {3.6288404856389093`*^9, 3.6288404873237123`*^9}, {
   3.628840517872566*^9, 3.6288406501888*^9}, {3.6288407539358625`*^9, 
   3.6288407899527264`*^9}, {3.6288408687733097`*^9, 
   3.6288408687733097`*^9}, {3.628841083558158*^9, 3.62884115726262*^9}, {
   3.6288420287840567`*^9, 3.6288420287840567`*^9}, {3.6288423029120092`*^9, 
   3.628842310296521*^9}, {3.628842359964644*^9, 3.628842359965644*^9}, {
   3.628842441725917*^9, 3.628842641079469*^9}, 3.6288427322952304`*^9, 
   3.62884862992288*^9, {3.628848772024931*^9, 3.628848803182186*^9}, {
   3.6288488645596943`*^9, 3.628848994353323*^9}, {3.6288490565556326`*^9, 
   3.628849092129695*^9}, {3.628999299317421*^9, 3.628999540211647*^9}, {
   3.6289996149517794`*^9, 3.628999631207008*^9}, 3.6290132389067235`*^9, 
   3.629013272821183*^9, {3.697369728912703*^9, 
   3.697369771488366*^9}},ExpressionUUID->"ac8977ea-9533-467f-bfda-\
d47c28e2acc2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"congr", "[", 
    RowBox[{"f_", ",", "g_", ",", "a_"}], "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"plcurve", "[", 
     RowBox[{"f", ",", "g"}], "]"}], "[", "s", "]"}], " ", "+", 
   RowBox[{"t", "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"g", "'"}], "[", "s", "]"}]}], ",", 
         RowBox[{
          RowBox[{"f", "'"}], "[", "s", "]"}], ",", "0"}], "}"}], "*", 
       RowBox[{
        RowBox[{"Cos", "[", "a", "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"f", "'"}], "[", "s", "]"}], "^", "2"}], " ", "+", 
          RowBox[{
           RowBox[{
            RowBox[{"g", "'"}], "[", "s", "]"}], "^", "2"}]}], "]"}]}]}], "+", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"Sin", "[", "a", "]"}]}], "}"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6288491287313595`*^9, 3.6288493832914085`*^9}, {
  3.628849470269562*^9, 
  3.628849502737219*^9}},ExpressionUUID->"d90b29e9-ceae-432f-b92d-\
9ab654c3c761"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "1", "]"}], "[", 
   RowBox[{"congr", "[", 
    RowBox[{"f", ",", "g", ",", "a"}], "]"}], "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6288496146512165`*^9, 3.628849689366748*^9}, {
  3.628849748452052*^9, 
  3.6288497553628645`*^9}},ExpressionUUID->"cbb6da1f-76bc-466a-b951-\
3c6264b2f1fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "2", "]"}], "[", 
   RowBox[{"congr", "[", 
    RowBox[{"f", ",", "g", ",", "a"}], "]"}], "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6288497772693033`*^9, 
  3.628849805164152*^9}},ExpressionUUID->"f1dbf0e9-959e-4381-a10f-\
239712029f19"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", 
    RowBox[{"Cross", "[", 
     RowBox[{"%", ",", "%%"}], "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["g", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"]}], ">", "0"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.628849831265998*^9, 3.6288499420225935`*^9}, {
  3.6290002900471725`*^9, 
  3.6290003028275948`*^9}},ExpressionUUID->"84f5468a-6f38-453e-8b0e-\
9a58e7b3d203"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nvector", " ", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6290003608394976`*^9, 
  3.629000383243137*^9}},ExpressionUUID->"a0a4fc28-1465-4fa6-88ea-\
b6b2883ab97f"],

Cell["At the singularities the n - vector is zero, thu we solve", "Text",
 CellChangeTimes->{{3.697369997274124*^9, 
  3.697370044693239*^9}},ExpressionUUID->"3f90d584-4c18-4b42-a080-\
62679ffe8eb7"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"nvector", "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6290003965227604`*^9, 
  3.6290004286034174`*^9}},ExpressionUUID->"9645ad57-1475-4937-98e8-\
2b06cc59aaae"],

Cell[BoxData[
 RowBox[{"?", "curvatures"}]], "Input",
 CellChangeTimes->{{3.6290009344649105`*^9, 3.629000941937324*^9}, 
   3.6290010944087934`*^9},ExpressionUUID->"94d5d51d-ba79-43c3-a559-\
440ea79f10a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"curve2D", "[", 
    RowBox[{"f_", ",", "g_"}], "]"}], "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", "s", "]"}], ",", 
    RowBox[{"g", "[", "s", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6290011512048936`*^9, 
  3.6290012007565813`*^9}},ExpressionUUID->"f0a99ca4-e0b3-462f-8b5c-\
f4f3754a4cc2"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
  "Thus", " ", "for", " ", "the", " ", "oriented", " ", "plane", " ", "curve",
    " "}]], "Input",ExpressionUUID->"d92a0662-fc26-42dd-aaf5-184db19f40c1"],
 "curve2D the curvature ",
 "with the correct sign is the only element of"
}], "Text",
 CellChangeTimes->{{3.6290015897156677`*^9, 3.6290016212649236`*^9}, {
  3.629001652205778*^9, 3.629001663347198*^9}, {3.6290017335125217`*^9, 
  3.629001734698124*^9}},ExpressionUUID->"57f7cf37-3604-435f-bb60-\
e8611af9a66a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"curvatures", "[", 
    RowBox[{"curve2D", "[", 
     RowBox[{"f", ",", "g"}], "]"}], "]"}], "[", "s", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.629001212415802*^9, 3.629001235301042*^9}, {
  3.6290016810084295`*^9, 
  3.629001727878912*^9}},ExpressionUUID->"97543a9c-2ed7-4165-9ad0-\
141631d1f17f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", "%", "]"}], ",", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["g", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], "2"]}], ">", "0"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6290012850907297`*^9, 
  3.6290013545812526`*^9}},ExpressionUUID->"fb535442-85aa-4e17-a715-\
dc1935a91af3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"k2D", "[", 
    RowBox[{"f_", ",", "g_"}], "]"}], "[", "s_", "]"}], " ", ":=", " ", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["g", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}]}], " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "s", "]"}], " ", 
     RowBox[{
      SuperscriptBox["g", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "s", "]"}]}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["g", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"]}], ")"}], 
    RowBox[{"3", "/", "2"}]]]}]], "Input",
 CellChangeTimes->{{3.6290018263606863`*^9, 3.6290018536983356`*^9}, 
   3.629001891379402*^9},ExpressionUUID->"e8797b5a-dc4a-4958-86bf-\
f978aa677f8c"],

Cell["Thus this vector is the null vector  iff", "Text",
 CellChangeTimes->{{3.6288506737594833`*^9, 3.628850688065708*^9}, {
  3.628850735604992*^9, 
  3.628850738350597*^9}},ExpressionUUID->"1e6ce402-71c1-4d4c-a866-\
8fea282cfd2c"],

Cell[BoxData[
 RowBox[{"t", " ", "\[Equal]", " ", 
  RowBox[{"1", "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"k2D", "[", 
       RowBox[{"f", ",", "g"}], "]"}], "[", "s", "]"}], "*", 
     RowBox[{"Cos", "[", "a", "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.628850764156042*^9, 3.6288508063571167`*^9}, {
   3.628850837856572*^9, 3.628850863054617*^9}, 3.628850951078972*^9, {
   3.6290019373450837`*^9, 3.6290019466583*^9}, 
   3.6290019931573825`*^9},ExpressionUUID->"f8716ab6-3e70-4746-bbb3-\
b7d2b90a9998"],

Cell["\<\
For a == \[PlusMinus]Pi/2 it follows t == Infinity, and this corresponds to \
the cylindrical surface: the evolute is empty. The flat points, k[s] == 0, \
must be excluded. For a == 0 the evolute consists of the curvature centers of \
the involute. For arbitrary a the parameter representation of the a-evolute \
is (with s the arc length parameter of the given involute)\
\>", "Text",
 CellChangeTimes->{{3.6288516468381596`*^9, 3.628851893235795*^9}, {
   3.6288519719873266`*^9, 3.6288519743741302`*^9}, {3.6288520750349927`*^9, 
   3.62885209606583*^9}, {3.628852129578689*^9, 3.6288521651839523`*^9}, {
   3.6288524813639107`*^9, 3.6288524863423195`*^9}, {3.6288528450719533`*^9, 
   3.6288528712548*^9}, 3.697285019535365*^9, {3.697370306297319*^9, 
   3.697370307601603*^9}},ExpressionUUID->"4225a8a5-e059-4e8c-9edd-\
6c6ca9d3120c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plevolute", "[", 
    RowBox[{"f_", ",", "g_", ",", "a_"}], "]"}], "[", "s_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"congr", "[", 
     RowBox[{"f", ",", "g", ",", "a"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], "/.", 
   RowBox[{"t", "->", " ", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"k2D", "[", 
         RowBox[{"f", ",", "g"}], "]"}], "[", "s", "]"}], "*", 
       RowBox[{"Cos", "[", "a", "]"}]}], ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.628852635461183*^9, 3.628852648038805*^9}, {
   3.628852704347305*^9, 3.62885270721971*^9}, 3.6288528126646957`*^9, {
   3.6288528847976236`*^9, 3.6288529286895013`*^9}, {3.629002130381624*^9, 
   3.629002158608074*^9}, {3.6290023516602154`*^9, 3.629002360681031*^9}, {
   3.629002519093111*^9, 3.629002564963192*^9}, {3.6290026001004543`*^9, 
   3.6290026283883038`*^9}},ExpressionUUID->"1ae616ac-343c-432b-85fe-\
7a82fcfe6525"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plevolute", "[", 
   RowBox[{"f", ",", "g", ",", "a"}], "]"}], "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.629002643617931*^9, 3.629002657739956*^9}, 
   3.629002688821211*^9},ExpressionUUID->"c0508009-d498-4a37-8264-\
dd7aeb95ac44"],

Cell["For the unit circle we get", "Text",
 CellChangeTimes->{{3.62901060080169*^9, 
  3.6290106128137107`*^9}},ExpressionUUID->"68f53635-4a53-44bb-be5e-\
d55341ff8568"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plevolute", "[", 
   RowBox[{"Cos", ",", "Sin", ",", "a"}], "]"}], "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.629003320262925*^9, 
  3.6290033296913424`*^9}},ExpressionUUID->"606f8ac9-76f1-45ad-a42d-\
dfdf3a8bb90b"],

Cell["This is the vertex of a circular cone:", "Text",
 CellChangeTimes->{{3.6290034227097063`*^9, 
  3.629003493717431*^9}},ExpressionUUID->"d6fb389b-f041-44d6-aedb-\
438f7f7807b5"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"congr", "[", 
     RowBox[{"Cos", ",", "Sin", ",", 
      RowBox[{"Pi", "/", "3"}]}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "3"}], ",", "6"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6290034964680367`*^9, 3.6290034964836364`*^9}, 
   3.629003536207307*^9, {3.6290106549337845`*^9, 
   3.6290107423095384`*^9}},ExpressionUUID->"1f49d360-038e-482a-ba62-\
61d4af7274b7"],

Cell["\<\
The a-evolute of the unit circle degenerates to the vertex {0, 0, Tan[a]} of  \
the normal surface; a circular cone. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.6290107804516053`*^9, 3.629010858217742*^9}, {
  3.629010987432769*^9, 3.6290110266356378`*^9}, {3.629012881104495*^9, 
  3.629012886970105*^9}},ExpressionUUID->"9953fa9d-da1e-46c3-850e-\
6174a8192779"],

Cell[TextData[{
 StyleBox["Example 7.",
  FontColor->RGBColor[0, 0, 1]],
 " a-Evolutes of  an ellipse."
}], "Text",
 CellChangeTimes->{{3.6290111135589905`*^9, 3.6290111465998487`*^9}, {
  3.697370586926628*^9, 
  3.6973705978305473`*^9}},ExpressionUUID->"11ae6156-d1ce-4503-ba72-\
c53ff18f4b42"],

Cell["We consider the ellipse defined by fc and Sin", "Text",
 CellChangeTimes->{{3.6290111978459387`*^9, 3.629011256158841*^9}, 
   3.62901343550743*^9},ExpressionUUID->"3ec7a398-e104-4365-9652-\
758d7c0dea66"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fc", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{"2", "*", 
    RowBox[{"Cos", "[", "s", "]"}]}]}], ";", " ", 
  RowBox[{"ell", "=", 
   RowBox[{"ParametricPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"fc", "[", "s", "]"}], ",", 
       RowBox[{"Sin", "[", "s", "]"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.629011263537654*^9, 3.6290113435501947`*^9}, {
  3.6290123228575144`*^9, 3.6290123329975324`*^9}, {3.629012402979255*^9, 
  3.6290124110132694`*^9}},ExpressionUUID->"649ee725-0864-4db0-8cf1-\
11321e3dc080"],

Cell["For a = Pi/4 the developable normal surface is", "Text",
 CellChangeTimes->{{3.629011429818346*^9, 3.6290114688652143`*^9}, 
   3.6290118770399313`*^9},ExpressionUUID->"90ea5e3f-e2e7-4807-9055-\
c11450854e4d"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"congr", "[", 
     RowBox[{"fc", ",", "Sin", ",", 
      RowBox[{"Pi", "/", "4"}]}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "3"}], ",", "7"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"Opacity", "[", ".3", "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.629011478069231*^9, 3.629011486852046*^9}, {
   3.629011538176136*^9, 3.6290115817158127`*^9}, 3.6290116392175136`*^9, {
   3.629011699246419*^9, 3.629011792877784*^9}, {3.697285574073761*^9, 
   3.6972856315282583`*^9}},ExpressionUUID->"1e99b8e8-d1df-43b8-af86-\
993f982ec6d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spcgr", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.697285686173333*^9, 
  3.697285695567233*^9}},ExpressionUUID->"0cc9b891-9dbc-4165-b53d-\
244345369446"],

Cell["The \[Pi]/4-evolute of the ellipse is", "Text",
 CellChangeTimes->{{3.629011907693985*^9, 
  3.6290119475520554`*^9}},ExpressionUUID->"13ef21ed-1f41-41e3-9074-\
dc02a8439b70"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"plevolute", "[", 
     RowBox[{"fc", ",", "Sin", ",", 
      RowBox[{"Pi", "/", "4"}]}], "]"}], "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", " ", "0", ",", " ", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6290119657884874`*^9, 3.6290120194057817`*^9}, {
  3.697285716539171*^9, 
  3.697285745303133*^9}},ExpressionUUID->"eab1def3-e37d-4c32-baed-\
435db2af6abb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spev", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.697285761179484*^9, 
  3.69728576873448*^9}},ExpressionUUID->"4c38b351-1046-4c0f-a22d-\
4d136be9fa93"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"spcgr", ",", "spev"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "None"}], ",", " ", 
   RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.69728577154795*^9, 
  3.697285849878189*^9}},ExpressionUUID->"481158ef-2f0c-42a5-89a7-\
b3add3edbf36"],

Cell["This is not a plane curve; its torsion is", "Text",
 CellChangeTimes->{{3.629012090073906*^9, 
  3.629012105861133*^9}},ExpressionUUID->"65d9795f-0b3f-415e-8bbb-\
91bd8adb0520"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"torsion", "[", 
     RowBox[{"plevolute", "[", 
      RowBox[{"fc", ",", "Sin", ",", 
       RowBox[{"Pi", "/", "4"}]}], "]"}], "]"}], "[", "s", "]"}], ",", " ", 
   RowBox[{"s", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6290121132711463`*^9, 
  3.6290121657496386`*^9}},ExpressionUUID->"16872825-2bfa-4a1e-8d04-\
5d282e3ef69b"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.629012177434059*^9, 
  3.62901221183212*^9}},ExpressionUUID->"ee52461a-dfd6-4dbe-92f9-\
c6750b922f04"],

Cell["The plane evolute of the ellipse is", "Text",
 CellChangeTimes->{{3.6973709217957067`*^9, 
  3.6973709792672377`*^9}},ExpressionUUID->"fe46952b-94ea-4a54-b4ff-\
51490c209ada"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"plevolute", "[", 
     RowBox[{"fc", ",", "Sin", ",", "0"}], "]"}], "[", "s", "]"}], ",", 
   RowBox[{"s", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697285475970531*^9, 
  3.6972854999048977`*^9}},ExpressionUUID->"b3663b11-f839-4df7-b74d-\
29626e57f1b6"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"plevolute", "[", 
     RowBox[{"fc", ",", "Sin", ",", "0"}], "]"}], "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", " ", "0", ",", " ", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", "Red"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6290119657884874`*^9, 3.6290120194057817`*^9}, {
  3.629012279177438*^9, 
  3.62901230903589*^9}},ExpressionUUID->"88bb3321-4454-439f-8eb4-\
ee5c114b34c9"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"ell", ",", "%"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.629012350625563*^9, 
  3.629012375429607*^9}},ExpressionUUID->"0df1b864-9298-408e-83ff-\
da1764a2e43b"],

Cell["\<\
\[FilledSquare]
Find developable normal surfaces and a-evolutes   for other plane or not \
plane 3D-curves! In the next subsection we do this for a helix.\
\>", "Text",
 CellChangeTimes->{{3.6290125932995896`*^9, 3.629012596591195*^9}, {
  3.6290126359656644`*^9, 
  3.629012835412015*^9}},ExpressionUUID->"07fe3b26-1409-4827-b2e0-\
a0e62b05114b"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.8.2. Normal Congruence of the Helix", "Subsubsection",
 CellChangeTimes->{{3.592115389572919*^9, 3.592115426638584*^9}, 
   3.5921354646825233`*^9, 3.5922182112163124`*^9, 3.5942701628864923`*^9, 
   3.598596137570768*^9, 3.6116673526853304`*^9, 3.6119986168238125`*^9, {
   3.6155592477178297`*^9, 3.615559249355833*^9}, 3.6161383195804777`*^9, 
   3.618564015369048*^9, 3.6186374644950294`*^9, 3.6280852651103015`*^9, 
   3.6282292445934086`*^9, {3.6282293236387477`*^9, 3.6282293292235575`*^9}, 
   3.6282293736836357`*^9, 3.628229447222165*^9, 3.629013014422329*^9, 
   3.6291254008855953`*^9, {3.697371167267441*^9, 3.69737118179393*^9}, 
   3.697436523711665*^9, 3.7077279402090893`*^9, 3.7077289265388613`*^9},
 CellTags->"helix",ExpressionUUID->"c46a0b57-65b8-4ab5-a5a6-aacc53df653a"],

Cell[" As example we consider the normal congruence of a helix.", "Text",
 CellChangeTimes->{{3.598596193044465*^9, 3.5985962126692996`*^9}, {
   3.598596242824153*^9, 3.5985963424459276`*^9}, 3.5986252137382*^9, 
   3.5986252462330575`*^9, {3.6156418819882107`*^9, 3.615641952219534*^9}, {
   3.6282295708991823`*^9, 
   3.628229591974819*^9}},ExpressionUUID->"58b81182-c165-4902-a59c-\
256627f06633"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hel", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"helix", "[", 
     RowBox[{"1", ",", "1"}], "]"}], "[", "s", "]"}], "/", 
   RowBox[{"Sqrt", "[", "2", "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.592115431786593*^9, 3.5921154360142*^9}, {
  3.59211546966346*^9, 3.5921154800374775`*^9}, {3.592115539411182*^9, 
  3.592115660030594*^9}, {3.5921157321963205`*^9, 3.5921157646287775`*^9}, {
  3.614750259680585*^9, 3.6147502813958235`*^9}, {3.614750440531703*^9, 
  3.614750474570963*^9}, {3.6290971891808167`*^9, 
  3.629097200802837*^9}},ExpressionUUID->"9b76a9cc-5d76-42d0-a361-\
355cc7835bdf"],

Cell[BoxData[
 RowBox[{"hel", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.614750403200837*^9, 3.614750411578052*^9}, 
   3.6290972426109104`*^9},ExpressionUUID->"626c8f83-bd8f-45be-909f-\
293911148043"],

Cell["\<\
Normed by 1/Sqrt[2] the parameter s becomes the arc length parameter of the \
curve hel:\
\>", "Text",
 CellChangeTimes->{{3.6147505405122786`*^9, 3.6147506061883936`*^9}, 
   3.629097410982006*^9, {3.697377087919236*^9, 
   3.697377113839204*^9}},ExpressionUUID->"2b0de31a-57e2-42d9-91d5-\
72cec5a7c772"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"hel", "'"}], "[", "s", "]"}], ".", 
   RowBox[{
    RowBox[{"hel", "'"}], "[", "s", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592115673696218*^9, 3.5921156966750584`*^9}, {
  3.5921157757515974`*^9, 3.5921157855640144`*^9}, {3.614750345465136*^9, 
  3.614750352344748*^9}, {3.629097455348484*^9, 3.629097456159685*^9}, {
  3.6290977914042745`*^9, 
  3.629097792340276*^9}},ExpressionUUID->"0ff3451e-f767-487e-b8e6-\
9fca0601398a"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"hel", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697377131004444*^9, 3.697377177207506*^9}, {
  3.6973772105830803`*^9, 
  3.6973772742068853`*^9}},ExpressionUUID->"f100ddf3-6560-4898-ad18-\
202a9806b1a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"heli", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6973772919177523`*^9, 3.697377299782398*^9}, {
  3.69743431661244*^9, 
  3.6974343197615633`*^9}},ExpressionUUID->"e8b42bfb-607e-4232-a077-\
39ca5f0b9d46"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"helixnormalcongr", "[", "a_", "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"normalcongruence", "[", "hel", "]"}], "[", 
   RowBox[{"a", ",", "s", ",", "t"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.592115877026975*^9, 3.592115984230363*^9}, {
   3.592116019377225*^9, 3.5921161327894244`*^9}, {3.59859658850516*^9, 
   3.5985966192840137`*^9}, {3.614750762812669*^9, 3.61475076927108*^9}, {
   3.629097457189287*^9, 3.629097462696097*^9}, {3.6290977932450776`*^9, 
   3.6290978027922945`*^9}, 3.6290979253461094`*^9, {3.6290984935147076`*^9, 
   3.629098538239986*^9}, 3.629098582216463*^9, {3.6290986665190115`*^9, 
   3.6290986687810154`*^9}},ExpressionUUID->"6d3e120f-f86d-4f91-b3cb-\
9834a6d44331"],

Cell[BoxData[
 RowBox[{
  RowBox[{"helixnormalcongr", "[", "a", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6290986002344947`*^9, 3.6290986190637283`*^9}, {
  3.629098685863045*^9, 
  3.629098733193528*^9}},ExpressionUUID->"1fa465d0-ee6c-40e7-b995-\
6a61792ef7af"],

Cell["Here again is a tube around the helix:", "Text",
 CellChangeTimes->{{3.69737698008792*^9, 
  3.697376999567889*^9}},ExpressionUUID->"d700cab9-b05e-41ba-b4bf-\
fc83261895ba"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"t", "\[Rule]", " ", "1"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Yellow", ",", 
      RowBox[{"Opacity", "[", ".5", "]"}]}], "}"}]}], ",", 
   RowBox[{"Mesh", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6973768137369337`*^9, 3.697376950225141*^9}, {
  3.6973773258502827`*^9, 3.697377362293962*^9}, {3.697377508142248*^9, 
  3.6973775168375263`*^9}},ExpressionUUID->"47f764c2-889c-49f0-bb44-\
bf6beb9922f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"heltube", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.697377394561297*^9, 
  3.697377402669633*^9}},ExpressionUUID->"c05daa15-2da9-4f22-ba69-\
c7df038dd540"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"heltube", ",", "heli"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", "None"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6973774104660788`*^9, 3.697377448133328*^9}, {
  3.697377479176569*^9, 3.697377491132618*^9}, {3.6973775474598083`*^9, 
  3.697377564331296*^9}},ExpressionUUID->"dbcea7ce-6d94-48c5-b7b8-\
03354c3d7657"],

Cell["\<\
The function a[s] denotes the angle of the normal chosen at the point hel[s] \
with the principal normal at this point. The surface generated by the \
principal normals is\
\>", "Text",
 CellChangeTimes->{{3.598596667690899*^9, 3.598596740636627*^9}, {
   3.598596885264481*^9, 3.5985969100217247`*^9}, 3.614750778131896*^9, {
   3.6290974653325014`*^9, 3.6290974663777037`*^9}, {3.629097804289897*^9, 
   3.6290978052570987`*^9}, {3.697377626251348*^9, 
   3.6973776319180937`*^9}},ExpressionUUID->"f744f1e3-d2b1-423b-aaab-\
be045f07b8f9"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"helixnormalcongr", "[", "0", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5921161521646585`*^9, 3.5921162529720354`*^9}, 
   3.5921162866056943`*^9, {3.5921163851354675`*^9, 3.59211639789629*^9}, 
   3.598596854392027*^9, 3.614861860143141*^9, 3.6149177919205613`*^9, {
   3.6290980374323063`*^9, 3.629098042034314*^9}, 3.629098866792163*^9, {
   3.62909899034438*^9, 3.629098993167985*^9}, 
   3.69737771323945*^9},ExpressionUUID->"79c6552b-3979-4dba-8872-\
ae9db911090d"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"heli", ",", "%"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697377953501224*^9, 3.6973779781604013`*^9}, {
  3.697378035902771*^9, 
  3.697378045711924*^9}},ExpressionUUID->"43612062-929c-4bc2-82e4-\
b68e82131787"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pichel0", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6973797445040607`*^9, 
  3.6973797597676764`*^9}},ExpressionUUID->"0f08379c-de22-4965-886a-\
5ba0805e4300"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"helixnormalcongr", "[", "0", "]"}], "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592116441529567*^9, 3.592116487518447*^9}, 
   3.5985969281489563`*^9, 3.629098866807763*^9, {3.6290990076136103`*^9, 
   3.6290990129176197`*^9}, 
   3.697377768559177*^9},ExpressionUUID->"2bd761fc-0370-452d-859d-\
210a97dc9894"],

Cell["The normal surface generated by the binormals is", "Text",
 CellChangeTimes->{{3.697377810365885*^9, 3.697377842441963*^9}, 
   3.697377874626841*^9},ExpressionUUID->"5dfebd71-1d24-4a1b-8ce1-\
d57f3f9e2f1f"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"helixnormalcongr", "[", 
      RowBox[{"Pi", "/", "2"}], "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5921161521646585`*^9, 3.5921162529720354`*^9}, 
   3.5921162866056943`*^9, {3.5921163851354675`*^9, 3.59211639789629*^9}, 
   3.598596854392027*^9, 3.614861860143141*^9, 3.6149177919205613`*^9, {
   3.6290980374323063`*^9, 3.629098042034314*^9}, 3.629098866792163*^9, {
   3.62909899034438*^9, 3.629098993167985*^9}, 3.69737771323945*^9, {
   3.697377915875142*^9, 
   3.697377918409566*^9}},ExpressionUUID->"bf6c48f9-d0ff-43bd-b73d-\
817c1fbf2102"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"heli", ",", "%"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697377953501224*^9, 3.6973779781604013`*^9}, {
  3.697378035902771*^9, 
  3.697378045711924*^9}},ExpressionUUID->"498d0422-e8fd-488a-8cb3-\
a431bfbaa31c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pichel1", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.697379785181796*^9, 
  3.697379792423696*^9}},ExpressionUUID->"430596c7-e71f-4271-abdd-\
5c8f58b3c0c6"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"pichel0", ",", "pichel1"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.69737979882145*^9, 
  3.697379817631126*^9}},ExpressionUUID->"60e08c10-e64c-4fc7-a2ef-\
9616453a06ef"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"helixnormalcongr", "[", 
     RowBox[{"Pi", "/", "2"}], "]"}], "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592116441529567*^9, 3.592116487518447*^9}, 
   3.5985969281489563`*^9, 3.629098866807763*^9, {3.6290990076136103`*^9, 
   3.6290990129176197`*^9}, 3.697377768559177*^9, {3.697379219646802*^9, 
   3.69737922317208*^9}},ExpressionUUID->"9f3ce5eb-aa95-4979-b860-\
225ef4991561"],

Cell["\<\
Obviously, both surfaces aren\[CloseCurlyQuote]t developable.  To find the \
developable normal surfaces we apply the criterion of Proposition 3.8.1. The \
torsion of hel is\
\>", "Text",
 CellChangeTimes->{{3.6155454978738985`*^9, 3.6155455235827436`*^9}, 
   3.615642092604181*^9, {3.629099653501545*^9, 3.6290997312988815`*^9}, {
   3.629099785196976*^9, 3.6290998144782276`*^9}, {3.6973798635269747`*^9, 
   3.697379902742065*^9}},ExpressionUUID->"df05e845-4e45-4597-9266-\
f0258f0db9d1"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"torsion", "[", "hel", "]"}], "[", "s", "]"}], ",", 
   RowBox[{"s", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.629099818003834*^9, 
  3.629099864101915*^9}},ExpressionUUID->"6d810bb8-90c9-44a6-a820-\
ab728f96034c"],

Cell["\<\
Thus the developable normal surfaces of hel correspond to the  parameter \
function\
\>", "Text",
 CellChangeTimes->{{3.629099959792483*^9, 
  3.629100051037043*^9}},ExpressionUUID->"87260e89-7b9c-498f-af2d-\
47607e7036f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fa", "[", 
   RowBox[{"s_", ",", "c_"}], "]"}], ":=", " ", 
  RowBox[{"c", "-", 
   RowBox[{"s", "/", 
    RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.62910006624707*^9, 
  3.629100160455635*^9}},ExpressionUUID->"be9d086d-c2ca-46b3-a763-\
2b1998b99233"],

Cell[BoxData[
 RowBox[{
  RowBox[{"helixnormalcongr", "[", 
   RowBox[{"fa", "[", 
    RowBox[{"s", ",", "c"}], "]"}], "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{
  3.629103152572091*^9},ExpressionUUID->"53df1c57-8aae-445f-bc6c-\
89292d5fd329"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Element]", "Reals"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6291031707617226`*^9, 
  3.6291032089193897`*^9}},ExpressionUUID->"b2e15d87-7010-42ce-9e84-\
f43e996c1027"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"helcgr", "[", "c_", "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "s", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         SqrtBox["2"]], "-", 
        RowBox[{"t", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"c", "-", 
           FractionBox["s", 
            SqrtBox["2"]]}], "]"}]}]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{"t", " ", 
       RowBox[{"Sin", "[", "s", "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"c", "-", 
         FractionBox["s", 
          SqrtBox["2"]]}], "]"}]}], 
      SqrtBox["2"]]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         SqrtBox["2"]], "-", 
        RowBox[{"t", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"c", "-", 
           FractionBox["s", 
            SqrtBox["2"]]}], "]"}]}]}], ")"}], " ", 
      RowBox[{"Sin", "[", "s", "]"}]}], "-", 
     FractionBox[
      RowBox[{"t", " ", 
       RowBox[{"Cos", "[", "s", "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"c", "-", 
         FractionBox["s", 
          SqrtBox["2"]]}], "]"}]}], 
      SqrtBox["2"]]}], ",", 
    FractionBox[
     RowBox[{"s", "+", 
      RowBox[{"t", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"c", "-", 
         FractionBox["s", 
          SqrtBox["2"]]}], "]"}]}]}], 
     SqrtBox["2"]]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6291032498382616`*^9, 3.6291032907883334`*^9}, {
   3.6291033253267937`*^9, 3.6291033326432066`*^9}, 3.629108366709649*^9, {
   3.62911819574774*^9, 
   3.6291181992265463`*^9}},ExpressionUUID->"43e55912-7a44-45d4-b036-\
1000d17c8b3c"],

Cell["We control the Gaussian curvature:", "Text",
 CellChangeTimes->{{3.629108422214546*^9, 
  3.62910845850021*^9}},ExpressionUUID->"87d8d09a-b442-40e7-8195-\
0662fcb172f7"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"helcgr", "[", "c", "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Element]", "Reals"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}]}], "}"}], ",", 
   RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.592116441529567*^9, 3.5921165134768925`*^9}, {
   3.5921165735837984`*^9, 3.5921166331759033`*^9}, {3.5985969638886194`*^9, 
   3.5985969657918224`*^9}, {3.6119269126930046`*^9, 3.611926926561429*^9}, 
   3.6290974676101055`*^9, 3.6290978063959007`*^9, 3.629098866807763*^9, {
   3.62909905305649*^9, 3.629099056426096*^9}, {3.6291002016085076`*^9, 
   3.6291002111401243`*^9}, 3.6291002494849916`*^9, {3.6291033455600295`*^9, 
   3.6291033721268764`*^9}},ExpressionUUID->"19ca7392-1b43-4ccf-be9f-\
80b7a6f5cb16"],

Cell["OK. We consider some examples", "Text",
 CellChangeTimes->{{3.615642127345442*^9, 3.615642168201914*^9}, 
   3.615894763370123*^9, {3.6291084712142324`*^9, 3.629108514535508*^9}, 
   3.6291255059517794`*^9},ExpressionUUID->"ce7ae744-e7ef-4600-aa1f-\
bcc764551731"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"helcgr", "[", "Pi", "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Green", ",", 
      RowBox[{"Opacity", "[", ".3", "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.629108703701441*^9, 3.6291087923719964`*^9}, 
   3.629108829141261*^9, 3.629108870138133*^9, {3.6291182299274*^9, 
   3.6291182700350704`*^9}, {3.6973721543952837`*^9, 3.6973721904736557`*^9}, 
   3.697372273086315*^9, {3.697380261797127*^9, 3.6973802741400557`*^9}, {
   3.697432263569668*^9, 3.697432301957613*^9}, {3.697432336108952*^9, 
   3.69743233731085*^9}, {3.697433827887518*^9, 3.6974338401094522`*^9}, {
   3.69743396925664*^9, 3.697433981164472*^9}, {3.697434518324585*^9, 
   3.6974345319926443`*^9}},ExpressionUUID->"fd2683ed-3a5b-472c-b949-\
418799f007b5"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"heli", ",", "%"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697377953501224*^9, 3.6973779781604013`*^9}, {
  3.697378035902771*^9, 
  3.697378045711924*^9}},ExpressionUUID->"b854a0fd-d915-4214-9f99-\
b9559faaf8c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"helcgpi", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6973816355555267`*^9, 3.697381642344595*^9}, {
  3.697432498374999*^9, 
  3.697432503118516*^9}},ExpressionUUID->"f117f890-36d0-470f-a655-\
b6d62c1fb8c7"],

Cell["\<\
To find the singularities of the surface we calculate its tangent and normal \
vectors\
\>", "Text",
 CellChangeTimes->{{3.697434659153882*^9, 
  3.697434783573785*^9}},ExpressionUUID->"d022bdd9-4ece-4b4b-bb64-\
c1af5e660cd5"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"tv", "[", "1", "]"}], "[", 
     RowBox[{"helcgr", "[", "c", "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Element]", "Reals"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.629118429763751*^9, 3.629118447469782*^9}, 
   3.6291185314759293`*^9, {3.629118564688388*^9, 3.6291185966684437`*^9}, {
   3.629118632361307*^9, 
   3.6291186514557405`*^9}},ExpressionUUID->"4feb8e61-b798-4f93-82a9-\
1d43791058ad"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"tv", "[", "2", "]"}], "[", 
     RowBox[{"helcgr", "[", "c", "]"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Element]", "Reals"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.629118429763751*^9, 3.629118447469782*^9}, 
   3.6291185314759293`*^9, {3.629118564688388*^9, 3.6291185966684437`*^9}, {
   3.629118632361307*^9, 
   3.6291186764469843`*^9}},ExpressionUUID->"065fac43-ed50-4408-b243-\
15e49d507920"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{"%", ",", "%%"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Element]", "Reals"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}], ",", 
     RowBox[{"t", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.629118429763751*^9, 3.629118447469782*^9}, 
   3.6291185314759293`*^9, {3.629118564688388*^9, 3.6291185966684437`*^9}, {
   3.629118632361307*^9, 
   3.629118722326665*^9}},ExpressionUUID->"acbc32e1-3c5e-4c7d-911b-\
de38d8370348"],

Cell["The singularities are the solutions of", "Text",
 CellChangeTimes->{{3.6974348026211357`*^9, 
  3.697434829341072*^9}},ExpressionUUID->"1a83b050-06b9-4fe2-aaac-\
a38558780c9f"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.62911875929873*^9, 
  3.6291187888139815`*^9}},ExpressionUUID->"74e2f9e5-05ba-45de-b5ba-\
e4dedb5069f9"],

Cell["They form the a-evoute", "Text",
 CellChangeTimes->{{3.697434884316654*^9, 3.697434898356616*^9}, 
   3.697436233991426*^9},ExpressionUUID->"69d3369f-39a4-474f-b549-\
7ad668bc7c2f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"helaevolute", "[", "c_", "]"}], "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"helcgr", "[", "c", "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], "/.", " ", 
   RowBox[{"t", "->", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"Sec", "[", 
      RowBox[{"c", "-", 
       FractionBox["s", 
        SqrtBox["2"]]}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.6291188366592655`*^9, 3.6291188564557004`*^9}, {
  3.6291188920237627`*^9, 
  3.6291189516158676`*^9}},ExpressionUUID->"3ee93ead-526d-4c7d-ba8e-\
ad2d37ddc8e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"helaevolute", "[", "c", "]"}], "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6291189605390835`*^9, 
  3.6291189720987034`*^9}},ExpressionUUID->"a6138fa8-1a91-4a98-b74b-\
8231482455c7"],

Cell["We get a strange picture:", "Text",
 CellChangeTimes->{{3.697435057755114*^9, 
  3.6974350735230007`*^9}},ExpressionUUID->"c3f7ec30-3989-468b-b9e6-\
69300843f8e6"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"helaevolute", "[", "Pi", "]"}], "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", " ", "Thick"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6291191718726544`*^9, 3.6291192474703875`*^9}, {
   3.6291192990284777`*^9, 3.629119345407359*^9}, {3.697372336253281*^9, 
   3.697372390306988*^9}, 3.697372768995102*^9, {3.69738086689001*^9, 
   3.697380876575191*^9}, 3.697381759654022*^9, {3.6973819765623407`*^9, 
   3.697382030590713*^9}, {3.697382243864852*^9, 3.6973822459082813`*^9}, {
   3.6973828566821938`*^9, 3.6973828579182367`*^9}, {3.6973838901883373`*^9, 
   3.697383997021542*^9}, 3.697384075891436*^9, {3.697432844748549*^9, 
   3.6974328720680523`*^9}},ExpressionUUID->"ee91bdfe-1c40-4500-8555-\
a9393282ad20"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"%", ",", "helcgpi"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.697435083945663*^9, 
  3.697435120051552*^9}},ExpressionUUID->"f8174e20-1bd4-4302-808f-\
834a1eafca47"],

Cell["\<\
hellcgpi is invisible in this graphic, it is too small. We change the \
PlotRange to get more information:\
\>", "Text",
 CellChangeTimes->{{3.697435351272376*^9, 
  3.6974354649118853`*^9}},ExpressionUUID->"a255086c-b96b-4d4b-96bf-\
bfc0d34017f5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pr", "[", "b_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "x"}], ",", "x"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "x"}], ",", "x"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "10"}], "}"}]}], "}"}], ")"}], "/.", 
    RowBox[{"x", "\[Rule]", "b"}]}]}], ";", 
  RowBox[{"pr", "[", "50", "]"}]}]], "Input",
 CellChangeTimes->{{3.697384232612719*^9, 3.697384343218886*^9}, {
  3.697435971039592*^9, 
  3.6974359831484623`*^9}},ExpressionUUID->"3b4ed540-e89a-4cd5-9988-\
bf8bb98b55e9"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"helaevolute", "[", "Pi", "]"}], "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"pr", "[", "5", "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", " ", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.697383563745875*^9, {3.697383597272687*^9, 3.697383634912705*^9}, {
   3.697383665003498*^9, 3.697383702763565*^9}, 3.6973840915624313`*^9, {
   3.6973841537066402`*^9, 3.6973841925649223`*^9}, 3.697384262825564*^9, {
   3.697384354883584*^9, 3.697384441427018*^9}, {3.697384476134951*^9, 
   3.697384509558979*^9}, {3.697433187593535*^9, 3.697433213390236*^9}, {
   3.697433254099161*^9, 3.6974332857048264`*^9}, {3.6974333261958838`*^9, 
   3.6974333278566313`*^9}, {3.697433403060565*^9, 3.697433408024366*^9}, {
   3.697433583691074*^9, 3.697433602470916*^9}, 3.697433662714789*^9, 
   3.69743371440343*^9, 
   3.697434180928093*^9},ExpressionUUID->"18cad79c-e335-418b-8973-\
0384b4bae424"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"%", ",", "helcgpi"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{
  3.697384511947343*^9, {3.697433439783703*^9, 3.697433468447414*^9}, {
   3.6974335132472897`*^9, 
   3.697433525959059*^9}},ExpressionUUID->"3e1aed5e-5f96-4036-aa3e-\
013286714536"],

Cell["\<\
Experiment with other PlotRanges or values of c!
The invariants of the a-evoute are\
\>", "Text",
 CellChangeTimes->{{3.697436093698698*^9, 3.697436116906377*^9}, 
   3.6974362507859993`*^9, {3.69743642398417*^9, 
   3.69743646633578*^9}},ExpressionUUID->"8e1031a1-617f-4532-9f5c-\
93519902334b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"curvature", "[", 
     RowBox[{"helaevolute", "[", "c", "]"}], "]"}], "[", "s", "]"}], ",", 
   RowBox[{"s", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6291195077412443`*^9, 3.6291195894385877`*^9}, {
  3.6291196547091026`*^9, 
  3.6291196667055235`*^9}},ExpressionUUID->"92df50b8-7d43-4aad-862a-\
06b58a963585"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"acurvaturehel", "[", 
    RowBox[{"s_", ",", "c_"}], "]"}], " ", ":=", " ", 
   FractionBox[
    SqrtBox[
     RowBox[{"1", "+", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", "c"}], "-", 
        RowBox[{
         SqrtBox["2"], " ", "s"}]}], "]"}]}]], 
    RowBox[{"2", " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sec", "[", 
         RowBox[{"c", "-", 
          FractionBox["s", 
           SqrtBox["2"]]}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Tan", "[", 
         RowBox[{"c", "-", 
          FractionBox["s", 
           SqrtBox["2"]]}], "]"}], "2"]}]]}]]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.6291196963767757`*^9, 3.629119755126479*^9}, {
  3.6291221908367567`*^9, 
  3.6291222294780245`*^9}},ExpressionUUID->"c2e80687-2e5f-4506-93c2-\
1076c6dfe635"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"torsion", "[", 
     RowBox[{"helaevolute", "[", "c", "]"}], "]"}], "[", "s", "]"}], ",", 
   RowBox[{"s", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6291224354607863`*^9, 
  3.6291224386431923`*^9}},ExpressionUUID->"233f2d5e-a4a8-4c49-b930-\
2f20794ebd9b"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"acurvaturehel", "[", 
    RowBox[{"s", ",", "Pi"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6973831367901583`*^9, 3.69738320443544*^9}, {
  3.697383244936575*^9, 3.697383260060915*^9}, {3.697433044938723*^9, 
  3.697433045786385*^9}},ExpressionUUID->"772437cf-15a1-4d46-9b6c-\
4d31843fe2ff"],

Cell[BoxData[","], "Input",
 CellChangeTimes->{3.6974330471351852`*^9},
 EmphasizeSyntaxErrors->
  True,ExpressionUUID->"0f4a4f01-1b7f-4bb9-a2e7-6167d7bb932d"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"Pi", "-", 
        FractionBox["s", 
         SqrtBox["2"]]}], "]"}], "2"], 
     SqrtBox["2"]]}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6973831367901583`*^9, 3.69738320443544*^9}, {
   3.697383244936575*^9, 3.697383260060915*^9}, 3.697383314787847*^9, {
   3.697383393148767*^9, 3.697383400579608*^9}, {3.6974330637084303`*^9, 
   3.697433072764163*^9}},ExpressionUUID->"ef6be350-e8b5-4382-aebf-\
ddc56da9758d"],

Cell["\<\
Obviously, the a-evolute of the helix hel are generally curved curves in the \
3-space with isolated singularities.\
\>", "Text",
 CellChangeTimes->{
  3.616065523621974*^9, 3.6185806840470195`*^9, 3.6291190521892443`*^9, {
   3.629125290421801*^9, 
   3.6291253653331327`*^9}},ExpressionUUID->"3dfc5b2f-5e38-4047-9180-\
832a5cf7eebb"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.8.3. Normal Surfaces of a Surface", "Subsubsection",
 CellChangeTimes->{{3.5922181089604635`*^9, 3.5922181546640778`*^9}, {
   3.5988619755006013`*^9, 3.598861982021413*^9}, 3.6185622090977354`*^9, 
   3.6185639613379583`*^9, 3.628085258168289*^9, 3.6282293786288443`*^9, 
   3.629125440884065*^9, 3.6291863673197055`*^9, 3.697436531824391*^9, 
   3.6974400151809597`*^9, 3.7077289492991333`*^9, 
   3.707741474841342*^9},ExpressionUUID->"36b19020-0264-4ce9-8515-\
7548bc556fce"],

Cell[TextData[{
 "The normals of a surface form a 2-parameter family of lines, named the ",
 StyleBox["normal congruence of the surface",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.5922049711314583`*^9, 3.592205009202636*^9}, {
   3.592205189986976*^9, 3.592205219635672*^9}, {3.592205300843317*^9, 
   3.5922053260107565`*^9}, 3.5922053597396855`*^9, 3.592217768303979*^9, {
   3.598596409822446*^9, 
   3.598596446888111*^9}},ExpressionUUID->"5a571e04-32ef-462a-935d-\
c1eb7230a920"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normals", "[", 
    RowBox[{"ff_", ",", " ", "u_", ",", "v_"}], "]"}], "[", "s_", "]"}], " ", 
  ":=", " ", 
  RowBox[{
   RowBox[{"ff", "[", 
    RowBox[{"u", ",", "v"}], "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "3", "]"}], "[", "ff", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", "s"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.592205394333664*^9, 3.5922054044162407`*^9}, {
   3.592205454349097*^9, 3.59220549234127*^9}, 3.5922055233200417`*^9, 
   3.5922056857913346`*^9, 3.61486186009634*^9, 3.614917791858161*^9, 
   3.615531673064457*^9, {3.629174897118985*^9, 3.62917490005179*^9}, {
   3.629175105839157*^9, 
   3.629175110175965*^9}},ExpressionUUID->"e1597b84-eb41-4c61-872d-\
1d3c9a101008"],

Cell[BoxData[
 RowBox[{"?", "normals"}]], "Input",
 CellChangeTimes->{{3.615531879804282*^9, 3.6155319923537197`*^9}, {
  3.615532027924754*^9, 3.615532036194227*^9}, {3.6228848660061088`*^9, 
  3.6228848794845324`*^9}},ExpressionUUID->"7194ff86-43e6-4bf5-8789-\
4790b9879cac"],

Cell[BoxData[
 RowBox[{"Context", "[", "normals", "]"}]], "Input",
 CellChangeTimes->{{3.622884925286213*^9, 
  3.6228849373918343`*^9}},ExpressionUUID->"85bfce1c-9775-4639-920b-\
4e544ad4df32"],

Cell["\<\
Consider a curve on the surface sf[u, v], given in the parameter  \
neighborhood by \
\>", "Text",
 CellChangeTimes->{{3.5922057532761946`*^9, 3.592205856435095*^9}, {
  3.598595786398551*^9, 
  3.5985957881769543`*^9}},ExpressionUUID->"2d55fa0f-8765-46bc-a6b1-\
236ebff42e03"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hu", "[", "t", "]"}], ",", 
    RowBox[{"hv", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5922059133623505`*^9, 3.592205943501075*^9}, 
   3.6185624445392017`*^9},ExpressionUUID->"fb3c5595-497b-4d1b-9dcc-\
127bc3b2fe87"],

Cell["\<\
Then the normals along the curve form a ruled surface with directrix\
\>", "Text",
 CellChangeTimes->{{3.592206047180005*^9, 3.592206078795813*^9}, {
  3.5922061699950294`*^9, 3.592206174531289*^9}, {3.5985957986133723`*^9, 
  3.5985957997521744`*^9}},ExpressionUUID->"03ab4443-1d50-4e7c-a02e-\
3f488f8994ef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"sf", "[", 
   RowBox[{
    RowBox[{"hu", "[", "t", "]"}], ",", 
    RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5922060867402678`*^9, 
  3.5922061155499153`*^9}},ExpressionUUID->"553974a7-45e9-44bf-bff9-\
a73a7c8f670e"],

Cell["The normal vectors of the surface along the curve are", "Text",
 CellChangeTimes->{{3.5922062089312563`*^9, 3.5922062280593505`*^9}, {
   3.611665413773525*^9, 3.6116654420563745`*^9}, 
   3.6146693565981827`*^9},ExpressionUUID->"0d589dc5-cb3a-4330-94e2-\
0407efd212f7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"yy", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{
    RowBox[{"hu", "[", "t", "]"}], ",", 
    RowBox[{"hv", "[", "t", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5922062360348067`*^9, 3.5922063003584857`*^9}, 
   3.6148618601119404`*^9, 3.614917791873761*^9, 
   3.615531676222638*^9},ExpressionUUID->"9ef1fb61-3ff6-4884-80a0-\
47740dfb5558"],

Cell["\<\
The parameter representation of the ruled surface generated by the normals of \
the surface along the curve is\
\>", "Text",
 CellChangeTimes->{{3.611665474582432*^9, 3.611665527762925*^9}, 
   3.618562101492581*^9},ExpressionUUID->"82964cd4-33f3-4938-be3c-\
1a8d45dbf961"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf", "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"xx", "[", "t", "]"}], " ", "+", "  ", 
   RowBox[{"s", "*", 
    RowBox[{"yy", "[", "t", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5922063337603965`*^9, 
  3.592206366014241*^9}},ExpressionUUID->"faf493df-bbfe-4c59-a8c2-\
3799f3f4f931"],

Cell[TextData[{
 "Such a surface is named a ",
 StyleBox["normal surface.",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5922180596636443`*^9, 3.592218076359599*^9}, {
   3.6116655888370323`*^9, 3.6116656122682734`*^9}, 3.6146694043429136`*^9, 
   3.618562954160351*^9},ExpressionUUID->"40d48265-fa29-4211-835f-\
212ecfd305cb"],

Cell[BoxData[
 RowBox[{"rsf", "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5922064062155404`*^9, 
  3.5922064138929796`*^9}},ExpressionUUID->"54f0deeb-e112-4e3a-b5b7-\
645c30755c60"],

Cell[TextData[{
 "We will answer the question: \n",
 StyleBox["Which curves on the surface generate developable normal surfaces?",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 "\nTo this aim we have to consider the Gaussian curvature gauss[rsf][s,t] \
and find those curves for which this Gaussian curvature equals zero. The \
direct calculation of gauss[rsf][s,t]  symbolically in this generality is \
hopeless: "
}], "Text",
 CellChangeTimes->{{3.5922067006993837`*^9, 3.5922067612428465`*^9}, {
   3.59220679293966*^9, 3.592206827362629*^9}, {3.5922068605635276`*^9, 
   3.5922071163711596`*^9}, 3.5922074624679546`*^9, {3.5922178556159735`*^9, 
   3.592217870047799*^9}, {3.5922179504163957`*^9, 3.592217957559804*^9}, 
   3.6116657781901655`*^9, 
   3.615532199768268*^9},ExpressionUUID->"d073f027-9763-411e-b026-\
70e388d5125b"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", "rsf", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], ",", 
    RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.592206528380528*^9, 3.592206541620285*^9}, {
   3.61553224945711*^9, 3.615532286417224*^9}, {3.618563047210673*^9, 
   3.6185630693639402`*^9}, {3.62573886182058*^9, 3.625738869916994*^9}, 
   3.6257412565877867`*^9, {3.707729184823167*^9, 
   3.707729218690853*^9}},ExpressionUUID->"03196883-6324-4b8a-b892-\
ddc52117aee5"],

Cell["\<\
Therefore we will apply Criterion 3.7.  The condition of developability we \
will apply is\
\>", "Text",
 CellChangeTimes->{{3.5922072468236203`*^9, 3.5922073230269794`*^9}, {
  3.5922074788518915`*^9, 3.5922075577394037`*^9}, {3.592218413391876*^9, 
  3.592218423719467*^9}, {3.6291753155153275`*^9, 3.6291753645386143`*^9}, {
  3.697436911463251*^9, 
  3.697436913655211*^9}},ExpressionUUID->"d2187819-78ac-45ae-9876-\
84c5564e35d0"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"(*", 
   RowBox[{
    RowBox[{")", "                      ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["yy", "\[Prime]",
        MultilineFunction->None], "(", "t", ")"}], ".", 
      RowBox[{
       SuperscriptBox["yy", "\[Prime]",
        MultilineFunction->None], "(", "t", ")"}]}]}], "\[LongEqual]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["yy", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}], ".", 
        RowBox[{
         SuperscriptBox["xx", "\[Prime]",
          MultilineFunction->None], "(", "t", ")"}]}], ")"}], "2"], "."}]}]}],
   TraditionalForm]],
 Evaluatable->False,
 CellChangeTimes->{{3.5919703342231636`*^9, 3.591970334456177*^9}, 
   3.5919703812638545`*^9, 3.592047182216324*^9, {3.592047410741125*^9, 
   3.5920474186035385`*^9}, {3.6116464842946773`*^9, 
   3.611646496306698*^9}},ExpressionUUID->"a9622649-4b08-40bd-b69e-\
df8c5f5af13c"]], "Text",
 CellChangeTimes->{{3.6154435063429728`*^9, 3.615443534313822*^9}, {
  3.615443574858293*^9, 3.6154436171811676`*^9}, {3.6154436514544277`*^9, 
  3.6154436537008314`*^9}, {3.6154437181133447`*^9, 3.6154437181133447`*^9}, {
  3.615443791183873*^9, 3.615443791183873*^9}, {3.6155330280896454`*^9, 
  3.6155330478407745`*^9}},ExpressionUUID->"49bb287e-ca04-4a3c-a7b5-\
87cc3c059670"],

Cell["\<\
We consider a fixed value t and assume that the frame of sf[\[Gamma][t]] at \
this point has principal directions, such that\
\>", "Text",
 CellChangeTimes->{{3.5922081614029317`*^9, 3.592208197498996*^9}, {
   3.592208436427662*^9, 3.592208587483302*^9}, {3.615532908975832*^9, 
   3.6155329097028737`*^9}, 
   3.618562485131524*^9},ExpressionUUID->"05bddabf-437f-4d2a-a429-\
775df1744de2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cf", "[", 
    RowBox[{"1", ",", "1"}], "]"}], " ", "=", " ", "k1"}], ";", " ", 
  RowBox[{
   RowBox[{"cf", "[", 
    RowBox[{"1", ",", "2"}], "]"}], " ", "=", " ", "0"}], ";", " ", 
  RowBox[{
   RowBox[{"cf", "[", 
    RowBox[{"2", ",", "2"}], "]"}], " ", "=", " ", "k2"}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.592208596248803*^9, 3.5922086683489275`*^9}, {
  3.6179721880391293`*^9, 
  3.6179721906402783`*^9}},ExpressionUUID->"a8a87f71-3fc5-4483-baa4-\
a8ca537d6ffa"],

Cell["\<\
are given by the principal curvatures of sf at this point. For the tangent \
vector of the curve xx[t] at this point we have\
\>", "Text",
 CellChangeTimes->{{3.5922086876910334`*^9, 3.5922087121154304`*^9}, {
  3.5922087602831855`*^9, 3.592208787339733*^9}, {3.6155329249997487`*^9, 
  3.6155329518872867`*^9}},ExpressionUUID->"7bedcc40-fa4a-410a-ae85-\
5750cab11b07"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["xx", "\[Prime]",
     MultilineFunction->None], "(", "t", ")"}], "\[LongEqual]", " ", 
   RowBox[{
    RowBox[{"x", " ", 
     RowBox[{
      RowBox[{"amf", "(", "1", ")"}], "\[InvisibleApplication]", 
      RowBox[{"(", "sf", ")"}]}]}], "+", 
    RowBox[{"y", " ", 
     RowBox[{
      RowBox[{"amf", "(", "2", ")"}], "\[InvisibleApplication]", 
      RowBox[{"(", "sf", ")"}]}], "  ", "with", "  ", 
     SuperscriptBox["x", "2"]}], " ", "+", " ", 
    SuperscriptBox["y", "2"]}], "\[LongEqual]", "1"}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5922087972623005`*^9, 3.5922088957339325`*^9}, {
   3.5922089455897846`*^9, 3.5922090179659243`*^9}, {3.6155329861842484`*^9, 
   3.615532999689021*^9}, 
   3.6185626038273125`*^9},ExpressionUUID->"e8e0218c-834d-4ead-8b05-\
630ab03f998e"],

Cell["\<\
assuming that t is the arc length of the curve.  Using the third derivation \
equation we obtain for the derivative of yy[t]\
\>", "Text",
 CellChangeTimes->{{3.592209073251086*^9, 3.5922091739078436`*^9}, {
   3.615533014047842*^9, 3.6155330161909647`*^9}, 
   3.618563604760563*^9},ExpressionUUID->"a0d1fc13-d9da-4747-9c00-\
aa8508233ce6"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["yy", "\[Prime]",
     MultilineFunction->None], "(", "t", ")"}], " ", "\[LongEqual]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "(", 
      RowBox[{
       RowBox[{"amf", "(", "3", ")"}], "\[InvisibleApplication]", 
       RowBox[{"(", "sf", ")"}]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "(", "t", ")"}], ")"}]}], ".", 
    SuperscriptBox["\[Gamma]", "\[Prime]",
     MultilineFunction->None]}], "\[LongEqual]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"amf", "(", "1", ")"}], "\[InvisibleApplication]", 
        RowBox[{"(", "sf", ")"}]}], 
       RowBox[{"\[Omega]", "(", "2", ")"}]}], " ", "-", 
      RowBox[{
       RowBox[{
        RowBox[{"amf", "(", "2", ")"}], "\[InvisibleApplication]", 
        RowBox[{"(", "sf", ")"}]}], 
       RowBox[{"\[Omega]", "(", "1", ")"}]}]}], " ", ")"}], ".", 
    SuperscriptBox["\[Gamma]", "\[Prime]",
     MultilineFunction->None]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5922091796091695`*^9, 3.592209399005718*^9}, 
   3.5922094301304984`*^9, {3.5922094720768976`*^9, 3.5922095483502607`*^9}, {
   3.6155331102723455`*^9, 3.615533147672485*^9}, {3.618562644897662*^9, 
   3.6185626640177555`*^9}, 
   3.6185636420766973`*^9},ExpressionUUID->"7b3b4aba-c3b3-4020-ac34-\
fb7b51f62f44"],

Cell[TextData[{
 "In the chosen frame with principal directions we have, using the formulas \
for the ",
 ButtonBox["\[Omega][i]",
  BaseStyle->"Hyperlink",
  ButtonData->"cij"],
 " in Subsection 2.2.3, Inserting \[Sigma][1] = x, \[Sigma][2] = y"
}], "Text",
 CellChangeTimes->{{3.5922096102918034`*^9, 3.5922096605156755`*^9}, {
  3.592213357239681*^9, 3.5922134378152895`*^9}, {3.5922134816957994`*^9, 
  3.5922134817037997`*^9}, {3.592215535215254*^9, 
  3.5922155360162997`*^9}},ExpressionUUID->"debdfb0b-db3a-4ae8-a235-\
87fb65b8fffd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Omega]", "[", "1", "]"}]}], " ", "==", " ", 
   RowBox[{"k2", "*", "y"}]}], ";", "  ", 
  RowBox[{
   RowBox[{"\[Omega]", "[", "2", "]"}], " ", "==", " ", 
   RowBox[{"k1", "*", "x"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5922135413852134`*^9, 3.5922136907857585`*^9}, {
  3.59221373679439*^9, 3.5922137769206853`*^9}, {3.592215489306628*^9, 
  3.5922155094177785`*^9}},ExpressionUUID->"04883c07-1aef-40cb-9797-\
f69770bd213a"],

Cell["It follows:", "Text",
 CellChangeTimes->{{3.592213810783622*^9, 3.592213814695846*^9}, {
  3.5922138524090033`*^9, 3.5922138799195766`*^9}, {3.592215530463982*^9, 
  3.59221555909562*^9}},ExpressionUUID->"78aa325b-3b83-4011-bb94-\
8d0975bb2731"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"yy", "'"}], ".", 
    RowBox[{"yy", "'"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"k1", "^", "2"}], "*", 
     RowBox[{"x", "^", "2"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"k2", "^", "2"}], "*", 
     RowBox[{"y", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xx", "'"}], ".", 
   RowBox[{"yy", "'"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"k1", "*", 
    RowBox[{"x", "^", "2"}]}], "+", " ", 
   RowBox[{"k2", "*", 
    RowBox[{"y", "^", "2"}]}]}]}]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5922155975878215`*^9, 3.592215639401213*^9}, {
   3.592215732299526*^9, 3.592215762529256*^9}, 
   3.592215806385764*^9},ExpressionUUID->"83d147fc-917d-49db-950f-\
386b2d604624"],

Cell["\<\
In the case k1 == k2 any curve on the surface is a principal  curves, and the \
corresponding normal surface is always developable:\
\>", "Text",
 CellChangeTimes->{{3.592216110336149*^9, 3.592216217967305*^9}, {
  3.592216888759672*^9, 3.592216900167325*^9}, {3.592217137663909*^9, 
  3.5922171386879673`*^9}},ExpressionUUID->"bc2dcd13-f234-42bb-8028-\
a9cd0f2a9d31"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "2"}], " ", "+", " ", 
       RowBox[{"y", "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", 
     RowBox[{"k1", " ", "==", " ", "k2"}]}], "}"}], ",", " ", "\n", "  ", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"k1", "^", "2"}], "*", 
       RowBox[{"x", "^", "2"}]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"k2", "^", "2"}], "*", 
       RowBox[{"y", "^", "2"}]}]}], " ", "==", " ", "\n", "    ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k1", "*", 
         RowBox[{"x", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"k2", "*", 
         RowBox[{"y", "^", "2"}]}]}], ")"}], "^", "2"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.592215866233187*^9, 3.5922159659308896`*^9}, {
  3.59221601646778*^9, 
  3.5922160588312035`*^9}},ExpressionUUID->"16a0f3c2-286f-4d1a-ade7-\
00c2ecd623d4"],

Cell[TextData[{
 "We used ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], " ", "+", " ", 
    SuperscriptBox["y", "2"]}], "\[LongEqual]", "1"}]],
  Evaluatable->False,
  CellChangeTimes->{{3.5922087972623005`*^9, 3.5922088957339325`*^9}, {
   3.5922089455897846`*^9, 3.5922090179659243`*^9}},ExpressionUUID->
  "9b95e13d-6025-4fa7-8088-0661bf180b00"],
 " since t must be assumed to be  the arc length of the curve xx[t]. Now we \
assume \nk1 <k2 and solve the condition"
}], "Text",
 CellChangeTimes->{{3.5922162494631066`*^9, 3.5922163814636564`*^9}, 
   3.592216485983635*^9, {3.615537646480226*^9, 3.6155376744510756`*^9}, {
   3.6155377729340477`*^9, 
   3.6155377904996786`*^9}},ExpressionUUID->"c78510d1-f278-4685-ba88-\
eb6e2dd318ac"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"k1", "^", "2"}], "*", 
        RowBox[{"x", "^", "2"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"k2", "^", "2"}], "*", 
        RowBox[{"y", "^", "2"}]}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k1", "*", 
          RowBox[{"x", "^", "2"}]}], "+", " ", 
         RowBox[{"k2", "*", 
          RowBox[{"y", "^", "2"}]}]}], ")"}], "^", "2"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "2"}], "+", 
       RowBox[{"y", "^", "2"}]}], "\[Equal]", "1"}], ",", 
     RowBox[{"k1", "<", "k2"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t1", ",", "t2"}], "}"}], ",", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.592200842980342*^9, 3.592200961997149*^9}, {
   3.592201251093684*^9, 3.5922013459261084`*^9}, {3.5922015293455997`*^9, 
   3.592201554663048*^9}, {3.5922020007245607`*^9, 3.5922020071349277`*^9}, {
   3.592202175170539*^9, 3.592202182919982*^9}, 3.5922023318775015`*^9, 
   3.5922033977764673`*^9, {3.5922035067917027`*^9, 3.5922035132950745`*^9}, {
   3.5922035968798556`*^9, 3.592203648999837*^9}, 3.6148618601275406`*^9, 
   3.614917791904961*^9, 
   3.6900917128649273`*^9},ExpressionUUID->"5b714dda-e38d-45da-81e9-\
a2ad490c4550"],

Cell[TextData[{
 "Thus we proved\n",
 StyleBox["Proposition 4.",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 StyleBox["A curve on a regular surface is a principal curve of the surface \
iff its corresponding normal surface is developable",
  FontSlant->"Italic"],
 ". \[FilledRectangle]\n\nWe remember, that on a surface without umbilic \
points there exist two families of principal lines intersecting orthogonally, \
namely the integral curves of the two fields of principal directions."
}], "Text",
 CellChangeTimes->{{3.59221665199113*^9, 3.5922166772315736`*^9}, {
   3.5922167386160846`*^9, 3.5922167741271152`*^9}, {3.592217151807718*^9, 
   3.592217208774976*^9}, {3.592217254623598*^9, 3.5922173034473915`*^9}, {
   3.592217335319214*^9, 3.592217420312075*^9}, {3.5922175010716944`*^9, 
   3.5922175148644834`*^9}, {3.592218543152298*^9, 3.5922185677917075`*^9}, {
   3.5984545080142236`*^9, 3.5984545145705986`*^9}, {3.598454584037572*^9, 
   3.5984545866857233`*^9}, 3.6155384990217237`*^9, {3.697439875630802*^9, 
   3.697439877734638*^9}},ExpressionUUID->"1a71dea2-4570-4a26-83af-\
c93b10844400"],

Cell[TextData[{
 StyleBox["Corollary",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["On a developable surface a family of generating lines and their \
orthogonal trajectories are ",
  FontSlant->"Italic"],
 "principal curve",
 StyleBox["s",
  FontSlant->"Italic"],
 ".\n",
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". The normal vector of the surface along a generating line is constant. \
Thus the normal surface over a generating line is a plane. \[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.598595326447343*^9, 3.598595355291794*^9}, {
   3.5985954204219084`*^9, 3.598595640085894*^9}, {3.5985957006764*^9, 
   3.5985957064952106`*^9}, 3.6174428163857994`*^9, 
   3.618564000414193*^9},ExpressionUUID->"73f42006-6c68-49e7-9e52-\
ee86f830068b"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.9. Surfaces of Revolution", "Subsection",
 CellChangeTimes->{{3.5922186227278495`*^9, 3.592218655535726*^9}, 
   3.5924598940730705`*^9, 3.611998625801326*^9, 3.6120759619398127`*^9, 
   3.616138350874133*^9, 3.616236325855336*^9, 
   3.6280851914781723`*^9},ExpressionUUID->"82743fe3-2c5e-4ece-be6c-\
970ece2598fd"],

Cell["\<\
Any body produced on a lathe or a potter\[CloseCurlyQuote]s wheel is bordered \
by a surface of revolution. Such surfaces are not only easy to produce;  they \
may serve also as easy to handle examples in surface geometry. The reason is \
that the geometric properties of such a surface are defined by the properties \
of its generating curve, the profile curve or meridian of the surface. Thus \
two-dimensional problems for surfaces can be reduced to one-dimensional \
problems for curves, e.g. partial differential equations for surfaces  to \
ordinary differential equations for the meridians, which are much easier to \
solve. In this section we consider some of these applications.\
\>", "Text",
 CellChangeTimes->{{3.594271376925708*^9, 3.594271399649008*^9}, 
   3.594271494168414*^9, {3.5942716242798557`*^9, 3.594271650616362*^9}, 
   3.5942717013762655`*^9, {3.5942718587122645`*^9, 3.5942719851514964`*^9}, {
   3.5942721101926484`*^9, 3.594272209720341*^9}, {3.5942723600879416`*^9, 
   3.5942724882642727`*^9}, {3.594272641160018*^9, 3.5942727229756975`*^9}, {
   3.5942727668722086`*^9, 3.5942729100653987`*^9}, {3.594272942136233*^9, 
   3.5942729601122613`*^9}, {3.5942729958403044`*^9, 3.594273047392253*^9}, {
   3.5942747450093517`*^9, 3.5942747465524397`*^9}, 3.594274784344601*^9, 
   3.698997364728491*^9, {3.699795861868799*^9, 
   3.699795889413745*^9}},ExpressionUUID->"9a1e1fc7-a667-4031-9458-\
e768ab9f5c8c"],

Cell[CellGroupData[{

Cell["3.9.1. Definition and Fundamental Invariants", "Subsubsection",
 CellChangeTimes->{{3.5924599150863075`*^9, 3.5924599499211693`*^9}, 
   3.618637581542035*^9, 3.62048228513097*^9, 3.628085323922405*^9, {
   3.629186596970511*^9, 3.62918663603998*^9}, {3.6291867838712406`*^9, 
   3.6291867870088463`*^9}, 3.6291877482677407`*^9, 3.69744003147788*^9, 
   3.697459246981945*^9, 3.707741482329783*^9, 
   3.707742243090084*^9},ExpressionUUID->"46a71205-93f6-4f60-b2cd-\
264cb7810502"],

Cell[TextData[{
 "Rotating a curve in the x,z-plane around the z-axis generates a ",
 StyleBox["surface of revolution",
  FontColor->RGBColor[0, 0, 1]],
 ". A parameter representation of a surface of revolution is"
}], "Text",
 CellChangeTimes->{{3.5922246929608603`*^9, 3.5922247958887477`*^9}, 
   3.618637861515727*^9},ExpressionUUID->"7da5e862-aa09-4973-ba3a-\
aa5ce34dbc09"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f_", ",", "h_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], "*", 
     RowBox[{"Cos", "[", "v", "]"}]}], ",", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], "*", 
     RowBox[{"Sin", "[", "v", "]"}]}], ",", " ", 
    RowBox[{"h", "[", "u", "]"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5922251535142026`*^9, 3.5922251573054194`*^9}, {
  3.592225626315245*^9, 3.59222574073979*^9}, {3.5927415105422573`*^9, 
  3.592741513818263*^9}},ExpressionUUID->"78acdcef-3d34-46be-841b-\
3a35d5c65943"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"f", ",", "h"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.592226758859023*^9, 3.592226768058549*^9}, {
   3.5922268420587816`*^9, 3.59222685356244*^9}, {3.592227075467132*^9, 
   3.5922270836586003`*^9}, {3.592316504708578*^9, 3.592316515347797*^9}, 
   3.592741514426664*^9},ExpressionUUID->"50b1290d-fe4b-4a75-8208-\
871b09816cb5"],

Cell[TextData[{
 "The rotating curves v = const. are the ",
 StyleBox["meridians",
  FontColor->RGBColor[0, 0, 1]],
 " of the surface of revolution, e.g."
}], "Text",
 CellChangeTimes->{{3.592455608074743*^9, 3.5924556618168373`*^9}, 
   3.5942709406726584`*^9},ExpressionUUID->"834c3963-7b4c-4e2b-9bb2-\
d9bdf5719d59"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", "h"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "/.", " ", 
  RowBox[{"v", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.592226758859023*^9, 3.592226768058549*^9}, {
   3.5922268420587816`*^9, 3.59222685356244*^9}, {3.592227075467132*^9, 
   3.5922270836586003`*^9}, {3.592316504708578*^9, 3.592316515347797*^9}, {
   3.592455691269689*^9, 3.592455708289319*^9}, 
   3.5927415323198953`*^9},ExpressionUUID->"455fc558-bc48-4116-a63b-\
b482bd1ce61a"],

Cell["The sphere and the torus are such surfaces", "Text",
 CellChangeTimes->{{3.5922271717606397`*^9, 
  3.592227193319873*^9}},ExpressionUUID->"3a774f71-bf64-4485-aa03-\
f678535677f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"Cos", ",", "Sin"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.592226758859023*^9, 3.592226768058549*^9}, {
  3.5922268420587816`*^9, 3.59222685356244*^9}, {3.592227075467132*^9, 
  3.5922270836586003`*^9}, {3.612072328365831*^9, 
  3.6120723342938414`*^9}},ExpressionUUID->"b50ca1f2-99e7-4d1f-a32a-\
fbb87d4ff44b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923061930991216`*^9, 
  3.592306214393159*^9}},ExpressionUUID->"1f8b9a2c-6031-492a-8f10-\
3560351d5a3a"],

Cell[BoxData[
 RowBox[{"?", "torus"}]], "Input",
 CellChangeTimes->{{3.5923062653272486`*^9, 
  3.592306284000481*^9}},ExpressionUUID->"f28d7f15-c3f3-4f7d-ad29-\
bab56cc83e1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"torus", "[", 
   RowBox[{"3", ",", "1"}], "]"}], "[", 
  RowBox[{"v", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923063610022163`*^9, 3.5923063772574453`*^9}, {
  3.612072444539235*^9, 
  3.6120724721980834`*^9}},ExpressionUUID->"8825b89d-1b18-4918-9ce8-\
c6228cdce506"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ftor", "[", "v_", "]"}], " ", ":=", 
   RowBox[{"3", "+", 
    RowBox[{"Cos", "[", "v", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"htor", "[", "v_", "]"}], " ", ":=", " ", 
   RowBox[{"Sin", "[", "v", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5922272678111334`*^9, 3.592227311142612*^9}, {
   3.592227345322567*^9, 3.592227440772026*^9}, 
   3.5927415350966997`*^9},ExpressionUUID->"88cd2e53-e643-4655-9ed9-\
6b75b3442164"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"ftor", ",", "htor"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5927415501507263`*^9},ExpressionUUID->"8d4f28f0-0be3-4eae-8b72-\
b02055e3276c"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"torus", "[", 
    RowBox[{"8", ",", "3"}], "]"}], "[", 
   RowBox[{"0", ",", 
    RowBox[{"3", 
     RowBox[{"Pi", "/", "2"}]}], ",", 
    RowBox[{"-", "Pi"}], ",", "Pi"}], "]"}]}]], "Input",ExpressionUUID->\
"1104f88a-f3d7-466d-bdc7-018085289cc0"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"torus", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5922257630910683`*^9, 3.592225775968805*^9}, {
   3.592225989373011*^9, 3.5922259964974184`*^9}, {3.5922260927779255`*^9, 
   3.5922261304900827`*^9}, {3.5922261650030565`*^9, 
   3.5922261971228933`*^9}, {3.592226229242731*^9, 3.5922263441073008`*^9}, {
   3.592226740379966*^9, 3.592226750132524*^9}, {3.592226787731674*^9, 
   3.59222679937234*^9}, {3.59222687175648*^9, 3.592226888444435*^9}, {
   3.5922269726212497`*^9, 3.5922269743323474`*^9}, 3.5922270304075546`*^9, {
   3.5922271192936387`*^9, 3.5922271563647594`*^9}, {3.592227492203968*^9, 
   3.59222750168251*^9}, {3.5922275492762327`*^9, 3.592227574379668*^9}, {
   3.5922279260677834`*^9, 3.5922279324121466`*^9}, {3.5922280294676976`*^9, 
   3.5922280530840483`*^9}, 3.5923064930564485`*^9, {3.6120725609778395`*^9, 
   3.6120725888394885`*^9}},ExpressionUUID->"558ae2d1-6e78-4b06-9ba6-\
614a8053d930"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"ftor", ",", "htor"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5922257630910683`*^9, 3.592225775968805*^9}, {
   3.592225989373011*^9, 3.5922259964974184`*^9}, {3.5922260927779255`*^9, 
   3.5922261304900827`*^9}, {3.5922261650030565`*^9, 
   3.5922261971228933`*^9}, {3.592226229242731*^9, 3.5922263441073008`*^9}, {
   3.592226740379966*^9, 3.592226750132524*^9}, {3.592226787731674*^9, 
   3.59222679937234*^9}, {3.59222687175648*^9, 3.592226888444435*^9}, {
   3.5922269726212497`*^9, 3.5922269743323474`*^9}, 3.5922270304075546`*^9, {
   3.5922271192936387`*^9, 3.5922271563647594`*^9}, {3.592227492203968*^9, 
   3.59222750168251*^9}, {3.5922275492762327`*^9, 3.592227574379668*^9}, {
   3.5922279260677834`*^9, 3.5922279324121466`*^9}, {3.5922280294676976`*^9, 
   3.5922280530840483`*^9}, 
   3.5927415515391293`*^9},ExpressionUUID->"c5943a66-f6fd-415f-9259-\
1c5f3dfed6b5"],

Cell["Example of rotating function graphs", "Text",
 CellChangeTimes->{{3.59427376520831*^9, 
  3.594273780472183*^9}},ExpressionUUID->"e64e42d7-4f79-4142-817c-\
ece6e3cbf455"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"id", "[", "u_", "]"}], " ", ":=", " ", "u"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5922276737623525`*^9, 3.5922277054741664`*^9}, {
  3.5942736968433995`*^9, 
  3.594273702465721*^9}},ExpressionUUID->"cc695911-80c7-40ef-a629-\
75b179f6456f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"Cos", ",", "id"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",ExpressionUUID->"96baec23-7170-\
4609-a879-fd99487e3511"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"Cos", ",", "id"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"4", "*", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5922257630910683`*^9, 3.592225775968805*^9}, {
   3.592225989373011*^9, 3.5922259964974184`*^9}, {3.5922260927779255`*^9, 
   3.5922261304900827`*^9}, {3.5922261650030565`*^9, 
   3.5922261971228933`*^9}, {3.592226229242731*^9, 3.5922263441073008`*^9}, {
   3.592226740379966*^9, 3.592226750132524*^9}, {3.592226787731674*^9, 
   3.59222679937234*^9}, {3.59222687175648*^9, 3.592226888444435*^9}, {
   3.5922269726212497`*^9, 3.5922269743323474`*^9}, 3.5922270304075546`*^9, {
   3.5922271192936387`*^9, 3.5922271563647594`*^9}, {3.592227492203968*^9, 
   3.59222750168251*^9}, {3.5922275492762327`*^9, 3.592227574379668*^9}, {
   3.592227739908136*^9, 3.5922277753561635`*^9}, {3.592228075636338*^9, 
   3.592228080619623*^9}, {3.5942731171882453`*^9, 3.594273179040783*^9}, {
   3.594273287980014*^9, 3.59427333423666*^9}, {3.5942733772041173`*^9, 
   3.5942733783931856`*^9}, {3.5942734515083675`*^9, 
   3.5942734539215055`*^9}, {3.594273661022351*^9, 3.594273673524066*^9}, {
   3.5942737331404757`*^9, 3.594273734280541*^9}, {3.594273822492586*^9, 
   3.594273824035675*^9}},ExpressionUUID->"380cbe50-4bd2-4936-92c3-\
b674a37844a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"id", ",", "Sin"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6976910122036543`*^9, 3.697695672080495*^9, 3.697695808076261*^9, {
   3.6976973677519913`*^9, 
   3.697697404719733*^9}},ExpressionUUID->"3acea782-5aae-494f-a7e8-\
68fa2ba1f59e"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"id", ",", "Sin"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5922257630910683`*^9, 3.592225775968805*^9}, {
   3.592225989373011*^9, 3.5922259964974184`*^9}, {3.5922260927779255`*^9, 
   3.5922261304900827`*^9}, {3.5922261650030565`*^9, 
   3.5922261971228933`*^9}, {3.592226229242731*^9, 3.5922263441073008`*^9}, {
   3.592226740379966*^9, 3.592226750132524*^9}, {3.592226787731674*^9, 
   3.59222679937234*^9}, {3.59222687175648*^9, 3.592226888444435*^9}, {
   3.5922269726212497`*^9, 3.5922269743323474`*^9}, 3.5922270304075546`*^9, {
   3.5922271192936387`*^9, 3.5922271563647594`*^9}, {3.592227492203968*^9, 
   3.59222750168251*^9}, {3.5922275492762327`*^9, 3.592227574379668*^9}, {
   3.592227739908136*^9, 3.5922277753561635`*^9}, {3.592228075636338*^9, 
   3.592228080619623*^9}, {3.5942731171882453`*^9, 3.594273179040783*^9}, {
   3.594273287980014*^9, 3.59427333423666*^9}, {3.5942733772041173`*^9, 
   3.5942733783931856`*^9}, {3.5942734515083675`*^9, 3.594273490251583*^9}, {
   3.594273530348877*^9, 3.5942735469958286`*^9}, 3.697691006120614*^9, {
   3.6976974168345633`*^9, 
   3.697697493293829*^9}},ExpressionUUID->"8f1eeb06-e894-4db9-a309-\
6c571788253c"],

Cell["\<\
We return to the general surfaces of revolution. The intersections of the \
surface with the z-axis are singularities:\
\>", "Text",
 CellChangeTimes->{{3.592307003801346*^9, 3.592307178864853*^9}, {
  3.697454121828744*^9, 
  3.6974541256846733`*^9}},ExpressionUUID->"9535dee6-f819-4d53-838a-\
c182120ed2f3"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "1", "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"tv", "[", "2", "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592307183295261*^9, 3.592307206632902*^9}, 
   3.5923114948741784`*^9, {3.5927415609927454`*^9, 3.592741561928747*^9}, 
   3.61760002546109*^9, 
   3.617600085817596*^9},ExpressionUUID->"2fcc1cb2-7952-4282-b934-\
17af242e174d"],

Cell["\<\
This vector vanishes for f[u] == 0. If f[u] \[NotEqual]0 the singularities of \
the surface are circles generated by rotating a singularity of the meridian. \
\>", "Text",
 CellChangeTimes->{{3.5988833745252876`*^9, 3.5988834041653395`*^9}, {
   3.5988834859718833`*^9, 3.5988836255765285`*^9}, 
   3.612073729544692*^9},ExpressionUUID->"88ab18e7-d4c4-4d52-bb73-\
3f117a611170"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"amf", "[", "3", "]"}], "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", "\[Element]", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5988828503643675`*^9, 3.5988829588157578`*^9}, 
   3.614861860314741*^9, 3.6149177921077614`*^9, 
   3.6155317601264367`*^9},ExpressionUUID->"5f150cff-686f-42fa-a565-\
583ec7415a51"],

Cell["The normal vector is Indeterminate iff", "Text",
 CellChangeTimes->{{3.5923116177555943`*^9, 3.59231164965765*^9}, {
  3.697454592621673*^9, 
  3.697454638965097*^9}},ExpressionUUID->"d988db5e-e73b-4b7f-8dc8-\
339c6ac60cc1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "\[Equal]", " ", "0"}], ")"}], "  ", "||", 
  " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "u", "]"}], "\[Equal]", " ", "0"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"h", "'"}], "[", "u", "]"}], "\[Equal]", " ", "0"}], ")"}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.592311665117277*^9, 3.592311835422776*^9}, 
   3.592741566343555*^9},ExpressionUUID->"bc801e33-3641-4a97-82a0-\
e8f88eaced00"],

Cell["\<\
We calculate general formulas for the fundamental invariants of the surfaces \
of revolution. To this aim we often assume that u is the arc length of the \
meridians v == const.\
\>", "Text",
 CellChangeTimes->{{3.592312523212384*^9, 3.5923126353141813`*^9}, {
  3.5924558966908503`*^9, 3.5924558969404507`*^9}, {3.618637873730548*^9, 
  3.6186378991117926`*^9}},ExpressionUUID->"956b113f-bfc4-4dba-af42-\
f2f49f0d3b18"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund1", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293457656372*^9}, 
   3.5927415729891667`*^9},ExpressionUUID->"059bb68a-92d4-4a91-b466-\
bd9d10c16131"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923126741270494`*^9, 3.592312682005063*^9}, {
   3.5927415848451877`*^9, 3.59274158606199*^9}, {3.614861860330341*^9, 
   3.614861860330341*^9}, {3.6149177921233616`*^9, 3.6149177921233616`*^9}, 
   3.6155317601744394`*^9, 
   3.616235037932674*^9},ExpressionUUID->"95373f55-845f-4a29-8a7c-\
f1ca5c2389c0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund2", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, 
   3.592741587465992*^9},ExpressionUUID->"f58a63a0-cf65-4224-9d06-\
13fba2821a53"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
         "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
         "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}], ")"}]}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fund2", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
  3.592312753687189*^9, 3.5923127859948463`*^9}, {3.592741600554415*^9, 
  3.592741602722819*^9}, {3.612073960315897*^9, 3.612074035164829*^9}, {
  3.614861860330341*^9, 3.6148618603459406`*^9}, {3.614917792138962*^9, 
  3.614917792138962*^9}},ExpressionUUID->"acf4df47-4251-40b0-9d92-\
b9512bf6c4c8"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
         "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
         "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}], ")"}]}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"1", ",", " ", "1"}], "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", "\n", "    ", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
   3.592293728987649*^9, 3.592293822790614*^9}, {3.5927416150780406`*^9, 
   3.5927416171528444`*^9}, {3.612074104850151*^9, 3.6120741149901686`*^9}, {
   3.6148618603459406`*^9, 3.6148618603459406`*^9}, {3.6149177921545615`*^9, 
   3.6149177921545615`*^9}, 
   3.617972391888789*^9},ExpressionUUID->"73fb1aee-a8a3-496d-99b7-\
ce243006def1"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"1", ",", " ", "2"}], "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", "\n", "    ", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
   3.592293728987649*^9, 3.592293822790614*^9}, {3.592293870589098*^9, 
   3.59229388912193*^9}, {3.5927416267468615`*^9, 3.5927416281196637`*^9}, {
   3.614861860361541*^9, 3.614861860361541*^9}, {3.6149177921701612`*^9, 
   3.6149177921701612`*^9}, 
   3.6179723934888806`*^9},ExpressionUUID->"a71207df-ada9-4a47-9001-\
36fbc1ef3b7e"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
         "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
         "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}], ")"}]}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"cf", "[", 
       RowBox[{"2", ",", " ", "2"}], "]"}], "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", "\n", "    ", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
   3.592293728987649*^9, 3.592293822790614*^9}, {3.592293870589098*^9, 
   3.592293909916767*^9}, {3.592741633018072*^9, 3.5927416341256742`*^9}, {
   3.612074196281912*^9, 3.6120742080599327`*^9}, {3.614861860361541*^9, 
   3.614861860361541*^9}, {3.6149177921857615`*^9, 3.6149177921857615`*^9}, 
   3.61797239487296*^9},ExpressionUUID->"592fe328-b4ae-4864-844b-\
d933175ef08b"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"prcurvatures", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
      RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592293344680974*^9, 3.592293492662834*^9}, {
  3.592293728987649*^9, 3.592293822790614*^9}, {3.592293870589098*^9, 
  3.592293909916767*^9}, {3.5923129860183973`*^9, 3.592313012959645*^9}, {
  3.5923130719745483`*^9, 3.5923131018642006`*^9}, {3.592741640880486*^9, 
  3.5927416422688885`*^9}, {3.614861860377141*^9, 3.614861860377141*^9}, {
  3.6149177922013617`*^9, 
  3.6149177922013617`*^9}},ExpressionUUID->"cabc9971-df6b-4a9c-991e-\
600ef5cceb6f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"prcurvatures", "[", 
    RowBox[{"sfrev", "[", 
     RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
   RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.592315825904586*^9, 3.592315836169404*^9}, 
   3.592315870785865*^9, 3.592741650505703*^9, 3.5988843282017965`*^9, {
   3.612074334747755*^9, 
   3.612074353998189*^9}},ExpressionUUID->"a37d95ef-dff8-4888-a712-\
8654cf437739"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"gauss", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
      RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
  3.592741687072167*^9, 3.5927416925009766`*^9}, {3.614861860392741*^9, 
  3.614861860392741*^9}, {3.614917792216962*^9, 
  3.614917792216962*^9}},ExpressionUUID->"f2339c18-abdb-451a-8136-\
a1a45368538a"],

Cell[BoxData[
 RowBox[{"Assuming", "[", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", "\[Element]", "Reals"}], ",", " ", 
     RowBox[{"v", "\[Element]", "Reals"}]}], "}"}], ",", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"gauss", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"Cos", ",", " ", "Sin"}], "]"}], "]"}], "[", " ", 
     RowBox[{"u", ",", " ", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
   3.592741687072167*^9, 3.5927416925009766`*^9}, 3.5988845224279056`*^9, 
   3.5988845565158553`*^9, {3.598884601500428*^9, 
   3.598884656618581*^9}},ExpressionUUID->"4fd9207a-d933-4334-bcb6-\
63da0db01f1b"],

Cell[TextData[{
 "This is the curvature of the unit sphere; the singularities u = \
\[PlusMinus] \[Pi]/2 of the parameter representation (not the surface!) are \
neglected by ",
 StyleBox["Mathematica.",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.598884719488177*^9, 3.5988849026396523`*^9}, {
   3.5988849344074697`*^9, 3.5988849347754908`*^9}, 
   3.5988849765198784`*^9},ExpressionUUID->"2953cff4-9b5a-4fdd-94b4-\
38a7078e2119"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"meancurvature", "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
      RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
   3.5923161606031733`*^9, 3.5923161764528017`*^9}, {3.592741702859395*^9, 
   3.5927417040449967`*^9}, {3.614861860392741*^9, 3.6148618604083414`*^9}, 
   3.6148631366153827`*^9, {3.614917792232562*^9, 
   3.614917792232562*^9}},ExpressionUUID->"67b51bb4-6ea3-45b4-ba43-\
8ebe4e277a5e"],

Cell[TextData[{
 StyleBox["The parameter curves u =const, resp. v= const. are the ",
  FontSlant->"Italic"],
 StyleBox["principal curves",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 ". For u= const the normal surfaces are circular cones, or cylinders if the \
tangent to the meridian at u is parallel to the  z-axis, or planes if the \
tangent at u to the meridian is parallel to the x,y-plane. They are planes \
containing the z-axis for the curves v = const."
}], "Text",
 CellChangeTimes->{{3.5923166334400043`*^9, 3.5923167850410705`*^9}, {
   3.592316831903553*^9, 3.592316919622507*^9}, {3.592316964098185*^9, 
   3.592317059741953*^9}, {3.598885239647928*^9, 3.5988852870966425`*^9}, 
   3.6162356507017508`*^9},ExpressionUUID->"dd6a4988-99f8-4e2b-9b13-\
ba8f11b1b28f"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"sfrev", "[", 
        RowBox[{"f", ",", " ", "h"}], "]"}], "]"}], "[", " ", 
      RowBox[{"u", ",", " ", "v"}], "]"}], ",", " ", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
  3.5923161606031733`*^9, 3.5923161764528017`*^9}, {3.5923175406751976`*^9, 
  3.592317559504431*^9}, {3.5927417169150195`*^9, 3.592741717944621*^9}, {
  3.6148618604083414`*^9, 3.614861860423941*^9}, {3.614917792248162*^9, 
  3.614917792248162*^9}, {3.6162357121814585`*^9, 
  3.6162357144434624`*^9}},ExpressionUUID->"0012f8c0-66c0-4ba1-a574-\
7061cd785e0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"f", ",", " ", "h"}], "]"}], "[", " ", 
  RowBox[{"u", ",", " ", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.616235837855279*^9},ExpressionUUID->"5a5ea414-2a46-4fdf-98b0-\
c766fa22d3d8"],

Cell["\<\
A parameter representation of the meridian in the x,z-plane is\
\>", "Text",
 CellChangeTimes->{{3.592318386851884*^9, 3.592318411250327*^9}, 
   3.5923192904366713`*^9},ExpressionUUID->"c3b947b7-cf23-4925-8255-\
f8519aac4b15"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xx", "[", "u_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], ",", 
     RowBox[{"h", "[", "u", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5923177760796113`*^9, 3.592317802069257*^9}, 
   3.592741726399836*^9},ExpressionUUID->"6cf6aa32-4526-451f-a592-\
d6b4a9420613"],

Cell["\<\
We see that the normal vector of the surface coincides with the normal vector \
of the meridian. For the curvature k[u] of xx[u] we have\
\>", "Text",
 CellChangeTimes->{{3.592318436849972*^9, 3.5923184469743896`*^9}, {
   3.59231853820335*^9, 3.592318550979772*^9}, {3.592319354537184*^9, 
   3.592319416235292*^9}, 
   3.598454226766137*^9},ExpressionUUID->"a4d4871e-7ee6-4548-bf64-\
1659f9319d55"],

Cell[BoxData[
 RowBox[{"?", "curvatures"}]], "Input",
 CellChangeTimes->{{3.5923178150952797`*^9, 
  3.59231782085169*^9}},ExpressionUUID->"a908b819-1be4-4676-87a7-\
fae49e1bca88"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "f", "]"}], "[", "u", 
       "]"}], "^", "2"}], " ", "+", " ", "\n", "    ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "1", "]"}], "[", "h", "]"}], "[", "u", 
       "]"}], "^", "2"}]}], " ", "==", " ", "1"}], ",", " ", "\n", "  ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"curvatures", "[", "xx", "]"}], "[", "u", "]"}], 
    "\[IndentingNewLine]", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923159480528*^9, 3.5923159491604023`*^9}, {
   3.5923161606031733`*^9, 3.5923161764528017`*^9}, {3.5923175406751976`*^9, 
   3.592317559504431*^9}, {3.5923177112926974`*^9, 3.592317725878723*^9}, {
   3.5923178594149575`*^9, 3.592317965136343*^9}, 3.5927417433258657`*^9, {
   3.614861860423941*^9, 3.614861860439541*^9}, {3.614917792263762*^9, 
   3.614917792263762*^9}},ExpressionUUID->"8c76754a-4228-43e5-a499-\
77bbaccc992c"],

Cell["\<\
It follows for the  principal curvature: k2 [u,v] == -k[u]. To obtain a \
geometric interpretation of the  principal curvature k1[u] = -h\
\[CloseCurlyQuote](u)/f(u) we set\
\>", "Text",
 CellChangeTimes->{{3.592318462059616*^9, 3.5923185135553064`*^9}, {
   3.5923197207946267`*^9, 3.592319804972375*^9}, {3.592457358429017*^9, 
   3.5924573688498354`*^9}, 3.5924574456175704`*^9, 3.592457476022024*^9, {
   3.59245750784608*^9, 3.592457516067294*^9}, 3.592741757755891*^9, 
   3.5988856176475487`*^9, {3.598885840976322*^9, 3.5988858679358644`*^9}, 
   3.6120752354153366`*^9, {3.612075287004627*^9, 
   3.612075303540656*^9}},ExpressionUUID->"222a565d-3d58-4faa-a594-\
4828d85f097f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "'"}], ",", 
    RowBox[{"h", "'"}]}], "}"}], " ", "\[Equal]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cos", "[", "\[Alpha]", "]"}], ",", " ", 
    RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5923198184663982`*^9, 3.5923198916461267`*^9}, 
   3.5923199762294755`*^9, 3.5923201472057757`*^9, {3.5923201953474607`*^9, 
   3.592320207624682*^9}, 3.592741759237894*^9, {3.5984543124800396`*^9, 
   3.598454319863462*^9}},ExpressionUUID->"b4e3f01e-c3f7-4c56-9f24-\
c014ec0011cc"],

Cell["\<\
where \[Alpha] is the intersection angle of the tangent at xx[u] with the \
x-axis. For the normal curvature radius r1 = 1/k1 we obtain 
r1 = -f[u]/ Sin[\[Alpha]], and this equals the length of the normal segment \
from the point xx[u] to the z-axis with  appropriate sign.\
\>", "Text",
 CellChangeTimes->{{3.592319980987484*^9, 3.592320109001309*^9}, {
   3.5923201533209867`*^9, 3.5923201626030025`*^9}, {3.5923202265163155`*^9, 
   3.5923202504623575`*^9}, {3.5923203898999653`*^9, 3.5923204463161917`*^9}, 
   3.592320613900777*^9, {3.5924575738653955`*^9, 3.5924575840366135`*^9}, 
   3.5942749734884195`*^9, {3.612075640095648*^9, 
   3.6120756606876836`*^9}},ExpressionUUID->"0cf9aeba-45f6-4cd4-92ac-\
ac22696e6120"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", 
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6126851006025085`*^9, 3.612685155985676*^9}, 
   3.697459097361372*^9},ExpressionUUID->"90a6d5da-64bf-46c0-aaaf-\
c78d7294a2f6"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], "\[Equal]", 
      "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"v", "\[Element]", " ", "Reals"}], ")"}]}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"gauss", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6126853156718097`*^9, 3.612685489498752*^9}, 
   3.6126855397236247`*^9, {3.697459106377796*^9, 
   3.697459125681609*^9}},ExpressionUUID->"1dfeee9f-3163-42ea-9e44-\
68653e5bc8af"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], ">", "0"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], "\[Equal]", 
      "1"}], ")"}], "&&", 
    RowBox[{"(", 
     RowBox[{"v", "\[Element]", " ", "Reals"}], ")"}]}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"meancurvature", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6126853156718097`*^9, 3.612685489498752*^9}, 
   3.6126855397236247`*^9, {3.612685581324004*^9, 3.6126856003970947`*^9}, 
   3.614861860439541*^9, 3.6148631366309824`*^9, {3.69745913928664*^9, 
   3.6974591464171247`*^9}},ExpressionUUID->"623355ca-e2dc-42e9-87e8-\
39a4aa6ed584"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.9.2. Minimal Surfaces of Revolution", "Subsubsection",
 CellChangeTimes->{{3.592460039870927*^9, 3.592460088511812*^9}, 
   3.612075971237429*^9, 3.6120777693766346`*^9, 3.6162363473209743`*^9, 
   3.616249192488927*^9, 3.6280853246868057`*^9, 3.629187754059351*^9, 
   3.6291884415088315`*^9, 3.697459254471122*^9, 3.697613043262143*^9, 
   3.707742250842617*^9, 
   3.707742387097013*^9},ExpressionUUID->"7ec45c47-32b7-44fe-9ee6-\
813303ee0015"],

Cell[TextData[{
 "Surfaces whose mean curvature is identically zero are named ",
 StyleBox["minimal surfaces",
  FontColor->RGBColor[0, 0, 1]],
 ". They appear as solution of the problem to find surfaces with ",
 ButtonBox["minimal area",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Minimal_surface"], None},
  ButtonNote->"https://en.wikipedia.org/wiki/Minimal_surface"],
 " having a given boundary. In this subsection we find the ",
 StyleBox["minimal surfaces of revolution. ",
  FontColor->RGBColor[0, 0, 1]],
 " \nLocally we always can assume that the surface is obtained  rotating the \
graph f[z] of a function of the z coordinate."
}], "Text",
 CellChangeTimes->{{3.5923922154218073`*^9, 3.592392309933213*^9}, {
   3.5923923561738577`*^9, 3.592392418821441*^9}, {3.5923924792458973`*^9, 
   3.592392484629205*^9}, {3.5924037899994526`*^9, 3.5924038106956367`*^9}, {
   3.5924038678159037`*^9, 3.5924039006877837`*^9}, 3.616236447972351*^9, {
   3.697459490268207*^9, 3.6974595685954943`*^9}, {3.6974600759674873`*^9, 
   3.697460171551031*^9}, {3.697460382369959*^9, 3.6974603823725967`*^9}, {
   3.697460430037423*^9, 3.6974604331725683`*^9}, {3.697460592308353*^9, 
   3.697460652923053*^9}},
 CellTags->"sfrev",ExpressionUUID->"a49f22f4-32d7-4119-aca4-5ccff7874c3c"],

Cell[BoxData[
 RowBox[{"??", "id"}]], "Input",
 CellChangeTimes->{{3.614336919250351*^9, 
  3.6143369213794727`*^9}},ExpressionUUID->"04759584-fd9a-445a-a8e7-\
2461d39c7ac6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfr", "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", "id"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.592373484017357*^9, 
  3.5923736033263664`*^9}},ExpressionUUID->"daf9207c-7cf6-42cd-a5b4-\
8425d0499d48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfr", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6143369034754486`*^9},ExpressionUUID->"e53e3187-48aa-4b63-bbda-\
ab2e0bf31e21"],

Cell["For the mean curvature we calculate", "Text",
 CellChangeTimes->{{3.5924039232400737`*^9, 
  3.592403949191558*^9}},ExpressionUUID->"c68ad75d-8a2c-46ff-a82e-\
e12d6e54bb34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"meancurvature", "[", 
   RowBox[{"sfr", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923736246204042`*^9, 3.5923736590028644`*^9}, 
   3.614861860455141*^9, 
   3.6148631366465826`*^9},ExpressionUUID->"80037f1d-0579-483f-8fe8-\
fec70328f2bf"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", "%", "]"}], ",", 
   RowBox[{"v", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923737127917585`*^9, 3.5923737360513997`*^9}, {
  3.697463286725239*^9, 
  3.6974632947888813`*^9}},ExpressionUUID->"abede640-e9fb-4119-8679-\
fdd04fc10794"],

Cell["\<\
We  can exclude the case of the function f = zero  since in that sase the \
surface degenerates to the z-axis:\
\>", "Text",
 CellChangeTimes->{{3.69752469418954*^9, 
  3.697524818444826*^9}},ExpressionUUID->"46fabf91-b841-4ece-9c50-\
1f6f400e83c9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfr", "[", "zero", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.697524629669194*^9, 
  3.697524647606781*^9}},ExpressionUUID->"045871d7-67be-41e4-af84-\
cf047c2a6ec9"],

Cell["\<\
To find the functions f for which the surface is minimal we have to solve the \
differential equation\
\>", "Text",
 CellChangeTimes->{{3.5924039805513515`*^9, 
  3.5924040254469194`*^9}},ExpressionUUID->"706583ef-5c8b-46e1-9194-\
5f5a8b523018"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
       RowBox[{
        RowBox[{"f", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}]}], "\[Equal]", " ", 
      "0"}], ",", 
     RowBox[{
      RowBox[{"f", "[", "0", "]"}], "\[Equal]", " ", "1"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "0", "]"}], "\[Equal]", " ", "0"}]}], "}"}], 
   ",", " ", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.59237394119176*^9, 3.5923739467141695`*^9}, 
   3.592374104087246*^9, {3.592374137658505*^9, 3.5923741653017535`*^9}, {
   3.5923744127337885`*^9, 3.5923746021493206`*^9}, 3.5923746475922008`*^9, {
   3.5923746813506603`*^9, 3.5923747107879114`*^9}, 3.5923748965530376`*^9, 
   3.614861860455141*^9, 3.614864659895658*^9, {3.6975237691591454`*^9, 
   3.697523830878439*^9}, {3.697523878444702*^9, 3.697523927212484*^9}, {
   3.697524197456903*^9, 3.697524224043331*^9}, {3.697524463541193*^9, 
   3.697524483216914*^9}},ExpressionUUID->"badb86e9-946c-448f-8240-\
1cf374db83b1"],

Cell["Thus we try", "Text",
 CellChangeTimes->{{3.697524885892836*^9, 
  3.697524904126362*^9}},ExpressionUUID->"28d3dc66-fd67-4b9c-8f88-\
cc928c0e24d7"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "-", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"], "+", 
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], "\[Equal]", " ", 
     "0"}], "}"}], ",", " ", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.59237394119176*^9, 3.5923739467141695`*^9}, 
   3.592374104087246*^9, {3.592374137658505*^9, 3.5923741653017535`*^9}, {
   3.5923744127337885`*^9, 3.5923746021493206`*^9}, 3.5923746475922008`*^9, {
   3.5923746813506603`*^9, 3.5923747107879114`*^9}, 3.5923748965530376`*^9, 
   3.614861860455141*^9, 3.614864659895658*^9, {3.6975237691591454`*^9, 
   3.697523830878439*^9}, {3.697523878444702*^9, 3.697523927212484*^9}, {
   3.697524197456903*^9, 3.697524224043331*^9}, {3.697524463541193*^9, 
   3.697524483216914*^9}, {3.697524911933794*^9, 
   3.6975249296210938`*^9}},ExpressionUUID->"380f8eb4-5f10-47d1-b06f-\
a0aa5fbe159c"],

Cell["The two solutions are", "Text",
 CellChangeTimes->{{3.5924040563586874`*^9, 
  3.5924040733436594`*^9}},ExpressionUUID->"217622f5-5e06-447b-a481-\
fc8cd38a1d17"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", "u_", "]"}], " ", ":=", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"C", "[", "1", "]"}]]}], " ", "u"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"C", "[", "1", "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"C", "[", "1", "]"}]], " ", 
      RowBox[{"C", "[", "2", "]"}]}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", 
       RowBox[{"C", "[", "1", "]"}]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"C", "[", "1", "]"}]], " ", 
       RowBox[{"(", 
        RowBox[{"u", "+", 
         RowBox[{"C", "[", "2", "]"}]}], ")"}]}]]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.5923749685003643`*^9, 3.592375012102441*^9}, {
   3.592375074783351*^9, 3.592375088948176*^9}, 3.697528793511262*^9, {
   3.6976047308632812`*^9, 
   3.697604742579125*^9}},ExpressionUUID->"f3070a4a-1031-4f55-a9f6-\
28a7adb4e098"],

Cell[BoxData[
 RowBox[{"f1", "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.697528719035289*^9, 
  3.69752872564328*^9}},ExpressionUUID->"5ab8af37-0a70-49dc-9ba6-\
83ee8396188c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f2", "[", "u_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"C", "[", "1", "]"}]]}], " ", "u"}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"C", "[", "1", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"C", "[", "1", "]"}]], " ", 
        RowBox[{"C", "[", "2", "]"}]}]}]], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"C", "[", "1", "]"}]], " ", "u"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"C", "[", "1", "]"}]], " ", 
        RowBox[{"C", "[", "2", "]"}]}]}]]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.697528719035289*^9, 3.69752872564328*^9}, {
   3.697528800500195*^9, 3.697528808682987*^9}, {3.6976047810258617`*^9, 
   3.697604790161467*^9}, 
   3.69760484747621*^9},ExpressionUUID->"eea564f0-45b5-4c0e-a5c5-\
f2e1660b1087"],

Cell[BoxData[
 RowBox[{"f2", "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.6976048778967524`*^9, 
  3.6976048858722677`*^9}},ExpressionUUID->"4586537b-22a2-47c6-ba82-\
33173d1f0b4d"],

Cell["\<\
The indicated initial conditions are satisfied for C[1]== C[2]== 0:\
\>", "Text",
 CellChangeTimes->{{3.697524958091487*^9, 
  3.697525030402938*^9}},ExpressionUUID->"2730b048-a929-4595-af91-\
a3eec1c818ce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", "u", "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.697523967873502*^9, 3.6975239888284607`*^9}, {
   3.697524047288645*^9, 3.697524163387039*^9}, 
   3.6976050570933933`*^9},ExpressionUUID->"aa657e32-9d81-42fd-b3d6-\
9b7d79ae04f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", "0", "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.697523967873502*^9, 3.6975239888284607`*^9}, {
   3.697524047288645*^9, 3.697524163387039*^9}, 
   3.6976050397350273`*^9},ExpressionUUID->"a091fc16-2639-4a68-be93-\
477f681efad4"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"f1", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{
  3.697524247546324*^9, {3.6975242825935707`*^9, 
   3.6975242935777607`*^9}},ExpressionUUID->"1246cb2f-1003-4043-aa0f-\
1a14519895f0"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6975243363202744`*^9, 3.6975243407454433`*^9}, {
  3.697524372698065*^9, 
  3.697524401825058*^9}},ExpressionUUID->"ffd371c7-3726-4fa2-a6b1-\
ff6811f8b304"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "[", "u", "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.697525071371966*^9, 3.6975251142034473`*^9}, 
   3.6975251702810783`*^9, 3.6976049667196903`*^9, 
   3.697605083308549*^9},ExpressionUUID->"c883f8c4-3455-4c13-a495-\
87a6eb760873"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f2", "[", "u", "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.697525071371966*^9, 3.6975251142034473`*^9}, {
  3.6975251702810783`*^9, 
  3.6975251898182793`*^9}},ExpressionUUID->"34016b21-70c2-47c8-9451-\
9b2919aa2708"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "==", "%%"}], "]"}]], "Input",
 CellChangeTimes->{{3.6975252113488197`*^9, 3.6975252314021177`*^9}, {
  3.697605117047042*^9, 
  3.697605130519043*^9}},ExpressionUUID->"7c9e333e-0040-41e1-a7bc-\
0b5101fe85f5"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f2", "[", "u", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}], 
   "\[Equal]", 
   RowBox[{"Cosh", "[", "u", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6975252490139437`*^9, 3.697525262801836*^9}, {
   3.697525370252474*^9, 3.697525396680316*^9}, 3.697525455636836*^9, {
   3.6975255050338717`*^9, 
   3.697525514119782*^9}},ExpressionUUID->"7a2d963e-9145-4608-a8c9-\
0a98ccbe70cf"],

Cell["Thus we found the solution f[u] = Cosh[u]:", "Text",
 CellChangeTimes->{{3.6975256500073357`*^9, 
  3.697525755060713*^9}},ExpressionUUID->"119bd3f9-9dfe-45ac-a4f5-\
777af257d5bd"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"sfr", "[", "Cosh", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"u", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697525759633087*^9, 3.697525784044918*^9}, {
  3.697525821325041*^9, 
  3.697525879108511*^9}},ExpressionUUID->"8dbc3b6e-54a5-4aea-95c1-\
89ddccdcb3a2"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfr", "[", "Cosh", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697525887936247*^9, 3.697525983451806*^9}, {
  3.697526013541731*^9, 
  3.69752609277906*^9}},ExpressionUUID->"4af4ce88-5894-442b-8437-\
e908c00f1802"],

Cell[TextData[{
 "The curve y = a*Cosh[u/a+c] is named a ",
 ButtonBox["catenary",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Catenary.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/Catenary.html"],
 ", and the corresponding surface of revolution is a ",
 StyleBox["catenoid",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.592403369800419*^9, 3.592403375974772*^9}, {
   3.592403409599695*^9, 3.5924034140069475`*^9}, 3.59240355794518*^9, {
   3.592403598175481*^9, 3.5924036565918226`*^9}, 3.592403704551565*^9, {
   3.592404230990676*^9, 3.5924042309966764`*^9}, 
   3.592404299751609*^9},ExpressionUUID->"eea06f40-f17b-4f3b-b859-\
3395c562f24d"],

Cell[BoxData[
 RowBox[{"?", "catenoid"}]], "Input",
 CellChangeTimes->{{3.61623708531147*^9, 
  3.6162371066523075`*^9}},ExpressionUUID->"f4b9bd1c-a381-4eaa-aa3f-\
bd6a9cefce05"],

Cell[BoxData[
 RowBox[{
  RowBox[{"catenoid", "[", "1", "]"}], "[", 
  RowBox[{"0", ",", " ", 
   RowBox[{"3", "*", 
    RowBox[{"Pi", "/", "2"}]}], ",", 
   RowBox[{"-", "1.5"}], ",", "1.5"}], "]"}]], "Input",
 CellChangeTimes->{{3.6162371338275557`*^9, 
  3.61623721036129*^9}},ExpressionUUID->"640cdd4b-2413-4bfa-a406-\
407f0e3d5e5d"],

Cell["All the catenary functions solve the differential equation :", "Text",
 CellChangeTimes->{{3.592406210985925*^9, 
  3.5924062689602413`*^9}},ExpressionUUID->"22390ffc-7e63-436a-8363-\
89276b29338c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fch", "[", 
    RowBox[{"a_", ",", "c_"}], "]"}], "[", "u_", "]"}], " ", "=", " ", 
  RowBox[{"a", "*", 
   RowBox[{"Cosh", "[", 
    RowBox[{
     RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5924063384082136`*^9, 
  3.592406369394986*^9}},ExpressionUUID->"1f3bafeb-1e47-4728-9aeb-\
57fa2c41cfef"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "-", " ", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fch", "[", 
         RowBox[{"a", ",", "c"}], "]"}], "[", "u", "]"}], ",", "u"}], "]"}], 
     "^", "2"}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"fch", "[", 
       RowBox[{"a", ",", "c"}], "]"}], "[", "u", "]"}], "*", " ", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fch", "[", 
         RowBox[{"a", ",", "c"}], "]"}], "[", "u", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", "2"}], "}"}]}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5924058117980933`*^9, 3.5924058226167116`*^9}, {
  3.5924059291928077`*^9, 3.5924061164775195`*^9}, {3.592406313278776*^9, 
  3.5924063256014805`*^9}, {3.592406455974938*^9, 
  3.5924065108300753`*^9}},ExpressionUUID->"5dbdcba7-4c0b-4a9c-8547-\
ae7ee27f379d"],

Cell["\<\
The corresponding surfaces of revolution are minimal surfaces:\
\>", "Text",
 CellChangeTimes->{{3.697606925711331*^9, 
  3.697606970175391*^9}},ExpressionUUID->"059d20ba-aacd-4b3a-9c29-\
93785e2dcbd8"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"sfr", "[", 
      RowBox[{"fch", "[", 
       RowBox[{"a", ",", "c"}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[NotEqual]", "0"}], ",", 
     RowBox[{"c", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923761453976316`*^9, 3.5923762008245287`*^9}, {
   3.592406400466763*^9, 3.592406406930133*^9}, {3.6120767595224133`*^9, 
   3.6120767901920676`*^9}, {3.612076855306582*^9, 3.612076902091064*^9}, 
   3.614861860501941*^9, 3.6148631366465826`*^9, {3.697607005260118*^9, 
   3.697607030810563*^9}, {3.697607070528076*^9, 
   3.697607082535328*^9}},ExpressionUUID->"2cb0e4e1-2586-4143-87a9-\
74fa95fa9675"],

Cell["with Gaussian curvature", "Text",
 CellChangeTimes->{{3.697607165653809*^9, 
  3.697607178549569*^9}},ExpressionUUID->"686e66a8-0f44-41ae-8a59-\
688d36ad8a3e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfr", "[", 
      RowBox[{"fch", "[", 
       RowBox[{"a", ",", "c"}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5923761453976316`*^9, 3.5923762008245287`*^9}, {
   3.5923763196031375`*^9, 3.5923763375119686`*^9}, 3.5924065540515475`*^9, {
   3.6120769821348047`*^9, 
   3.6120769963620296`*^9}},ExpressionUUID->"4eab9280-ab69-4964-b6a3-\
d8d004cfc233"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", "\[Rule]", "0"}], ",", 
      RowBox[{"a", "\[Rule]", "1"}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592376419677313*^9, 3.592376439489348*^9}, {
  3.592376495290646*^9, 3.592376538362322*^9}, {3.5924066466428432`*^9, 
  3.592406682546897*^9}},ExpressionUUID->"ca8d5ac4-5a7f-4a42-943f-\
3d493f74ac1a"],

Cell["\<\
Now we consider the first solution family depending on the integration \
constants C[1], C[2]\
\>", "Text",
 CellChangeTimes->{{3.5924067279284925`*^9, 3.5924067953433485`*^9}, 
   3.6162455668285513`*^9},ExpressionUUID->"dfd3472d-02dc-4acc-bc82-\
70e9cbfda116"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fc", "[", 
    RowBox[{"c1_", ",", "c2_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"f1", "[", "u", "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "\[Rule]", "c1"}], ",", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], "\[Rule]", "c2"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5923766072208424`*^9, 3.5923766754709625`*^9}, {
  3.592376706561817*^9, 3.592376714455431*^9}, {3.5923767748899374`*^9, 
  3.5923767911919656`*^9}},ExpressionUUID->"b1613623-b41f-456e-a2ae-\
cf55a60a077f"],

Cell["\<\
We want to show that all solutions are catenoids; for c1=c2=0 we have \
fc[0,0][u] = Cosh[u]. Insert arbitrary values for c1,c2 in the next cell and \
plot the corresponding surfaces:\
\>", "Text",
 CellChangeTimes->{{3.5924044154162245`*^9, 3.592404454479459*^9}, {
   3.592404494679758*^9, 3.5924046417831717`*^9}, 3.592406810392209*^9, {
   3.6186381829491167`*^9, 3.6186382067574778`*^9}, {3.697607276885111*^9, 
   3.69760727866899*^9}},ExpressionUUID->"72324ff7-e34b-4f2f-88e8-\
f3815fe905e0"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfr", "[", 
     RowBox[{"fc", "[", 
      RowBox[{".3", ",", ".2"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592376018163808*^9, 3.592376106974764*^9}, {
   3.5923768369936457`*^9, 3.592376917848588*^9}, 3.592376962090266*^9, {
   3.592381577598248*^9, 3.592381672414671*^9}, {3.5923817308470135`*^9, 
   3.5923817497980976`*^9}, {3.592381785999168*^9, 3.59238179215052*^9}, {
   3.592381892599265*^9, 3.592381938686901*^9}, {3.6975292609556713`*^9, 
   3.697529282535164*^9}, {3.6975293149757032`*^9, 
   3.697529336962044*^9}},ExpressionUUID->"2b21c969-0b44-45c7-a349-\
4761adf0ceaf"],

Cell["Obviously, all these surfaces are minimal:", "Text",
 CellChangeTimes->{{3.59240467654416*^9, 3.592404687135766*^9}, {
  3.697607316988514*^9, 
  3.697607328540537*^9}},ExpressionUUID->"daad77da-e099-46a9-9d2a-\
b5203875aa0c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"c1", ",", "c2"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"sfr", "[", 
      RowBox[{"fc", "[", 
       RowBox[{"c1", ",", "c2"}], "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"c1", "|", "c2", "|", "u", "|", "v"}], ",", "Reals"}], "]"}], 
   ",", 
   RowBox[{"TimeConstraint", "\[Rule]", "Infinity"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.5923770400280027`*^9, {3.592402645102968*^9, 3.592402685762294*^9}, {
   3.6120771413018847`*^9, 3.6120771477446957`*^9}, 3.614861860517541*^9, 
   3.614863136662183*^9, {3.6974672810771847`*^9, 3.697467327244239*^9}, {
   3.6974674080842533`*^9, 3.697467417410459*^9}, {3.697526457044783*^9, 
   3.697526464119555*^9}, {3.697526544955127*^9, 3.6975265638308477`*^9}, {
   3.697526818069478*^9, 3.697526835203391*^9}, {3.697526902297059*^9, 
   3.6975269081717453`*^9}, {3.697607397161538*^9, 3.697607408445855*^9}, 
   3.6976074797894287`*^9, {3.6976084612800007`*^9, 
   3.69760849811666*^9}},ExpressionUUID->"3b76db5b-b6f6-4007-a197-\
c4f3ad494ce9"],

Cell["\<\
To show that any function fc[c1,c2][u] is a catenary we consider the function \
\>", "Text",
 CellChangeTimes->{{3.592406927479906*^9, 3.5924069740795717`*^9}, {
  3.5924070154639387`*^9, 
  3.592407048239814*^9}},ExpressionUUID->"6f367ae9-2f29-4c30-9aea-\
fd54b388e17c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", "u", "]"}], " ", "=", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{"Cosh", "[", 
      RowBox[{
       RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{"fc", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.5924070587674155`*^9, 
  3.5924070657398143`*^9}},ExpressionUUID->"c4cd5ca4-cbe1-4011-bbbf-\
fa7349dff232"],

Cell["\<\
and solve the necessary condition expressed in the equations  {ff[0] == 0, ff\
\[CloseCurlyQuote][0] == 0} for the unknowns a>0, c. If such a solution exist \
then the function fc[c1,c2] [u] equals fch[a,c][u], since both function solve \
the differential equation with the same integration constants c1,c2. \
\>", "Text",
 CellChangeTimes->{{3.59240708559795*^9, 3.592407252647505*^9}, {
   3.5924072923117733`*^9, 3.592407416431873*^9}, 3.6162457001251755`*^9, 
   3.618638246605757*^9, {3.6975294542369423`*^9, 3.697529483276204*^9}, 
   3.697607575401874*^9, 
   3.6976126189408817`*^9},ExpressionUUID->"300e313c-4ed8-4721-95b8-\
cbe55ea595c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", "*", 
     RowBox[{"Cosh", "[", 
      RowBox[{
       RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{"fc", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ")"}], "/.", 
  RowBox[{"u", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{
  3.592391432480026*^9},ExpressionUUID->"13be0a38-3fb0-4967-b9e4-\
be221eede4b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "*", 
       RowBox[{"Cosh", "[", 
        RowBox[{
         RowBox[{"u", "/", "a"}], "+", "c"}], "]"}]}], " ", "-", " ", 
      RowBox[{
       RowBox[{"fc", "[", 
        RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ")"}], ",", 
    "u"}], "]"}], "/.", 
  RowBox[{"u", "\[Rule]", " ", "0"}]}]], "Input",
 CellChangeTimes->{{3.5923910346082687`*^9, 3.5923910392705355`*^9}, {
  3.5923910704973216`*^9, 3.5923911040812426`*^9}, {3.5923911540981035`*^9, 
  3.592391157953324*^9}},ExpressionUUID->"96f3d648-dfe5-4b15-b640-\
0ed431e5af66"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c1", "\[Element]", "Reals"}], ",", 
     RowBox[{"c", "\[Element]", "Reals"}], ",", 
     RowBox[{"c2", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.592391170736055*^9, 3.5923913059287877`*^9}, {
  3.5923913602958975`*^9, 
  3.592391377799898*^9}},ExpressionUUID->"9803b14c-8a63-4d47-8d47-\
8537c534c176"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"Cosh", "[", "c", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cosh", "[", 
         RowBox[{"c1", "-", 
          RowBox[{"c2", " ", 
           SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
          RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}]}]}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Sinh", "[", "c", "]"}], "+", 
       RowBox[{"Sinh", "[", 
        RowBox[{"c1", "-", 
         RowBox[{"c2", " ", 
          SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}]}], "\[Equal]", 
      "0"}], ",", 
     RowBox[{"a", ">", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "c"}], "}"}], ",", " ", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.5923790170437927`*^9, 3.5923791509614525`*^9}, {
   3.5923822007118883`*^9, 3.5923822065432215`*^9}, {3.5923905062420483`*^9, 
   3.5923905404490047`*^9}, {3.592391583304652*^9, 3.5923915990655537`*^9}, {
   3.5923916412429667`*^9, 3.5923916766269903`*^9}, {3.592404722684799*^9, 
   3.592404773292694*^9}, 3.614861860533141*^9, 
   3.614917792341762*^9},ExpressionUUID->"2469206e-c7da-4dfd-b309-\
9bc15b96cac5"],

Cell["\<\
For any real values c1,  c2  only the second case is possible and we see that \
for any such pair we find  numbers a, c  with fc[c1,c2][u] == a*Cosh[u/a + c].\
\>", "Text",
 CellChangeTimes->{{3.5924050900318103`*^9, 3.592405155695566*^9}, {
   3.592405412983282*^9, 3.592405454815675*^9}, {3.592405556992519*^9, 
   3.592405591679503*^9}, {3.5924056395522413`*^9, 3.5924058092159452`*^9}, 
   3.5924074485357094`*^9, 3.592459559078082*^9, {3.612077504922923*^9, 
   3.612077507044527*^9}},ExpressionUUID->"32db2611-fb33-4918-a199-\
b257ca455ab7"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ff", "[", "u", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", 
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cosh", "[", 
             RowBox[{"c1", "-", 
              RowBox[{"c2", " ", 
               SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Cosh", "[", "c1", "]"}]}], "+", 
              RowBox[{"Sinh", "[", "c1", "]"}]}], ")"}], "2"]}], 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"Sinh", "[", 
             RowBox[{"c1", "-", 
              RowBox[{"c2", " ", 
               SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]]}],
        ",", " ", 
       RowBox[{"c", "->", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Sinh", "[", 
            RowBox[{"c1", "-", 
             RowBox[{"c2", " ", 
              SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}]}], "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"Sinh", "[", 
              RowBox[{"c1", "-", 
               RowBox[{"c2", " ", 
                SuperscriptBox["\[ExponentialE]", "c1"]}]}], "]"}], "2"]}]]}],
          "]"}]}]}], "}"}]}], ",", " ", 
    RowBox[{"u", "\[Element]", "Reals"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.697543895661043*^9, 3.697543979748682*^9}, {
  3.6975440414788*^9, 
  3.697544104669353*^9}},ExpressionUUID->"01c7aefd-6475-4aff-958f-\
e8573cea0a79"],

Cell["We define", "Text",
 CellChangeTimes->{{3.697608749953327*^9, 
  3.697608753889572*^9}},ExpressionUUID->"02c1355e-834b-4a61-9b5b-\
74b7242b2f52"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hh", "[", 
    RowBox[{"c1_", ",", " ", "c2_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ",
   "\n", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}]}], "/", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"E", "^", "c1"}], "*", 
       RowBox[{"(", 
        RowBox[{"c2", " ", "+", " ", "u"}], ")"}]}], ")"}]}]}], " ", "-", " ",
    "\n", "   ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "*", "c1"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"E", "^", "c1"}], "*", 
        RowBox[{"(", 
         RowBox[{"c2", " ", "+", " ", "u"}], ")"}]}]}], ")"}]}]}], " ", "+", 
   " ", "\n", "   ", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{"E", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "*", "c1"}], ")"}]}], "]"}], "*", "\n", "    ", 
    RowBox[{"Cosh", "[", 
     RowBox[{
      RowBox[{"u", "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "*", "c1"}], ")"}]}], "]"}]}], " ", "-", " ", 
      "\n", "      ", 
      RowBox[{"ArcSinh", "[", 
       RowBox[{"Sinh", "[", 
        RowBox[{"c1", " ", "-", " ", 
         RowBox[{"c2", "*", 
          RowBox[{"E", "^", "c1"}]}]}], "]"}], "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.697554488519867*^9, 3.69755455426775*^9}, 
   3.69760810420391*^9},ExpressionUUID->"3ffac7e2-b013-4ca0-9c42-\
c75124146793"],

Cell["and show", "Text",
 CellChangeTimes->{{3.697608788393281*^9, 
  3.69760879302497*^9}},ExpressionUUID->"51afe6e0-5060-4b5f-a6f9-\
c430fc911f9c"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"ExpToTrig", "[", 
    RowBox[{
     RowBox[{"hh", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}], "]"}], ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"c1", "|", "c2", "|", "u"}], ",", "Reals"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6976081229511347`*^9, 3.6976081821912003`*^9}, {
  3.697608279728141*^9, 
  3.697608315806382*^9}},ExpressionUUID->"465ea0f3-4bee-467e-9379-\
e732535b8541"],

Cell["\<\
Thus fc[c1,c2][u] is a catenary with parameters a,c of the solution.\
\>", "Text",
 CellChangeTimes->{{3.6976089586641417`*^9, 3.697609017847309*^9}, {
  3.697609055927147*^9, 
  3.697609074294923*^9}},ExpressionUUID->"55484243-47fd-41ab-9c8f-\
76582dd7b877"],

Cell["\<\
Now we show with the same argumentation that also the second solution f2[u]  \
is a catenary for all values of c1,c2:\
\>", "Text",
 CellChangeTimes->{{3.5924595963153477`*^9, 
  3.5924596781998916`*^9}},ExpressionUUID->"b99c6a3d-a759-48f5-883b-\
0e887c3898a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fd", "[", 
    RowBox[{"c1_", ",", "c2_"}], "]"}], "[", "u_", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"f2", "[", "u", "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "\[Rule]", "c1"}], ",", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], "\[Rule]", "c2"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5923766072208424`*^9, 3.5923766754709625`*^9}, {
  3.592376706561817*^9, 3.592376714455431*^9}, {3.5923767748899374`*^9, 
  3.5923767911919656`*^9}, {3.5924580355170064`*^9, 
  3.592458056904644*^9}},ExpressionUUID->"f8a56b79-2d22-4d2f-ac4e-\
dcc143f710b7"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"ExpToTrig", "[", 
    RowBox[{
     RowBox[{"fd", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}], "]"}], ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"c1", "|", "c2", "|", "u"}], ",", "Reals"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.697609229884503*^9, 3.6976092995255833`*^9}, 
   3.697609377766425*^9, {3.6976094190890913`*^9, 
   3.697609428661108*^9}},ExpressionUUID->"33afef35-42ad-4620-a755-\
70c917df0e2b"],

Cell["and this function defines a catenary with", "Text",
 CellChangeTimes->{{3.6976098239524183`*^9, 
  3.6976098622244177`*^9}},ExpressionUUID->"fe39b220-14bd-4150-a39d-\
dcb3ed77240e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "*", 
        RowBox[{"Cosh", "[", 
         RowBox[{"c", "+", 
          RowBox[{"u", "/", "a"}]}], "]"}]}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", 
         RowBox[{"Exp", "[", 
          RowBox[{"-", "c1"}], "]"}]}], ",", " ", 
        RowBox[{"c", "\[Rule]", " ", 
         RowBox[{"(", 
          RowBox[{"c1", "+", 
           RowBox[{"c2", "*", 
            RowBox[{"Exp", "[", "c1", "]"}]}]}], " ", ")"}]}]}], "}"}]}], 
     ")"}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{"fd", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "[", "u", "]"}]}], ",", 
   RowBox[{"Element", "[", 
    RowBox[{
     RowBox[{"c1", "|", "c2", "|", "u"}], ",", "Reals"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.697609868299852*^9, 3.697609869952662*^9}, {
  3.697610954224942*^9, 3.697610959535293*^9}, {3.69761100689511*^9, 
  3.697611008551231*^9}, {3.69761103984731*^9, 3.6976111586698*^9}, {
  3.6976112499413567`*^9, 3.697611276573234*^9}, {3.6976113348374863`*^9, 
  3.6976114027798443`*^9}, {3.697611434940557*^9, 3.697611460790674*^9}, {
  3.697611516777595*^9, 3.697611539811656*^9}, {3.697611579235594*^9, 
  3.697611592163251*^9}, {3.6976116245428667`*^9, 3.697611640307015*^9}, {
  3.697611698014155*^9, 3.697611707650846*^9}, {3.697611847670145*^9, 
  3.697611857345378*^9}},ExpressionUUID->"5d4cda65-4188-4af3-8f28-\
f27f0e0b2cd6"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"meancurvature", "[", 
    RowBox[{"sfr", "[", 
     RowBox[{"fd", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5923770400280027`*^9, {3.592402645102968*^9, 3.592402685762294*^9}, 
   3.592458198490493*^9, {3.6120775588834176`*^9, 3.612077567744233*^9}, 
   3.6148618605487413`*^9, 3.614863136677783*^9, {3.697530097478827*^9, 
   3.697530106942959*^9}},ExpressionUUID->"228b1f82-b776-4ee2-b0a7-\
9f77b0681d1a"],

Cell[TextData[{
 "Thus we proved\n",
 StyleBox["Proposition 5",
  FontColor->RGBColor[0, 0, 1]],
 ". The only minimal surfaces of revolution are the catenoids, generated \
rotating catenaries. \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.5924597361539936`*^9, 3.592459803031311*^9}, {
   3.5924601472459154`*^9, 3.592460166199949*^9}, 3.697526695572405*^9, {
   3.6976129680307302`*^9, 
   3.697613004773847*^9}},ExpressionUUID->"8ff612c6-38f6-41d7-81a5-\
46ffa525d9a4"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.9.3.  Surfaces of Revolution of Constant Gaussian Curvature\
\>", "Subsubsection",
 CellChangeTimes->{{3.5930088090318155`*^9, 3.593008813228223*^9}, {
   3.5934178586395583`*^9, 3.593417908497246*^9}, 3.6120777755369873`*^9, 
   3.612159908316609*^9, 3.61624922015751*^9, 3.616656611139438*^9, 
   3.6280853254044075`*^9, 3.697613060831102*^9, {3.697631391836596*^9, 
   3.697631393268276*^9}, {3.697636920630753*^9, 3.697636921190097*^9}, 
   3.697951092561222*^9, 3.7077423959055853`*^9, 
   3.707742698671434*^9},ExpressionUUID->"b7274637-00f4-4dec-a11b-\
2e15c97b76cb"],

Cell["\<\
We assume that the surface of revoluti\[LineSeparator]on is generated by the \
graph of a function f\
\>", "Text",
 CellChangeTimes->{{3.5934179940789967`*^9, 3.5934181363824463`*^9}, {
   3.593418242759033*^9, 3.593418244974237*^9}, 3.616301755428102*^9, 
   3.697691289775497*^9},ExpressionUUID->"b7330a3e-9e78-40aa-9101-\
23956f3db247"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xrev", "[", "f_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"id", ",", "f"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.5934182656442733`*^9, {3.697637046775447*^9, 3.69763707909422*^9}, 
   3.69763713577575*^9, 3.6976909999557343`*^9, {3.6976912529683237`*^9, 
   3.697691263496667*^9}, 
   3.6976955402406597`*^9},ExpressionUUID->"a8733d65-faeb-4ca3-9794-\
89cbfaa07a62"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xrev", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6976371821764708`*^9, 3.6976371968287497`*^9}, 
   3.697695540256773*^9},ExpressionUUID->"e81dfac9-c3dc-4a35-95c9-\
d5724cfb64f7"],

Cell["\<\
An additive constant added to the function f in xref[f][u,v] means only a \
translation of the surface in direction of the z-axis; thus we may set c[2] \
=0 in the solution found above. A change of the sign of f in xrev[f][u,v] \
means a reflection at the x,y-plane:\
\>", "Text",
 CellChangeTimes->{{3.6977275579590483`*^9, 3.6977278019655447`*^9}, {
  3.697728842997871*^9, 3.697728999404746*^9}, {3.697948659100945*^9, 
  3.697948664380451*^9}, {3.697948710372149*^9, 
  3.697948720635729*^9}},ExpressionUUID->"01642d42-6250-440f-8dd7-\
60ba76c98f48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "f", "]"}], ";", 
  RowBox[{
   RowBox[{"f1", "[", "u_", "]"}], ":=", 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "+", "a"}]}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"xrev", "[", "f1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "a"}], "}"}], "+", " ", 
     RowBox[{
      RowBox[{"xrev", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6983803983433733`*^9, 3.698380487606668*^9}, {
  3.698380520832059*^9, 3.6983805584670267`*^9}, {3.698381883204517*^9, 
  3.698381903401964*^9}, {3.6983819445783663`*^9, 3.698381956161846*^9}, {
  3.6983820068981247`*^9, 
  3.6983820434808073`*^9}},ExpressionUUID->"1e6addc5-781a-455f-b12b-\
f633cabafb8a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f", ",", "f1"}], "]"}], ";", 
  RowBox[{
   RowBox[{"xrev", "[", "f", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.69772857552092*^9, 3.697728662191576*^9}, {
  3.698380572133877*^9, 
  3.698380577453693*^9}},ExpressionUUID->"35cd805a-a2e4-404d-acc3-\
449e0f7fb267"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xrev", "[", 
   RowBox[{"-", "f"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.69772857552092*^9, 
  3.697728713959613*^9}},ExpressionUUID->"9f2774cd-075c-498f-8435-\
cd81338244b0"],

Cell["Its Gaussian curvature K of xrev[f][u,v] is", "Text",
 CellChangeTimes->{{3.59341829782713*^9, 3.5934183065475454`*^9}, {
  3.6976160953399754`*^9, 3.69761609630016*^9}, {3.698385896162665*^9, 
  3.698385910322262*^9}},ExpressionUUID->"f2359f5a-1021-49ac-ab33-\
2937d3e59877"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"xrev", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.593008824007842*^9, 3.59300892540802*^9}, 
   3.697631915151066*^9, 
   3.6976955402709637`*^9},ExpressionUUID->"80ff21ff-c6f5-4ae2-a9b4-\
99dd35563095"],

Cell[TextData[{
 "We define the ",
 StyleBox["curvature differential operator",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.616328440589955*^9, 3.6163284701016426`*^9}, {
   3.61632880241465*^9, 3.6163288045097694`*^9}, {3.616473145681977*^9, 
   3.6164732661538677`*^9}, 3.6164873978281136`*^9, 3.6976160650205173`*^9, 
   3.697616311074253*^9},ExpressionUUID->"fd6ac66e-80d3-45c5-ac90-\
c8b228713525"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "diff", "]"}], ";", 
   RowBox[{
    RowBox[{
     RowBox[{"diff", "[", 
      RowBox[{"f_", ",", "k_"}], "]"}], "[", "u_", "]"}], " ", ":=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "''"}], "[", "u", "]"}], "*", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "u", "]"}]}], "-", 
     RowBox[{"k", "*", " ", "u", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "'"}], "[", "u", "]"}], "^", "2"}]}], ")"}], "^", 
       "2"}]}]}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6163268268226523`*^9, 3.6163268268246527`*^9}, {
  3.616327879928887*^9, 3.616327923097356*^9}, {3.697637865490941*^9, 
  3.6976379518392763`*^9}},ExpressionUUID->"f001eca6-b2e6-41af-8b09-\
b61c6da86717"],

Cell["\<\
Its kernel defines  meridians generating surfaces of revolution with constant \
Gaussian curvature k. The general solution is\
\>", "Text",
 CellChangeTimes->{{3.61632851358313*^9, 3.616328569550331*^9}, {
   3.616328825054945*^9, 3.6163288317103257`*^9}, {3.6164877106670074`*^9, 
   3.6164877260268855`*^9}, {3.6976163701857767`*^9, 3.69761637694601*^9}, 
   3.697637627128688*^9, 3.697637793871045*^9, {3.697639083884203*^9, 
   3.697639094748159*^9}, 3.697945238249282*^9, {3.69794528856074*^9, 
   3.697945297424501*^9}},ExpressionUUID->"5a361653-ba47-4769-8470-\
6c330ac4ba71"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"diff", "[", 
       RowBox[{"f", ",", "k"}], "]"}], "[", "u", "]"}], "\[Equal]", " ", 
     "0"}], "}"}], ",", " ", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.593009068101471*^9, 3.5930091129671497`*^9}, {
   3.5930091433872027`*^9, 3.593009245723383*^9}, {3.593009299044276*^9, 
   3.593009307530691*^9}, 3.6148618605643415`*^9, 3.6148646599112577`*^9, 
   3.6163941993331203`*^9, {3.6163942501580095`*^9, 3.6163942809992633`*^9}, {
   3.616394314960523*^9, 3.6163943961430655`*^9}, {3.6164733180838375`*^9, 
   3.616473429445207*^9}, {3.697631003126884*^9, 3.697631058069593*^9}, {
   3.697631110136573*^9, 3.69763112698685*^9}, 
   3.697638061536434*^9},ExpressionUUID->"da822a64-ebb1-4f3e-9f0e-\
2c37ffb1c0fd"],

Cell["\<\
The second terms of both solutions differ by the sign only: We consider\
\>", "Text",
 CellChangeTimes->{{3.697639254314579*^9, 3.6976393122579117`*^9}, {
  3.6976894818884573`*^9, 
  3.697689542759713*^9}},ExpressionUUID->"417339fb-b21d-40d2-89bf-\
a22c797c3feb"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"2", "+", 
          FractionBox[
           RowBox[{"k", " ", 
            SuperscriptBox["u", "2"]}], 
           RowBox[{"C", "[", "1", "]"}]]}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"C", "[", "1", "]"}]}]}]], 
        RowBox[{"EllipticE", "[", 
         RowBox[{
          RowBox[{"ArcSin", "[", 
           FractionBox[
            RowBox[{"u", " ", 
             SqrtBox[
              RowBox[{"-", 
               FractionBox["k", 
                RowBox[{"C", "[", "1", "]"}]]}]]}], 
            SqrtBox["2"]], "]"}], ",", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"C", "[", "1", "]"}]}], 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             RowBox[{"C", "[", "1", "]"}]}]}]]}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"-", 
          FractionBox["k", 
           RowBox[{"C", "[", "1", "]"}]]}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"k", " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"C", "[", "1", "]"}]}]}]], " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"k", " ", 
            SuperscriptBox["u", "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"C", "[", "1", "]"}]}]}], 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            RowBox[{"C", "[", "1", "]"}]}]}]]]}], ")"}]}], ")"}], "/.", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", "c"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[NotEqual]", "0"}], ",", 
     RowBox[{"c", "\[NotEqual]", 
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}]}], ",", 
     RowBox[{"k", "\[NotEqual]", "0"}], ",", 
     RowBox[{"Element", "[", 
      RowBox[{
       RowBox[{"k", "|", "c", "|", "u"}], ",", "Reals"}], "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.697638368339089*^9, 3.6976386596787357`*^9}, {
   3.6979454631573067`*^9, 3.6979455683698473`*^9}, {3.6983800766617126`*^9, 
   3.6983800878704853`*^9}, {3.6983814177276173`*^9, 3.6983814341689663`*^9}, 
   3.6983814973453627`*^9},ExpressionUUID->"05e6d9d6-a7e3-4063-abc1-\
6fb14d2645ec"],

Cell["With this result we define", "Text",
 CellChangeTimes->{{3.697639563963874*^9, 
  3.697639590193905*^9}},ExpressionUUID->"f9a6584e-ed98-4997-9c8f-\
275c3bdf9833"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"solf", "[", 
     RowBox[{"k_", ",", "c_"}], "]"}], "[", "u_", "]"}], ":=", " ", 
   FractionBox[
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", "c"}], "-", 
       RowBox[{"k", " ", 
        SuperscriptBox["u", "2"]}]}]], " ", 
     SqrtBox[
      RowBox[{"2", "+", 
       FractionBox[
        RowBox[{"k", " ", 
         SuperscriptBox["u", "2"]}], "c"]}]], " ", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        FractionBox[
         RowBox[{
          SqrtBox[
           RowBox[{"-", 
            FractionBox["k", "c"]}]], " ", "u"}], 
         SqrtBox["2"]], "]"}], ",", 
       FractionBox[
        RowBox[{"2", " ", "c"}], 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "c"}]}]]}], "]"}]}], 
    RowBox[{
     SqrtBox[
      RowBox[{"-", 
       FractionBox["k", "c"]}]], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"2", " ", "c"}], "+", 
       RowBox[{"k", " ", 
        SuperscriptBox["u", "2"]}]}]], " ", 
     SqrtBox[
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"k", " ", 
         SuperscriptBox["u", "2"]}], 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "c"}]}]]}]]}]]}]}]], "Input",
 CellChangeTimes->{{3.697638720024364*^9, 
  3.697638751716379*^9}},ExpressionUUID->"dee20251-9b03-436f-a385-\
e4b959b068d9"],

Cell["Now we simplify further using the identity", "Text",
 CellChangeTimes->{{3.698385580244783*^9, 
  3.6983856236606073`*^9}},ExpressionUUID->"f4881816-6a4f-4ddd-90a8-\
d8cabae8f9eb"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{"-", 
       FractionBox["k", "c"]}]], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"2", " ", "c"}], "+", 
       RowBox[{"k", " ", 
        SuperscriptBox["u", "2"]}]}]], " ", 
     SqrtBox[
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"k", " ", 
         SuperscriptBox["u", "2"]}], 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "c"}]}]]}]]}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", "k", "]"}], "*", 
     RowBox[{"(", 
      SqrtBox[
       RowBox[{"2", " ", "+", 
        RowBox[{"k", " ", 
         RowBox[{
          SuperscriptBox["u", "2"], "/", "c"}]}]}]], " ", ")"}], "*", 
     RowBox[{
      RowBox[{"(", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"2", " ", "c"}], "-", 
         RowBox[{"k", " ", 
          SuperscriptBox["u", "2"]}]}]], ")"}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "+", 
        RowBox[{"2", "*", "c"}]}], "]"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[NotEqual]", "0"}], ",", 
     RowBox[{"c", "\[NotEqual]", 
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}]}], ",", 
     RowBox[{"k", "\[NotEqual]", "0"}], ",", 
     RowBox[{"Element", "[", 
      RowBox[{
       RowBox[{"k", "|", "c", "|", "u"}], ",", "Reals"}], "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6979457861009417`*^9, 3.697945833724814*^9}, {
   3.697945889788538*^9, 3.69794591915559*^9}, {3.697945981907741*^9, 
   3.697946021099434*^9}, {3.6979460658982058`*^9, 3.697946182012779*^9}, 
   3.6979464280560923`*^9, 3.697946459600081*^9, {3.69794652122901*^9, 
   3.6979465253992662`*^9}, {3.698380139626042*^9, 
   3.6983801880514927`*^9}},ExpressionUUID->"7c758385-36f8-4a7d-bfd6-\
caf9fa41168d"],

Cell["Therefore solf equals", "Text",
 CellChangeTimes->{{3.6979468828194227`*^9, 3.6979469022116547`*^9}, 
   3.6979484502697678`*^9, {3.69838569453202*^9, 
   3.6983857161879377`*^9}},ExpressionUUID->"4a7ec058-f823-4970-af8d-\
3014f8202d5c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"solfn", "[", 
    RowBox[{"k_", ",", " ", "c_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"2", "*", "c"}]}], "]"}], "*", "\n", "   ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"k", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", "c"}], ")"}]}], ")"}]}], "]"}], "*", "\n", 
         "       ", "u"}], "]"}], ",", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "*", "c"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          RowBox[{"2", "*", "c"}]}], ")"}]}]}], "]"}], "/", 
     RowBox[{"Sqrt", "[", "k", "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.6979469086239653`*^9, 3.697946914795927*^9}, {
   3.697946955083949*^9, 3.6979470159667177`*^9}, {3.697947116631194*^9, 
   3.697947137846542*^9}, {3.697947180405262*^9, 3.697947197699205*^9}, 
   3.697947231243588*^9, {3.69794729140335*^9, 3.697947311754775*^9}, 
   3.697947351129835*^9},ExpressionUUID->"4f21f863-0405-4713-8bc2-\
51ebcd518060"],

Cell["\<\
Therefore, to find all surfaces of type xrev[f][u,v] with constant Gaussian \
curvature k \[NotEqual]0it suffices to consider the functions \
\>", "Text",
 CellChangeTimes->{{3.697729037403967*^9, 3.6977292642419786`*^9}, {
   3.697948786387104*^9, 3.6979488002747297`*^9}, 3.698380673124634*^9, 
   3.698380703700171*^9, {3.698381775403566*^9, 
   3.698381822754093*^9}},ExpressionUUID->"76fe34b1-c352-478e-8f63-\
02355febbc80"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"solfn", "[", 
    RowBox[{"k", ",", "c"}], "]"}], "[", "u", "]"}], " ", "+", "a"}]], "Input",
 CellChangeTimes->{{3.6977294023301487`*^9, 3.697729404945224*^9}, 
   3.6979488350274897`*^9, {3.69838073448452*^9, 
   3.698380737324562*^9}},ExpressionUUID->"7dc9ad39-27d6-4133-a127-\
7596bcc6d184"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"solfn", "[", 
    RowBox[{"k", ",", "c"}], "]"}], "[", "u", "]"}]}]], "Input",ExpressionUUID\
->"caa00531-4eac-4b8e-89f1-561cfb1ec44b"],

Cell[TextData[{
 "We replace c by the parameter b= ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"1", "+", 
    RowBox[{"2", " ", "c"}]}]]], "Output",
  CellChangeTimes->{3.698384190363139*^9},ExpressionUUID->
  "8f1f130e-9949-4b40-8596-439a8b83e3ba"],
 "  \[NotEqual]0 and control"
}], "Text",
 CellChangeTimes->{{3.6983865425013742`*^9, 3.698386652852463*^9}, {
  3.6983866832180033`*^9, 
  3.698386687092222*^9}},ExpressionUUID->"b810023d-8e3c-4181-89d8-\
96af9b820d1a"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "u_", "]"}], ":=", " ", 
    RowBox[{
     RowBox[{"b", "*", 
      RowBox[{
       RowBox[{"EllipticE", "[", 
        RowBox[{
         RowBox[{"ArcSin", "[", 
          RowBox[{
           SqrtBox[
            RowBox[{"-", 
             FractionBox["k", 
              RowBox[{
               RowBox[{"b", "^", "2"}], "-", "1"}]]}]], " ", "u"}], "]"}], 
         ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", "^", "2"}], "-", "1"}], ")"}], "/", 
          RowBox[{"b", "^", "2"}]}]}], "]"}], "/", 
       RowBox[{"Sqrt", "[", "k", "]"}]}]}], "+", "a"}]}], ";", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"diff", "[", 
       RowBox[{"f", ",", "k"}], "]"}], "[", "u", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b", "\[NotEqual]", "0"}], ",", ",", 
       RowBox[{"k", "\[NotEqual]", "0"}], ",", 
       RowBox[{"Element", "[", 
        RowBox[{
         RowBox[{"k", "|", "u"}], ",", "Reals"}], "]"}]}], "}"}]}], "]"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.6983812342844687`*^9, 3.698381364463271*^9}, 
   3.698382058210228*^9, {3.698384630992063*^9, 3.698384633172752*^9}, 
   3.6983846903840923`*^9, {3.6983847298919973`*^9, 3.698384998131199*^9}, {
   3.6983850525116577`*^9, 3.698385083674406*^9}, 3.6983851143781233`*^9, {
   3.698385166113253*^9, 3.698385166881744*^9}, {3.698385317413871*^9, 
   3.698385346968444*^9}, 
   3.6983853770482883`*^9},ExpressionUUID->"3dd1ca7a-3b18-431e-863e-\
302b0e96b374"],

Cell["We define for b\[NotEqual]0, k\[NotEqual]0", "Text",
 CellChangeTimes->{{3.698386766403789*^9, 3.698386770907386*^9}, {
  3.6983871519685793`*^9, 
  3.6983872047600737`*^9}},ExpressionUUID->"7fbffea0-1591-439a-b303-\
5eee40130d6c"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"solv", "[", 
     RowBox[{"k_", ",", "b_"}], "]"}], "[", "u_", "]"}], ":=", 
   RowBox[{"b", "*", 
    RowBox[{
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcSin", "[", 
        RowBox[{
         SqrtBox[
          RowBox[{"-", 
           FractionBox["k", 
            RowBox[{
             RowBox[{"b", "^", "2"}], "-", "1"}]]}]], " ", "u"}], "]"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b", "^", "2"}], "-", "1"}], ")"}], "/", 
        RowBox[{"b", "^", "2"}]}]}], "]"}], "/", 
     RowBox[{"Sqrt", "[", "k", "]"}]}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.698385434912305*^9},ExpressionUUID->"fcbc65aa-8a48-453b-b1e8-\
c689e3a591fc"],

Cell[TextData[{
 StyleBox["Lemma 2",
  FontColor->RGBColor[0, 0, 1]],
 ". The  general solution of diff[f,k][u]==0 for  k\[NotEqual]0 is\nf[u] = \
solv[k,b][u] +a with b\[NotEqual]0 and a=constant. \nHere f[u] is the \
meridian of the surface of revolution of constant curvature k. \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.6983872252812767`*^9, 3.6983873731272507`*^9}, {
  3.6983874564869757`*^9, 3.6983874609584208`*^9}, {3.6983874917182093`*^9, 
  3.6983875311097813`*^9}, {3.6983876280451317`*^9, 3.69838768797278*^9}, {
  3.698387735740283*^9, 
  3.69838781299477*^9}},ExpressionUUID->"6c835e65-c6aa-4fef-a41c-\
2d7e7cd8745d"],

Cell[TextData[{
 "We remark yet\n",
 StyleBox["Lemma 2",
  FontColor->RGBColor[0, 0, 1]],
 ". The function solv[k,b][u] is odd in u and b"
}], "Text",
 CellChangeTimes->{{3.698382185788341*^9, 3.6983822202542458`*^9}, {
   3.698382407709276*^9, 3.69838244729247*^9}, 3.698384053904739*^9, 
   3.698386942665593*^9, {3.6983903029671173`*^9, 
   3.69839031053496*^9}},ExpressionUUID->"e60aab5f-0066-4a26-81b6-\
d2b16edc6f0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"solv", "[", 
    RowBox[{"k", ",", "b"}], "]"}], "[", 
   RowBox[{"-", "u"}], "]"}], "\[Equal]", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"solv", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.698382459138997*^9, 3.6983825145246677`*^9}, {
  3.698386944493648*^9, 
  3.698386944533163*^9}},ExpressionUUID->"1ede3b1b-eaf4-4a8f-a5a4-\
f01f52b9a6f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"solv", "[", 
    RowBox[{"k", ",", 
     RowBox[{"-", "b"}]}], "]"}], "[", "u", "]"}], " ", "\[Equal]", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"solv", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.698390325517104*^9, 
  3.6983903708311043`*^9}},ExpressionUUID->"2013d3c5-6e1a-4ca9-b315-\
1b36faed3e38"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"solv", "[", 
    RowBox[{"k", ",", "b"}], "]"}], "[", "0", "]"}], "\[Equal]", " ", 
  "0"}]], "Input",
 CellChangeTimes->{{3.698382520805532*^9, 3.69838255206861*^9}, 
   3.6983869544127817`*^9},ExpressionUUID->"91d86e6e-96c3-4d6f-8237-\
b1abd046a595"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6983825796060534`*^9, 
  3.6983825796075087`*^9}},ExpressionUUID->"81ab5a0c-212d-40ec-82ab-\
a481cb660885"],

Cell["\<\
The cases k>0 and k<0 we consider in the next subsections; the case k==0 isn\
\[CloseCurlyQuote]t contained in the general solution; \
\>", "Text",
 CellChangeTimes->{{3.697948963824469*^9, 3.697949131000024*^9}, {
   3.697950436710327*^9, 3.6979504516299677`*^9}, {3.6979509170184717`*^9, 
   3.6979509976020117`*^9}, 3.6983811718405037`*^9, {3.698382111671719*^9, 
   3.698382122039537*^9}, {3.698382637611649*^9, 3.698382742826728*^9}, 
   3.698387110337202*^9},ExpressionUUID->"b9e4562c-7b9f-4b13-ba63-\
3710e22113de"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"solv", "[", 
    RowBox[{"0", ",", "c"}], "]"}], "[", "u", "]"}], " ", "+", "a"}]], "Input",
 CellChangeTimes->{{3.697948885982997*^9, 3.6979488983308163`*^9}, 
   3.69838705398643*^9, {3.6983871263547077`*^9, 
   3.6983871292173147`*^9}},ExpressionUUID->"903768fc-ad70-4221-8173-\
b7ac3a257485"],

Cell["We consider the case k==0 directly:", "Text",
 CellChangeTimes->{{3.6977294321284237`*^9, 3.6977294503365307`*^9}, {
  3.6979491698476753`*^9, 3.697949189543622*^9}, {3.6979492303032084`*^9, 
  3.697949232679212*^9}, {3.6979510309214354`*^9, 
  3.697951050873178*^9}},ExpressionUUID->"2c1670ff-5039-4a56-aa5e-\
8da69f0316e6"],

Cell[BoxData[
 RowBox[{"K", "==", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"u", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}], "2"]}]], 
  " ", "\[Equal]", " ", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6976417175115013`*^9, 
  3.697641755414427*^9}},ExpressionUUID->"0f817cbf-f0e0-4350-97df-\
e85f9c4f5ddf"],

Cell["If  f\.b4[u] == 0 then f[u] = u0 = const, ", "Text",
 CellChangeTimes->{{3.616473593105568*^9, 3.616473629433646*^9}, {
   3.616473662185519*^9, 3.6164736992976418`*^9}, {3.616474248058029*^9, 
   3.6164742561944942`*^9}, 3.616487116010995*^9, {3.6976418321647997`*^9, 
   3.697641838764797*^9}, 3.697642023707388*^9, 3.6979492835429707`*^9, 
   3.6979493401183147`*^9},ExpressionUUID->"fb620cb5-57e5-46f7-88fa-\
7d415c0b9d7e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fc", "[", "u_", "]"}], "=", "a"}], ";", 
  RowBox[{
   RowBox[{"xrev", "[", "fc", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6976426031594057`*^9, 3.69764269549483*^9}, 
   3.697695540285095*^9},ExpressionUUID->"3e609c69-ef04-4b0a-857f-\
e867a2fe098d"],

Cell["we obtain the plane z== a:", "Text",
 CellChangeTimes->{{3.697642786221814*^9, 3.697642808837171*^9}, 
   3.697690325263411*^9},ExpressionUUID->"f4df3a98-260a-4611-a7a6-\
634548af2ab0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fc", "[", "u_", "]"}], " ", "=", "3"}], ";", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"xrev", "[", "fc", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6164737205658584`*^9, 3.616473838821622*^9}, {
   3.697642046575989*^9, 3.69764207136382*^9}, 3.697642520301366*^9, 
   3.6976955402944736`*^9},ExpressionUUID->"292ecb41-ce55-4a66-b581-\
4be57181ff7d"],

Cell["\<\
Changing the order of the arguments in sfrev, we obtain for the Gausian  \
curvature\
\>", "Text",
 CellChangeTimes->{{3.6164871579953957`*^9, 3.616487213555574*^9}, 
   3.6186383414936686`*^9, {3.697642298442274*^9, 3.69764232844088*^9}, 
   3.69764276876547*^9, {3.6976914338380547`*^9, 
   3.697691480285726*^9}},ExpressionUUID->"14dd7cee-0c7d-41e3-af9d-\
4104bc732923"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"sfrev", "[", 
     RowBox[{"f", ",", "id"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.697691486825049*^9, 
  3.69769159686145*^9}},ExpressionUUID->"2c7caa0e-6cb9-4508-bda4-\
06441629c15f"],

Cell["\<\
The case k=0 leads to the equation f\[CloseCurlyQuote]\[CloseCurlyQuote][u] \
=0 with the solution\
\>", "Text",
 CellChangeTimes->{{3.697693167700822*^9, 3.6976932323429413`*^9}, {
   3.6976932673107557`*^9, 3.697693315502223*^9}, 
   3.69794946781349*^9},ExpressionUUID->"b8787609-22a4-42ca-942e-\
685750b59d22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f0", "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"a", "+", 
   RowBox[{"c", "*", "u"}]}]}]], "Input",
 CellChangeTimes->{{3.697693329728777*^9, 
  3.697693390798855*^9}},ExpressionUUID->"9e59ed64-0a63-4c47-99a9-\
77bab61bb368"],

Cell["\<\
Particularly, for c == 0 we obtain a circular cylinder of radius a,e.g. \
\>", "Text",
 CellChangeTimes->{{3.697693501732535*^9, 
  3.697693600020051*^9}},ExpressionUUID->"f8833246-b84d-4ad5-bb1e-\
fb5425f51504"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fa", "[", "u_", "]"}], " ", "=", "1"}], ";", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"fa", ",", " ", "id"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6164737205658584`*^9, 3.616473838821622*^9}, {
   3.616474059494244*^9, 3.616474067365694*^9}, 3.697642356532329*^9, {
   3.697642427245882*^9, 3.6976424409690247`*^9}, {3.69769346066222*^9, 
   3.6976934690464563`*^9}},ExpressionUUID->"b57d974f-e5ba-4862-9d45-\
4c4cd85db722"],

Cell[BoxData[
 RowBox[{"Clear", "[", "fa", "]"}]], "Input",
 CellChangeTimes->{{3.6164742984839134`*^9, 3.616474307804446*^9}, 
   3.69769495269818*^9},ExpressionUUID->"818c95f8-c2b7-4196-90f7-\
0f0f89caf0fa"],

Cell["\<\
Clearly, this surface can\[CloseCurlyQuote]t be generated by a graph of a \
function over the 
x-axis. In general, points of the surfaces xrev[f][u,v]  with a tangent plane \
parallel to the z-axis, couldn\[CloseCurlyQuote]t be represented by xrev.  \
Rotating the tangent of the circle r{Cos[u], Sin[u],a} in the plane z=a  \
yields the outer region of a plane disk as a surface of revolution with k==0:\
\>", "Text",
 CellChangeTimes->{{3.697694560228929*^9, 3.6976947007320147`*^9}, {
   3.697694754547595*^9, 3.697694757715632*^9}, {3.697694929362252*^9, 
   3.697694931586122*^9}, {3.6976978529460173`*^9, 3.6976979702805557`*^9}, 
   3.697698009644517*^9, {3.69769805363218*^9, 3.6976982189027367`*^9}, {
   3.697698260830448*^9, 3.697698324165739*^9}, {3.697698371070435*^9, 
   3.697698381621151*^9}, {3.697698805969469*^9, 3.69769886113702*^9}, {
   3.697698894264392*^9, 3.69769894852808*^9}, {3.697698981999909*^9, 
   3.6976993459244337`*^9}},ExpressionUUID->"1f4811fd-e7e0-42b4-aa87-\
967459dbfc2a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hr", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", "v", "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", "v", "]"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sin", "[", "v", "]"}], ",", 
       RowBox[{"Cos", "[", "v", "]"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], ".", 
   RowBox[{"{", 
    RowBox[{"u", ",", "3", ",", "3"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.697701977687755*^9, 3.697702206244912*^9}, 
   3.697702263314166*^9, {3.697702382231988*^9, 3.697702393385997*^9}, 
   3.697702448924355*^9, {3.6977024934545393`*^9, 3.69770250985856*^9}, {
   3.697702607759173*^9, 3.697702729129075*^9}, {3.6977027672248507`*^9, 
   3.697702808432682*^9}, {3.697702865532995*^9, 3.697702877144723*^9}, {
   3.6977029072423687`*^9, 3.697702918887841*^9}, {3.6977030299026337`*^9, 
   3.697703079406344*^9}, 3.6977032143689632`*^9, {3.697703286650153*^9, 
   3.697703310357048*^9}, 3.6977251921447353`*^9, {3.6977270031448183`*^9, 
   3.6977270405969067`*^9}},ExpressionUUID->"79b348b9-6be3-4a20-ba10-\
c049c39516ac"],

Cell[BoxData[
 RowBox[{"hr", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.697725209020109*^9, 
  3.697725216104187*^9}},ExpressionUUID->"67a4359d-f89d-47d5-8938-\
a8040a0c32c6"],

Cell[BoxData[
 RowBox[{"hr", "[", 
  RowBox[{"u", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.697703139250752*^9, 
  3.6977031534777727`*^9}},ExpressionUUID->"f825f188-530a-4f3f-b663-\
e0184e0b04dc"],

Cell["\<\
This is the parallel to the x-axis through the point {0,3,3}. The \
corresponding surface of revolution is\
\>", "Text",
 CellChangeTimes->{{3.697949805874465*^9, 
  3.6979499144576397`*^9}},ExpressionUUID->"cc9c661d-c37d-419a-932f-\
46a0a42535a0"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"hr", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697702317548543*^9, 
  3.6977023303160133`*^9}},ExpressionUUID->"339e95b7-8842-4e3e-bc76-\
38514c94e01c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", "hr", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.697726235943268*^9, 
  3.697726264698689*^9}},ExpressionUUID->"06543ccf-3e85-4a72-8bd8-\
6c9b8ee65098"],

Cell["\<\
Thus hr[u,v] defines a surface of revolution with K=0 not contained in the \
families sfrev[f,id], sfrev[id,f]. But the surface as a part of the plane is \
there:\
\>", "Text",
 CellChangeTimes->{{3.697726647454898*^9, 
  3.697726913948749*^9}},ExpressionUUID->"c7ea2036-419b-4928-9863-\
862cb2beda7d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "u_", "]"}], ":=", "3"}], ";", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"id", ",", "f"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "3", ",", "5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6976993560031776`*^9, 3.697699446835885*^9}, {
   3.6976995118351088`*^9, 3.6976996569306917`*^9}, {3.697699701654566*^9, 
   3.6976997516093616`*^9}, 3.697699789369321*^9, {3.697699881572173*^9, 
   3.697699978327565*^9}, {3.697700186481745*^9, 3.6977002420316563`*^9}, 
   3.697727126167143*^9},ExpressionUUID->"40e862d4-80b4-49e8-a904-\
77adecfef3ab"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"f", ",", "h", ",", "hr"}], "]"}]], "Input",
 CellChangeTimes->{{3.697727313495584*^9, 
  3.697727354066485*^9}},ExpressionUUID->"6eb0c197-7348-4488-856c-\
30c99be50ea1"],

Cell["\<\
 If f\[CloseCurlyQuote][u]\[NotEqual]0, the differential equation for K==0 in \
both cases reduces to f\.b4\.b4 [u] =0, which has the general solution\
\>", "Text",
 CellChangeTimes->{{3.616474377681443*^9, 3.6164744774261484`*^9}, {
   3.697615857270362*^9, 3.6976159528693953`*^9}, 3.6976904575981913`*^9, {
   3.697698444964467*^9, 
   3.697698451636639*^9}},ExpressionUUID->"dafff44e-2321-4afa-b45e-\
04ca9695ec1b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fl", "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"u0", " ", "+", 
   RowBox[{"u", "*", "c0"}]}]}]], "Input",
 CellChangeTimes->{{3.6164744983583455`*^9, 
  3.616474559035816*^9}},ExpressionUUID->"39ab8887-289a-4ee3-b734-\
e55dea544438"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", 
   RowBox[{"xrev", "[", "fl", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.616474586925411*^9, 3.6164746220444202`*^9}, 
   3.697690801177588*^9, 
   3.697695540300726*^9},ExpressionUUID->"579db135-f4ea-485f-9ddf-\
0ca00fddcb7d"],

Cell["\<\
which yields  besides of the already mentioned developable surfaces  the \
circular cones; e.g. \
\>", "Text",
 CellChangeTimes->{{3.6164746434736457`*^9, 3.616474751481823*^9}, {
  3.6164872703158207`*^9, 
  3.6164873153713975`*^9}},ExpressionUUID->"93411a0b-6af6-4986-a443-\
80af58bb9fff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fl", "[", "u_", "]"}], " ", "=", 
   RowBox[{
    RowBox[{"3", "*", "u"}], "+", "1"}]}], ";", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"xrev", "[", "fl", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6164737205658584`*^9, 3.616473838821622*^9}, {
   3.616474059494244*^9, 3.616474067365694*^9}, {3.6164747940862603`*^9, 
   3.616474876637982*^9}, 3.697690801229978*^9, {3.6976951984526453`*^9, 
   3.6976951995607233`*^9}, 
   3.6976955403101254`*^9},ExpressionUUID->"a79c465f-d0af-49fb-b03b-\
6a76735f5735"],

Cell[BoxData[
 RowBox[{"Clear", "[", "fl", "]"}]], "Input",
 CellChangeTimes->{{3.6977274820947437`*^9, 
  3.6977274912321453`*^9}},ExpressionUUID->"dbf21f00-03e5-41f4-bf87-\
a6cce344cd90"],

Cell[TextData[{
 "Tus we proved:\n",
 StyleBox["Proposition 6.",
  FontColor->RGBColor[0, 0, 1]],
 " The surfaces of revolution with constant Gaussian curvature K=0 are the \
pane, circular cylinder, circular cones, or parts of them. \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.69772800429186*^9, 3.697728023659752*^9}, {
  3.697728093523197*^9, 3.697728103898737*^9}, {3.697728181722378*^9, 
  3.697728365521249*^9}},ExpressionUUID->"004cdc94-1038-4b1c-9183-\
d7cb93f6fb22"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.9.4. Surfaces of Revolution of Constant Positive Gaussian Curvature\
\>", "Subsubsection",
 CellChangeTimes->{{3.592460039870927*^9, 3.592460088511812*^9}, {
   3.592460175341565*^9, 3.5924602045760164`*^9}, {3.592743295809393*^9, 
   3.5927433008794017`*^9}, 3.59341846877223*^9, {3.6166566434732876`*^9, 
   3.616656645879425*^9}, 3.6167420110361643`*^9, 3.6170153528088784`*^9, 
   3.620482334629857*^9, 3.6280853261532087`*^9, 3.697954188073036*^9, 
   3.698473064007313*^9, 3.707742705951929*^9, 
   3.7077428342868*^9},ExpressionUUID->"630fa08f-6c46-4f58-a400-273a3d621721"],

Cell["\<\
In this  subsection we shall find the  surfaces of revolution with constant \
Gaussian curvature k >0.  The differential equation for surfaces of type xrev \
\>", "Text",
 CellChangeTimes->{{3.616669104636664*^9, 3.6166694203500185`*^9}, {
  3.616669476541317*^9, 3.616669536351822*^9}, {3.6979547172759457`*^9, 
  3.697954724891776*^9}, {3.6980450601729393`*^9, 3.698045110780685*^9}, {
  3.698045188731883*^9, 3.69804519051551*^9}, {3.6980452255557327`*^9, 
  3.698045340050777*^9}},ExpressionUUID->"e776e4aa-c591-40f6-b0e0-\
84595ad4b513"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xrev", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.698045357946311*^9, 
  3.6980453774267817`*^9}},ExpressionUUID->"6029f882-87dc-46a5-88b5-\
c4f5f7687cc3"],

Cell["is", "Text",
 CellChangeTimes->{{3.698045425849812*^9, 
  3.698045426521657*^9}},ExpressionUUID->"34954e7e-559f-4fad-b0d0-\
2784f457496f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"diff", "[", 
    RowBox[{"f", ",", "k"}], "]"}], "[", "u", "]"}], "\[Equal]", " ", 
  "0"}]], "Input",
 CellChangeTimes->{{3.6979823451334953`*^9, 3.6979823593999023`*^9}, {
  3.6979823927162943`*^9, 3.697982399520455*^9}, {3.698045441010339*^9, 
  3.698045444225889*^9}},ExpressionUUID->"bdac15ee-16e6-4623-b9b4-\
bc6e68080426"],

Cell["with the general solution (see Lemma 2)", "Text",
 CellChangeTimes->{{3.6980455825606613`*^9, 3.6980455946079893`*^9}, {
  3.698388100097034*^9, 
  3.698388142376786*^9}},ExpressionUUID->"24201ee6-2824-4a38-a8f6-\
e5e6c0a20351"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "u_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"solv", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}], " ", "+", 
   "a"}]}]], "Input",
 CellChangeTimes->{{3.697954323432159*^9, 3.69795433955156*^9}, {
   3.6983792759763803`*^9, 3.6983792909926653`*^9}, {3.698379347863738*^9, 
   3.69837935746354*^9}, {3.698379420558885*^9, 3.698379434494884*^9}, 
   3.6983879761027727`*^9},ExpressionUUID->"de9f4d2c-8958-4f0e-ae84-\
09a8f78c4f09"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"diff", "[", 
     RowBox[{"f", ",", "k"}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k", "!=", "0"}], ",", 
     RowBox[{"b", "\[NotEqual]", "0"}], ",", 
     RowBox[{"Element", "[", 
      RowBox[{
       RowBox[{"k", "|", "b", "|", "a", "|", "u"}], ",", "Reals"}], "]"}]}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698379361868129*^9, 3.698379378319907*^9}, {
  3.698379447639318*^9, 3.698379616550111*^9}, {3.698379652582313*^9, 
  3.698379697453472*^9}, {3.6983880085430393`*^9, 
  3.698388055587447*^9}},ExpressionUUID->"5c4582f0-f367-4d79-98b0-\
e986dc699388"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solv", "[", 
   RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}]], "Input",ExpressionUUID->\
"abfdfba0-58f3-4f60-badd-ef77b1693866"],

Cell["\<\
The general solution function solv is odd in u and b, see Lemma 3. Thus it \
suffices to consider b >0. Obviously, we have to exclude b= 0, 1.  
Values  b >1yield complex  solutions\
\>", "Text",
 CellChangeTimes->{{3.698300934005828*^9, 3.698300988621313*^9}, {
  3.698301134564193*^9, 3.698301139604401*^9}, {3.6983881628567247`*^9, 
  3.698388166496731*^9}, {3.698388198256404*^9, 3.698388222424224*^9}, {
  3.698390445501812*^9, 3.698390454229546*^9}, {3.698390490621439*^9, 
  3.698390760291388*^9}, {3.698390793960288*^9, 
  3.698390804258754*^9}},ExpressionUUID->"b5906faa-916b-41f8-a8b6-\
8afc0e519b62"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solv", "[", 
   RowBox[{"k", ",", "1"}], "]"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.698388873151102*^9, 3.698388914240334*^9}, {
  3.698389532453776*^9, 
  3.6983895560185347`*^9}},ExpressionUUID->"e331a07c-1329-4e7d-ac0d-\
cdb253ed6789"],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"solv", "[", 
      RowBox[{"1", ",", "b"}], "]"}], "[", "u", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "1", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697954991129994*^9, 3.697955055585209*^9}, {
   3.697955221580123*^9, 3.697955289303526*^9}, {3.697955937351399*^9, 
   3.697956009933679*^9}, {3.697956041919833*^9, 3.697956048346706*^9}, {
   3.697956107773431*^9, 3.6979561173055487`*^9}, {3.697956158958737*^9, 
   3.697956172752556*^9}, 3.697956526819228*^9, {3.698388405455049*^9, 
   3.6983884565032873`*^9}, {3.698388496203856*^9, 3.6983884988306828`*^9}, {
   3.6983886655736027`*^9, 3.698388681749155*^9}, {3.698388746200235*^9, 
   3.6983887469882603`*^9}, {3.698388802453622*^9, 3.698388813483953*^9}, 
   3.698388949592181*^9, {3.6983890048002*^9, 3.698389012242077*^9}, {
   3.698389582146509*^9, 3.69838958309403*^9}, {3.69838963492102*^9, 
   3.6983896435387917`*^9}},ExpressionUUID->"132cae92-b03b-4431-9efc-\
1a3468e4e82a"],

Cell["\<\
For 0 < b < 1 we obtain real solutions in an interval -u0<u<u0\
\>", "Text",
 CellChangeTimes->{{3.6983909893892593`*^9, 
  3.698391122183749*^9}},ExpressionUUID->"dc1c74a7-19db-4d60-b76b-\
cb6dec84af4a"],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"solv", "[", 
      RowBox[{"1", ",", "b"}], "]"}], "[", "u", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697954991129994*^9, 3.697955055585209*^9}, {
   3.697955221580123*^9, 3.697955289303526*^9}, {3.697955937351399*^9, 
   3.697956009933679*^9}, {3.697956041919833*^9, 3.697956048346706*^9}, {
   3.697956107773431*^9, 3.6979561173055487`*^9}, {3.697956158958737*^9, 
   3.697956172752556*^9}, 3.697956526819228*^9, {3.698388405455049*^9, 
   3.6983884565032873`*^9}, {3.698388496203856*^9, 3.6983884988306828`*^9}, {
   3.6983886655736027`*^9, 3.698388681749155*^9}, {3.698388746200235*^9, 
   3.6983887469882603`*^9}, {3.698388802453622*^9, 3.698388813483953*^9}, 
   3.698388949592181*^9, {3.6983890048002*^9, 3.698389012242077*^9}, {
   3.698389093363203*^9, 3.698389146521387*^9}, {3.6983891787118597`*^9, 
   3.698389222752967*^9}, {3.698389275699868*^9, 3.698389314908677*^9}, {
   3.698390895810494*^9, 
   3.698390901322667*^9}},ExpressionUUID->"7886de8d-d06a-4c57-916d-\
f3ef29e48f85"],

Cell["For values b with 0<b<1 the solution is real:", "Text",
 CellChangeTimes->{{3.6979569111620703`*^9, 3.697956972017294*^9}, {
  3.698390056640959*^9, 3.698390093280611*^9}, {3.698391195575452*^9, 
  3.698391201568059*^9}},ExpressionUUID->"886acbd8-2e88-4479-ac78-\
4e27ace71cb8"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"solv", "[", 
     RowBox[{"1", ",", ".5"}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697954991129994*^9, 3.697955055585209*^9}, {
   3.697955221580123*^9, 3.697955289303526*^9}, {3.697955440807088*^9, 
   3.6979554974622602`*^9}, {3.697955579634046*^9, 3.697955583373003*^9}, {
   3.698048725883449*^9, 3.698048841799025*^9}, {3.698049147687788*^9, 
   3.698049199347508*^9}, 3.6980493621823473`*^9, 3.69804941629316*^9, {
   3.698054519308766*^9, 3.69805452423979*^9}, 3.6983901083496447`*^9, {
   3.6983901415173903`*^9, 
   3.6983901632924833`*^9}},ExpressionUUID->"3f514405-7a9c-4c6f-a630-\
0ab093a7b12a"],

Cell["If u runs through the interval ", "Text",
 CellChangeTimes->{{3.698054642700363*^9, 
  3.6980546722203627`*^9}},ExpressionUUID->"ec9d8b3f-4002-46ce-a542-\
a577e422aa8e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"b", "^", "2"}]}], ")"}], "/", "k"}], "]"}]}], "<", "u", "<", 
  RowBox[{"Sqrt", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"b", "^", "2"}]}], ")"}], "/", "k"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.698054695576496*^9, 3.698054783451725*^9}, 
   3.698054844644421*^9, {3.698056917058156*^9, 3.6980569551224194`*^9}, 
   3.6980570739747753`*^9, 3.698392190312059*^9, {3.69839222890274*^9, 
   3.698392240382676*^9}, 3.698392277872137*^9, {3.698392475293268*^9, 
   3.698392507069132*^9}, {3.698419174708783*^9, 3.698419209676132*^9}, {
   3.69841925575681*^9, 
   3.698419267859853*^9}},ExpressionUUID->"24e58d45-a53a-4547-a086-\
de48cb147cf3"],

Cell[TextData[{
 "them the  argument ",
 Cell[BoxData[
  RowBox[{
   SqrtBox[
    RowBox[{"-", 
     FractionBox["k", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["b", "2"]}]]}]], " ", "u"}]], "Output",
  CellChangeTimes->{3.6983885688501453`*^9},ExpressionUUID->
  "2408d412-a6c7-4386-b0ad-612905a2796c"],
 " of ArcSin runs from -1 to 1, and this  yields the full picture of the \
surface; enter appropriate values of k>0 and b, 0<b<1, into the next cell to \
see the corresponding surfaces:"
}], "Text",
 CellChangeTimes->{{3.6980549007942877`*^9, 3.698055104104409*^9}, {
   3.698055141256393*^9, 3.6980553092949963`*^9}, {3.698058197359036*^9, 
   3.698058245542935*^9}, 3.698392330685628*^9, {3.698392439717266*^9, 
   3.698392449740699*^9}, {3.6983925600603724`*^9, 
   3.6983925937074547`*^9}},ExpressionUUID->"aaf024e1-55ee-4a52-9fdd-\
a95ada58e340"],

Cell[TextData[{
 StyleBox[" Example 8.",
  FontColor->RGBColor[0, 0, 1]],
 " Evaluate this example for various values of k>0,0<b<1. "
}], "Text",
 CellChangeTimes->{{3.6979585559869967`*^9, 3.69795856519471*^9}, {
   3.6979587094099007`*^9, 3.69795886640829*^9}, 3.6979626683757153`*^9, {
   3.697970931492173*^9, 3.697970937751494*^9}, {3.69839261131514*^9, 
   3.698392616883172*^9}},ExpressionUUID->"dcbcef03-0665-4ee8-afeb-\
a93cc1850ea4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "b"}], "]"}], ";", " ", 
  RowBox[{"k", "=", ".5"}], ";", 
  RowBox[{"b", "=", ".00001"}], ";", 
  RowBox[{"uo", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"b", "^", "2"}]}], ")"}], "/", "k"}], "]"}]}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\<uo= \>\"", ",", "uo"}], "]"}], ";"}], "\n", 
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"xrev", "[", 
     RowBox[{"solv", "[", 
      RowBox[{"k", ",", "b"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "uo"}], ",", "uo"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.697958930433399*^9, 3.697959004280004*^9}, {
   3.697959315608423*^9, 3.697959354372793*^9}, {3.6979595356239147`*^9, 
   3.697959552210476*^9}, {3.6979595893114443`*^9, 3.697959596010421*^9}, 
   3.697959634335326*^9, {3.697959703750457*^9, 3.697959717433536*^9}, 
   3.698058315870472*^9, {3.6980584133554707`*^9, 3.698058461798932*^9}, 
   3.6980585292523613`*^9, {3.6980698519920683`*^9, 3.698069938323862*^9}, {
   3.698069974016927*^9, 3.698070024282358*^9}, {3.698392630660075*^9, 
   3.698392643803815*^9}, {3.698392697187587*^9, 3.698392722710614*^9}, {
   3.698392821683531*^9, 3.698392860666086*^9}, {3.698392924039661*^9, 
   3.698392925185614*^9}, {3.698392958491168*^9, 3.6983929587046556`*^9}, 
   3.698393005023202*^9, 3.698393081797839*^9, {3.698393122171631*^9, 
   3.698393169203335*^9}, {3.698393531833132*^9, 3.6983935510370502`*^9}, {
   3.698419336900825*^9, 
   3.698419353596396*^9}},ExpressionUUID->"33098766-488e-43b2-802e-\
6b7929f232bc"],

Cell[TextData[{
 " You get surfaces of revolution with positive curvature k of the",
 StyleBox[" conical type",
  FontColor->RGBColor[0, 0, 1]],
 ".  \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.697960270025715*^9, 3.6979602700279913`*^9}, {
  3.697962681007612*^9, 3.697962684984418*^9}, {3.697962716167289*^9, 
  3.697962738127075*^9}},ExpressionUUID->"621ca10f-b762-4b7c-aa4a-\
dcdef3db7829"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"k", ",", "b", ",", "uo"}], "]"}]], "Input",
 CellChangeTimes->{{3.697960278266054*^9, 3.697960302308226*^9}, 
   3.698069426291016*^9, 
   3.698393241350644*^9},ExpressionUUID->"bfdebfa5-9a13-4fff-8dbc-\
bd96a92dddaf"],

Cell["\<\
Unfortunately, the half-sphere is not contained in the family of surfaces \
considered in example 8. One would expect to get the half-sphere if b \
approaches0,, but this value can\[CloseCurlyQuote]t be used in\
\>", "Text",
 CellChangeTimes->{{3.6980701039686947`*^9, 3.698070180911921*^9}, {
   3.698070220975713*^9, 3.698070453414187*^9}, {3.6981224081560583`*^9, 
   3.698122415108176*^9}, 3.698393286477825*^9, {3.698393596947378*^9, 
   3.698393635618767*^9}},ExpressionUUID->"8354ae3c-351a-4ec6-92d1-\
42ff7dee86d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solv", "[", 
   RowBox[{"k", ",", "0"}], "]"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.698070463526083*^9, 3.6980704822466383`*^9}, {
  3.698393646903117*^9, 
  3.6983936635305758`*^9}},ExpressionUUID->"7faa3f87-9879-4d98-9f4c-\
f33d41b62500"],

Cell["The next cell gives nothing", "Text",
 CellChangeTimes->{{3.6980708098830957`*^9, 
  3.698070863806552*^9}},ExpressionUUID->"ee686949-fa96-4dda-a4e1-\
1f7ee9769dc7"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"solv", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"b", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698070579149971*^9, 3.6980706269411*^9}, {
   3.698070694221077*^9, 3.6980707069808407`*^9}, {3.6983936974507647`*^9, 
   3.6983937554825497`*^9}, 3.698393809415085*^9, 
   3.698393839798707*^9},ExpressionUUID->"9a36d863-6e8d-4780-addd-\
7a5e84598d67"],

Cell["Consider the initial values", "Text",
 CellChangeTimes->{{3.697956997144508*^9, 
  3.69795702132651*^9}},ExpressionUUID->"285bec7f-594d-40e9-8df9-\
13f5dede7866"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solv", "[", 
   RowBox[{"k", ",", "b"}], "]"}], "[", "0", "]"}]], "Input",
 CellChangeTimes->{
  3.697957092497143*^9, {3.698393868977675*^9, 
   3.698393909241106*^9}},ExpressionUUID->"1be63382-f0d8-424e-8fdb-\
2ff4ec57fbee"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"solv", "[", 
       RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}], ",", "u"}], "]"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k", ">", "0"}], ",", 
     RowBox[{"b", ">", "0"}], ",", 
     RowBox[{"b", "<", "1"}], ",", 
     RowBox[{"u", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697957112716058*^9, 3.6979571806324873`*^9}, {
  3.698070901924766*^9, 3.6980709292025757`*^9}, {3.69807097358731*^9, 
  3.698071037890245*^9}, {3.698394009548128*^9, 
  3.6983940716878347`*^9}},ExpressionUUID->"a168ec2c-313a-4de8-9e5a-\
6ea2643768cc"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"u", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.698071081888401*^9, 
  3.698071091169656*^9}},ExpressionUUID->"4f8ee577-9fd9-4fb3-be7b-\
e4891f2fe4a0"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6979570299922543`*^9, 3.697957061521059*^9}, {
  3.697957283615638*^9, 3.69795738906264*^9}, {3.698071344780788*^9, 
  3.6980713572156143`*^9}, {3.698394116375332*^9, 
  3.698394130119197*^9}},ExpressionUUID->"590f81ad-e907-49c0-b2d5-\
7a66b421bc5f"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"%%", ",", 
   RowBox[{"b", "\[Rule]", "0"}], ",", 
   RowBox[{"Direction", " ", "->", 
    RowBox[{"-", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6980713022088614`*^9, 3.698071311992507*^9}, {
  3.6980713911031637`*^9, 3.698071467203045*^9}, {3.698394157726878*^9, 
  3.698394172596426*^9}},ExpressionUUID->"fc30cd13-5d93-49b5-a57e-\
b321f34255bd"],

Cell["\<\
Thus the initial conditions f[0]==0,f\[CloseCurlyQuote][0]== 0 are not \
satisfied by any solution  solv[k,b].  \
\>", "Text",
 CellChangeTimes->{{3.6979582015662537`*^9, 3.6979582233009253`*^9}, {
   3.697958254837721*^9, 3.697958512275516*^9}, 3.697958542515346*^9, {
   3.698122510387225*^9, 3.6981225547868032`*^9}, {3.698394267335051*^9, 
   3.698394276541514*^9}},ExpressionUUID->"9be20f71-e3bc-41a8-968a-\
899f843ed2fc"],

Cell["\<\
It seems to be a bit strange that the half-sphere generated by a meridian \
with the initial conditions f[0]==0, f\[CloseCurlyQuote][0]==0 is not found \
by DSolve:\
\>", "Text",
 CellChangeTimes->{{3.697971176237236*^9, 3.69797136635567*^9}, {
  3.69797141805134*^9, 3.697971446954976*^9}, {3.697971494186439*^9, 
  3.697971532394499*^9}, {3.6979716183455973`*^9, 3.697971628289225*^9}, {
  3.698071594941481*^9, 3.6980715978055077`*^9}, {3.698071655477552*^9, 
  3.698071662652739*^9}, {3.698071710452737*^9, 3.6980717848998013`*^9}, {
  3.698122742185388*^9, 
  3.698122746680992*^9}},ExpressionUUID->"cd2b06eb-a51e-4910-bf24-\
79651ab0cf64"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"diff", "[", 
        RowBox[{"f", ",", "1"}], "]"}], "[", "u", "]"}], "\[Equal]", " ", 
      "0"}], ",", 
     RowBox[{
      RowBox[{"f", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
   "f", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.698071792877932*^9, 3.698071935379051*^9}, {
  3.6980721297558107`*^9, 
  3.69807213151401*^9}},ExpressionUUID->"c3842b2c-ced3-4bae-be88-\
5a82ec9272b4"],

Cell[" Consider the function", "Text",
 CellChangeTimes->{{3.697971176237236*^9, 3.69797136635567*^9}, {
  3.69797141805134*^9, 3.697971446954976*^9}, {3.697971494186439*^9, 
  3.697971532394499*^9}, {3.6979716183455973`*^9, 3.697971628289225*^9}, {
  3.698071594941481*^9, 3.6980715978055077`*^9}, {3.698071655477552*^9, 
  3.698071662652739*^9}, {3.698071710452737*^9, 
  3.698071771092013*^9}},ExpressionUUID->"e150e43d-d25a-4206-bda6-\
1284909dbed2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsph", "[", "k_", "]"}], "[", "u_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"k", "^", "2"}]}], " ", "-", 
     RowBox[{"u", "^", "2"}]}], "]"}], "-", 
   RowBox[{"1", "/", "k"}]}]}]], "Input",
 CellChangeTimes->{{3.697960324479168*^9, 3.6979604931387243`*^9}, {
  3.6979613575992603`*^9, 3.69796136436371*^9}, {3.697971599389502*^9, 
  3.6979716089224863`*^9}},ExpressionUUID->"cd47af73-aa98-4fc0-ada4-\
78c452fdc4f3"],

Cell["generating the half-sphere of radius 1/k", "Text",
 CellChangeTimes->{{3.697971667135942*^9, 
  3.697971729648436*^9}},ExpressionUUID->"6bce9d16-07b1-4af1-b8e4-\
38f826007e46"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xrev", "[", 
   RowBox[{"fsph", "[", "k", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6979605156026154`*^9, 3.697960575329858*^9}, 
   3.697960684155959*^9, {3.69797176127641*^9, 
   3.6979717709603853`*^9}},ExpressionUUID->"d88a8457-00b3-4ebc-8d67-\
cced1c3cc792"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"xrev", "[", 
     RowBox[{"fsph", "[", "2", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", ".5"}], ",", ".5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6979610241771507`*^9, 3.6979610443498487`*^9}, {
   3.6979611216788883`*^9, 3.697961201653185*^9}, {3.697961242590514*^9, 
   3.697961258268737*^9}, 
   3.698072225109879*^9},ExpressionUUID->"232fc6d3-6194-42b4-90b5-\
1b236f52a720"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"xrev", "[", 
     RowBox[{"fsph", "[", "k", "]"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6979606964118137`*^9, 3.697960726920389*^9}, {
  3.697960886281397*^9, 3.6979608931593037`*^9}, {3.698072247714899*^9, 
  3.698072292108235*^9}},ExpressionUUID->"273913eb-749a-471a-b92e-\
affe99f72559"],

Cell["The initial conditions are satisfied:", "Text",
 CellChangeTimes->{{3.697962812717906*^9, 3.697962874981662*^9}, {
  3.697971955814241*^9, 
  3.6979719863984127`*^9}},ExpressionUUID->"9d2aca61-578d-4ed5-8b9f-\
c5ccebe0b8f3"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fsph", "[", "k", "]"}], "[", "0", "]"}], ",", 
   RowBox[{"k", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6979614637224817`*^9, 3.697961503652419*^9}, 
   3.698072382455789*^9, {3.698122840945565*^9, 
   3.6981228938775253`*^9}},ExpressionUUID->"ec2f653a-c9a8-4586-83e0-\
9900f1c42b0f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fsph", "[", "k", "]"}], "[", "u", "]"}], ",", "u"}], "]"}], "/.", 
  RowBox[{"u", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.697961513838257*^9, 3.697961548201572*^9}, {
   3.698072389295979*^9, 3.698072397279564*^9}, 
   3.69812290958453*^9},ExpressionUUID->"0700c47f-404f-44a5-ad36-\
ffe96641cef3"],

Cell["\<\
In spite of the fact that solv[k,b][u] is complex for b>1 one can find real \
solutions using this function with an additive constant. The reason is that \
the imaginary part of the function is constant on certain real intervals of \
u. Subtracting this constant  one gets a real solution on these intervals. \
First we have to find intervals with the indicated property:\
\>", "Text",
 CellChangeTimes->{{3.6981233539931087`*^9, 3.6981236367013617`*^9}, {
   3.6981237200608807`*^9, 3.698123813148294*^9}, {3.698123849380237*^9, 
   3.6981239328114567`*^9}, {3.6982090154817266`*^9, 3.6982090242496843`*^9}, 
   3.698209068217812*^9, {3.698239181702651*^9, 3.6982392280064373`*^9}, 
   3.698394408413805*^9, {3.69839444340543*^9, 3.69839444598092*^9}},
 CellTags->"barrel",ExpressionUUID->"43216cae-9973-4c5f-8e44-7b29a277faa0"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"k", ",", "b"}], "]"}]], "Input",
 CellChangeTimes->{{3.6980463763554077`*^9, 3.698046390602573*^9}, {
  3.698394430300767*^9, 
  3.6983944318687763`*^9}},ExpressionUUID->"2a69e8a7-1f58-4fe1-a9c7-\
4b3f131a983e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"solv", "[", 
        RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}], ",", "u"}], "]"}], "/.",
     " ", 
    RowBox[{"u", "\[Rule]", "t"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Element", "[", 
      RowBox[{"t", ",", "Reals"}], "]"}], ",", 
     RowBox[{"k", ">", "0"}], ",", 
     RowBox[{"b", ">", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.698047523250721*^9, {3.698047594807211*^9, 3.698047602314138*^9}, {
   3.698047647137988*^9, 3.698047657257441*^9}, 3.6981241292516403`*^9, {
   3.6981257255054483`*^9, 3.6981258871738863`*^9}, {3.6982396605152817`*^9, 
   3.698239694235094*^9}, {3.6982397432479362`*^9, 3.698239746411255*^9}, {
   3.6982397877703247`*^9, 3.6982398034743156`*^9}, {3.698239875789844*^9, 
   3.698239876633459*^9}, 3.698241878907118*^9, 3.69824192281988*^9, 
   3.698394416448904*^9, {3.698394512476829*^9, 
   3.698394515381008*^9}},ExpressionUUID->"dc4d63f3-3551-452c-a724-\
f22d0a036927"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"k", ">", "0"}], ")"}], ",", 
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           RowBox[{"1", "+", 
            FractionBox["1", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"b", "^", "2"}], "+", 
              RowBox[{"k", "*", 
               RowBox[{"t", "^", "2"}]}]}]]}]]}], "]"}], "\[Equal]", " ", 
        "0"}], ",", 
       RowBox[{"t", ">", "0"}]}], "}"}], ",", "t"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698242062517044*^9, 3.6982420684246197`*^9}, {
   3.69824214441677*^9, 3.69824218587304*^9}, {3.698242236481121*^9, 
   3.69824228571185*^9}, {3.698242523776523*^9, 3.698242583289235*^9}, {
   3.6982426146151*^9, 3.698242617605764*^9}, {3.6983945657486343`*^9, 
   3.698394641683648*^9}, 
   3.6983951246438*^9},ExpressionUUID->"f4dcf853-612e-4a8a-88b6-7bb1bae0369c"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"Im", "[", "b", "]"}], ">", "1"}], ",", 
     RowBox[{"Element", "[", 
      RowBox[{"t", ",", "Reals"}], "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698242803692165*^9, 3.6982429236824007`*^9}, {
   3.698394687058928*^9, 3.6983946929390287`*^9}, {3.698394973300449*^9, 
   3.69839500064082*^9}, 
   3.69839507581245*^9},ExpressionUUID->"aff8a5fb-4fa2-4188-b59f-\
ceb3b8ecd1bd"],

Cell["We use this interval in the next definition:", "Text",
 CellChangeTimes->{{3.698244540727799*^9, 3.698244606437553*^9}, 
   3.698471790522417*^9},ExpressionUUID->"596cdee9-c3fe-4f9b-9f8d-\
26724164ef46"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "k", ",", " ", "c", ",", " ", "u", ",", " ", "t", ",", " ", "realsolv"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"realsolv", "[", 
    RowBox[{"k_", ",", " ", "c_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "fff", ",", " ", "u0", ",", " ", "u1", ",", " ", "um", ",", " ", "t", 
      ",", "Fin"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "<=", "0"}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Abs", "[", "c", "]"}], "==", "1"}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{"c", "\[Equal]", "0"}], ")"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Invalid arguments \>\"", ",", "k", ",", "c", ",", 
          "\"\< !\>\""}], "]"}], ";", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "c", "]"}], "<", "1"}], ",", 
       RowBox[{
        RowBox[{"u0", "=", 
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"c", "^", "2"}]}], ")"}], "/", "k"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"u1", "=", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"c", "^", "2"}]}], ")"}], "/", "k"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"fff", "[", "t_", "]"}], " ", ":=", " ", 
         RowBox[{
          RowBox[{"solv", "[", 
           RowBox[{"k", ",", "c"}], "]"}], "[", "t", "]"}]}], ";", 
        RowBox[{"Goto", "[", "Fin", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"u0", "=", " ", 
      RowBox[{"c", "/", 
       RowBox[{"Sqrt", "[", "k", "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"u1", "=", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"c", "^", "2"}]}], ")"}], "/", "k"}], "]"}]}], ";", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"um", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"u1", " ", "+", " ", "u0"}], ")"}], "/", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fff", "[", "t_", "]"}], " ", ":=", " ", "\n", 
      RowBox[{"Re", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"solv", "[", 
          RowBox[{"k", ",", " ", 
           RowBox[{"I", "*", "c"}]}], "]"}], "[", "t", "]"}], " ", "-", "   ", 
        RowBox[{"I", "*", 
         RowBox[{"Im", "[", 
          RowBox[{
           RowBox[{"solv", "[", 
            RowBox[{"k", ",", 
             RowBox[{"I", "*", " ", "c"}]}], "]"}], "[", "um", "]"}], 
          "]"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Label", "[", "Fin", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<The interval is \>\"", ",", 
       RowBox[{"{", 
        RowBox[{"u0", ",", "u1"}], "}"}]}], "]"}], ";", " ", 
     RowBox[{"fff", "[", "u", "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.698156388654882*^9, 3.6981564791043577`*^9}, 
   3.6981566626942472`*^9, {3.6981579838513193`*^9, 3.6981581194984283`*^9}, {
   3.698158222377708*^9, 3.698158648998774*^9}, {3.698158682598198*^9, 
   3.698158759773923*^9}, {3.6981587906218023`*^9, 3.698158876388667*^9}, {
   3.6981589065508842`*^9, 3.6981589359004993`*^9}, {3.698159012374146*^9, 
   3.698159103762879*^9}, {3.6981592786810503`*^9, 3.698159318393166*^9}, {
   3.6981594051712427`*^9, 3.698159422296301*^9}, {3.698159479266576*^9, 
   3.698159518006962*^9}, 3.698160183613432*^9, {3.698160802966792*^9, 
   3.698160814603478*^9}, {3.698206133061389*^9, 3.698206146924282*^9}, {
   3.6982063110786057`*^9, 3.6982063267401037`*^9}, {3.698216232946164*^9, 
   3.698216259641632*^9}, {3.6982188320742893`*^9, 3.6982188503549643`*^9}, {
   3.698236347207809*^9, 3.698236620918927*^9}, {3.698236666055223*^9, 
   3.6982366984073477`*^9}, 3.6982367607665854`*^9, {3.69824464987267*^9, 
   3.698244671006496*^9}, {3.698244729863401*^9, 3.698244750524589*^9}, {
   3.69824485771775*^9, 3.698244885533866*^9}, 3.698244949301092*^9, {
   3.698244990467465*^9, 3.698244996419793*^9}, {3.698245189401*^9, 
   3.698245197985167*^9}, {3.698245233408247*^9, 3.698245246801107*^9}, {
   3.698245289040511*^9, 3.6982453642389517`*^9}, 3.698245438359867*^9, {
   3.698305988137576*^9, 3.6983060555343323`*^9}, 3.6984049568363953`*^9, {
   3.698405052084464*^9, 3.6984050657265453`*^9}, {3.698405152867888*^9, 
   3.6984051848360786`*^9}, {3.698405291146386*^9, 3.698405347114451*^9}, {
   3.69840556014454*^9, 3.698405584144665*^9}, {3.698405631975491*^9, 
   3.6984057043189783`*^9}, 3.698405738223283*^9, {3.698405776062677*^9, 
   3.698405786254128*^9}, 3.698407929316751*^9, {3.6984081829005623`*^9, 
   3.698408215257986*^9}, {3.698409213518065*^9, 3.69840928213715*^9}, {
   3.698416933604764*^9, 3.698416937872716*^9}, {3.69841700776257*^9, 
   3.698417043047537*^9}, {3.6984170766797647`*^9, 3.698417096031258*^9}, {
   3.698417130247387*^9, 3.6984172979014597`*^9}, {3.698417796677702*^9, 
   3.698417855817472*^9}, 3.698418728201388*^9, {3.698418814240979*^9, 
   3.698418876145035*^9}, {3.698419488947648*^9, 3.698419666516161*^9}, {
   3.698419701827148*^9, 3.698419732666497*^9}, {3.6984197877317963`*^9, 
   3.698419817672924*^9}, {3.698419917881271*^9, 3.698419920864753*^9}, {
   3.6984200914551153`*^9, 3.6984201057514343`*^9}, {3.698427160414132*^9, 
   3.6984271894629383`*^9}, {3.698427235790564*^9, 3.6984273009050217`*^9}, {
   3.698427340185055*^9, 3.69842736022475*^9}, {3.6984274191120243`*^9, 
   3.69842751827872*^9}, {3.698427575544058*^9, 3.698427633638516*^9}, {
   3.698427707093288*^9, 3.698427709029512*^9}, {3.698427764173046*^9, 
   3.698427779429041*^9}, 3.6984279175261593`*^9, {3.698470096679196*^9, 
   3.698470105342559*^9}, 3.6984701972702017`*^9, {3.698470239941773*^9, 
   3.698470285564447*^9}, {3.69847032142052*^9, 3.698470331387601*^9}, 
   3.698470369785515*^9, {3.698470517815053*^9, 3.698470519521618*^9}, {
   3.698470621735544*^9, 3.6984706254650784`*^9}, 3.698470656240075*^9, 
   3.698470700400695*^9, {3.698470734120021*^9, 3.698470736175808*^9}, 
   3.6984707887994127`*^9, {3.698471754687106*^9, 
   3.6984717585263977`*^9}},ExpressionUUID->"9a94a225-8206-4518-bf57-\
3e0918c8a702"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"realsolv", "::", "usage"}], " ", "=", " ", 
   "\"\<realsolf[k,c][u] for u running through the indicated interval is a \
graph over the x-axis showing the meridian of a surface of revolution of \
conctant Gaussian curvature k>0 with the parameter c, c\[NotEqual]0, c^2\
\[NotEqual]1.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.698236795500224*^9, 3.6982368660113707`*^9}, {
   3.698236897410492*^9, 3.6982370341216717`*^9}, {3.6982372183923397`*^9, 
   3.6982374124942904`*^9}, {3.6982374838891*^9, 3.698237559629265*^9}, 
   3.698417363519001*^9, {3.6984174400994043`*^9, 3.698417488578498*^9}, {
   3.698471567985113*^9, 
   3.698471650685321*^9}},ExpressionUUID->"99857775-5fe7-4ef3-b428-\
80ef48fde1a5"],

Cell["\<\
In this definition we included the meridians of surfaces of revolution of \
conical type considered in Example 8. They correspond to the case c^2<1:\
\>", "Text",
 CellChangeTimes->{{3.6984719741362343`*^9, 
  3.698472138174715*^9}},ExpressionUUID->"9f22e0c3-0912-449b-b2e2-\
a3a11c87ec76"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "b", ",", "c"}], "]"}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"realsolv", "[", 
     RowBox[{"2", ",", 
      RowBox[{"-", ".6"}]}], "]"}], "[", "u", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.698428047865582*^9, 
  3.698471829790966*^9},ExpressionUUID->"c8cf8359-62b1-4a38-bf34-\
b563922e9550"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", "u_", "]"}], "=", "%"}]], "Input",
 CellChangeTimes->{{3.698428069425362*^9, 3.698428079929348*^9}, {
  3.698470974781705*^9, 
  3.698470985866456*^9}},ExpressionUUID->"c6c7d059-22f1-4bfe-b1c5-\
06d5b6719922"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"ff", "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "0.565685424949238`"}], ",", "0.565685424949238`"}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698428060835985*^9, 3.698428121321231*^9}, {
  3.6984283022001133`*^9, 3.6984283246232843`*^9}, {3.698470916989277*^9, 
  3.698470942203416*^9}},ExpressionUUID->"4cc1847f-1060-4635-858f-\
95a395d53001"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"xrev", "[", "ff", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "0.565685424949238`"}], ",", "0.565685424949238`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.69847102821766*^9, 3.6984710817701283`*^9}, {
  3.6984711201949244`*^9, 
  3.698471159537779*^9}},ExpressionUUID->"c7f83596-0453-4663-8831-\
e4bbdaa9f172"],

Cell["\<\
Try other values with c^2<1. In the next example we consider the case c^2>1.\
\>", "Text",
 CellChangeTimes->{{3.698472166334396*^9, 
  3.698472250309938*^9}},ExpressionUUID->"10b4fa21-0deb-486a-9712-\
a32d8c033b23"],

Cell[TextData[{
 StyleBox["Example 9. Barrel-shaped",
  FontColor->RGBColor[0, 0, 1]],
 " surfaces of revolution of constant Gaussian curvature k>0, Abs[b]> 1."
}], "Text",
 CellChangeTimes->{{3.69830569867973*^9, 3.6983058031180553`*^9}, {
  3.698405835307795*^9, 
  3.698405905995227*^9}},ExpressionUUID->"e4fea29d-4efe-4923-a4e7-\
11ae63c0c4ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "b", ",", "c"}], "]"}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"realsolv", "[", 
     RowBox[{"2", ",", "1.6"}], "]"}], "[", "u", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.698158885123641*^9, 3.69815889713328*^9}, {
  3.698158948833756*^9, 3.698158964801406*^9}, {3.698160519495122*^9, 
  3.698160525707612*^9}, {3.6982163287264833`*^9, 3.698216356998618*^9}, {
  3.698405921046335*^9, 3.698405928793503*^9}, {3.698406294093301*^9, 
  3.698406348188283*^9}},ExpressionUUID->"f91672e0-806c-477b-8cbc-\
29cedd6a12d8"],

Cell["The generating meridian is", "Text",
 CellChangeTimes->{{3.698300425660891*^9, 
  3.698300471516029*^9}},ExpressionUUID->"72343e7e-94fe-4260-98bf-\
cd51dac94635"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fs", "[", "u_", "]"}], "=", "%"}]], "Input",
 CellChangeTimes->{{3.6981598132326*^9, 3.698159866817634*^9}, {
   3.698160429257365*^9, 3.698160457444319*^9}, 3.698160555951583*^9, 
   3.6981608399894457`*^9, 3.69823760550177*^9, 3.6984062573000813`*^9, {
   3.69840640495936*^9, 3.69840642857543*^9}, {3.698406499531534*^9, 
   3.698406525062976*^9}, 3.698407335037093*^9, {3.6984074467827797`*^9, 
   3.698407504654374*^9}, 3.698407686185946*^9, {3.698409381551731*^9, 
   3.6984093849821663`*^9}, 
   3.698417924579039*^9},ExpressionUUID->"fbb8c369-7f74-4347-8729-\
1e9c7cc62449"],

Cell["Using the indicated interval we plot the surface:", "Text",
 CellChangeTimes->{{3.698300483681341*^9, 
  3.698300524905208*^9}},ExpressionUUID->"b2436cfd-9856-4290-a110-\
59fc1e456123"],

Cell[BoxData[
 RowBox[{"sfr1", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"xrev", "[", "fs", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "u", ",", "1.131370849898476`", ",", "\[InvisibleSpace]", 
      "1.3341664064126335`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.698159702412537*^9, 3.698159774738266*^9}, {
   3.698159888745714*^9, 3.698159926849223*^9}, {3.698159957577537*^9, 
   3.6981599587529078`*^9}, {3.698159998032691*^9, 3.698160023248065*^9}, {
   3.698160251017819*^9, 3.698160265749626*^9}, {3.698160616575437*^9, 
   3.698160647714425*^9}, 3.698160678727056*^9, {3.698217191392685*^9, 
   3.698217205544291*^9}, {3.698302403005343*^9, 3.6983024074897346`*^9}, {
   3.698406163051548*^9, 
   3.698406215025573*^9}},ExpressionUUID->"129ffa1c-4a61-4548-a41c-\
88d064e9f53a"],

Cell["\<\
Since solv[k,c] is odd, we obtain a new surface of revolution with the same \
constant curvature k by reflection at the x,y-plane: \
\>", "Text",
 CellChangeTimes->{{3.698301209267488*^9, 3.6983013269387074`*^9}, {
  3.698301365026474*^9, 3.698301389194274*^9}, {3.6983791198975487`*^9, 
  3.6983791471209784`*^9}, {3.698406725108255*^9, 
  3.6984067280204887`*^9}},ExpressionUUID->"fbacde66-a825-4452-9307-\
8b9a80aac7b9"],

Cell[BoxData[
 RowBox[{"sfr2", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"xrev", "[", 
      RowBox[{"-", "fs"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "u", ",", "1.131370849898476`", "\[InvisibleSpace]", ",", 
      "\[InvisibleSpace]", "1.3341664064126335`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.698159702412537*^9, 3.698159774738266*^9}, {
   3.698159888745714*^9, 3.698159926849223*^9}, {3.698159957577537*^9, 
   3.6981599587529078`*^9}, {3.698159998032691*^9, 3.698160023248065*^9}, {
   3.698160251017819*^9, 3.698160265749626*^9}, {3.698160616575437*^9, 
   3.698160647714425*^9}, 3.698160678727056*^9, {3.698217191392685*^9, 
   3.698217205544291*^9}, 3.6983014851878223`*^9, {3.6983024262854424`*^9, 
   3.698302430209667*^9}, {3.698406802728141*^9, 
   3.69840684364431*^9}},ExpressionUUID->"3bf318e6-670a-404b-bb03-\
f5ddcf4a3726"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sfr1", ",", "sfr2"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6983015269770412`*^9, 3.698301637000587*^9}, {
  3.698301678869842*^9, 3.6983016793520527`*^9}, {3.698302447789515*^9, 
  3.698302454001018*^9}},ExpressionUUID->"45c7f46d-6797-422b-a0bc-\
c66c9bbf7027"],

Cell["The same picture can be created at once by ", "Text",
 CellChangeTimes->{{3.69830256987936*^9, 
  3.698302603999298*^9}},ExpressionUUID->"1dd8cde9-4586-49f8-9452-\
024e9ca28844"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"xrev", "[", "fs", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"xrev", "[", 
       RowBox[{"-", "fs"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "u", ",", "1.131370849898476`", "\[InvisibleSpace]", ",", 
     "\[InvisibleSpace]", "1.3341664064126335`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", "Yellow"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698159702412537*^9, 3.698159774738266*^9}, {
   3.698159888745714*^9, 3.698159926849223*^9}, {3.698159957577537*^9, 
   3.6981599587529078`*^9}, {3.698159998032691*^9, 3.698160023248065*^9}, {
   3.698160251017819*^9, 3.698160265749626*^9}, {3.698160616575437*^9, 
   3.698160647714425*^9}, 3.698160678727056*^9, {3.698217191392685*^9, 
   3.698217205544291*^9}, {3.698217316088752*^9, 3.6982173847025833`*^9}, {
   3.698217772184003*^9, 3.698217786059063*^9}, {3.69821784975618*^9, 
   3.6982178659299297`*^9}, 3.698300302689538*^9, 3.698301764819086*^9, {
   3.698301803343567*^9, 3.698301845991362*^9}, {3.698301912026309*^9, 
   3.698301944966703*^9}, {3.698303324054035*^9, 3.698303338722248*^9}, {
   3.698303375557797*^9, 3.6983033878338823`*^9}, 3.698303453053526*^9, 
   3.698406925853073*^9},ExpressionUUID->"413c19bc-5951-4ae0-9b06-\
8e7f7f0309c4"],

Cell["\<\
Translating the second meridian in an appropriate way along the z-axis:\
\>", "Text",
 CellChangeTimes->{{3.698304549070904*^9, 
  3.698304612111042*^9}},ExpressionUUID->"37a95ce5-dc93-4d53-a795-\
961090e74e0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "fss", "]"}], ";", 
  RowBox[{
   RowBox[{"fss", "[", "u_", "]"}], " ", ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"fs", "[", "u", "]"}]}], "+", 
    RowBox[{"2", "*", 
     RowBox[{"fs", "[", "1.3341664064126335`", "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.698302696069625*^9, 3.698302748572791*^9}, {
   3.698302812751478*^9, 3.6983028328781033`*^9}, {3.6983029169126596`*^9, 
   3.698302948428957*^9}, {3.698303631347742*^9, 3.698303632199506*^9}, 
   3.698303937754891*^9, {3.698304050015808*^9, 3.698304069164342*^9}, {
   3.698304142135611*^9, 3.698304142547151*^9}, {3.698304259267303*^9, 
   3.6983042707300777`*^9}, {3.698304469571968*^9, 3.6983044736566553`*^9}, {
   3.6983061190524*^9, 3.6983061263563137`*^9}, {3.6984070211706343`*^9, 
   3.698407025690901*^9}, 
   3.6984071081713*^9},ExpressionUUID->"b6dd91c8-8265-4bde-9bc3-a7a7344de044"],

Cell[BoxData[
 RowBox[{"sfr3", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"xrev", "[", "fss", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "u", ",", "1.131370849898476`", "\[InvisibleSpace]", ",", 
      "\[InvisibleSpace]", "1.3341664064126335`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.698159702412537*^9, 3.698159774738266*^9}, {
   3.698159888745714*^9, 3.698159926849223*^9}, {3.698159957577537*^9, 
   3.6981599587529078`*^9}, {3.698159998032691*^9, 3.698160023248065*^9}, {
   3.698160251017819*^9, 3.698160265749626*^9}, {3.698160616575437*^9, 
   3.698160647714425*^9}, 3.698160678727056*^9, {3.698217191392685*^9, 
   3.698217205544291*^9}, 3.6983014851878223`*^9, {3.6983024262854424`*^9, 
   3.698302430209667*^9}, {3.698304665609874*^9, 3.698304693143117*^9}, {
   3.698407187192985*^9, 
   3.6984072149383802`*^9}},ExpressionUUID->"4538b857-5277-4d33-a5c6-\
6689bdc05d64"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sfr1", ",", "sfr3"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698304748774919*^9, 
  3.69830480087011*^9}},ExpressionUUID->"1bb130ed-f2cc-4fd2-9ed9-\
0126598e174d"],

Cell["or", "Text",
 CellChangeTimes->{{3.6983048250537367`*^9, 
  3.698304825997365*^9}},ExpressionUUID->"fca6fbcf-1393-4dec-8f34-\
b002d2040c51"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"xrev", "[", "fs", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"xrev", "[", "fss", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "u", ",", "1.131370849898476`", "\[InvisibleSpace]", ",", 
     "\[InvisibleSpace]", "1.3341664064126335`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", "Yellow"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698159702412537*^9, 3.698159774738266*^9}, {
   3.698159888745714*^9, 3.698159926849223*^9}, {3.698159957577537*^9, 
   3.6981599587529078`*^9}, {3.698159998032691*^9, 3.698160023248065*^9}, {
   3.698160251017819*^9, 3.698160265749626*^9}, {3.698160616575437*^9, 
   3.698160647714425*^9}, 3.698160678727056*^9, {3.698217191392685*^9, 
   3.698217205544291*^9}, {3.698217316088752*^9, 3.6982173847025833`*^9}, {
   3.698217772184003*^9, 3.698217786059063*^9}, {3.69821784975618*^9, 
   3.6982178659299297`*^9}, 3.698300302689538*^9, 3.698301764819086*^9, {
   3.698301803343567*^9, 3.698301845991362*^9}, {3.698301912026309*^9, 
   3.698301944966703*^9}, {3.698303324054035*^9, 3.698303338722248*^9}, {
   3.698303375557797*^9, 3.6983033878338823`*^9}, 3.698303453053526*^9, {
   3.6983035697706623`*^9, 3.698303570575926*^9}, {3.698303741418013*^9, 
   3.698303774990242*^9}, 
   3.698407261938282*^9},ExpressionUUID->"488c4091-52a7-4878-baf1-\
fc73a61a1dae"],

Cell["Try this example changing k,b:", "Text",
 CellChangeTimes->{{3.698333866244494*^9, 3.6983339052041073`*^9}, {
  3.698407291903528*^9, 3.6984072931755733`*^9}, {3.698472927952153*^9, 
  3.6984729440959053`*^9}},ExpressionUUID->"0440a8c1-ade8-4df6-a9ff-\
729597850278"],

Cell[BoxData[
 RowBox[{
  RowBox[{"realsolv", "[", 
   RowBox[{"1", ",", "1.000001"}], "]"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.69821888710928*^9, 3.698218927527987*^9}, 
   3.6982436884969387`*^9, {3.6982437418323936`*^9, 3.698243743251676*^9}, 
   3.698243799381119*^9, 3.6983330343538*^9, {3.698333506933835*^9, 
   3.698333510600093*^9}, {3.698408557018738*^9, 3.698408588308723*^9}, {
   3.698409554104106*^9, 3.698409554348053*^9}, {3.698472412751594*^9, 
   3.6984724133726377`*^9}},ExpressionUUID->"b6996a12-c5c1-48ae-bbf6-\
90592d96e5b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fs", "[", "u_", "]"}], "=", "%"}]], "Input",
 CellChangeTimes->{{3.698219304496258*^9, 
  3.698219318444619*^9}},ExpressionUUID->"94db7d16-b803-4576-a6d9-\
0dc9ea061798"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fs", "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "u", ",", "\[InvisibleSpace]", "1.000001`", ",", "1.414214269480053`"}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698219579169332*^9, 3.698219612898576*^9}, {
   3.698219659442257*^9, 3.698219671113347*^9}, {3.698219703186492*^9, 
   3.698219746865135*^9}, {3.698219784696867*^9, 3.698219803440254*^9}, 
   3.698219836969421*^9, {3.69830642651553*^9, 3.698306433025011*^9}, {
   3.698306467706051*^9, 3.6983065092166557`*^9}, {3.698333180267638*^9, 
   3.698333216331325*^9}, {3.6983335565380993`*^9, 3.698333583351972*^9}, 
   3.6984087732289743`*^9, 3.698417738813932*^9, {3.698418111306757*^9, 
   3.6984181248530893`*^9}, 
   3.698472472250766*^9},ExpressionUUID->"6b454a69-f024-4300-b1d3-\
9119cefb8468"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"xrev", "[", "fs", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "1.000001`", ",", "1.414214269480053`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698220066234*^9, 3.698220117397683*^9}, {
   3.698220150078486*^9, 3.698220166221758*^9}, {3.698306586184832*^9, 
   3.698306608056006*^9}, 3.698333264223645*^9, {3.698333629874804*^9, 
   3.698333642271708*^9}, {3.6984086848521547`*^9, 3.698408688212702*^9}, 
   3.69840880030803*^9, 3.698418155938775*^9, 
   3.6984725156502323`*^9},ExpressionUUID->"b6dd4cdc-7860-4f0e-813a-\
295a2db78df0"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"xrev", "[", 
     RowBox[{"-", "fs"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "1.000001`", ",", "1.414214269480053`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698220066234*^9, 3.698220117397683*^9}, {
   3.698220150078486*^9, 3.6982202103094378`*^9}, {3.698220246261673*^9, 
   3.698220260292754*^9}, {3.698306652135914*^9, 3.698306722911305*^9}, 
   3.698333351327752*^9, {3.69833366341096*^9, 3.698333697943365*^9}, 
   3.6984086992215776`*^9, {3.698408733356279*^9, 3.6984087366603127`*^9}, 
   3.698418183226231*^9, 
   3.698472563209489*^9},ExpressionUUID->"4545ee5a-1827-4358-be87-\
b93d7b6a8016"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "%%"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6982202777236156`*^9, 3.698220335475556*^9}, 
   3.698238385043894*^9, {3.698238434186339*^9, 3.698238488396806*^9}, {
   3.698306748614794*^9, 3.698306783294252*^9}, {3.698333407251779*^9, 
   3.698333429312796*^9}, {3.698333711393264*^9, 
   3.698333721158319*^9}},ExpressionUUID->"7609ccec-332f-4cb4-9cc8-\
88c376bbe303"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fss", "[", "u_", "]"}], "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fs", "[", "u", "]"}]}], " ", "+", 
   RowBox[{"2", "*", 
    RowBox[{"fs", "[", "1.414214269480053`", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.698408864561*^9, 3.6984088997466516`*^9}, {
   3.698408953963089*^9, 3.698408958697626*^9}, 3.698409101260429*^9, {
   3.698418287266385*^9, 3.6984182905240383`*^9}, {3.6984183412918*^9, 
   3.698418347539154*^9}, 3.6984184950717783`*^9, {3.698472720583087*^9, 
   3.698472755979895*^9}},ExpressionUUID->"f15a0a47-749e-450d-be48-\
64fd897a1e12"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1.1974285755702865`"}], "-", 
  RowBox[{"Re", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.001`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    RowBox[{"EllipticE", "[", 
     RowBox[{
      RowBox[{"ArcSin", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0.7067533162284243`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", "u"}], "]"}], 
      ",", 
      RowBox[{"1.9980029960049945`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.698472383797917*^9, 
  3.6984723924776993`*^9}},ExpressionUUID->"b3cbf0a0-2aa7-4821-94ae-\
4bb33add19ea"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"xrev", "[", "fs", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"xrev", "[", "fss", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "1.000001`", ",", "1.414214269480053`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", "Yellow"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698159702412537*^9, 3.698159774738266*^9}, {
   3.698159888745714*^9, 3.698159926849223*^9}, {3.698159957577537*^9, 
   3.6981599587529078`*^9}, {3.698159998032691*^9, 3.698160023248065*^9}, {
   3.698160251017819*^9, 3.698160265749626*^9}, {3.698160616575437*^9, 
   3.698160647714425*^9}, 3.698160678727056*^9, {3.698217191392685*^9, 
   3.698217205544291*^9}, {3.698217316088752*^9, 3.6982173847025833`*^9}, {
   3.698217772184003*^9, 3.698217786059063*^9}, {3.69821784975618*^9, 
   3.6982178659299297`*^9}, 3.698300302689538*^9, 3.698301764819086*^9, {
   3.698301803343567*^9, 3.698301845991362*^9}, {3.698301912026309*^9, 
   3.698301944966703*^9}, {3.698303324054035*^9, 3.698303338722248*^9}, {
   3.698303375557797*^9, 3.6983033878338823`*^9}, 3.698303453053526*^9, {
   3.6983035697706623`*^9, 3.698303570575926*^9}, {3.698303741418013*^9, 
   3.698303774990242*^9}, 3.698407261938282*^9, 3.6984090721967154`*^9, 
   3.6984184304232683`*^9, 
   3.6984728488634367`*^9},ExpressionUUID->"54b0306e-3ba7-47fd-9623-\
24f99f0fca33"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.9.5. Surfaces of Revolution of Constant Negative Gaussian Curvature\
\>", "Subsubsection",
 CellChangeTimes->{{3.592460039870927*^9, 3.592460088511812*^9}, {
   3.592460175341565*^9, 3.5924602045760164`*^9}, {3.592743295809393*^9, 
   3.5927433008794017`*^9}, 3.592743439329645*^9, {3.592743475989709*^9, 
   3.5927434804045167`*^9}, 3.5934185161963134`*^9, {3.6126938340250387`*^9, 
   3.612693841775482*^9}, 3.6128496103122997`*^9, 3.6170153609043417`*^9, {
   3.620482324521039*^9, 3.6204823404486666`*^9}, 3.628085327416811*^9, 
   3.698473077415759*^9, 3.698672342153792*^9, 3.707742842302215*^9, 
   3.707743018557274*^9},ExpressionUUID->"9922fe80-95df-4d2b-8bf3-\
79a3ed4efffc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solv", "[", 
   RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.69847422923225*^9, 
  3.6984742468051043`*^9}},ExpressionUUID->"c70be573-9d29-447b-8b46-\
0bc0a2493fce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f1", ",", "b"}], "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"f1", "[", "b_", "]"}], "[", "u_", "]"}], "=", 
   RowBox[{
    RowBox[{"solv", "[", 
     RowBox[{
      RowBox[{"-", "3"}], ",", "b"}], "]"}], "[", "u", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6984742707564373`*^9, 3.698474306964848*^9}, {
   3.698474412872106*^9, 3.698474424251519*^9}, {3.698479928461336*^9, 
   3.6984799685787687`*^9}, {3.698502699004764*^9, 3.6985027006966467`*^9}, {
   3.6985034857453814`*^9, 3.698503507012637*^9}, 
   3.698503823703264*^9},ExpressionUUID->"fbb2c6be-c1ff-4590-95f5-\
08f0a9609f4b"],

Cell["\<\
The next cell shows that for b^2 < 1 there may exist a neighborhood 
|u|<uo with a real solution\
\>", "Text",
 CellChangeTimes->{{3.698556353156643*^9, 
  3.698556498299426*^9}},ExpressionUUID->"eab298fa-ed83-4c14-973b-\
7e2c8300add3"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{
       RowBox[{"f1", "[", ".5", "]"}], "[", "u", "]"}], "]"}], ",", 
     RowBox[{"Im", "[", 
      RowBox[{
       RowBox[{"f1", "[", ".5", "]"}], "[", "u", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "2."}], ",", "2."}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Green", ",", "Red"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6984757539878597`*^9, 3.6984757900494137`*^9}, {
   3.6984758512327547`*^9, 3.6984759650893373`*^9}, {3.698476007880122*^9, 
   3.6984760557119904`*^9}, 3.69847614078481*^9, {3.698476275495682*^9, 
   3.698476276830031*^9}, {3.698476317279204*^9, 3.698476318966072*^9}, {
   3.698476350777252*^9, 3.6984763519333982`*^9}, {3.698476416841704*^9, 
   3.698476450018141*^9}, {3.698476498591876*^9, 3.6984765416202707`*^9}, {
   3.6984766167633257`*^9, 3.698476662096692*^9}, 3.698476770439896*^9, {
   3.698476804591323*^9, 3.698476882526141*^9}, {3.69847692960389*^9, 
   3.698476946519876*^9}, {3.698477230232915*^9, 3.698477281082882*^9}, {
   3.698477463234292*^9, 3.698477466228787*^9}, {3.698477520572755*^9, 
   3.6984775314006977`*^9}, {3.698477614681875*^9, 3.698477639467157*^9}, {
   3.698477747255035*^9, 3.698477791278112*^9}, {3.698479523495013*^9, 
   3.698479559329352*^9}, {3.698556759019665*^9, 3.69855676286594*^9}, {
   3.698556862354906*^9, 
   3.698556877480937*^9}},ExpressionUUID->"749fa29d-7aff-430e-9816-\
e3eed7ee4ca9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "=", ".5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f1", "[", "b", "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{
      RowBox[{"-", "b"}], "/", 
      RowBox[{"Sqrt", "[", "3", "]"}]}], ",", 
     RowBox[{"b", "/", 
      RowBox[{"Sqrt", "[", "3", "]"}]}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6984796485446568`*^9, 3.698479708126107*^9}, {
   3.698480004886456*^9, 3.698480005633684*^9}, {3.6985032347036257`*^9, 
   3.698503292142704*^9}, {3.698503327384837*^9, 3.698503332738776*^9}, {
   3.698503367191228*^9, 3.698503385772718*^9}, {3.6985034316090403`*^9, 
   3.698503455118599*^9}, 3.698503547112632*^9, {3.6985035801424417`*^9, 
   3.698503589876213*^9}, 3.698503716176033*^9, {3.698503886766609*^9, 
   3.698503938663268*^9}, 3.698504001446042*^9, 
   3.698556539836076*^9},ExpressionUUID->"730c2d6c-8845-4793-b036-\
c1041ffaed63"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"xrev", "[", 
     RowBox[{"f1", "[", ".5", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{
      RowBox[{"-", "b"}], "/", 
      RowBox[{"Sqrt", "[", "3", "]"}]}], ",", 
     RowBox[{"b", "/", 
      RowBox[{"Sqrt", "[", "3", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698479784952682*^9, 3.6984798986278057`*^9}, {
   3.698480025187665*^9, 3.698480040153379*^9}, 3.698503643736392*^9, {
   3.698503743673122*^9, 3.6985037655231256`*^9}, {3.698504049022094*^9, 
   3.698504092089171*^9}, 3.698556927280509*^9, 
   3.698557006657947*^9},ExpressionUUID->"2fddaf33-16a2-498c-96ac-\
d4ec70de1c62"],

Cell["We control the Gaussian curvature", "Text",
 CellChangeTimes->{{3.698557060838541*^9, 
  3.698557079822397*^9}},ExpressionUUID->"db2a2416-e319-4a5b-98bd-\
231a2f66c1e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"xrev", "[", 
     RowBox[{"f1", "[", ".5", "]"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.698480094252475*^9, 3.698480097749752*^9}, {
   3.698480179344646*^9, 3.6984801961548243`*^9}, 
   3.698502941074712*^9},ExpressionUUID->"d2bfb77d-91b3-4e8d-9f8e-\
2b5305c7c19b"],

Cell["By symmetry, it suffices to consider the arguments v=0, u>0:", "Text",
 CellChangeTimes->{{3.698557106398183*^9, 
  3.698557178365624*^9}},ExpressionUUID->"6903a287-dd41-44d2-95c8-\
9a079ad72032"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"v", "\[Rule]", "0"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ">", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698480266417637*^9, 3.698480310853429*^9}, {
   3.698480340862151*^9, 3.6984803746924686`*^9}, 
   3.69850297321183*^9},ExpressionUUID->"974c83a3-687c-4b4b-b13c-\
f8933844ddf2"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", "%", "]"}], ",", 
   RowBox[{"u", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6984805892504*^9, 3.6984806705757837`*^9}, 
   3.698502986202342*^9},ExpressionUUID->"736cf058-7a59-46f9-b27e-\
2d32482a10f2"],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{
   RowBox[{"%", "+", "3"}], ",", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"-", "10"}], ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.69850417648164*^9, 3.6985041839446383`*^9}, {
  3.6985042891462*^9, 3.6985043518244753`*^9}, {3.6985046178588142`*^9, 
  3.69850466055881*^9}, {3.69855727252505*^9, 
  3.6985572996928043`*^9}},ExpressionUUID->"c344819e-670b-4820-974e-\
af21d8555557"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"%", ",", 
     RowBox[{"10", "^", 
      RowBox[{"(", 
       RowBox[{"-", "10"}], ")"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", ".0055"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698504211018079*^9, 3.698504256801017*^9}, {
   3.698504701810363*^9, 3.698504717054612*^9}, {3.698504753912134*^9, 
   3.698504781546094*^9}, {3.698504812663371*^9, 3.698504818598134*^9}, 
   3.698557339956531*^9},ExpressionUUID->"03721f7a-9725-4a5d-8565-\
8bd3152676c0"],

Cell["\<\
This shows K=-3. 
The next question is to find the interval |u|<uo on which the solution is \
real. Aiming this we consider the derivative of\
\>", "Text",
 CellChangeTimes->{{3.6985574185396214`*^9, 3.698557435619224*^9}, {
  3.698557561738146*^9, 3.698557689489193*^9}, {3.69855776575253*^9, 
  3.698557795112274*^9}, {3.698561329837099*^9, 3.698561348445113*^9}, {
  3.698561387748828*^9, 
  3.698561390644764*^9}},ExpressionUUID->"2712cc24-e451-40e6-8bb8-\
1369156e78a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "b"}], "]"}], ";", 
  RowBox[{
   RowBox[{"solv", "[", 
    RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}]}]], "Input",
 CellChangeTimes->{{3.698557803151116*^9, 
  3.698557857544198*^9}},ExpressionUUID->"cf19b650-15cf-4e18-96f0-\
953ab39f2c62"],

Cell["which mus be real on the same intervals as the solution:", "Text",
 CellChangeTimes->{{3.698557956439093*^9, 3.698557961615264*^9}, {
  3.698561433660536*^9, 
  3.69856152529173*^9}},ExpressionUUID->"6bbcccce-f5f2-4f6d-8a74-\
fcd5f67ffbdc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "b"}], "]"}], ";", 
  RowBox[{
   RowBox[{"f2", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"solv", "[", 
        RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}], ",", "u"}], "]"}], "/.", 
    RowBox[{"u", "\[Rule]", "t"}]}]}], ";", 
  RowBox[{"f2", "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.698505241060423*^9, 3.698505324081586*^9}, {
  3.698505368042712*^9, 3.698505399325254*^9}, {3.698561613348506*^9, 
  3.698561620763167*^9}},ExpressionUUID->"0dad8c53-ec09-4a95-8012-\
177a44e0ae40"],

Cell[TextData[{
 "under the s k<0,  0<",
 Cell[BoxData[
  SuperscriptBox["b", "2"]], "Output",
  CellChangeTimes->{3.6985580777784986`*^9},ExpressionUUID->
  "77e456be-5440-4d51-9a4e-c7c8c806f2ad"],
 "<1. "
}], "Text",
 CellChangeTimes->{{3.698558093206215*^9, 3.698558105423594*^9}, {
  3.69855815217384*^9, 3.69855819930958*^9}, {3.698558256149158*^9, 
  3.6985582744690237`*^9}, {3.698558319748781*^9, 3.698558338589325*^9}, {
  3.698561672402608*^9, 
  3.698561701826292*^9}},ExpressionUUID->"371f1374-bfba-4664-8f83-\
3e6f0141c07d"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "t", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"k", "->", 
        RowBox[{"-", "2"}]}], ",", 
       RowBox[{"b", "->", ".5"}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6985054081499166`*^9, 3.698505507345029*^9}, 
   3.698559309750971*^9, {3.698561760252006*^9, 
   3.698561826385748*^9}},ExpressionUUID->"40ce820b-ec01-4c17-a34a-\
78bf71b78ea5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "b"}], "]"}], ";", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"k", "<", "0"}], ",", 
      RowBox[{
       RowBox[{"b", "^", "2"}], ">", "0"}], ",", 
      RowBox[{
       RowBox[{"b", "^", "2"}], "<", "1"}]}], "}"}], ",", 
    RowBox[{"Reduce", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f2", "[", "t", "]"}], "\[Equal]", "0"}], ",", "t"}], "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.698505702557653*^9, 3.698505790751474*^9}, {
  3.6985059538540916`*^9, 
  3.698506068453938*^9}},ExpressionUUID->"2485305a-016d-4050-9fe9-\
36359c86fdff"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k", "<", "0"}], ",", 
     RowBox[{"b", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "<", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698506268372513*^9, 3.6985063288035717`*^9}, {
  3.698559657618082*^9, 
  3.69855975100977*^9}},ExpressionUUID->"67bc8449-4b22-47f0-bd10-\
c95fbde47c13"],

Cell["Compare the last Plot with", "Text",
 CellChangeTimes->{{3.6985621695665607`*^9, 
  3.6985621983184023`*^9}},ExpressionUUID->"fae5b7da-b490-4f65-bf31-\
ebfe7bc73365"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"b", "\[Rule]", ".5"}], ",", 
    RowBox[{"k", "\[Rule]", 
     RowBox[{"-", "2"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6985598655807123`*^9, 
  3.69855991911206*^9}},ExpressionUUID->"6f7596ea-a4b1-42ca-a0a3-\
bf00613857cd"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "b"}], 
     SqrtBox["k"]], "\[Equal]", 
    RowBox[{"b", "/", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"-", "k"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k", "<", "0"}], ",", 
     RowBox[{"b", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698559976338624*^9, 3.698560089686757*^9}, {
   3.698560146680228*^9, 3.698560170838402*^9}, 3.698560209784062*^9, {
   3.69856030455155*^9, 3.698560307181518*^9}, 3.698560872410657*^9, {
   3.698560905425804*^9, 
   3.6985609128491297`*^9}},ExpressionUUID->"ce11fbc9-a0f1-4fd3-9ea1-\
bf9cf8b991f8"],

Cell["Thus we set", "Text",
 CellChangeTimes->{{3.698562325573195*^9, 
  3.6985623310530357`*^9}},ExpressionUUID->"a800be9a-3946-4fd1-87e3-\
27ae4fddbfe6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"uo", "[", 
   RowBox[{"k_", ",", "b_"}], "]"}], ":=", " ", 
  RowBox[{"b", "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"-", "k"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.698562343362656*^9, 
  3.698562408669009*^9}},ExpressionUUID->"1f2f70ec-e62a-44e2-b956-\
e33e1319d16f"],

Cell[TextData[{
 StyleBox["Proposition 7",
  FontColor->RGBColor[0, 0, 1]],
 ". For any k<0 and b with0<",
 Cell[BoxData[
  SuperscriptBox["b", "2"]], "Output",
  CellChangeTimes->{3.698506070083433*^9, 3.698559552282749*^9, 
   3.698561965634521*^9},ExpressionUUID->
  "22866c63-95a3-4e0c-b4f7-347494453592"],
 "<1 the function solv[k,b][u] is real on the interval -uo[k, b]<u<uo[k, b]; \
its graph is the meridian of a surface of constant curvature k. \
\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.698563890052346*^9, 3.698563897036353*^9}, {
  3.698563931939966*^9, 3.6985642526577187`*^9}, {3.6985642994333963`*^9, 
  3.698564318373296*^9}},ExpressionUUID->"3093202f-8678-45e4-9bc0-\
acf7fb894869"],

Cell[TextData[{
 "The surfaces obtained this way are of ",
 StyleBox["conical type",
  FontColor->RGBColor[0, 0, 1]],
 ".To confirm proposition 7 test the next Example.\n",
 StyleBox["Example 10",
  FontColor->RGBColor[0, 0, 1]],
 ". Try the next cells for arbitrary values k, b with k<0 and 0<",
 Cell[BoxData[
  SuperscriptBox["b", "2"]], "Output",
  CellChangeTimes->{3.698506070083433*^9, 3.698559552282749*^9, 
   3.698561965634521*^9},ExpressionUUID->
  "44844807-854b-4841-8b08-3eafbbdd8a8a"],
 "<1."
}], "Text",
 CellChangeTimes->{{3.698564407424377*^9, 3.6985644440161858`*^9}, {
  3.69856456260719*^9, 3.6985646960299473`*^9}, {3.6985647437025557`*^9, 
  3.6985647464457903`*^9}, {3.698646376492577*^9, 
  3.698646445115621*^9}},ExpressionUUID->"e2828587-b74a-4044-acbb-\
c9eef1c38c7e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "b", ",", "fs", ",", "u0"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k", "=", 
   RowBox[{"-", "4"}]}], ";", 
  RowBox[{"b", "=", ".6"}], ";", 
  RowBox[{
   RowBox[{"fs", "[", "u_", "]"}], "=", 
   RowBox[{
    RowBox[{"solv", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}]}], ";", 
  RowBox[{"u0", "=", 
   RowBox[{"uo", "[", 
    RowBox[{"k", ",", "b"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6985648157895327`*^9, 3.6985649571805487`*^9}, {
   3.6985649912599087`*^9, 3.698565012772044*^9}, {3.698565065555369*^9, 
   3.698565099363275*^9}, {3.698565208418475*^9, 3.698565223170154*^9}, 
   3.698565666719927*^9, {3.698565724184144*^9, 3.69856572892618*^9}, {
   3.69856578722296*^9, 3.6985657998778477`*^9}, {3.698565890006815*^9, 
   3.698565890381049*^9}, 3.6985659779576283`*^9, {3.698566033085546*^9, 
   3.698566033588129*^9}, {3.6985661390125017`*^9, 3.6985661421470823`*^9}, 
   3.698566249547509*^9, {3.698566312571293*^9, 3.698566317785891*^9}, {
   3.698566430033976*^9, 3.698566440664783*^9}, {3.698566607304377*^9, 
   3.698566611559166*^9}},ExpressionUUID->"c776cea9-d637-48b8-86f6-\
5324d1fc0945"],

Cell["The Meridian is", "Text",
 CellChangeTimes->{{3.698565378464759*^9, 
  3.698565389544413*^9}},ExpressionUUID->"9bfbfc67-4482-4a55-b9a9-\
938020cdc860"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fs", "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "u0"}], ",", "u0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698565020335765*^9, 3.698565035988274*^9}, {
  3.69856511633913*^9, 
  3.698565189666793*^9}},ExpressionUUID->"25032255-85a5-4cf1-a72a-\
944fda08343d"],

Cell["The corresponding surface:", "Text",
 CellChangeTimes->{{3.698565407831643*^9, 
  3.69856544524833*^9}},ExpressionUUID->"42c1b3f2-b019-46e5-8e52-\
1738ae23412d"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"xrev", "[", "fs", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "u0"}], ",", "u0"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6985652408921347`*^9, 
  3.6985653489387093`*^9}},ExpressionUUID->"573363cd-876f-46a4-a530-\
ccaa9c0c0741"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.698566525569911*^9, 
  3.698566525571701*^9}},ExpressionUUID->"de7e2406-bd93-43b6-bc5b-\
49db17da934c"],

Cell[TextData[{
 "There exists yet a second series of surfaces of revolution of constant \
Gaussian curvature k<0. They are obtained with the same method applied in \
case of the barrel-shaped surfaces of curvature k>0, see ",
 ButtonBox["above",
  BaseStyle->"Hyperlink",
  ButtonData->"barrel"],
 ". Again we will find intervals where the imaginary part of the solution \
solv[k,b][u] is constant. We consider the derivative"
}], "Text",
 CellChangeTimes->{{3.698646596722196*^9, 3.698646840640524*^9}, {
  3.698646996916665*^9, 3.698647110862084*^9}, {3.698647186737689*^9, 
  3.69864718673918*^9}},ExpressionUUID->"d659e860-0514-4833-b72d-\
639ed953ee41"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "b", ",", "fs", ",", "u0"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f2", "[", "t_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"solv", "[", 
       RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}], ",", "u"}], "]"}], "/.", 
   RowBox[{"u", "\[Rule]", "t"}]}]}]}], "Input",
 CellChangeTimes->{{3.698646877600816*^9, 
  3.698646968248049*^9}},ExpressionUUID->"eb36f45f-8f61-4208-ba5c-\
7343fc3493cd"],

Cell[BoxData[
 RowBox[{"f2", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.698566824783584*^9, 
  3.698566830669422*^9}},ExpressionUUID->"a87f6c68-3c16-40b4-b245-\
296494eb5331"],

Cell["Simplifying this expression we control", "Text",
 CellChangeTimes->{{3.6986472505489073`*^9, 
  3.6986472717966013`*^9}},ExpressionUUID->"b257e41a-dfa1-4cb4-a821-\
1c1edc3ad7f0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%%", "\[Equal]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sign", "[", "b", "]"}]}], "*", "I", "*", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"b", "^", "2"}], "+", 
        RowBox[{"k", "*", 
         RowBox[{"t", "^", "2"}]}]}], "]"}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"b", "^", "2"}], "-", "1", "+", 
        RowBox[{"k", "*", 
         RowBox[{"t", "^", "2"}]}]}], "]"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k", "<", "0"}], ",", 
     RowBox[{
      RowBox[{"b", "^", "2"}], ">", "1"}], ",", 
     RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.69856732150711*^9, 3.698567444736628*^9}, {
   3.69856749212815*^9, 3.698567509784128*^9}, {3.6985675674796343`*^9, 
   3.698567682166685*^9}, {3.698567744375299*^9, 3.698567756270094*^9}, 
   3.698568139892717*^9},ExpressionUUID->"dfd60295-6e52-44a6-a6ef-\
2d90d9306962"],

Cell["\<\
Many test show that the identity is True.The real parts of both functions \
agree, the imaginary parts differ by ca 10^(-15) Thus we define:\
\>", "Text",
 CellChangeTimes->{{3.6986411562366323`*^9, 3.698641251972085*^9}, {
  3.698641732618556*^9, 
  3.6986417595372477`*^9}},ExpressionUUID->"a328d843-807e-4f1d-a8d9-\
852dadc099b2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f2", ",", "k", ",", "b"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f2", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sign", "[", "b", "]"}]}], "*", "I", "*", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"b", "^", "2"}], "+", 
       RowBox[{"k", "*", 
        RowBox[{"t", "^", "2"}]}]}], "]"}], "/", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"b", "^", "2"}], "-", "1", "+", 
       RowBox[{"k", "*", 
        RowBox[{"t", "^", "2"}]}]}], "]"}]}]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.698640977624745*^9, 3.6986410593339443`*^9}, {
   3.6986411118320932`*^9, 3.6986411406381598`*^9}, {3.698641258733118*^9, 
   3.698641260990222*^9}, 
   3.698652607759884*^9},ExpressionUUID->"82534d4e-1ca2-476e-8dcd-\
96327b9b19cb"],

Cell[BoxData[
 RowBox[{"f2", "[", "t", "]"}]], "Input",ExpressionUUID->"caf3d8aa-0d18-4066-a1ca-43083a139e62"],

Cell[BoxData[
 RowBox[{"Plot", "[", "\n", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"f2", "[", "t", "]"}], "]"}], "/.", " ", "\n", "   ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"b", " ", "->", " ", "2"}], ",", " ", 
      RowBox[{"k", " ", "->", " ", 
       RowBox[{"-", "3"}]}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", " ", "50"}], "}"}], ",", " ", "\n", "  ", 
   RowBox[{"PlotStyle", " ", "->", "Red"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698567728302288*^9, 3.6985677353580303`*^9}, {
   3.698587511627534*^9, 3.69858753545116*^9}, {3.698587597549262*^9, 
   3.698587600435322*^9}, {3.698587632035099*^9, 3.698587635363647*^9}, {
   3.69858766595516*^9, 3.698587813825989*^9}, 3.6985878646435003`*^9, {
   3.698587901362759*^9, 3.698587957522225*^9}, {3.698587994642205*^9, 
   3.6985879980003242`*^9}, {3.698588079137808*^9, 3.698588101088626*^9}, 
   3.6985881422509327`*^9, {3.698588198232267*^9, 3.698588198990344*^9}, {
   3.698588635403721*^9, 3.6985887788650703`*^9}, {3.698588816714432*^9, 
   3.698588818761015*^9}, {3.698588861873981*^9, 3.6985888694178123`*^9}, {
   3.698588900703936*^9, 3.6985889569596243`*^9}, 3.69858899642452*^9, 
   3.698589081240046*^9, {3.698589130223372*^9, 3.698589311589354*^9}, 
   3.6985893725738373`*^9, {3.6985895135723133`*^9, 3.6985895143623953`*^9}, {
   3.698589930536249*^9, 3.6985899765585537`*^9}, {3.698641501604985*^9, 
   3.698641541827883*^9}, {3.698641592107708*^9, 
   3.6986416149396753`*^9}},ExpressionUUID->"cd14c47f-6918-4475-ad77-\
de0ffe819583"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{
     RowBox[{"solv", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "2"}], "]"}], "[", "u", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "1.7", ",", "2.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6985903165511007`*^9, 3.69859044044198*^9}, {
   3.698590694185954*^9, 3.69859076391259*^9}, {3.698590936823599*^9, 
   3.698590985093273*^9}, {3.698591015759326*^9, 3.69859104807029*^9}, {
   3.698591089830677*^9, 3.698591097228672*^9}, {3.698591133718108*^9, 
   3.698591156509364*^9}, {3.698591206253385*^9, 3.6985912577393436`*^9}, {
   3.698591317916485*^9, 3.6985913471410303`*^9}, 3.69864190101795*^9, {
   3.698642027880875*^9, 
   3.698642049352977*^9}},ExpressionUUID->"3e6d4383-5f8a-48fd-88a1-\
5ec76d3011f9"],

Cell["\<\
Here is an interval with constant imaginary part of the solution:\
\>", "Text",
 CellChangeTimes->{{3.698647398124106*^9, 
  3.698647446635301*^9}},ExpressionUUID->"6c1fbeac-b686-45bc-9dec-\
5353929d71dc"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"solv", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "2"}], "]"}], "[", "u", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "1.7", ",", "2.1"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6985903165511007`*^9, 3.69859044044198*^9}, {
  3.698590694185954*^9, 3.69859076391259*^9}, {3.698590936823599*^9, 
  3.698590985093273*^9}, {3.698591015759326*^9, 3.69859104807029*^9}, {
  3.698591089830677*^9, 3.698591097228672*^9}, {3.698591133718108*^9, 
  3.698591156509364*^9}, {3.698591206253385*^9, 3.6985912577393436`*^9}, {
  3.698591317916485*^9, 3.6985913471410303`*^9}, {3.698591562065041*^9, 
  3.698591580096354*^9}, {3.69864207508848*^9, 
  3.698642087756267*^9}},ExpressionUUID->"2aa1435c-7b33-4d10-9c42-\
2cb94fd318e8"],

Cell["The real solution on this interval is", "Text",
 CellChangeTimes->{{3.698648315444063*^9, 3.698648337380096*^9}, 
   3.698650363931697*^9},ExpressionUUID->"ecea5337-85a6-43e3-a634-\
06428da7d117"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"solv", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "2"}], "]"}], "[", "u", "]"}], "-", 
    RowBox[{"I", "*", 
     RowBox[{"Im", "[", 
      RowBox[{
       RowBox[{"solv", "[", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "2"}], "]"}], "[", "1.9", "]"}], "]"}]}]}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "1.6", ",", "2.3"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698591398834173*^9, 3.698591476377426*^9}, {
  3.6985915098581*^9, 3.698591523712963*^9}, {3.698591607002164*^9, 
  3.6985916099526463`*^9}, {3.698591679641574*^9, 3.6985917084954033`*^9}, {
  3.698591753017166*^9, 3.698591753934905*^9}, {3.6985919789829473`*^9, 
  3.698592050844235*^9}, {3.698642185582657*^9, 3.6986421938622026`*^9}, {
  3.698642244034396*^9, 
  3.698642249908074*^9}},ExpressionUUID->"39c767bb-319e-4b13-a843-\
be884cd3e596"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV03k0lesaAHAzIYdCdNEtQsdQcVI3V4+QUi3JnJAyNCHJKVEokgxxTlIU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       "]]},
     Annotation[#, "Charting`Private`Tag$4839#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1.7320586962312734`, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Input",
 CellChangeTimes->{{3.6986487147652197`*^9, 
  3.698648714797175*^9}},ExpressionUUID->"be158f9a-c659-4f4c-8579-\
bf84bd6e4be5"],

Cell[TextData[{
 "In the next example one may construct barrel-shaped surfaces for all values \
k,b, with k<=, b^2>1.\n",
 StyleBox["Example 11",
  FontColor->RGBColor[0, 0, 1]],
 ". Choose k, b:"
}], "Text",
 CellChangeTimes->{{3.6986485589542027`*^9, 3.698648638297638*^9}, 
   3.698650400339263*^9, {3.698650529402429*^9, 3.698650596705806*^9}, {
   3.69865063228741*^9, 3.698650632322165*^9}, {3.698650675881089*^9, 
   3.698650719248632*^9}, {3.698650749584629*^9, 3.698650877935542*^9}, {
   3.698651341860201*^9, 
   3.6986513458037653`*^9}},ExpressionUUID->"007f19ef-840d-4973-be98-\
ace143549245"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", " ", "b", ",", " ", "ff", ",", " ", "fs"}], "]"}], ";", 
  " ", 
  RowBox[{"k", "=", 
   RowBox[{"-", "3"}]}], ";", " ", 
  RowBox[{"b", "=", "1.0002"}], ";"}]], "Input",
 CellChangeTimes->{{3.698651349721654*^9, 3.698651349722763*^9}, {
  3.698652303120545*^9, 3.698652309196905*^9}, {3.698653048722546*^9, 
  3.6986530490067043`*^9}},ExpressionUUID->"16050e0e-3fdc-4bb7-90e8-\
81e7bf727764"],

Cell["Remember: f2[t] is the derivative of the general solution.", "Text",
 CellChangeTimes->{{3.698652452819098*^9, 
  3.698652503938815*^9}},ExpressionUUID->"58ea7504-45a1-4391-a009-\
404efabcd5b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", "t_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"f2", "[", "t", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"k", "\[Rule]", 
        RowBox[{"-", "3"}]}], ",", 
       RowBox[{"b", "\[Rule]", "2"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.698642499973565*^9, 3.698642590498864*^9}, 
   3.698642706408643*^9, {3.698650912875599*^9, 
   3.698650927392397*^9}},ExpressionUUID->"d83c72a7-2956-4eea-88b5-\
a72de907f8d3"],

Cell["By symmetry, it suffices to consider the positive interval:", "Text",
 CellChangeTimes->{{3.6986528554479094`*^9, 
  3.698652895327531*^9}},ExpressionUUID->"f1b8b332-d58e-40be-9a1a-\
4d33a0377bac"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"ff", "[", "t", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"t", ">", "0"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.698592091846287*^9, 3.698592200922896*^9}, {
   3.698642383901485*^9, 3.698642421477086*^9}, 3.69864254335391*^9, {
   3.698642634082781*^9, 
   3.698642640250268*^9}},ExpressionUUID->"05e09e51-f1b8-45be-a3be-\
52bea532facf"],

Cell["We calculate and plot the meridian:", "Text",
 CellChangeTimes->{{3.698652934295182*^9, 
  3.698652955911141*^9}},ExpressionUUID->"8a2d62ae-31e1-4e21-b9cf-\
a25a7bc21224"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"u0", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
  RowBox[{"u1", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", 
     RowBox[{"-", "1"}], "]"}], "]"}]}], ";", 
  RowBox[{"um", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"u0", "+", "u1"}], ")"}], "/", "2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fs", "[", "u_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"solv", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}], "-", 
   RowBox[{"I", "*", 
    RowBox[{"Im", "[", 
     RowBox[{
      RowBox[{"solv", "[", 
       RowBox[{"k", ",", "b"}], "]"}], "[", "um", "]"}], 
     "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.698651042962335*^9, 3.6986511453339*^9}, {
  3.6986514489109087`*^9, 
  3.69865148706835*^9}},ExpressionUUID->"e15f32a7-9f51-499d-8dc4-\
ba192d75859c"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fs", "[", "u", "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"fs", "[", "u", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "u0", ",", "u1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6986427997599497`*^9, 3.698642935167653*^9}, {
   3.6986430368873043`*^9, 3.698643065254827*^9}, {3.69864310219073*^9, 
   3.698643122982758*^9}, {3.698651188538566*^9, 3.6986511952320433`*^9}, {
   3.698651255878159*^9, 3.698651314020898*^9}, 3.698651401429903*^9, 
   3.698651474792446*^9, {3.698651513763069*^9, 
   3.698651564323065*^9}},ExpressionUUID->"e9e88123-8fbd-46b6-8ee7-\
0ee8fd7e624c"],

Cell["Here is the surface:", "Text",
 CellChangeTimes->{{3.698652969223073*^9, 
  3.698652985118988*^9}},ExpressionUUID->"aa01fd9b-cfa1-4531-9602-\
2dea8f02d8ac"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"xrev", "[", "fs", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"xrev", "[", 
       RowBox[{"-", "fs"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "u0", ",", "u1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Yellow", "}"}], ",", 
      RowBox[{"{", "Yellow", "}"}]}], "}"}]}], ",", 
   RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6986451212369957`*^9, 3.698645230446947*^9}, {
   3.698645280071547*^9, 3.6986453012947607`*^9}, {3.698645354506452*^9, 
   3.698645543020918*^9}, {3.698645601721992*^9, 3.698645687153632*^9}, {
   3.698645742734956*^9, 3.698645760251093*^9}, 3.69864587559618*^9, {
   3.698645911674749*^9, 3.69864592249004*^9}, {3.698645968919029*^9, 
   3.698646015651527*^9}, {3.6986460651145763`*^9, 3.698646076121251*^9}, {
   3.69865165780733*^9, 
   3.6986517419783154`*^9}},ExpressionUUID->"b9fbe3fd-bcad-4999-9a9f-\
6fd2541f07d0"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.698651779947791*^9, 
  3.698651779949143*^9}},ExpressionUUID->"98d7f67e-f9df-47f7-afcc-\
8d13ac3de04b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"gauss", "[", 
       RowBox[{"xrev", "[", "fs", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "/.", 
     RowBox[{"v", "\[Rule]", "0"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ">", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698653294063993*^9, 3.69865340908423*^9}, {
  3.6986534765334044`*^9, 3.6986535133473663`*^9}, {3.698653545396399*^9, 
  3.698653561442727*^9}},ExpressionUUID->"62540c6f-e230-435d-98ce-\
3307fe20cbbc"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Chop", "[", 
    RowBox[{"%", "-", "k"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "u0", ",", "u1"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6986536172776318`*^9, 
  3.698653716641365*^9}},ExpressionUUID->"2cfbec93-2401-4cdf-84b6-\
976abaffcbd7"],

Cell[BoxData[
 RowBox[{"?", "pseudosphere"}]], "Input",
 CellChangeTimes->{{3.698653433239287*^9, 
  3.698653441266879*^9}},ExpressionUUID->"95378921-1a3c-4d24-b5b0-\
1574388cacbb"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"pseudosphere", "[", "1", "]"}], "[", 
   RowBox[{"0", ",", 
    RowBox[{"2", "Pi"}], ",", ".000001", ",", 
    RowBox[{"Pi", "-", "0.000001"}]}], "]"}], "MSG"]], "Input",
 CellChangeTimes->{{3.698654266499855*^9, 
  3.698654371434732*^9}},ExpressionUUID->"5d647ac6-c51d-48a7-b6a1-\
691c13f8dc75"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pseudosphere", "[", "1", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ";"}], "\n", 
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.69865377197816*^9, 3.69865382227204*^9}, {
  3.698654531828801*^9, 3.698654589305107*^9}, {3.698654625724284*^9, 
  3.698654664776842*^9}, {3.698654695802724*^9, 3.698654725205553*^9}, {
  3.698670886581962*^9, 
  3.698670887781911*^9}},ExpressionUUID->"d7fbbf74-b47c-4c0f-99e6-\
19eef2668833"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"pseudosphere", "[", "a", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.698655460918145*^9, 3.698655497808402*^9}, 
   3.698656462346581*^9},ExpressionUUID->"a5e27aa1-cd0a-444c-a321-\
46d1586d8a38"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", "/.", 
   RowBox[{"u", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698655571074641*^9, 3.698655585751906*^9}, {
  3.698655619855915*^9, 
  3.698655638855012*^9}},ExpressionUUID->"38165cd1-f5a2-45be-be2b-\
d03fd098add9"],

Cell["\<\
The pseudo-spheres are standard examples for surfaces of constant negative \
Gaussian curvature. They are not members of the two series considered above \
containing bounded surfaces only, but the pseudo-spheres are unbounded:\
\>", "Text",
 CellChangeTimes->{{3.698656725333128*^9, 3.69865679798036*^9}, {
  3.6986710157081013`*^9, 
  3.698671176067217*^9}},ExpressionUUID->"6626f8e4-c7da-4903-af08-\
c4729ba7c052"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"v", "\[Rule]", "Pi"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698671188164297*^9, 
  3.698671255402828*^9}},ExpressionUUID->"4b86273e-2885-43fa-a17b-\
f7ac50d43fe8"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"v", "\[Rule]", 
    RowBox[{"-", "Pi"}]}], ",", 
   RowBox[{"Direction", "\[Rule]", 
    RowBox[{"-", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698671188164297*^9, 3.698671255402828*^9}, {
  3.6986712896520357`*^9, 
  3.698671338946574*^9}},ExpressionUUID->"4a16e6b7-0fd8-49b8-8f68-\
aef17a6c28fa"],

Cell[TextData[{
 StyleBox["Proposition 8",
  FontColor->RGBColor[0, 0, 1]],
 ". For all k<0 the pseudo-sphere with parameter a =1",
 Cell[BoxData[
  RowBox[{"/", 
   SqrtBox[
    RowBox[{"-", "k"}]]}]], "Input",
  CellChangeTimes->{{3.697638720024364*^9, 3.697638751716379*^9}},
  ExpressionUUID->"7b8c4317-1eb7-4adc-8b5a-745692d0bcd5"],
 " is an unbounded surface of revolution of constant Gaussian curvature k. \
\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.69867005431131*^9, 3.698670059869966*^9}, 
   3.6986700977622013`*^9, {3.698670201852131*^9, 3.698670205699897*^9}, {
   3.698670252371916*^9, 3.6986703656903553`*^9}, {3.698670628607958*^9, 
   3.698670658418976*^9}, {3.698670689130045*^9, 3.698670689130291*^9}, {
   3.698670727606729*^9, 3.6986707840864677`*^9}, {3.698670822573909*^9, 
   3.6986708306941338`*^9}, {3.6986715396323147`*^9, 
   3.698671546056237*^9}},ExpressionUUID->"bd0a95ac-40ac-49a6-b120-\
5c4e9528dfae"],

Cell["The meridian is", "Text",
 CellChangeTimes->{{3.6986556878338633`*^9, 
  3.698655713069634*^9}},ExpressionUUID->"98d7e736-8df0-4f7f-9436-\
8a30e8cb76bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
  RowBox[{"0", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.698654990025639*^9, 3.698654992172563*^9}, 
   3.698655277567236*^9, {3.6986553171024933`*^9, 3.698655335457613*^9}, 
   3.6986559510492973`*^9},ExpressionUUID->"26417ce3-a1b8-4e61-bd84-\
91576a33aae8"],

Cell["for  a= 1:", "Text",
 CellChangeTimes->{{3.698655994979848*^9, 3.69865601184348*^9}, {
  3.698670846029578*^9, 
  3.698670847837434*^9}},ExpressionUUID->"478c4f4b-379b-4160-9867-\
91a8239eee14"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "t", "]"}], ",", 
     RowBox[{
      RowBox[{"Cos", "[", "t", "]"}], "+", 
      RowBox[{"Log", "[", 
       RowBox[{"Tan", "[", 
        FractionBox["t", "2"], "]"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6986557325808897`*^9, 3.698655797582238*^9}, {
  3.698655833654372*^9, 
  3.69865588942941*^9}},ExpressionUUID->"0a7ae4d0-9220-4fe8-ba1b-\
1bafd9f394a4"],

Cell[TextData[{
 "This is a ",
 ButtonBox["tractrix",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/Tractrix.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/Tractrix.html"],
 " (or dog\[CloseCurlyQuote]s curve). This meridian isn\[CloseCurlyQuote]t a \
solution of diff[f,k]==0 since it is not a graph over the x-axis. Clearly, \
the corresponding surface has two infinite \[OpenCurlyDoubleQuote]ends\
\[CloseCurlyDoubleQuote]:"
}], "Text",
 CellChangeTimes->{{3.69865616439194*^9, 3.698656240441669*^9}, {
  3.698656272487672*^9, 3.698656272490066*^9}, {3.698656487688115*^9, 
  3.6986566526704273`*^9}, {3.6986717285353203`*^9, 
  3.698671750615011*^9}},ExpressionUUID->"eb615087-42bb-44e9-8ead-\
d633fcc211c2"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"pseudosphere", "[", "10", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698671762030983*^9, 3.69867184900699*^9}, {
   3.69867189932583*^9, 3.698671935917869*^9}, {3.698672015401616*^9, 
   3.698672033956813*^9}, 3.69867213603797*^9, {3.69867225301578*^9, 
   3.6986722544120007`*^9}},ExpressionUUID->"d06e51bb-471b-4149-9888-\
f70ff40f1449"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.698655219964149*^9, 3.6986552278106527`*^9}, {
  3.698671874117916*^9, 3.698671879702113*^9}, {3.6986721793558598`*^9, 
  3.6986721809240828`*^9}},ExpressionUUID->"2b227f72-d850-4b19-8b19-\
497219d43116"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.9.6. Alfred Gray\[CloseCurlyQuote]s Exposition", "Subsubsection",
 CellChangeTimes->{{3.616761707824889*^9, 3.616761725544903*^9}, {
   3.6167618514484744`*^9, 3.616761855888728*^9}, 3.628085328540013*^9, 
   3.707743038542103*^9, 
   3.7078207622010508`*^9},ExpressionUUID->"69c45e38-1909-4af3-a48f-\
9a963483ed1f"],

Cell[TextData[{
 "In this subsection we reproduce Alfred Gray\[CloseCurlyQuote]s exposition, \
see [",
 ButtonBox["G94",
  BaseStyle->"Hyperlink",
  ButtonData->"Gray3"],
 "], p. 331-351. He considers surfaces of revolution rotating the general \
curve {f[u],0,h[u]} around the z-axis:"
}], "Text",
 CellChangeTimes->{{3.616761864977248*^9, 3.6167619121849484`*^9}, {
  3.616762256056617*^9, 3.616762268648337*^9}, {3.616762315433013*^9, 
  3.6167623634807615`*^9}, {3.6167623992378063`*^9, 3.6167624170408244`*^9}, {
  3.616762447824585*^9, 3.616762528984227*^9}, {3.707819620243824*^9, 
  3.7078197079302063`*^9}},ExpressionUUID->"17323a91-a053-48fd-b39c-\
e305fe05340d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "sfrev", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{"f_", ",", "h_"}], "]"}], "[", 
    RowBox[{"v_", ",", "u_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], "*", 
      RowBox[{"Cos", "[", "v", "]"}]}], ",", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], "*", 
      RowBox[{"Sin", "[", "v", "]"}]}], ",", " ", 
     RowBox[{"h", "[", "u", "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6167625563717937`*^9, 3.616762562882166*^9}, {
   3.616762596579094*^9, 3.6167626241226687`*^9}, {3.707803316005233*^9, 
   3.707803334972129*^9}, 3.7078034856473293`*^9, {3.70780406318463*^9, 
   3.7078041018818398`*^9}, {3.707804221821829*^9, 3.70780423503144*^9}, {
   3.707804287733328*^9, 
   3.707804330905292*^9}},ExpressionUUID->"7b79ece8-fa60-431e-9903-\
fa8b51632698"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", 
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
  RowBox[{"v", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6168156415232797`*^9, 3.616815663410118*^9}, 
   3.707805136466337*^9},ExpressionUUID->"c70a5bac-5efe-4650-a660-\
3c873e1981d9"],

Cell[TextData[{
 "assuming that u is the arc length of the meridians: ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "2"], " "}]],
  CellChangeTimes->{{3.616763093942541*^9, 3.616763101653982*^9}},
  ExpressionUUID->"7157a445-22cd-4fa4-92a8-40e0ff0a8649"],
 " + ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["h", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "2"], " "}]],
  CellChangeTimes->{{3.616763093942541*^9, 3.616763101653982*^9}},
  ExpressionUUID->"e7b5f93b-19b6-4c89-92b9-1723b6ecba2c"],
 " = 1, we simplify"
}], "Text",
 CellChangeTimes->{{3.6167627698730054`*^9, 3.616762832176569*^9}, {
   3.61676314952072*^9, 3.616763207233021*^9}, {3.616763618840564*^9, 
   3.6167636504333706`*^9}, 3.616766019912897*^9, 3.616817422687608*^9, {
   3.616817534851805*^9, 
   3.6168175393758135`*^9}},ExpressionUUID->"7bb1a6a0-879c-4d6b-bea5-\
a068d0c3bb5d"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["h", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], "->", " ", 
     RowBox[{
      RowBox[{"-", " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], "*", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "/", 
       RowBox[{
        SuperscriptBox["h", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}]}]}], ",", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"], " ", "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["h", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], "  ", "==", 
      "1"}], ",", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616815692441769*^9, 3.616815734140642*^9}, {
   3.6168157725947104`*^9, 3.6168158224523973`*^9}, 3.6168158754300904`*^9, 
   3.616816933080748*^9, {3.6168169756220226`*^9, 3.61681703093972*^9}, {
   3.6168170698461885`*^9, 3.616817077193801*^9}, {3.616817155552739*^9, 
   3.6168172066272287`*^9}, 3.6168172513681073`*^9, {3.6168173069198046`*^9, 
   3.6168173135810165`*^9}, {3.6168173795067325`*^9, 3.6168173808639345`*^9}, 
   3.6168174826229134`*^9, {3.707804150300337*^9, 3.707804170928084*^9}, {
   3.7078044107275476`*^9, 3.707804439968224*^9}, 
   3.707805065791836*^9},ExpressionUUID->"9b870022-ade3-473e-9a7a-\
eb551c70943b"],

Cell["\<\

We define simplification rules completed with the regularity condition f[u]>0\
\>", "Text",
 CellChangeTimes->{
  3.6168174336700277`*^9, {3.616817814872297*^9, 3.6168178310495253`*^9}, 
   3.618638761429304*^9, {3.707755599425336*^9, 3.707755671687502*^9}, 
   3.707803853068349*^9},ExpressionUUID->"a5e7ecde-783f-4cc5-847f-\
55eeedd596a5"],

Cell[BoxData[
 RowBox[{"hfrules", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], 
       RowBox[{"2", " "}]], " ", "+", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["h", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "^", "2"}]}], " ", "==", 
     " ", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["h", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "*", 
       RowBox[{
        SuperscriptBox["h", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], "+", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "*", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], "\[Equal]", " ", 
     "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.616763093942541*^9, 3.616763101653982*^9}, {
  3.6167632193497143`*^9, 3.616763225317055*^9}, {3.616763584790616*^9, 
  3.616763593167095*^9}, {3.6167637325750685`*^9, 3.616763746788882*^9}, {
  3.616763851589876*^9, 3.616763855941125*^9}, {3.616766029566449*^9, 
  3.616766055494932*^9}, {3.6168168060341253`*^9, 3.6168168365945787`*^9}, {
  3.6168175677210627`*^9, 3.616817576035877*^9}, {3.6168176380615864`*^9, 
  3.6168177407253666`*^9}, {3.6168177737506247`*^9, 3.6168177833914413`*^9}, {
  3.698731468135105*^9, 3.698731481073359*^9}, {3.707804906646001*^9, 
  3.7078049103718557`*^9}},ExpressionUUID->"999239a8-934b-4964-9b12-\
419fbc535399"],

Cell["Corollary 18.9, p.333, is proved by the formulas", "Text",
 CellChangeTimes->{{3.616763273112789*^9, 
  3.6167633640009875`*^9}},ExpressionUUID->"bf199497-c73f-4130-a0a8-\
3a478fd206a5"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"v", ",", "u"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", "hfrules"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, 3.616766130622229*^9, {
   3.707804540847714*^9, 
   3.707804543513989*^9}},ExpressionUUID->"eec2e412-124c-4030-aed5-\
9a1623c1e32b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund2", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
     RowBox[{"v", ",", "u"}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], ",", "hfrules"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.6167661529985094`*^9, 3.6167661920377417`*^9}, {
   3.7078046184213963`*^9, 
   3.707804620843706*^9}},ExpressionUUID->"1498e278-b9f5-47ba-9dfb-\
ecccda4f65db"],

Cell["\<\
Indeed, remember that we permuted v,u and regard, that the second fundamental \
form in gray\[CloseCurlyQuote]s definition  is -fund2.\
\>", "Text",
 CellChangeTimes->{{3.6167658674081745`*^9, 3.61676593342495*^9}, 
   3.6167664090331535`*^9, 3.707805144952286*^9, {3.707807481741665*^9, 
   3.707807582300419*^9}},ExpressionUUID->"9c1c682c-6568-4aca-b90f-\
119405598456"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"prcurvatures", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", " ", "hfrules"}], "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.616764252801824*^9, 3.6167642858527145`*^9}, {
   3.6167663533249674`*^9, 3.6167663604363737`*^9}, 
   3.707805146265338*^9},ExpressionUUID->"cd9d7383-5546-4807-b2d5-\
8def33467f1d"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", " ", "hfrules"}], "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.616764252801824*^9, 3.6167642858527145`*^9}, {
   3.6167663533249674`*^9, 3.6167663604363737`*^9}, {3.61676642925731*^9, 
   3.6167664451882215`*^9}, 
   3.707805147234674*^9},ExpressionUUID->"9b7979cd-a660-4a2b-8944-\
d591eb03643b"],

Cell["Consider", "Text",
 CellChangeTimes->{{3.6167671612251763`*^9, 
  3.6167671647043753`*^9}},ExpressionUUID->"08f40aa1-3ff7-4cfc-a625-\
7e67fb777da5"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
     RowBox[{"f", "[", "u", "]"}]], "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "*", 
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"f", "[", "u", "]"}]]}]}], ",", " ", "hfrules"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.616764252801824*^9, 3.6167642858527145`*^9}, {
   3.6167663533249674`*^9, 3.6167663604363737`*^9}, {3.61676642925731*^9, 
   3.6167664451882215`*^9}, {3.6167669272437935`*^9, 
   3.6167669744854956`*^9}, {3.616767010878577*^9, 3.616767044479499*^9}, 
   3.616767126944216*^9},ExpressionUUID->"e264f4e7-4092-4c4c-b099-\
e55b1f73b2da"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{"f", ",", "h"}], "]"}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", " ", "hfrules"}], "]"}]], "Input",
 CellChangeTimes->{{3.6167633769727297`*^9, 3.616763411850724*^9}, {
   3.6167634592524357`*^9, 3.616763542812215*^9}, 3.6167636682603903`*^9, {
   3.6167637805648136`*^9, 3.616763782700936*^9}, {3.6167638833616934`*^9, 
   3.616763891758174*^9}, {3.6167639523656397`*^9, 3.616763959157028*^9}, 
   3.6167640369744797`*^9, {3.616764252801824*^9, 3.6167642858527145`*^9}, {
   3.6167663533249674`*^9, 3.6167663604363737`*^9}, {3.61676642925731*^9, 
   3.6167664451882215`*^9}, {3.616767194901102*^9, 3.6167672153722734`*^9}, 
   3.707805148242914*^9},ExpressionUUID->"fd1b6824-f686-4fec-8342-\
8fc7dfadb7ab"],

Cell["\<\
\[FilledSquare]
Now we apply the last formula and solve for constant k\
\>", "Text",
 CellChangeTimes->{{3.616819049895266*^9, 3.616819089846936*^9}, 
   3.6987316068673487`*^9, {3.707807706051547*^9, 
   3.707807724787624*^9}},ExpressionUUID->"9f981de3-3078-4e36-8648-\
469e359ff8d8"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["f", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{"-", "k"}], "*", 
     RowBox[{"f", "[", "u", "]"}]}]}], ",", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6168183087535644`*^9, 
  3.6168183645548625`*^9}},ExpressionUUID->"e3a545cf-ac8f-405b-bc98-\
3bbe41c42ac4"],

Cell["Setting", "Text",
 CellChangeTimes->{{3.6168217096187725`*^9, 
  3.6168217128323784`*^9}},ExpressionUUID->"a82194c7-db53-4bf3-879b-\
3ca5177d404f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Sqrt", "[", "k", "]"}], " ", "=", 
    RowBox[{"1", "/", "a"}]}], ";", 
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], " ", "=", 
    RowBox[{"b", "*", 
     RowBox[{"Cos", "[", "c", "]"}]}]}], ";", " ", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], "=", " ", 
    RowBox[{
     RowBox[{"-", "b"}], "*", 
     RowBox[{"Sin", "[", "c", "]"}]}]}], ";"}], "\[LineSeparator]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6168217372464213`*^9, 3.6168218967567015`*^9}, 
   3.69873167762282*^9},ExpressionUUID->"ff0705e4-0253-49a1-b0e8-\
6962be3b8618"],

Cell["\<\
leads to the general solution f[u] = b*Cos[u/a +c]; since the additive \
constant c means a parameter translaton for the generating curve, the \
meridian  {f[u],0,h[u]} only, we may assume c = 0 and define as the solution \
for f\
\>", "Text",
 CellChangeTimes->{{3.616822046454564*^9, 3.61682214638834*^9}, {
   3.6168222017060375`*^9, 3.616822233389693*^9}, {3.6168222749682674`*^9, 
   3.616822329784403*^9}, {3.616822380673313*^9, 3.61682239320903*^9}, {
   3.616822686496805*^9, 3.6168227043848286`*^9}, 3.618638772788954*^9, {
   3.7078084799745502`*^9, 3.707808553269977*^9}, {3.70780858389424*^9, 
   3.707808653963673*^9}, {3.707816594387896*^9, 
   3.707816602633816*^9}},ExpressionUUID->"6e6e46e0-300d-4d40-9e5c-\
cb2783bbe7cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsol", "[", 
    RowBox[{"k_", ",", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"b", "*", 
   RowBox[{"Cos", "[", 
    RowBox[{"u", "*", 
     RowBox[{"Sqrt", "[", "k", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.616822420616598*^9, 3.6168225175151405`*^9}, {
  3.698731693636442*^9, 
  3.698731702664074*^9}},ExpressionUUID->"ba69d32a-83f5-478b-a70b-\
08d63877f7ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"fsol", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", "k"}], "*", 
   RowBox[{
    RowBox[{"fsol", "[", 
     RowBox[{"k", ",", "b"}], "]"}], "[", "u", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.616822784435407*^9, 
  3.616822831668109*^9}},ExpressionUUID->"020f5f1f-647f-46ac-b17a-\
bef187597877"],

Cell["\<\
Since changing the sign of fsol means a reflection at the z-axis only and \
does not influence the function\
\>", "Text",
 CellChangeTimes->{{3.616822955943217*^9, 3.616823088680809*^9}, {
   3.6168232351451864`*^9, 3.616823284248995*^9}, 3.616823402856779*^9, {
   3.6168235962008376`*^9, 3.6168237090572925`*^9}, {3.616823977353638*^9, 
   3.616824004769206*^9}, {3.6168240378730993`*^9, 3.6168240444164743`*^9}, {
   3.6168240905691137`*^9, 3.61682411900174*^9}, {3.6168241508565617`*^9, 
   3.616824269849368*^9}, {3.616824377489525*^9, 3.6168243914573236`*^9}, {
   3.616824577209948*^9, 3.616824633353159*^9}, {3.697972794823886*^9, 
   3.697972808439776*^9}, {3.697972923695271*^9, 3.6979729372632217`*^9}, {
   3.7078169843747177`*^9, 3.7078170351677437`*^9}, 
   3.707817079421543*^9},ExpressionUUID->"de64440e-d9e8-4107-b79e-\
5342a81b39f7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", "u", "]"}], " ", "=", " ", 
  RowBox[{"\[Integral]", 
   RowBox[{
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox[
       RowBox[{
        RowBox[{"f", "'"}], "[", "u", "]"}], "2"]}]], 
    RowBox[{"\[DifferentialD]", "u"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.7078170844428387`*^9, 3.707817102402566*^9}, {
   3.707817164706276*^9, 3.7078172145213337`*^9}, {3.70781724746404*^9, 
   3.70781733816*^9}, 
   3.707817381627018*^9},ExpressionUUID->"ae9a9bfe-882e-4592-b103-\
eec0f2910798"],

Cell["\<\
we may assume b\[GreaterEqual]0;
the case b=0  fsol[k,b]==0,the surface degenerates to the z-axis, since \
h\.b4[u] = \[PlusMinus]1, h[u] = \[PlusMinus]u + c0:\
\>", "Text",
 CellChangeTimes->{{3.616822955943217*^9, 3.616823088680809*^9}, {
   3.6168232351451864`*^9, 3.616823284248995*^9}, 3.616823402856779*^9, {
   3.6168235962008376`*^9, 3.6168237090572925`*^9}, {3.616823977353638*^9, 
   3.616824004769206*^9}, {3.6168240378730993`*^9, 3.6168240444164743`*^9}, {
   3.6168240905691137`*^9, 3.61682411900174*^9}, {3.6168241508565617`*^9, 
   3.616824269849368*^9}, {3.616824377489525*^9, 3.6168243914573236`*^9}, {
   3.616824577209948*^9, 3.616824633353159*^9}, {3.697972794823886*^9, 
   3.697972808439776*^9}, {3.697972923695271*^9, 3.6979729372632217`*^9}, {
   3.7078169843747177`*^9, 3.7078170351677437`*^9}, 3.707817079421543*^9, {
   3.707817648011001*^9, 
   3.707817648016385*^9}},ExpressionUUID->"8a29c22e-7a4b-4dbe-8814-\
766de4a9e1de"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "u_", "]"}], " ", ":=", " ", 
   RowBox[{"u", "+", "1"}]}], ";", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"zero", ",", "h1"}], "]"}], "[", 
     RowBox[{"v", ",", "u"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6168237141345825`*^9, 3.616823839297742*^9}, {
   3.616823883861291*^9, 3.61682393560425*^9}, {3.616824280708989*^9, 
   3.6168243321969337`*^9}, 
   3.707805150840083*^9},ExpressionUUID->"c9dce204-26a3-4a9c-8dfc-\
57e2b4c9a564"],

Cell["Analogously, the case k = 0  leads to f\[CloseCurlyQuote]\
\[CloseCurlyQuote][u] = 0", "Text",
 CellChangeTimes->{{3.616824671409336*^9, 3.6168247003769927`*^9}, {
  3.6168247342969327`*^9, 3.6168247391772118`*^9}, {3.7078178044991207`*^9, 
  3.7078178497859993`*^9}, {3.707818344830044*^9, 
  3.707818351964736*^9}},ExpressionUUID->"816e7ee4-1055-490c-9223-\
dae9989a5fc9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f0", "[", "b_", "]"}], "[", "u_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"b", "*", "u"}], " ", "+", "c1"}]}], ";", " ", 
  RowBox[{
   RowBox[{"h0", "[", "u_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"c", "*", "u"}], " ", "+", " ", "c2"}]}], ";", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"b", "^", "2"}], " ", "+", 
    RowBox[{"c", "^", "2"}]}], "\[Equal]", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.616824747833707*^9, 3.6168248737079067`*^9}, {
  3.7078178932129793`*^9, 3.7078179028056993`*^9}, {3.70781878756534*^9, 
  3.7078188256538353`*^9}, {3.707818866445915*^9, 
  3.7078189260068293`*^9}},ExpressionUUID->"70e248e2-6a15-4f95-bf99-\
64e4e7a9174f"],

Cell["and gives a circular cylinder, e.g.", "Text",
 CellChangeTimes->{{3.616825074441388*^9, 3.6168250879691615`*^9}, 
   3.707818048904566*^9, {3.7078189440956383`*^9, 3.7078189998643103`*^9}, {
   3.707819064095706*^9, 3.707819077695019*^9}, 
   3.707819126197742*^9},ExpressionUUID->"ad0efcfe-bba2-441a-aece-\
296bbb9b639a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f0", "[", "u_", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"h0", "[", "u_", "]"}], " ", "=", " ", "u"}], ";", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"f0", ",", "h0"}], "]"}], "[", 
     RowBox[{"v", ",", "u"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6168237141345825`*^9, 3.616823839297742*^9}, {
   3.616823883861291*^9, 3.61682393560425*^9}, {3.616824280708989*^9, 
   3.6168243321969337`*^9}, {3.6168249119320927`*^9, 3.6168250119328127`*^9}, 
   3.7078051545362597`*^9, {3.707819136549265*^9, 3.707819266988564*^9}, 
   3.707819300213052*^9, 
   3.707819330842107*^9},ExpressionUUID->"81993aa7-330b-4fe8-910f-\
3d1cb3cd89f4"],

Cell["or a circular cone, e.g.", "Text",
 CellChangeTimes->{{3.707819507564248*^9, 
  3.707819526082738*^9}},ExpressionUUID->"bc1cf71c-e5a0-4c2a-b829-\
8f1ab2bd3908"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f0", "[", "u_", "]"}], "=", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{"1", "/", "2"}], "]"}], "*", "u"}]}], ";", 
  RowBox[{
   RowBox[{"h0", "[", "u_", "]"}], " ", "=", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{"1", "/", "2"}], "]"}], "*", " ", "u"}]}], ";", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{"f0", ",", "h0"}], "]"}], "[", 
     RowBox[{"v", ",", "u"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6168237141345825`*^9, 3.616823839297742*^9}, {
   3.616823883861291*^9, 3.61682393560425*^9}, {3.616824280708989*^9, 
   3.6168243321969337`*^9}, {3.6168249119320927`*^9, 3.6168250119328127`*^9}, 
   3.7078051545362597`*^9, {3.707819136549265*^9, 3.707819266988564*^9}, 
   3.707819300213052*^9, 3.707819330842107*^9, {3.707819390921465*^9, 
   3.707819481425458*^9}},ExpressionUUID->"5984ac4f-9790-4d83-9ffd-\
48d51b9d1589"],

Cell["\<\
Remember the discussion of the developable surfaces of revolution in  \
subsection 3.9.3. Thus we will suppose b>0 in the following, b then is the \
maximal distance of the meridian to the z-axis. To find h[u] we remember\
\>", "Text",
 CellChangeTimes->{{3.6168257166171184`*^9, 3.616825794936598*^9}, {
   3.6168258277774763`*^9, 3.6168258771372995`*^9}, {3.6168266438661537`*^9, 
   3.6168266721447716`*^9}, {3.616826897673671*^9, 3.6168269301615295`*^9}, {
   3.6186387818694725`*^9, 3.6186388047167797`*^9}, 3.62808533275202*^9, {
   3.697973170989685*^9, 3.697973193780985*^9}, {3.697973226332695*^9, 
   3.6979732448924017`*^9}},ExpressionUUID->"d8bae83c-3732-409b-8cd0-\
335bbd2dfe2e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"h\.b4", "[", "u", "]"}], " ", "\[Equal]", "  ", 
  RowBox[{"Sqrt", "[", 
   RowBox[{"1", "-", 
    RowBox[{
     RowBox[{"f\.b4", "[", "u", "]"}], "^", "2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.616826684975505*^9, 
  3.6168267685152836`*^9}},ExpressionUUID->"cc5f0e7d-11df-49c0-a9ca-\
46ae8d429900"],

Cell["with f\.b4[u] equal", "Text",
 CellChangeTimes->{{3.6168276321506805`*^9, 
  3.6168276803534374`*^9}},ExpressionUUID->"1247fc58-05c6-49e4-97db-\
a65e61cdc56c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fsol", "[", 
      RowBox[{"k", ",", "b"}], "]"}], "[", "t", "]"}], ",", "t"}], "]"}], "/.",
   " ", 
  RowBox[{"t", "\[Rule]", " ", "u"}]}]], "Input",
 CellChangeTimes->{{3.6168275053584285`*^9, 
  3.616827562586702*^9}},ExpressionUUID->"dc96238b-b839-4f98-b7e8-\
8981b25ae480"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "b"}], " ", 
  SqrtBox["k"], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{
    SqrtBox["k"], " ", "u"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.707820004472389*^9, 3.707820011417694*^9}, 
   3.7078200554686728`*^9},ExpressionUUID->"3bdcbea2-bc8b-4259-9a8d-\
b10b09e30199"],

Cell["\<\
The condition Abs[f\[CloseCurlyQuote][u]] \[LessEqual]1 implies restrictios \
to the variable u depending on the sign of k.\
\>", "Text",
 CellChangeTimes->{{3.7078200852641068`*^9, 3.707820158790448*^9}, {
  3.707820280157174*^9, 
  3.707820318459672*^9}},ExpressionUUID->"3cbde6a0-1465-445b-90e0-\
f2a7fddb870e"],

Cell["\<\
We assume h\.b4[u] \[GreaterEqual] 0; this can be reached always substituting \
u .> -u, if necessary.  To get h[u] we integrate\
\>", "Text",
 CellChangeTimes->{{3.6168273598091035`*^9, 3.6168274930327234`*^9}, 
   3.6168277062729197`*^9, {3.707820363292218*^9, 3.707820365276792*^9}, {
   3.707820462442687*^9, 
   3.7078205121063757`*^9}},ExpressionUUID->"68ced070-ebb9-4e40-afa6-\
0f7c5e7349e9"],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", "-", 
     RowBox[{"k", "*", 
      RowBox[{"b", "^", "2"}], "*", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", "k", "]"}], "*", "t"}], "]"}], "^", "2"}]}]}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168275053584285`*^9, 3.616827562586702*^9}, {
  3.6168277151474276`*^9, 3.616827777011966*^9}, {3.6168278227725835`*^9, 
  3.616827859483683*^9}, {3.61682790208412*^9, 
  3.616827911220642*^9}},ExpressionUUID->"3eb6e59f-87c0-4bbd-8393-\
4fb86498aa30"],

Cell["\<\
We set the additive integration constant equal zero; another constant acts as \
a translation along the z-axis only, and define \
\>", "Text",
 CellChangeTimes->{{3.616828038160903*^9, 3.616828084720566*^9}, {
  3.616828184393267*^9, 
  3.616828257961475*^9}},ExpressionUUID->"cf8a189e-1b74-4470-9676-\
f5c77d6dbdd9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsol", "[", 
    RowBox[{"k_", ",", " ", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{
   RowBox[{"EllipticE", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "k", "]"}], "*", "u"}], ",", " ", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "*", "k"}]}], "]"}], "/", 
   RowBox[{"Sqrt", "[", "k", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.616828268317067*^9, 
  3.6168283557230663`*^9}},ExpressionUUID->"9f0bcdb5-a155-4632-ac30-\
be76fbbad5fc"],

Cell["Control:", "Text",
 CellChangeTimes->{{3.616828630960809*^9, 3.616828636009098*^9}, {
  3.6168286713051167`*^9, 
  3.616828702768916*^9}},ExpressionUUID->"0ba9f1fa-2fad-4528-822d-\
fe5446ad7a34"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"fsol", "[", 
        RowBox[{"k", ",", "b"}], "]"}], ",", 
       RowBox[{"hsol", "[", 
        RowBox[{"k", ",", "b"}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616828375117176*^9, 3.6168284650523195`*^9}, {
   3.6168285000513215`*^9, 3.6168285465979843`*^9}, 
   3.707805156282898*^9},ExpressionUUID->"38489e7f-168e-4350-8386-\
e0cd14361cdb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{
    RowBox[{"fsol", "[", 
     RowBox[{"0", ",", "b"}], "]"}], ",", 
    RowBox[{"hsol", "[", 
     RowBox[{"0", ",", "b"}], "]"}]}], "]"}], "[", 
  RowBox[{"v", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{3.616828801107541*^9, 
  3.707805157314187*^9},ExpressionUUID->"a0328315-edc0-4a6c-943b-\
f6945810fafa"],

Cell["\<\
The developable surfaces are not contained in this family; the case k = b= 1 \
yields the unit sphere:\
\>", "Text",
 CellChangeTimes->{{3.616829005569236*^9, 
  3.6168290587852793`*^9}},ExpressionUUID->"805df220-d5fc-407c-864c-\
0ac0f9304eb0"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{"1", ",", "1"}], "]"}], ",", 
      RowBox[{"hsol", "[", 
       RowBox[{"1", ",", "1"}], "]"}]}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168287071561675`*^9, 3.6168287474044695`*^9}, {
   3.61682882626898*^9, 3.6168289348461905`*^9}, 
   3.707805161458218*^9},ExpressionUUID->"29573e98-05de-493b-9105-\
ce4e09dcbbf8"],

Cell["", "Text",ExpressionUUID->"04361a78-e3b4-42e7-b66b-4fbdf4b117df"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.9.6.a. Surfaces of Revolution of Constant Positive Gaussian Curvature\
\>", "Subsubsection",
 CellChangeTimes->{{3.6168293520900555`*^9, 3.6168294026009445`*^9}, {
   3.6168445489178305`*^9, 3.6168445611545305`*^9}, {3.617015288424196*^9, 
   3.6170153146076937`*^9}, {3.6170153724870043`*^9, 3.6170153975684385`*^9}, 
   3.6258046614906793`*^9, 3.629187774354987*^9, {3.69797364312927*^9, 
   3.6979736450409317`*^9}, 3.698732338234435*^9, 3.707820775425475*^9, 
   3.707826826254258*^9},ExpressionUUID->"1b09c752-f109-426a-bbdc-\
b7cd39676813"],

Cell["\<\
We assume k > 0 and distinguish three cases to obtain real solutions:\
\>", "Text",
 CellChangeTimes->{{3.616829477278216*^9, 
  3.6168295357855625`*^9}},ExpressionUUID->"615f9207-78c2-40ee-a4c0-\
5f4751519faf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"1.", " ", "b"}], "\[Equal]", 
   FractionBox["1", 
    SqrtBox["k"]]}], ",", " ", 
  RowBox[{
   RowBox[{"2.", "  ", "0"}], "<", "b", "<", 
   FractionBox["1", 
    SqrtBox["k"]]}], ",", 
  RowBox[{
   RowBox[{"3.", "  ", "b"}], ">", 
   SqrtBox["k"]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6168299083288703`*^9, 
  3.616829965910164*^9}},ExpressionUUID->"77d5ba51-4851-492b-b86b-\
e80f04b04d98"],

Cell["This integral must be real:", "Text",
 CellChangeTimes->{{3.616833170721469*^9, 
  3.616833187457426*^9}},ExpressionUUID->"9cacca62-63c0-4a77-a28c-\
5f990c1bd61b"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "u"], 
   RowBox[{
    SqrtBox[
     RowBox[{"1", "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "k", " ", 
       RowBox[{
        SuperscriptBox["sin", "2"], "(", 
        RowBox[{
         SqrtBox["k"], " ", "t"}], ")"}]}]}]], 
    RowBox[{"\[DifferentialD]", "t"}]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.6168301032840214`*^9},ExpressionUUID->"204d47a0-e1f9-47f2-b6e9-\
7900827fb982"],

Cell[TextData[{
 StyleBox["Case 1. ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["b", "2"], " ", "k"}]],
  Evaluatable->False,
  CellChangeTimes->{3.6168301032840214`*^9},
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1],ExpressionUUID->
  "301df23e-30ee-4a83-851e-81e64a261498"],
 StyleBox[" ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["= 1. ",
  FontColor->RGBColor[0, 0, 1]],
 "\nThe integral is real for all values of t. In this case we have"
}], "Text",
 CellChangeTimes->{{3.616833199884137*^9, 3.616833220898339*^9}, {
   3.61683335012973*^9, 3.616833371824971*^9}, {3.6168335148811536`*^9, 
   3.616833533841238*^9}, {3.61683481034625*^9, 3.6168348377698183`*^9}, 
   3.6168350450976768`*^9, {3.616835086377038*^9, 3.6168351081372824`*^9}, 
   3.6168471838425083`*^9},ExpressionUUID->"ce7d2f0e-11f4-4016-930a-\
a35a76856eb4"],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", "k", "]"}], "*", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61683355485244*^9, 3.6168335917955527`*^9}, {
  3.6168336859399376`*^9, 
  3.6168337029559107`*^9}},ExpressionUUID->"293be2bd-1e35-497a-8083-\
17c7a032dc21"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"EllipticE", "[", 
     RowBox[{"u", ",", "1"}], "]"}], "-", 
    RowBox[{"Sin", "[", "u", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], "<", "u"}], ",", 
     RowBox[{"u", "<", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616834449300599*^9, 3.6168345502833753`*^9}, {
  3.616834647315925*^9, 3.6168347160528564`*^9}, {3.6168347565251713`*^9, 
  3.616834757942252*^9}, {3.6168349378215413`*^9, 
  3.6168350062374544`*^9}},ExpressionUUID->"31419d0f-5841-41d0-b277-\
3d6173ca6cb0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"r", "^", "2"}]}], ",", "r"}], "]"}], ",", 
      RowBox[{"hsol", "[", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"r", "^", "2"}]}], ",", "r"}], "]"}]}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "1"}], " ", "<", "u"}], ",", " ", 
     RowBox[{"u", "<", 
      RowBox[{"Pi", "/", "2"}]}], ",", " ", 
     RowBox[{"v", "\[Element]", "Reals"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168301493156543`*^9, 3.6168302037477674`*^9}, {
   3.6168302402198534`*^9, 3.6168303768376675`*^9}, 3.6168315516728644`*^9, {
   3.616832109871792*^9, 3.61683215251023*^9}, 3.616832244134471*^9, {
   3.6168323161585903`*^9, 3.6168323190147543`*^9}, 
   3.7078051626491833`*^9},ExpressionUUID->"19eaac01-73ea-46de-a723-\
4c6c6a888078"],

Cell["here u has to be considered for  -Pi/2 < u/r <Pi/2.", "Text",
 CellChangeTimes->{{3.6168325282897234`*^9, 
  3.616832636000884*^9}},ExpressionUUID->"d41f07f9-4807-41a0-86a5-\
63b322cb11be"],

Cell[BoxData[
 RowBox[{"%", "//.", "  ", 
  RowBox[{"r", "\[Rule]", "2"}]}]], "Input",
 CellChangeTimes->{
  3.6168307265556707`*^9, 3.6168308348368635`*^9, 3.616830966524396*^9, {
   3.616830997092144*^9, 3.6168310186793785`*^9}, {3.61683105260732*^9, 
   3.6168310789158244`*^9}, {3.616832403811604*^9, 
   3.6168324092029123`*^9}},ExpressionUUID->"38a329b2-3ba3-47c2-a515-\
2afa4e9ed089"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6979739557072983`*^9, 3.697973961614911*^9}, {
  3.697974001470311*^9, 
  3.697974109837866*^9}},ExpressionUUID->"edc17631-b682-4b2b-9206-\
0e9911d5dfcf"],

Cell["The solutions are spheres of radius r (=b).", "Text",
 CellChangeTimes->{{3.616832671361907*^9, 
  3.616832704545805*^9}},ExpressionUUID->"f006728c-5e83-4e97-b8c1-\
26cec375d50b"],

Cell[TextData[{
 StyleBox["Case 2.  ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "2"], " ", "k"}], "<", "1"}], TraditionalForm]],
  CellChangeTimes->{{3.6168447609059553`*^9, 3.6168447853933563`*^9}},
  FontColor->RGBColor[0, 0, 1],ExpressionUUID->
  "35d2c709-7937-420b-b391-c6ddf8c97d86"]
}], "Text",
 CellChangeTimes->{{3.6168446858536625`*^9, 3.616844702922639*^9}, {
  3.616844742825921*^9, 3.6168447467141438`*^9}, {3.61684479280978*^9, 
  3.616844810883814*^9}},ExpressionUUID->"3c8064c2-3ec0-4592-9f69-\
217a5ff0c694"],

Cell["\<\
In this case the integrand and the Integral are real for all values of t, \
resp. u.\
\>", "Text",
 CellChangeTimes->{{3.616844897241753*^9, 3.616844938938138*^9}, 
   3.6168451400106387`*^9},ExpressionUUID->"596c478d-cedd-4e33-bebe-\
e73588ac28ac"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{"1", ",", 
        RowBox[{"1", "/", "2"}]}], "]"}], ",", 
      RowBox[{"hsol", "[", 
       RowBox[{"1", ",", 
        RowBox[{"1", "/", "2"}]}], "]"}]}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"3", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168304350179954`*^9, 3.6168305159716253`*^9}, 
   3.6168306246138396`*^9, 3.616830700981208*^9, {3.61683123811693*^9, 
   3.6168312828994913`*^9}, {3.616831485061054*^9, 3.6168314905633693`*^9}, 
   3.6168316288302774`*^9, {3.616831870246086*^9, 3.6168318809086957`*^9}, 
   3.6168319324366426`*^9, {3.6168319719739046`*^9, 3.6168320241508884`*^9}, 
   3.616832444068907*^9, 3.616845214575904*^9, {3.616845276031419*^9, 
   3.6168453394710474`*^9}, 3.616845373118972*^9, 
   3.707805164338747*^9},ExpressionUUID->"521ce8f5-8432-480f-bbe2-\
c7a361e04674"],

Cell["\<\
These surfaces are infinite strings whose links have the shape of a spindle \
(or American football).
Experiment with other values of k,b.\
\>", "Text",
 CellChangeTimes->{{3.6168461611130114`*^9, 3.6168462607227087`*^9}, {
  3.6168462990349007`*^9, 
  3.616846328698597*^9}},ExpressionUUID->"b76c01fe-399a-47d7-a875-\
6c2dd62826c4"],

Cell[TextData[{
 StyleBox["Case 3.  ",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "2"], " ", "k"}], ">", "1"}], TraditionalForm]],
  CellChangeTimes->{{3.6168447609059553`*^9, 3.6168447853933563`*^9}},
  FontColor->RGBColor[0, 0, 1],ExpressionUUID->
  "fdd182db-7cbe-4d05-936a-6bc872425eec"]
}], "Text",
 CellChangeTimes->{{3.6168463583232913`*^9, 
  3.616846375572278*^9}},ExpressionUUID->"ab52320a-c47f-41e9-adfd-\
741f7141bfa7"],

Cell["In this case the integrand is real for values t with", "Text",
 CellChangeTimes->{{3.616847201088495*^9, 
  3.616847246578097*^9}},ExpressionUUID->"a332f403-54ac-490f-9ce6-\
aee4a13ddb52"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"ArcSin", "[", 
     FractionBox["1", 
      RowBox[{"b", 
       SqrtBox["k"]}]], "]"}], 
    SqrtBox["k"]]}], "<", "t", "<", 
  FractionBox[
   RowBox[{"ArcSin", "[", 
    FractionBox["1", 
     RowBox[{"b", 
      SqrtBox["k"]}]], "]"}], 
   SqrtBox["k"]]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.6168475139593897`*^9, {3.616847759740448*^9, 
   3.6168477836828175`*^9}},ExpressionUUID->"923a01e4-fee6-462e-b6c5-\
2380c188de7a"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", "\n", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{"1", ",", " ", "1.5"}], "]"}], ",", " ", 
      RowBox[{"hsol", "[", 
       RowBox[{"1", ",", " ", "1.5"}], "]"}]}], "]"}], "[", "\n", "   ", 
    RowBox[{"v", ",", "u"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", " ", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"ArcSin", "[", 
        RowBox[{"1", "/", "1.5"}], "]"}], ")"}]}], ",", " ", "\n", "   ", 
     RowBox[{"ArcSin", "[", 
      RowBox[{"1", "/", "1.5"}], "]"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6168304350179954`*^9, 3.6168305159716253`*^9}, 
   3.6168306246138396`*^9, 3.616830700981208*^9, {3.61683123811693*^9, 
   3.6168312828994913`*^9}, {3.616831485061054*^9, 3.6168314905633693`*^9}, 
   3.6168316288302774`*^9, {3.616831870246086*^9, 3.6168318809086957`*^9}, 
   3.6168319324366426`*^9, {3.6168319719739046`*^9, 3.6168320241508884`*^9}, 
   3.616832444068907*^9, 3.616845214575904*^9, {3.616845276031419*^9, 
   3.6168453394710474`*^9}, 3.616845373118972*^9, {3.616847657623607*^9, 
   3.6168476918065624`*^9}, {3.616847927586048*^9, 3.616847970522504*^9}, {
   3.6168486582318387`*^9, 3.6168486806661215`*^9}, {3.616849296034319*^9, 
   3.616849394718963*^9}, {3.7078213704932404`*^9, 
   3.707821373353181*^9}},ExpressionUUID->"d90cdb77-ee02-4cfc-99eb-\
c3905a6e8d3e"],

Cell["\<\
Entering larger limits for u  doesn't change the figure since only real \
points are plotted:\
\>", "Text",
 CellChangeTimes->{{3.616849593778349*^9, 3.616849646162345*^9}, {
  3.6186388573087873`*^9, 
  3.6186388846473513`*^9}},ExpressionUUID->"4c320d1c-c316-4a0b-8524-\
5cdf0a48dfea"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", "\n", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsol", "[", 
       RowBox[{"1", ",", " ", "1.5"}], "]"}], ",", " ", 
      RowBox[{"hsol", "[", 
       RowBox[{"1", ",", " ", "1.5"}], "]"}]}], "]"}], "[", " ", 
    RowBox[{"v", ",", "u"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", " ", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.61684941687123*^9, 3.616849416921233*^9}, {
  3.6168494526232753`*^9, 3.616849541086335*^9}, {3.61684995066333*^9, 
  3.6168499651191573`*^9}, {3.707821429058704*^9, 
  3.707821431251293*^9}},ExpressionUUID->"bac9fedf-d541-457c-aa2b-\
8bed180a058a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{
    RowBox[{"fsol", "[", 
     RowBox[{"1", ",", " ", "1.5"}], "]"}], ",", " ", 
    RowBox[{"hsol", "[", 
     RowBox[{"1", ",", " ", "1.5"}], "]"}]}], "]"}], "[", " ", 
  RowBox[{"v", ",", " ", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.697974309507204*^9, 3.697974316934382*^9}, {
   3.697974448379915*^9, 3.6979744607382803`*^9}, 
   3.707821520329249*^9},ExpressionUUID->"b1fa3d2d-6eda-4491-8142-\
8233250dad64"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{
    RowBox[{"fsol", "[", 
     RowBox[{"k", ",", " ", "b"}], "]"}], ",", " ", 
    RowBox[{"hsol", "[", 
     RowBox[{"k", ",", " ", "b"}], "]"}]}], "]"}], "[", 
  RowBox[{"v", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.697974309507204*^9, 3.697974316934382*^9}, {
   3.697974448379915*^9, 3.697974504146833*^9}, {3.697974573078281*^9, 
   3.697974583953549*^9}, {3.697974618021244*^9, 3.6979746429047327`*^9}, 
   3.697974713149727*^9, 
   3.7078215369835243`*^9},ExpressionUUID->"97b6ec08-d47b-401d-b19e-\
f206ed5bb571"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "/", "b"}], "==", 
  RowBox[{"Cos", "[", 
   RowBox[{
    SqrtBox["k"], " ", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6979747892582417`*^9, 3.697974791232016*^9}, {
   3.697974825921303*^9, 3.697974905951026*^9}, 
   3.707821551086226*^9},ExpressionUUID->"0061528c-72c1-4f0d-914d-\
59a1f457ae87"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ArcCos", "[", 
    RowBox[{"x", "/", "b"}], "]"}], "/", 
   RowBox[{"Sqrt", "[", "k", "]"}]}], "\[Equal]", "v"}]], "Input",
 CellChangeTimes->{{3.697974933731282*^9, 3.6979750579577436`*^9}, 
   3.707821560797799*^9},ExpressionUUID->"329410bd-0896-4b68-904b-\
116185a048c2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"solf2", "[", 
    RowBox[{"k_", ",", "b_"}], "]"}], "[", "x_", "]"}], ":=", 
  FractionBox[
   RowBox[{"EllipticE", "[", 
    RowBox[{
     RowBox[{"ArcCos", "[", 
      RowBox[{"x", "/", "b"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", "k"}]}], "]"}], 
   SqrtBox["k"]]}]], "Input",
 CellChangeTimes->{{3.69797510870362*^9, 3.6979751857486973`*^9}, 
   3.6979752342300243`*^9, 
   3.69797534446165*^9},ExpressionUUID->"d3a83006-458a-44b4-9143-\
fc9a4ec07143"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xrev", "[", 
   RowBox[{"solf2", "[", 
    RowBox[{"k", ",", "b"}], "]"}], "]"}], "[", 
  RowBox[{"v", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.69797537950832*^9, 3.697975422634755*^9}, {
   3.697975452689755*^9, 3.6979754538421783`*^9}, 
   3.7078051678565493`*^9},ExpressionUUID->"a2181e9a-de94-4096-8a07-\
24a60d5c73b2"],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"k", "\[Rule]", "1"}], ",", 
    RowBox[{"b", "\[Rule]", "1.5"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6979754736478977`*^9, 3.6979755311051702`*^9}, 
   3.697975589861714*^9},ExpressionUUID->"7e5bbd4b-85b6-4373-80d4-\
dee8590f4b00"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", 
      RowBox[{"Cos", "[", "v", "]"}]}], ",", 
     RowBox[{"u", " ", 
      RowBox[{"Sin", "[", "v", "]"}]}], ",", 
     RowBox[{"EllipticE", "[", 
      RowBox[{
       RowBox[{"ArcCos", "[", 
        RowBox[{"0.6666666666666666`", " ", "u"}], "]"}], ",", "2.25`"}], 
      "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6979755444769163`*^9, 3.6979755613612967`*^9}, {
   3.697975678040444*^9, 3.6979757239837837`*^9}, {3.697975796428303*^9, 
   3.697975815255151*^9}, {3.697975999458366*^9, 3.6979760085493307`*^9}, 
   3.697976045946644*^9},ExpressionUUID->"4dabee3e-7fbd-4db9-9cf4-\
1ebd5831b8f4"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", " ", 
      RowBox[{"Cos", "[", "v", "]"}]}], ",", 
     RowBox[{"u", " ", 
      RowBox[{"Sin", "[", "v", "]"}]}], ",", 
     RowBox[{"-", 
      RowBox[{"EllipticE", "[", 
       RowBox[{
        RowBox[{"ArcCos", "[", 
         RowBox[{"0.6666666666666666`", " ", "u"}], "]"}], ",", "2.25`"}], 
       "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6979755444769163`*^9, 3.6979755613612967`*^9}, {
  3.697975678040444*^9, 3.6979757239837837`*^9}, {3.697975796428303*^9, 
  3.697975815255151*^9}, {3.697975999458366*^9, 3.6979760085493307`*^9}, {
  3.697976045946644*^9, 
  3.697976067237732*^9}},ExpressionUUID->"662ddc16-6116-43ef-ba9c-\
091d57b77c67"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "%%"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.697976077391973*^9, 3.697976094876318*^9}, {
  3.69797620946944*^9, 
  3.697976219371707*^9}},ExpressionUUID->"214a811b-30d1-445e-be2e-\
2963b2e4497e"],

Cell["\<\
In this case the surface doesn\[CloseCurlyQuote]t meet the z-axis. The \
surfaces have the shape of a barrel.\
\>", "Text",
 CellChangeTimes->{{3.616849694275097*^9, 3.6168497543625336`*^9}, {
  3.616849820738899*^9, 
  3.616849824155094*^9}},ExpressionUUID->"15a0f0ca-5580-4dd5-a442-\
721c404c3319"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.9.6.b. Surfaces of Revolution of Constant Negative Gaussian Curvature\
\>", "Subsubsection",
 CellChangeTimes->{{3.6168293520900555`*^9, 3.6168294026009445`*^9}, {
   3.6168445489178305`*^9, 3.6168445611545305`*^9}, {3.616849902363568*^9, 
   3.616849913674215*^9}, {3.6170154058879147`*^9, 3.617015418936661*^9}, {
   3.625804683476118*^9, 3.6258046934289355`*^9}, 3.629187778676194*^9, 
   3.698732344496533*^9, 
   3.698736433824019*^9},ExpressionUUID->"8d7c5d95-b343-43e2-adb5-\
582904d4c0ce"],

Cell["\<\
Alfred Gray uses the following solution of the differential equation\
\>", "Text",
 CellChangeTimes->{{3.6169913911456676`*^9, 
  3.6169914250601273`*^9}},ExpressionUUID->"09346680-d161-4caa-a894-\
1199b563311a"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "''"}], "[", "u", "]"}], "-", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], "/", 
      RowBox[{"a", "^", "2"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{"f", "[", "u", "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.616899810646412*^9, 3.616899899722568*^9}, 
   3.616899996115137*^9, {3.616900109948537*^9, 3.6169001203849554`*^9}, {
   3.6169007813113165`*^9, 
   3.616900806692561*^9}},ExpressionUUID->"c2a1026c-042b-4b54-8c0d-\
5879ecdb890d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn", "[", 
    RowBox[{"a_", ",", "A_", ",", "B_"}], "]"}], "[", "u_", "]"}], " ", ":=", 
  " ", 
  RowBox[{
   RowBox[{"A", "*", 
    RowBox[{"Exp", "[", 
     RowBox[{"u", "/", "a"}], "]"}]}], " ", "+", " ", 
   RowBox[{"B", "*", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "u"}], "/", "a"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6169389368467135`*^9, 3.6169390613788366`*^9}, {
  3.6169390930036454`*^9, 3.6169391115237045`*^9}, {3.616998034301736*^9, 
  3.6169980472497587`*^9}},ExpressionUUID->"39a21ae9-70f5-4d1f-901a-\
e38cf799761e"],

Cell[TextData[StyleBox["Case A=0, B>0.",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.6169397692433243`*^9, 3.6169398291707516`*^9}, {
  3.6169977852940984`*^9, 
  3.6169977862145*^9}},ExpressionUUID->"ee8e4dbd-4bd0-4aff-9824-8dfc41dc7e1d"],

Cell["We transform the variable u:", "Text",
 CellChangeTimes->{{3.6169914945894494`*^9, 
  3.6169915299859114`*^9}},ExpressionUUID->"b2167e35-2338-471d-88be-\
3732fedfd898"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"B", "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "u"}], "/", "a"}], "]"}]}], "/.", " ", 
    RowBox[{"u", "\[Rule]", 
     RowBox[{"w", "+", 
      RowBox[{"a", "*", 
       RowBox[{"Log", "[", "B", "]"}]}], "-", 
      RowBox[{"a", "*", 
       RowBox[{"Log", "[", "a", "]"}]}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B", ">", "0"}], ",", 
     RowBox[{"a", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169398777015276`*^9, 3.6169400590218983`*^9}, 
   3.616940481063038*^9},ExpressionUUID->"d40fc9a1-84cd-4397-9192-\
dd693ef77f8e"],

Cell["and set", "Text",
 CellChangeTimes->{{3.616991544103936*^9, 
  3.6169915524031506`*^9}},ExpressionUUID->"e7864f72-0750-492d-9ef2-\
6f053aad6322"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn1", "[", "a_", "]"}], "[", "u_", "]"}], ":=", 
  RowBox[{"a", "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "u"}], "/", "a"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6169405658588877`*^9, 3.616940632564703*^9}, 
   3.6169409437174997`*^9},ExpressionUUID->"04a97338-0f8f-4383-bc42-\
a659be88609f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn1", "[", "a", "]"}], "'"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.6169408458189006`*^9, 
  3.6169408906134624`*^9}},ExpressionUUID->"e35194ca-e913-4580-b2e9-\
40b057dc32e3"],

Cell["To obtain the h - function we calculate", "Text",
 CellChangeTimes->{{3.616991578002796*^9, 
  3.6169916349740963`*^9}},ExpressionUUID->"c72d03dc-3e38-4f10-89d1-\
9e9cc255f7ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsn1", "[", "a_", "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{"1", "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", "*", "t"}], "a"]}]]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.616907470301609*^9, 3.616907561087802*^9}, {
  3.6169407225198483`*^9, 3.616940779999136*^9}, {3.616941000447745*^9, 
  3.616941006096068*^9}},ExpressionUUID->"2313227a-7cd6-41f5-8d0c-\
b76ed6578c36"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"hsn1", "[", "a", "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169900368136888`*^9, 3.6169900521953163`*^9}, {
  3.616990255416873*^9, 
  3.616990312372573*^9}},ExpressionUUID->"8754c8f4-2dc0-476e-befc-\
1065ae979884"],

Cell["We redefine", "Text",
 CellChangeTimes->{{3.616990656290777*^9, 
  3.616990661345186*^9}},ExpressionUUID->"256446ec-1b53-468f-9215-\
0026c6fd9094"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsn1", "[", "a_", "]"}], "[", "u_", "]"}], " ", ":=", " ", "\n", 
  "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "a"}], ")"}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", "\n", "       ", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "*", "u"}], ")"}], "/", "a"}], ")"}]}]}], "]"}]}], 
     ")"}], "/", "\n", "    ", 
    RowBox[{"E", "^", 
     RowBox[{"(", 
      RowBox[{"u", "/", "a"}], ")"}]}]}], " ", "+", " ", "u", " ", "+", " ", 
   "\n", "   ", 
   RowBox[{"a", "*", 
    RowBox[{"Log", "[", 
     RowBox[{"1", " ", "+", " ", "\n", "      ", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "*", "u"}], ")"}], "/", "a"}], ")"}]}]}], "]"}], 
       "/", "\n", "       ", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"u", "/", "a"}], ")"}]}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6169907012500563`*^9, 
  3.616990715492881*^9}},ExpressionUUID->"1d23317d-78ed-4fac-bd26-\
654ccb8a2261"],

Cell["Try with  distinct parameters a", "Text",
 CellChangeTimes->{{3.616991665269349*^9, 
  3.616991726546257*^9}},ExpressionUUID->"7ac2f25d-ea22-40c9-a154-\
bcb20ecf178c"],

Cell[BoxData[
 RowBox[{"pss1", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"fsn1", "[", ".2", "]"}], ",", 
       RowBox[{"hsn1", "[", ".2", "]"}]}], "]"}], "[", 
     RowBox[{"v", ",", "u"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", ".5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6169076266495514`*^9, 3.6169077454233446`*^9}, {
   3.616941068335628*^9, 3.616941081603387*^9}, 3.6169902080239897`*^9, {
   3.61699079488142*^9, 3.6169909004156055`*^9}, {3.6169926328322487`*^9, 
   3.61699263938426*^9}, 
   3.70780516882436*^9},ExpressionUUID->"ecd098e4-b09b-40a8-8785-\
e508ae8ed258"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"gauss", "[", 
      RowBox[{"sfrev", "[", 
       RowBox[{
        RowBox[{"fsn1", "[", "a", "]"}], ",", 
        RowBox[{"hsn1", "[", "a", "]"}]}], "]"}], "]"}], "[", 
     RowBox[{"v", ",", "u"}], "]"}], "/.", 
    RowBox[{"v", "\[Rule]", "0"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169917639863224`*^9, 3.616991862796896*^9}, {
   3.6987344933786573`*^9, 3.698734502687038*^9}, 
   3.707805170024921*^9},ExpressionUUID->"37fc42e8-0343-4b54-a3b9-\
a647a8d0add4"],

Cell["\<\
By symmetry, it suffices to consider the curvature along the meridian v->0.\
\>", "Text",
 CellChangeTimes->{{3.616992879475482*^9, 3.616992947897202*^9}, {
   3.698734727955652*^9, 3.698734831067037*^9}, 
   3.698734900640883*^9},ExpressionUUID->"24f0f175-9dfe-44fb-9cc0-\
1c78a00a087d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{
    RowBox[{"fsn1", "[", "a", "]"}], ",", 
    RowBox[{"hsn1", "[", "a", "]"}]}], "]"}], "[", 
  RowBox[{"0", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6987349368347187`*^9, 3.698734971978695*^9}, {
  3.707822460088855*^9, 
  3.70782248265597*^9}},ExpressionUUID->"53e7634d-90c3-4cfe-8135-\
a6b7b199944e"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox["u", "a"]}]]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox["u", "a"]}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "u"}], "a"]]}]]}], "+", "u", "+", 
       RowBox[{"a", " ", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox["u", "a"]}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", "u"}], "a"]]}]]}]}], "]"}]}]}]}], "}"}], "/.", 
    RowBox[{"a", "\[Rule]", ".2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698735005555161*^9, 3.698735050899021*^9}, {
  3.69873548028833*^9, 3.698735588190152*^9}, {3.698735619401222*^9, 
  3.698735644301117*^9}},ExpressionUUID->"fc34d483-e541-4f9c-94ab-\
efcf984eaa05"],

Cell["\<\
Inverting the sign of the functions, clearly one gets a solution again\
\>", "Text",
 CellChangeTimes->{{3.616992879475482*^9, 3.616992947897202*^9}, {
  3.698734727955652*^9, 3.698734831067037*^9}, {3.698734913818042*^9, 
  3.698734916330254*^9}},ExpressionUUID->"14a66347-ea9f-45fc-883c-\
8fb2b284a85e"],

Cell[BoxData[
 RowBox[{"pss2", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"fsn1", "[", ".2", "]"}]}], ",", 
       RowBox[{"-", 
        RowBox[{"hsn1", "[", ".2", "]"}]}]}], "]"}], "[", 
     RowBox[{"v", ",", "u"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6169076266495514`*^9, 3.6169077454233446`*^9}, {
   3.616941068335628*^9, 3.616941081603387*^9}, 3.6169902080239897`*^9, {
   3.61699079488142*^9, 3.6169909004156055`*^9}, 3.616992481759183*^9, 
   3.6169926018349943`*^9, {3.6169926517706814`*^9, 3.6169926596018953`*^9}, 
   3.698735100382292*^9, {3.698735141796945*^9, 3.698735177585538*^9}, {
   3.698735211557357*^9, 3.698735218001092*^9}, 
   3.707805255256525*^9},ExpressionUUID->"8d9a67cf-217a-48b8-ae71-\
474e00e05b31"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox["u", "a"]}]]}], ",", "0", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox["u", "a"]}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[ExponentialE]", 
           FractionBox[
            RowBox[{"2", " ", "u"}], "a"]]}]]}], "+", "u", "+", 
       RowBox[{"a", " ", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "+", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox["u", "a"]}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[ExponentialE]", 
              FractionBox[
               RowBox[{"2", " ", "u"}], "a"]]}]]}]}], "]"}]}]}]}], "}"}], "/.", 
    RowBox[{"a", "\[Rule]", ".2"}]}], ",", 
   RowBox[{"u", "\[Rule]", 
    RowBox[{"-", "Infinity"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.698735244099221*^9, 3.698735296641364*^9}, {
  3.698735343653393*^9, 
  3.698735370860167*^9}},ExpressionUUID->"951d23f7-44c9-49b0-a983-\
c3c991067577"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox["u", "a"]}]]}], ",", "0", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox["u", "a"]}]], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "u"}], "a"]]}]]}], "+", "u", "+", 
     RowBox[{"a", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", 
           FractionBox["u", "a"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{"2", " ", "u"}], "a"]]}]]}]}], "]"}]}]}]}], "}"}], "/.", 
  RowBox[{"u", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.69873542967134*^9, 
  3.698735436078546*^9}},ExpressionUUID->"23de8671-9a39-4297-9a6f-\
333455e39163"],

Cell["the surface is a pseudo-sphere:", "Text",
 CellChangeTimes->{{3.6169929865384703`*^9, 3.6169930012804956`*^9}, {
  3.6987345996360493`*^9, 
  3.6987346285796843`*^9}},ExpressionUUID->"69efac00-0a20-42a9-b5f8-\
cd6d68f33e4e"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"pss1", ",", "pss2"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616992687151544*^9, 3.616992702626771*^9}, {
  3.616992735059228*^9, 
  3.6169927677948856`*^9}},ExpressionUUID->"8441f82f-db2e-4844-a05b-\
3d3a600cb07c"],

Cell["", "Text",ExpressionUUID->"0352dcfc-276c-4add-88a3-f12665ad7c02"],

Cell["Changing both signs  acts as a reflection at the origin:", "Text",
 CellChangeTimes->{{3.616995201804761*^9, 
  3.616995245375637*^9}},ExpressionUUID->"b47fe0b4-84a1-402d-b626-\
7732d347ee1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", "h"}], "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}], " ", "+", " ", 
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{
     RowBox[{"-", "f"}], ",", 
     RowBox[{"-", "h"}]}], "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.6169949972104015`*^9, 3.616995011780827*^9}, {
  3.7078052646084633`*^9, 
  3.707805265751536*^9}},ExpressionUUID->"a9c75d21-f394-444b-8166-\
56257f03d2b9"],

Cell["\<\
Changing the sign of f only acts as a reflection in the x, y - plane and \
yields the same surface :\
\>", "Text",
 CellChangeTimes->{{3.616995598435457*^9, 3.616995667247178*^9}, 
   3.6291879866203613`*^9},ExpressionUUID->"3d6a85df-9ab0-494f-b733-\
aa81dd55f8a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{"f", ",", "h"}], "]"}], "[", 
  RowBox[{"v", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{
  3.707805267471017*^9},ExpressionUUID->"86beec31-ccfa-49d6-beff-\
12d508790ac7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrev", "[", 
   RowBox[{
    RowBox[{"-", "f"}], ",", "h"}], "]"}], "[", 
  RowBox[{"v", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6169954540104036`*^9, 3.616995462902419*^9}, 
   3.70780526836073*^9},ExpressionUUID->"bba7869f-7464-4421-b336-\
fb28868df86d"],

Cell["\<\
Changing the sign at h only acts as a reflection at the x,y-plane:\
\>", "Text",
 CellChangeTimes->{{3.6169958078346252`*^9, 
  3.616995850719101*^9}},ExpressionUUID->"80bbc702-8704-4361-9f46-\
6b411766d6ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sfrev", "[", 
    RowBox[{"f", ",", 
     RowBox[{"-", "h"}]}], "]"}], "[", 
   RowBox[{"v", ",", "u"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.6169949972104015`*^9, 3.616995011780827*^9}, {
   3.616995091543767*^9, 3.616995097331377*^9}, {3.616995129389434*^9, 
   3.616995140683853*^9}, 3.6169957434845123`*^9, 
   3.707805271000411*^9},ExpressionUUID->"a4d927fe-3b54-4b9f-a678-\
33476f2ef939"],

Cell["\<\
The case B\[NotEqual]0, A=0 yields the same results by the variable transform 
u -> -u.\
\>", "Text",
 CellChangeTimes->{{3.616994639720174*^9, 3.6169946467869864`*^9}, {
   3.616994681824648*^9, 3.6169947215423174`*^9}, {3.6169948441117325`*^9, 
   3.6169948840166025`*^9}, 
   3.6169979055235095`*^9},ExpressionUUID->"3b1ed4e5-397e-452e-93bb-\
aa3380ff653f"],

Cell[TextData[{
 StyleBox["Case A",
  FontColor->RGBColor[0, 0, 1]],
 "\[NotEqual]",
 StyleBox["0, B",
  FontColor->RGBColor[0, 0, 1]],
 "\[NotEqual]",
 StyleBox["0.",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.6169397692433243`*^9, 3.6169398291707516`*^9}, {
  3.6169977852940984`*^9, 3.6169977862145*^9}, {3.616997819770159*^9, 
  3.6169978304093776`*^9}},ExpressionUUID->"1dea2bf7-2fa1-43e1-940e-\
448d54f68e70"],

Cell["We transform the variable ", "Text",
 CellChangeTimes->{{3.61699786607104*^9, 
  3.616997880563466*^9}},ExpressionUUID->"10c853f4-9993-41ee-ab0b-\
e7924ac0c0d7"],

Cell[BoxData[
 RowBox[{"u", " ", "\[Rule]", " ", 
  RowBox[{"w", " ", "+", 
   RowBox[{
    RowBox[{"a", "/", "2"}], "*", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"Abs", "[", "B", "]"}], "/", 
      RowBox[{"Abs", "[", "A", "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6169979139163246`*^9, 3.6169979917916613`*^9}, 
   3.6169981497419386`*^9},ExpressionUUID->"205ceaf2-8c26-438f-83d1-\
b40106a29551"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fsn", "[", 
      RowBox[{"a", ",", "A", ",", "B"}], "]"}], "[", "u", "]"}], "/.", 
    RowBox[{"u", " ", "\[Rule]", " ", 
     RowBox[{"w", " ", "+", 
      RowBox[{
       RowBox[{"a", "/", "2"}], "*", 
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"Abs", "[", "B", "]"}], "/", 
         RowBox[{"Abs", "[", "A", "]"}]}], "]"}]}]}]}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"A", "\[NotEqual]", "0"}], ",", 
     RowBox[{"B", "\[NotEqual]", "0"}], ",", " ", 
     RowBox[{"w", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616998096826646*^9, 3.616998136216715*^9}, {
  3.616998170255975*^9, 
  3.616998278083364*^9}},ExpressionUUID->"7661cd99-050a-40bd-a47e-\
6adfba6b363d"],

Cell[TextData[{
 "Thus we may assume Abs[A] == Abs[B].\n\n",
 StyleBox["Case A= B>0",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.6169983386894703`*^9, 3.6169983974703736`*^9}, {
   3.616998433646837*^9, 3.6169984349572396`*^9}, {3.616999099159606*^9, 
   3.6169991018428106`*^9}, 3.6170078639195557`*^9, 
   3.6170079205507946`*^9},ExpressionUUID->"4c1076b1-038e-430b-8951-\
9bac0fc886c1"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fsn", "[", 
     RowBox[{"a", ",", "A", ",", "A"}], "]"}], "[", "u", "]"}], "\[Equal]", 
   " ", 
   RowBox[{"2", "*", "A", "*", 
    RowBox[{"Cosh", "[", 
     RowBox[{"u", "/", "a"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.616999248670269*^9, 
  3.616999372331686*^9}},ExpressionUUID->"7f9906fc-b2b9-4a67-964b-\
abd433366516"],

Cell["Setting b= 2A we define", "Text",
 CellChangeTimes->{{3.6169994792074738`*^9, 
  3.616999497584306*^9}},ExpressionUUID->"7c4eb20d-90dd-495f-a9a3-\
058637ba9235"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn2", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"b", "*", 
   RowBox[{"Cosh", "[", 
    RowBox[{"u", "/", "a"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6169993881501136`*^9, 
  3.6169994609554415`*^9}},ExpressionUUID->"097583b7-08ed-4c31-aa85-\
e9a6af2c2140"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn2", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "'"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.616999512232732*^9, 
  3.6169995416387835`*^9}},ExpressionUUID->"0f7ea369-0f6b-48dd-9e05-\
1b28ed42ed07"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"b", "^", "2"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"Sinh", "[", 
           RowBox[{"t", "/", "a"}], "]"}], "^", "2"}], "/", 
         RowBox[{"a", "^", "2"}]}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], "*", 
       RowBox[{"ArcSinh", "[", 
        RowBox[{"a", "/", "b"}], "]"}]}], "<", "u"}], ",", 
     RowBox[{"u", "<", 
      RowBox[{"a", "*", 
       RowBox[{"ArcSinh", "[", 
        RowBox[{"a", "/", "b"}], "]"}]}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169996601209917`*^9, 
  3.6169999512955027`*^9}},ExpressionUUID->"49ea0d24-5f02-432e-8855-\
397d60c0aa6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsn2", "[", 
    RowBox[{"a_", ",", " ", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "I"}], ")"}], "*", "a", "*", 
   RowBox[{"EllipticE", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"I", "*", "u"}], ")"}], "/", "a"}], ",", " ", "\n", "    ", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", "^", "2"}], "/", 
        RowBox[{"a", "^", "2"}]}], ")"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6170004523059826`*^9, 
  3.6170005089340825`*^9}},ExpressionUUID->"c0f211ad-870b-4496-9c81-\
0195cec1ced7"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsn2", "[", 
       RowBox[{"1", ",", ".2"}], "]"}], ",", 
      RowBox[{"hsn2", "[", 
       RowBox[{"1", ",", ".2"}], "]"}]}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", 
      RowBox[{"ArcSinh", "[", "5", "]"}]}], ",", 
     RowBox[{"ArcSinh", "[", "5", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169076266495514`*^9, 3.6169077454233446`*^9}, {
   3.616941068335628*^9, 3.616941081603387*^9}, 3.6169902080239897`*^9, {
   3.61699079488142*^9, 3.6169909004156055`*^9}, 3.616992481759183*^9, 
   3.6169926018349943`*^9, {3.6169926517706814`*^9, 3.6169926596018953`*^9}, {
   3.617000567075384*^9, 3.6170006327359*^9}, {3.617000673888772*^9, 
   3.6170006823439865`*^9}, 3.617000763510929*^9, {3.6170007966297874`*^9, 
   3.6170008213246307`*^9}, 
   3.7078052733062143`*^9},ExpressionUUID->"aae0b1db-97c8-4b79-9043-\
f3c7cd581027"],

Cell["This is a surface of hyperboloidal type of  curvature -1:", "Text",
 CellChangeTimes->{{3.6170008768295283`*^9, 3.617000926858816*^9}, 
   3.6186391924136333`*^9},ExpressionUUID->"eb1a0026-db8a-4333-9c9a-\
8d0b1b691152"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"fsn2", "[", 
        RowBox[{"1", ",", 
         RowBox[{"2", "/", "10"}]}], "]"}], ",", 
       RowBox[{"hsn2", "[", 
        RowBox[{"1", ",", 
         RowBox[{"2", "/", "10"}]}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", "\[Element]", " ", "Reals"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6170009298072214`*^9, 3.6170009576688704`*^9}, {
   3.6170009942197347`*^9, 3.61700104857023*^9}, {3.6170021872745433`*^9, 
   3.617002200114278*^9}, 3.6170076753987727`*^9, 
   3.7078052743859177`*^9},ExpressionUUID->"d98a4683-497d-49e7-83b4-\
14ef020c2def"],

Cell[TextData[StyleBox["Case A = -B>0",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.6170078931032248`*^9, 
  3.617007928519251*^9}},ExpressionUUID->"454bd328-f29d-4954-b140-\
665c7c202521"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fsn", "[", 
     RowBox[{"a", ",", "A", ",", 
      RowBox[{"-", "A"}]}], "]"}], "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"A", ">", "0"}], ",", 
     RowBox[{"u", "\[Element]", " ", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617008009144862*^9, 3.6170080423057585`*^9}, {
  3.6170081028262205`*^9, 
  3.6170081747313333`*^9}},ExpressionUUID->"e451658d-4708-45ac-bcb1-\
471c6d803597"],

Cell["Setting 2A = b we define", "Text",
 CellChangeTimes->{{3.6170082573680596`*^9, 
  3.617008298823431*^9}},ExpressionUUID->"941a9319-4bd7-4c5a-9963-\
538d3562110f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn3", "[", 
    RowBox[{"a_", ",", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  RowBox[{"b", "*", 
   RowBox[{"Sinh", "[", 
    RowBox[{"u", "/", "a"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.617008308011956*^9, 
  3.617008385794405*^9}},ExpressionUUID->"bcd3333b-7feb-40ea-8e3b-\
1f9f98a5e2b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fsn3", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "'"}], "[", "u", "]"}]], "Input",
 CellChangeTimes->{{3.6170083932528315`*^9, 
  3.617008410296807*^9}},ExpressionUUID->"65401bed-9538-4f10-9065-\
c050c6fc64cb"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{
        RowBox[{"b", "^", "2"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"Cosh", "[", 
           RowBox[{"t", "/", "a"}], "]"}], "^", "2"}], "/", 
         RowBox[{"a", "^", "2"}]}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "u"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", " ", 
     RowBox[{"b", ">", "0"}], ",", 
     RowBox[{"b", "\[LessEqual]", "a"}], ",", 
     RowBox[{"u", "\[Element]", "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6170084693691854`*^9, 3.6170086802052445`*^9}, {
   3.617008986420759*^9, 3.6170090293732157`*^9}, 
   3.617009075739868*^9},ExpressionUUID->"4e7fbaba-50c6-4044-b599-\
b13b91fe8a81"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hsn3", "[", 
    RowBox[{"a_", ",", " ", "b_"}], "]"}], "[", "u_", "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "I"}], ")"}], "*", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"a", "^", "2"}], "-", 
     RowBox[{"b", "^", "2"}]}], "]"}], "*", "\n", "   ", 
   RowBox[{"EllipticE", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"I", "*", "u"}], ")"}], "/", "a"}], ",", " ", "\n", "    ", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"a", "^", "2"}]}], " ", "+", " ", 
        RowBox[{"b", "^", "2"}]}], ")"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6170131274146104`*^9, 3.6170131900961957`*^9}, {
   3.6170132542948675`*^9, 3.617013277140174*^9}, 
   3.617014579644656*^9},ExpressionUUID->"c948cf4c-25ab-43e4-9a1c-\
56aac28b9c56"],

Cell["To get a real solution one has to regard the conditions", "Text",
 CellChangeTimes->{{3.6170133466241484`*^9, 3.617013365167209*^9}, {
  3.6170134139999847`*^9, 
  3.617013421839433*^9}},ExpressionUUID->"324bccdb-a093-4d2c-bff4-\
6076c43add0b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", ">", "0"}], ",", 
   RowBox[{"b", ">", "0"}], ",", 
   RowBox[{"b", "\[LessEqual]", "a"}], ",", 
   RowBox[{"u", "\[LessEqual]", 
    RowBox[{"a", "*", 
     RowBox[{"ArcSinh", "[", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "^", "2"}], "-", 
          RowBox[{"b", "^", "2"}]}], ")"}], "]"}], "/", "b"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a"}], "*", 
     RowBox[{"ArcSinh", "[", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "^", "2"}], "-", 
          RowBox[{"b", "^", "2"}]}], ")"}], "]"}], "/", "b"}], "]"}]}], "<", 
    "u"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.6170084693691854`*^9, 3.6170086802052445`*^9}, {
   3.617008986420759*^9, 3.6170090293732157`*^9}, 3.617009075739868*^9, {
   3.6170092980325823`*^9, 3.6170093610641875`*^9}, 3.6170133012135515`*^9, {
   3.6170134490309887`*^9, 
   3.617013501571994*^9}},ExpressionUUID->"36963391-5467-4766-9121-\
66682a7b3a4f"],

Cell["Test with other parameters!", "Text",
 CellChangeTimes->{{3.617015088813779*^9, 
  3.6170151379445887`*^9}},ExpressionUUID->"36f48c6f-0361-4608-8c7d-\
393fa93b7d62"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sfrev", "[", 
     RowBox[{
      RowBox[{"fsn3", "[", 
       RowBox[{"1", ",", 
        RowBox[{"1", "/", "5"}]}], "]"}], ",", 
      RowBox[{"hsn3", "[", 
       RowBox[{"1", ",", 
        RowBox[{"1", "/", "5"}]}], "]"}]}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", " ", 
      RowBox[{"ArcSinh", "[", 
       SqrtBox["24"], "]"}]}], ",", " ", 
     RowBox[{"ArcSinh", "[", 
      SqrtBox["24"], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6169076266495514`*^9, 3.6169077454233446`*^9}, {
   3.616941068335628*^9, 3.616941081603387*^9}, 3.6169902080239897`*^9, {
   3.61699079488142*^9, 3.6169909004156055`*^9}, 3.616992481759183*^9, 
   3.6169926018349943`*^9, {3.6169926517706814`*^9, 3.6169926596018953`*^9}, {
   3.617000567075384*^9, 3.6170006327359*^9}, {3.617000673888772*^9, 
   3.6170006823439865`*^9}, 3.617000763510929*^9, {3.6170007966297874`*^9, 
   3.6170008213246307`*^9}, 3.6170145219403553`*^9, 3.617014597532679*^9, {
   3.617014628692461*^9, 3.617014645420418*^9}, {3.617014863190874*^9, 
   3.617014908262452*^9}, 
   3.7078052754653397`*^9},ExpressionUUID->"fc782331-cb2c-46be-bea7-\
7901bdce31c5"],

Cell["This is a surface of conical type with constant curvature", "Text",
 CellChangeTimes->{{3.6170149456085877`*^9, 3.6170149795755305`*^9}, 
   3.6186392130848155`*^9},ExpressionUUID->"0b124227-5a69-4a6d-9208-\
5e42473b77fe"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"sfrev", "[", 
      RowBox[{
       RowBox[{"fsn3", "[", 
        RowBox[{"1", ",", 
         RowBox[{"2", "/", "10"}]}], "]"}], ",", 
       RowBox[{"hsn3", "[", 
        RowBox[{"1", ",", 
         RowBox[{"2", "/", "10"}]}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"v", ",", "u"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", "\[Element]", " ", "Reals"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6170009298072214`*^9, 3.6170009576688704`*^9}, {
   3.6170009942197347`*^9, 3.61700104857023*^9}, {3.6170021872745433`*^9, 
   3.617002200114278*^9}, 3.6170076753987727`*^9, {3.617015016756657*^9, 
   3.617015040035989*^9}, 
   3.7078052765935497`*^9},ExpressionUUID->"642d8488-aa84-414e-aec7-\
7122038986e5"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Absolute Differential and Christoffel Symbols", "Section",
 CellChangeTimes->{{3.5946282877913494`*^9, 3.594628341078397*^9}, 
   3.5946287521269073`*^9, {3.5947080886573257`*^9, 3.5947081111446123`*^9}, 
   3.598083945859253*^9, {3.598946107413493*^9, 3.598946113378834*^9}, {
   3.612849789938574*^9, 3.612849791376656*^9}, {3.6130221703369937`*^9, 
   3.613022178273448*^9}, 3.6130231613936787`*^9, {3.6167422011590385`*^9, 
   3.6167422040602045`*^9}, 3.617010591446561*^9, 3.6171012878039837`*^9, {
   3.625741401469241*^9, 3.62574140636765*^9}, 3.626535112124546*^9, 
   3.698736442065196*^9, 
   3.6989354144066668`*^9},ExpressionUUID->"5f4ec5b5-2803-4131-800c-\
cdbb3fd48eec"],

Cell[TextData[{
 "In general, the differential and the derivatives of a tangent vector field \
on a surface are not tangent to the surface. The tangential component of the \
differential  of a vector field is called its ",
 StyleBox["absolute differential",
  FontColor->RGBColor[0, 0, 1]],
 "; we will calculate it in this section. The calculation leads to the ",
 StyleBox["Christoffel symbols",
  FontColor->RGBColor[0, 0, 1]],
 " which depend on the metric (the first fundamental form) of the surface \
only and so belong to the inner geometry. These concepts play a fundamental \
role in the n-dimensional differential geometry of Riemannian manifolds and \
in Einstein\[CloseCurlyQuote]s general relativity theory. We begin this \
section considering m-dimensional submanifolds as immersions of m-dimensional \
parameter manifolds into the n-dimensional Euclidean space."
}], "Text",
 CellChangeTimes->{{3.5947073216646147`*^9, 3.5947073544090724`*^9}, {
   3.5947074072803535`*^9, 3.594707416416876*^9}, {3.594707450000797*^9, 
   3.594707526440169*^9}, {3.5947075823123646`*^9, 3.5947076930887003`*^9}, {
   3.5947077549602394`*^9, 3.5947077900162444`*^9}, {3.5947079466812053`*^9, 
   3.594708039528516*^9}, {3.5947081384651747`*^9, 3.5947082368408012`*^9}, {
   3.594708283920494*^9, 3.594708429712833*^9}, 3.594708506376218*^9, {
   3.594708537489998*^9, 3.5947085395871177`*^9}, 3.5949729165971603`*^9, {
   3.595133846274932*^9, 3.595133848630536*^9}, {3.5951339368798914`*^9, 
   3.5951339615747347`*^9}, {3.6130240656604*^9, 3.613024071877756*^9}, 
   3.6170751047813716`*^9, 3.61744219818544*^9, 3.6231320983087835`*^9, {
   3.698743800093895*^9, 3.698743842253776*^9}, {3.699005939713559*^9, 
   3.699005942968708*^9}, 
   3.699006055538718*^9},ExpressionUUID->"647dcd56-8360-40a1-9960-\
b041bcffd2fe"],

Cell[CellGroupData[{

Cell["4.1. The First Fundamental Form of an Immersion", "Subsection",
 CellChangeTimes->{{3.5947089791212573`*^9, 3.5947089976963196`*^9}, {
   3.594883589600548*^9, 3.594883617945798*^9}, {3.594971429937128*^9, 
   3.5949714379675875`*^9}, 3.5949729180552435`*^9, {3.6234058500759945`*^9, 
   3.6234058518699975`*^9}, 3.6235877982564993`*^9, 3.699171568747368*^9, {
   3.6991754222481127`*^9, 3.699175443822235*^9}, {3.707828622128462*^9, 
   3.707828625127759*^9}, 
   3.70788743088352*^9},ExpressionUUID->"c678b81e-38c7-47c7-917d-\
bd353985def1"],

Cell[TextData[{
 "A smooth map f: ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "1cb33a33-4524-4f8c-a7a5-e825424ab042"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LongRightArrow]", " ", 
    SuperscriptBox["Y", "n"]}], TraditionalForm]],ExpressionUUID->
  "b7687604-6865-4cea-a5ca-85de6e0e3f6d"],
 ", m ",
 "\[LessEqual]",
 " n, of an m-dimensional manifold into an n-dimensional manifold is called \
an ",
 StyleBox["immersion",
  FontColor->RGBColor[0, 0, 1]],
 " if at any point x \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "5d228856-883f-40a8-accd-2d028ba93d5d"],
 " the differential "
}], "Text",
 CellChangeTimes->{{3.594709086392393*^9, 3.5947092776243305`*^9}, {
   3.5947093093291445`*^9, 3.5947095553792176`*^9}, {3.594709592893363*^9, 
   3.594709676260132*^9}, 3.594709830520955*^9, {3.594709960589394*^9, 
   3.594709960589394*^9}, {3.594710218598151*^9, 3.5947102185991516`*^9}, {
   3.6235878542449975`*^9, 
   3.62358786714622*^9}},ExpressionUUID->"b8772e62-bc3e-4635-ad73-\
92c0db9be3b8"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["df", "x"], TraditionalForm]],ExpressionUUID->
  "7af2b774-f9c1-4b84-a890-136514807ec3"],
 ": ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "x"], TraditionalForm]],ExpressionUUID->
  "4266c688-4564-40ae-886f-f4c5919c5b43"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "6babf778-4637-490a-b04e-f7e133e1c53d"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LongRightArrow]", " ", 
     SubscriptBox["T", 
      RowBox[{"f", "(", "x", ")"}]]}], 
    SuperscriptBox["Y", "n"]}], TraditionalForm]],ExpressionUUID->
  "3596c049-3e4e-4ef4-b3f1-d14d6490c3a9"]
}], "Text",
 CellChangeTimes->{{3.594709086392393*^9, 3.5947092776243305`*^9}, {
  3.5947093093291445`*^9, 3.5947095553792176`*^9}, {3.594709592893363*^9, 
  3.5947097207526765`*^9}},ExpressionUUID->"16d76b09-d466-4cb5-94be-\
e9ad2831e8a6"],

Cell[TextData[{
 "has maximal rank m. In the case m=n an immersion is named a",
 StyleBox[" local diffeomorphism",
  FontColor->RGBColor[0, 0, 1]],
 " a bijective immersion is then called a ",
 StyleBox["diffeomorphism",
  FontColor->RGBColor[0, 0, 1]],
 ". We name the image f(",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "c1d050ba-2d34-4566-ae06-e1185c58330f"],
 ") of an immersion f  an ",
 StyleBox["m-dimensional submanifold",
  FontColor->RGBColor[0, 0, 1]],
 ", shortly an  ",
 StyleBox["m-surface",
  FontColor->RGBColor[0, 0, 1]],
 " in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "n"], TraditionalForm]],ExpressionUUID->
  "3060f7f6-cddf-4307-a812-f3a647678982"],
 ". Of course, for m=1 we speak about curves, and for m=2 about surfaces; ",
 StyleBox["hypersurfaces",
  FontColor->RGBColor[0, 0, 1]],
 " are submanifolds with m = n-1. For the following local considerations we \
assume that ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "n"], TraditionalForm]],ExpressionUUID->
  "02030889-910e-4024-a632-d1e9116c0114"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "8b31be1c-aef7-4d44-9f4f-2c26a5f7b4fc"],
 " is the n-dimensional Euclidean space, and that  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "e1ede6b7-c63d-4767-a1ef-bdb27dffb4ef"],
 " = U is an open subset of the real vector space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "m"], TraditionalForm]],ExpressionUUID->
  "b988a3c1-fa99-42ed-bfed-91feb5fda10d"],
 " with Cartesian coordinates u[i], e.g."
}], "Text",
 CellChangeTimes->{{3.59470972972919*^9, 3.594709745073067*^9}, {
   3.59470993918517*^9, 3.594710073760867*^9}, {3.5947101193844767`*^9, 
   3.5947101879683995`*^9}, {3.59471027661747*^9, 3.5947103290484686`*^9}, {
   3.5947104053608336`*^9, 3.5947105040324774`*^9}, {3.5947105828459854`*^9, 
   3.5947106703929925`*^9}, {3.5947107725138335`*^9, 3.594710795201131*^9}, 
   3.59471086686523*^9, {3.594712076002389*^9, 3.5947120775364766`*^9}, {
   3.5947121190408506`*^9, 3.594712123329096*^9}, {3.5949713277202816`*^9, 
   3.594971351344633*^9}, 3.6174409203413515`*^9, {3.617442432065817*^9, 
   3.6174424531700244`*^9}, {3.617442959017957*^9, 3.6174429963860946`*^9}, {
   3.62358790107628*^9, 3.6235880783237915`*^9}, 
   3.623763201576983*^9},ExpressionUUID->"97155085-6dc3-41b0-8542-\
c3ebe74123f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m", "=", "3"}], ";", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"u", ",", "m"}], "]"}], " ", "\[Element]", " ", "U"}]}]], "Input",
 CellChangeTimes->{{3.594710822927717*^9, 3.5947108435468965`*^9}, {
  3.5947108983280296`*^9, 3.594710901706223*^9}, {3.5947109635867624`*^9, 
  3.594710990867323*^9}, {3.594711188715639*^9, 3.5947111972191253`*^9}, {
  3.5947112491310945`*^9, 
  3.594711271322364*^9}},ExpressionUUID->"f96e39e4-be84-42ea-9ac4-\
6e388fd02feb"],

Cell[TextData[{
 "For the dimension of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "n"], TraditionalForm]],ExpressionUUID->
  "fa989564-b1b2-43a7-92e7-4dbe5abfa941"],
 " we set  dim = n and define the coordinate representation of  \
differentiable map"
}], "Text",
 CellChangeTimes->{{3.5947121549129024`*^9, 3.5947122693124456`*^9}, {
   3.69892404497972*^9, 3.698924057913926*^9}, {3.698924137665172*^9, 
   3.698924157544881*^9}, 
   3.6989241953291397`*^9},ExpressionUUID->"015db320-63f2-402a-a81b-\
1f17fe170cd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", " ", 
   RowBox[{"m", ",", "n", ",", "dim", ",", "f", ",", "smf"}], "]"}], ";", 
  RowBox[{
   RowBox[{"smf", "[", "f_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "i", "]"}], "[", "##", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "dim"}], "}"}]}], "]"}], "&"}]}], ";", " ", 
  RowBox[{"dim", " ", "=", " ", "4"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.594711374151245*^9, 3.5947114794592686`*^9}, {
   3.5947115852673206`*^9, 3.5947116073685846`*^9}, {3.594711639827441*^9, 
   3.594711671263239*^9}, {3.5947117575881767`*^9, 3.594711828853253*^9}, 
   3.594711998116934*^9, {3.5953194640529366`*^9, 3.5953194932676077`*^9}, {
   3.5953195538850746`*^9, 3.5953195709550505`*^9}, {3.5953196051960096`*^9, 
   3.5953196419811134`*^9}, {3.5955694749613805`*^9, 3.595569489786228*^9}, {
   3.5955695866347675`*^9, 3.5955696055618505`*^9}, {3.5955715900903587`*^9, 
   3.595571629682624*^9}, 3.614861861422343*^9, 3.614863501890024*^9, 
   3.617442593030024*^9, 3.6174431535420837`*^9, 
   3.6231340527618237`*^9},ExpressionUUID->"501eb934-9243-4c7b-943c-\
e2c49f3d6469"],

Cell[BoxData[
 RowBox[{
  RowBox[{"smf", "[", "f", "]"}], "[", 
  RowBox[{
   RowBox[{"t", "[", "1", "]"}], ",", 
   RowBox[{"t", "[", "2", "]"}], ",", 
   RowBox[{"t", "[", "3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5955715213854294`*^9, 3.595571563568842*^9}, {
  3.5955716737611446`*^9, 
  3.595571675478243*^9}},ExpressionUUID->"62582ae2-370d-4eb1-ba8f-\
399b0803d40a"],

Cell[TextData[{
 "The components of this map, the functions f[i][u[1],...,u[m], are assumed \
to be smooth, what means continuously  differentiable as often as necessary \
in the given context. Its",
 ButtonBox[" Jacobian matrix",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://en.wikipedia.org/wiki/Jacobian_matrix_and_determinant"], 
    None},
  ButtonNote->"https://en.wikipedia.org/wiki/Jacobian_matrix_and_determinant"],
 " is the matrix of the partial derivatives in the differential of the map, \
for example"
}], "Text",
 CellChangeTimes->{{3.698924231169989*^9, 3.698924593489813*^9}, {
  3.698924899339123*^9, 3.698924920651025*^9}, {3.698926315986186*^9, 
  3.698926315988953*^9}, {3.6989264606949997`*^9, 
  3.6989265465741243`*^9}},ExpressionUUID->"76687c56-cac0-4f9c-ba57-\
f0f36bd50249"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellChangeTimes->{{3.622975514380331*^9, 
  3.6229755568748055`*^9}},ExpressionUUID->"00ece133-1551-4027-ab27-\
978276fdf90e"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6235882514996953`*^9, 
  3.6235882772553406`*^9}},ExpressionUUID->"139d82f5-deff-4664-b395-\
629e41680ec0"],

Cell[TextData[{
 StyleBox["Warning",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[".",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" Mathematica",
  FontSlant->"Italic"],
 " generically assume that the rank of a functional matrix is maximal;for \
concrete matrices this property needs a proof!"
}], "Text",
 CellChangeTimes->{{3.6235883066145926`*^9, 3.6235883315958357`*^9}, {
   3.6235887397904577`*^9, 3.6235888805313063`*^9}, 3.6237632074737935`*^9, {
   3.6987443384163933`*^9, 
   3.698744343943941*^9}},ExpressionUUID->"70f52200-9eaa-48b4-b215-\
45f488c9bd34"],

Cell[TextData[{
 "We consider the transpose of this matrix as the ",
 StyleBox["Jacobian",
  FontColor->RGBColor[0, 0, 1]],
 " jac"
}], "Text",
 CellChangeTimes->{{3.5947126263848686`*^9, 3.594712689952505*^9}, {
   3.594713832024828*^9, 3.594713852521*^9}, 3.5947142700248795`*^9, {
   3.6987483713684473`*^9, 3.698748371501463*^9}, {3.6987488311779823`*^9, 
   3.698748832393785*^9}, {3.698926665220518*^9, 
   3.698926713044471*^9}},ExpressionUUID->"f492832b-211a-4c3c-9e18-\
8704a682a190"],

Cell[BoxData[
 RowBox[{
  RowBox[{"jac", "[", "f_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"Transpose", "[", " ", 
    RowBox[{
     RowBox[{"d", "[", "f", "]"}], "[", "##", "]"}], "]"}], "&"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.594713386074321*^9, 3.5947134565803537`*^9}, {
   3.5947136684854736`*^9, 3.5947136955560217`*^9}, {3.594878799409334*^9, 
   3.594878809003351*^9}, {3.59531976814933*^9, 3.5953197990600977`*^9}, {
   3.5955699854815807`*^9, 3.5955699916969357`*^9}, 3.5955700826891403`*^9, {
   3.595570128169742*^9, 3.595570177161544*^9}, {3.595570330490314*^9, 
   3.5955703838003635`*^9}, {3.595571733209545*^9, 3.595571767456504*^9}, 
   3.6148618614379425`*^9, 3.6149177932153635`*^9, 3.6231342894000406`*^9, 
   3.623134342974535*^9, 3.6231343934612236`*^9, {3.623134440761507*^9, 
   3.623134444630314*^9}},ExpressionUUID->"64239994-7511-4387-8413-\
ed8196a9b09b"],

Cell[BoxData[
 RowBox[{"?", "jac"}]], "Input",
 CellChangeTimes->{{3.62314028648514*^9, 3.6231405273183627`*^9}, 
   3.623140582932461*^9, {3.6258056447520137`*^9, 
   3.6258056545176306`*^9}},ExpressionUUID->"90ce71c9-79ba-4ea7-93b7-\
5f9a8051fe28"],

Cell[TextData[{
 StyleBox["Examples",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text",
 CellChangeTimes->{{3.594713944363253*^9, 3.5947139681286125`*^9}, {
  3.623134525787657*^9, 3.623134529937264*^9}, {3.6231405953032827`*^9, 
  3.6231406050844994`*^9}},ExpressionUUID->"53d6246b-a747-4dcd-9c91-\
c05eba894e66"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"jac", "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.623132306224349*^9, 3.6231323410164104`*^9}, {
   3.623132371424864*^9, 3.6231324023335185`*^9}, {3.62313247155484*^9, 
   3.62313248834247*^9}, {3.623132535612553*^9, 3.6231325774920273`*^9}, 
   3.623134473133564*^9, 
   3.623140264894702*^9},ExpressionUUID->"fa6a7db0-86ba-4eac-81af-\
80280d05896b"],

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5955700385656166`*^9, 3.5955700433108883`*^9}, {
  3.5955717961761465`*^9, 
  3.5955718060007086`*^9}},ExpressionUUID->"976a4cdc-84d5-42ae-bc18-\
2dcf7eeeca6e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"jac", "[", "sf", "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.594713474555382*^9, 3.5947135063091974`*^9}, 
   3.594713705411586*^9, {3.5955718260968575`*^9, 
   3.595571832905247*^9}},ExpressionUUID->"2484b126-c0ba-4aab-8a36-\
ec2ff53aaf49"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"smf", "[", "f", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"u", ",", "v", ",", "w"}], "}"}], "}"}]}], "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{
  3.5947126945287666`*^9, {3.594712843322277*^9, 3.5947128956392694`*^9}, {
   3.5947129485562963`*^9, 3.5947129858044267`*^9}, 
   3.6231409108966846`*^9},ExpressionUUID->"b813b6d3-e37f-46e1-9528-\
0ee28c2de332"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"jac", "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.623140829090141*^9, 
  3.6231408876682434`*^9}},ExpressionUUID->"569b3e0f-2f96-4ee2-a6fc-\
a6dc80260ab5"],

Cell[TextData[{
 "A point u={u,v,...} is aid to be a ",
 StyleBox["singularity",
  FontColor->RGBColor[0, 0, 1]],
 " of smf (or ",
 StyleBox["singular",
  FontColor->RGBColor[0, 0, 1]],
 ") if the rank of the Jacobian at this point is less then min[{m,n}] and ",
 StyleBox["regular",
  FontColor->RGBColor[0, 0, 1]],
 " else; the map smf is said to be regular if it doesn\[CloseCurlyQuote]t \
have singular points. Regular maps smf with m\[LessEqual]n are called ",
 StyleBox["immersions",
  FontColor->RGBColor[0, 0, 1]],
 ", with m\[GreaterEqual]n they are ",
 StyleBox["submersions",
  FontColor->RGBColor[0, 0, 1]],
 ", and in case m=n they are",
 StyleBox[" local diffeomorphisms",
  FontColor->RGBColor[0, 0, 1]],
 ". Bijective regular maps with m=n are called ",
 StyleBox["diffeomorphisms",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.698927013697543*^9, 3.698927137440765*^9}, {
  3.698927168656638*^9, 3.698927476198777*^9}, {3.698927537301873*^9, 
  3.6989275550782557`*^9}, {3.698927688805441*^9, 
  3.6989277332771378`*^9}},ExpressionUUID->"78c26543-4ab3-47e5-9481-\
882c3f94cdbf"],

Cell[TextData[{
 "In the following we shall consider immersions into the n-dimensional \
Euclidean space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "64dd4c1f-1777-411d-bea8-82e6f300b2aa"],
 ". The rows of  the Jacobian jac[smf[f]][u,...] of the immersion are the \
coordinates of  mf = Length[{u}]",
 StyleBox[" tangent basis vectors",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5948852693022985`*^9, 3.594885337053217*^9}, {
   3.594885368814873*^9, 3.5948853968481226`*^9}, {3.5948861634958687`*^9, 
   3.59488616987628*^9}, {3.5953198474808674`*^9, 3.595319851433093*^9}, 
   3.595596847808015*^9, {3.623140656252589*^9, 3.6231406633194017`*^9}, {
   3.6989280074021273`*^9, 3.698928097081318*^9}, {3.6989281349051247`*^9, 
   3.698928191899379*^9}},ExpressionUUID->"097357c5-7c44-444e-b8aa-\
00c14282b4f5"],

Cell[BoxData[
 RowBox[{"?", "tv"}]], "Input",
 CellChangeTimes->{{3.6258062304872465`*^9, 
  3.6258062321720495`*^9}},ExpressionUUID->"6b33f5ce-730d-41f2-b13b-\
6a4dc98fbe01"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"tv", "[", "i_", "]"}], "[", "f_", "]"}], "[", "u__", "]"}], ":=",
    " ", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"IntegerQ", "[", "i", "]"}], "&&", 
      RowBox[{"i", ">", "0"}], "&&", 
      RowBox[{"i", "<=", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "u", "}"}], "]"}]}]}], ",", " ", "\n", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], "==", " ", "List"}], "&&", " ", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"f", "[", "u", "]"}], "]"}], ">", "1"}]}], ",", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}], "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "f", "]"}], "[", "u", "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Wrong i = \>\"", ",", " ", "i"}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 Evaluatable->False,ExpressionUUID->"f9ba31f0-ab07-4011-816c-caa8a63d47b2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "2", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"jac", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.594714541091384*^9, 3.5947145732912254`*^9}, {
   3.5947146047630253`*^9, 3.5947147040847063`*^9}, {3.5947147562046876`*^9, 
   3.5947148572694683`*^9}, {3.594878909670328*^9, 3.594878940402382*^9}, {
   3.594885417580559*^9, 3.594885424475771*^9}, {3.5953198901263065`*^9, 
   3.5953199276454525`*^9}, {3.5955706750110197`*^9, 
   3.5955707288821006`*^9}, {3.595571901346162*^9, 3.5955720037630196`*^9}, {
   3.5955720872657957`*^9, 3.595572121314743*^9}, {3.5955722913794703`*^9, 
   3.595572311092598*^9}, {3.595572402579831*^9, 3.5955724102522697`*^9}, {
   3.595572441820075*^9, 3.595572498956343*^9}, {3.5955725345643797`*^9, 
   3.595572831877385*^9}, 3.5955728836043434`*^9, 3.595572934572259*^9, {
   3.5955730768843985`*^9, 3.59557313163353*^9}, {3.595573173865946*^9, 
   3.5955731968172584`*^9}, {3.595573569185557*^9, 3.5955735798341656`*^9}, {
   3.625806292018156*^9, 3.6258063945389366`*^9}, 
   3.6258065815730667`*^9},ExpressionUUID->"d48a2a28-01ad-4fc2-a733-\
449820149796"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7083218528498507`*^9},ExpressionUUID->"e139839f-eb67-457a-b834-\
1949358f5c70"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "3", "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.5947150536677017`*^9, 3.594715076507008*^9}, {
   3.6258059156658916`*^9, 3.6258059303611174`*^9}, 3.6258069533279223`*^9, 
   3.698807256173658*^9},ExpressionUUID->"512fdea8-ff6d-4604-a720-\
72155102f40a"],

Cell["\<\
The basis vector field tv[i][smf[f]][u,v,w] is the field of tangent vectors \
of the 
i-th coordinate line\
\>", "Text",
 CellChangeTimes->{{3.6235909145786867`*^9, 3.6235910952426043`*^9}, 
   3.6258067605187826`*^9, 3.625806814643278*^9, {3.698851130190784*^9, 
   3.6988511322384567`*^9}, 3.69889582564122*^9, {3.6989153054297857`*^9, 
   3.698915312861415*^9}, {3.698928379422778*^9, 
   3.6989283913027*^9}},ExpressionUUID->"7e96203f-c158-46fa-ba0f-\
bdcaba98f11d"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"smf", "[", "f", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6235910997354116`*^9, 3.6235911334626713`*^9}, 
   3.625806989085185*^9},ExpressionUUID->"d3f4a919-8d52-4634-a656-\
8abf6cbeb7c8"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "1", "]"}], "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6989283153962297`*^9, 3.698928327175816*^9}, {
  3.6989284557665462`*^9, 
  3.698928457240735*^9}},ExpressionUUID->"430ef44a-fb50-423d-9c25-\
ac6fdf0ac453"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "4", "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.5947148725073395`*^9, 3.5947149377160697`*^9}, {
   3.5947149838037057`*^9, 3.5947149862728467`*^9}, {3.595573631609127*^9, 
   3.595573672792483*^9}, 3.6258068213824897`*^9, {3.698749060348535*^9, 
   3.698749094693122*^9}},ExpressionUUID->"b34773a0-58bf-426f-948f-\
0d7d3da94454"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", 
    RowBox[{"-", "1"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.5947148725073395`*^9, 3.5947149377160697`*^9}, {
   3.5947149838037057`*^9, 3.5947149862728467`*^9}, {3.595573631609127*^9, 
   3.595573672792483*^9}, 3.6258068213824897`*^9, {3.625807060213711*^9, 
   3.625807068220525*^9}, {3.6987491115124598`*^9, 
   3.6987491126805058`*^9}},ExpressionUUID->"0cca0950-033e-41c6-851b-\
ae21b9430629"],

Cell["\<\
To get the standard basis vector fields on the parameter manifold U we \
consider the identity function\
\>", "Text",
 CellChangeTimes->{
  3.623218571409417*^9, {3.62321866410478*^9, 3.623218743290519*^9}, {
   3.6232205419580784`*^9, 3.6232205534708986`*^9}, {3.6234021393998766`*^9, 
   3.6234021423014812`*^9}},ExpressionUUID->"b54e8b61-8797-4fd2-be6b-\
3b984f5a1936"],

Cell[BoxData[
 RowBox[{"?", "identity"}]], "Input",
 CellChangeTimes->{{3.6232183176593714`*^9, 3.623218328735391*^9}, {
  3.6232183670178585`*^9, 3.623218409403133*^9}, {3.625808351909989*^9, 
  3.6258083587448006`*^9}},ExpressionUUID->"7e32b062-d7be-48a9-8889-\
387deb9054ce"],

Cell[BoxData["dim"], "Input",
 CellChangeTimes->{{3.698915526000185*^9, 
  3.698915527227981*^9}},ExpressionUUID->"a6af18f9-b586-48d8-b7be-\
f07e6870854d"],

Cell[BoxData[
 RowBox[{"identity", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.698915532845327*^9, 
  3.69891554895592*^9}},ExpressionUUID->"365d587d-0773-4bb7-9559-\
49c816b573a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]u", "[", "i_", "]"}], "[", "x__", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "i", "]"}], "[", "identity", "]"}], "[", "x", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.698915802545642*^9, 3.6989158402497663`*^9}, 
   3.6989286239450808`*^9},ExpressionUUID->"a8681635-e7a0-43c1-806b-\
906852f41016"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]u", "::", "usage"}], " ", "=", " ", 
   "\"\<\[Delta]u[i][u1,...,um] is the i-th standard basis vector field on \
the paramjeter \nmanifold U with coordinates u1,...,um.\>\""}], 
  ";"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"30eb0684-df76-4600-b000-1c9774218ef2"],

Cell[BoxData[
 RowBox[{"identity", "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.623218415799144*^9, 3.6232184270623636`*^9}, {
  3.6235901130334764`*^9, 
  3.6235901154514804`*^9}},ExpressionUUID->"12b92785-0a5e-4c25-9198-\
50eba527879a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]u", "[", "3", "]"}], "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "==", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "3", "]"}], "[", "identity", "]"}], "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6989158668175983`*^9, 3.698915920388277*^9}, {
  3.698915981452114*^9, 
  3.698916064631506*^9}},ExpressionUUID->"ca87e1ed-8969-4936-bb08-\
a489f647a37f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tv", "[", "2", "]"}], "[", "identity", "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.6235916421633654`*^9, 3.6235916743774223`*^9}, 
   3.6236510505485196`*^9, 3.625806827731701*^9, 3.698807735313963*^9, 
   3.698808296877306*^9},ExpressionUUID->"7a018e16-edd0-48eb-a516-\
8f965dbdd6f7"],

Cell["\<\
An example for the basis decomposition of a tangent vector field is\
\>", "Text",
 CellChangeTimes->{{3.69892905708119*^9, 3.698929088065007*^9}, {
  3.6989295338535213`*^9, 
  3.69892953667726*^9}},ExpressionUUID->"8a3c6f31-ff16-4f37-90aa-\
9d5b845fe0bf"],

Cell[BoxData[
 RowBox[{"?", "tvf"}]], "Input",
 CellChangeTimes->{
  3.698929190352585*^9},ExpressionUUID->"67da66c2-e522-4e3d-ad6a-\
c40590f87d1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "s", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{"\[Delta]u", "[", "1", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], " ", "+", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "2", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "sf", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ".", 
     RowBox[{
      RowBox[{"\[Delta]u", "[", "2", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.623220292934841*^9, 3.623220442351904*^9}, {
   3.6233821187910833`*^9, 3.6233821254210954`*^9}, 3.623394381865259*^9, {
   3.623402346911441*^9, 3.6234023556318564`*^9}, {3.6989291228146687`*^9, 
   3.698929146201828*^9}, {3.698929247356345*^9, 3.698929272352325*^9}, {
   3.698929308808419*^9, 3.698929348223762*^9}, {3.698929393010103*^9, 
   3.698929460966424*^9}, {3.698929505863125*^9, 
   3.6989295092702217`*^9}},ExpressionUUID->"3cfb39a1-1236-49ba-ba02-\
e7c4335091ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ".", 
   RowBox[{
    RowBox[{"\[Delta]u", "[", "2", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.623649818275008*^9, 3.6236498914547367`*^9}, {
  3.625808709314419*^9, 3.6258087135576262`*^9}, {3.698928923231413*^9, 
  3.6989289297151337`*^9}, {3.6989289699799223`*^9, 
  3.698928974874415*^9}},ExpressionUUID->"059e2020-39b9-4201-8e3c-\
41723c248e73"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"tv", "[", "2", "]"}], "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.623650074879859*^9, 3.6236500781558647`*^9}, {
   3.6236501122731247`*^9, 3.623650150009591*^9}, 
   3.6258068300405045`*^9},ExpressionUUID->"0b437ae9-cca4-4985-aece-\
e86ed14ce3ad"],

Cell[TextData[{
 "Thus we see\n",
 StyleBox["Lemma 1",
  FontColor->RGBColor[0, 0, 1]],
 " The  basis vector fields \[Delta]u[i][u,v,...] of the parameter manifold U \
are mapped by  the differential of the immersion f onto the standard basis \
vector fields tv[i][smf[f]][u,v,...]. It follows that the vectors with the \
same coordinates with respect to these bases correspond to each other under \
the differential of the immersion.\[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.6236502403493495`*^9, 3.6236502422213526`*^9}, {
   3.6236502782574162`*^9, 3.623650353168748*^9}, {3.62365039992203*^9, 
   3.6236506565268803`*^9}, {3.623650833283537*^9, 3.62365089192404*^9}, 
   3.6236512671715*^9, 3.623763249235067*^9, 3.625806832162109*^9, {
   3.6990095185387087`*^9, 
   3.699009548217702*^9}},ExpressionUUID->"d114fb52-9794-496e-b15a-\
051e92dd326c"],

Cell[TextData[{
 "A ",
 StyleBox["tangent vector",
  FontColor->RGBColor[0, 0, 1]],
 " is a linear combination of the tangent basis vectors with the coordinates \
{s1,s2,...} \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "m"], TraditionalForm]],ExpressionUUID->
  "0982b2dc-7436-4c02-8e7b-9e16a4137da6"],
 ". A ",
 StyleBox["tangent vector field",
  FontColor->RGBColor[0, 0, 1]],
 " is obtained if the coordinates are given as functions of the parameters :"
}], "Text",
 CellChangeTimes->{{3.594878538608076*^9, 3.5948785573125095`*^9}, {
   3.594886028196831*^9, 3.5948861049957657`*^9}, {3.5955967368876705`*^9, 
   3.5955967454471607`*^9}, {3.5959112371428165`*^9, 3.595911291181311*^9}, {
   3.5959113324745836`*^9, 3.595911408431117*^9}, {3.59591146137761*^9, 
   3.595911536491742*^9}, 
   3.5959116685147743`*^9},ExpressionUUID->"2a4b4628-2f82-4421-9af3-\
c77343dd27e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv", "[", "\[Xi]_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "i", "]"}], "[", "##", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "##", "}"}], "]"}]}], "}"}]}], "]"}], "&"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5955963089271927`*^9, 3.595596389983829*^9}, {
   3.59559642496883*^9, 3.5955964744026575`*^9}, {3.59559657706553*^9, 
   3.595596688818921*^9}, {3.595596899914995*^9, 3.595596910010573*^9}, {
   3.5955969406903276`*^9, 3.5955969705550356`*^9}, {3.5955970131314707`*^9, 
   3.5955970157876225`*^9}, 3.6148618615003433`*^9, 3.6148635019056244`*^9, 
   3.6258098310601964`*^9},ExpressionUUID->"03d7e59d-5ba7-4cb3-b5a6-\
1a80497e04bc"],

Cell[BoxData[
 RowBox[{"?", "vv"}]], "Input",
 CellChangeTimes->{{3.623141182697962*^9, 3.6231414076191573`*^9}, {
   3.6231414474148273`*^9, 3.623141539720189*^9}, 3.62314953740816*^9, {
   3.625809877347478*^9, 
   3.6258098893282986`*^9}},ExpressionUUID->"6c8c2872-dd7a-4596-8b3d-\
4516a2021369"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.595596485708304*^9, 3.595596552745138*^9}, {
  3.5955969877460194`*^9, 
  3.5955969919132576`*^9}},ExpressionUUID->"d4a10cc8-cfb8-466b-9df0-\
741c9fcdc49b"],

Cell[BoxData[
 RowBox[{"%", "==", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Delta]u", "[", "1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], " ", "*", 
    RowBox[{
     RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Delta]u", "[", "2", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "*", 
    RowBox[{
     RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6236553641408057`*^9, 3.6236553680564127`*^9}, {
  3.6236554096304855`*^9, 
  3.6236555029810495`*^9}},ExpressionUUID->"2d3deb2c-9358-44a6-a822-\
11d9edbc44b1"],

Cell[TextData[{
 "Notice that this field is defined as a tangent vector field on the \
parameter manifold U. Its image under the differential of the immersion is a \
vector function on  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "m"], TraditionalForm]],ExpressionUUID->
  "21186e99-c86e-403e-a11f-656c0e4b04c7"],
 " with values in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "a707cc37-f63b-431d-8d59-6e1a78b19e2e"],
 ", e. g."
}], "Text",
 CellChangeTimes->{{3.5959117538781238`*^9, 3.5959119023591843`*^9}, {
   3.595911954619276*^9, 3.595911975195712*^9}, {3.5959121801956725`*^9, 
   3.595912259677812*^9}, 3.5960892898931456`*^9, 3.623655580669186*^9, 
   3.6237604876879764`*^9, {3.623760606001686*^9, 3.6237606248787193`*^9}, {
   3.6237606627867856`*^9, 3.6237606659847913`*^9}, {3.6237607313041058`*^9, 
   3.623760745484531*^9}},ExpressionUUID->"da7fbd98-550c-4d9d-85ec-\
04f92d4ff066"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "\[Equal]", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "i", "]"}], "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", 
      RowBox[{
       RowBox[{"\[Xi]", "[", "i", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5959119820753245`*^9, 3.5959119820753245`*^9}, {
   3.595912052790249*^9, 3.5959121489800177`*^9}, {3.617779223413473*^9, 
   3.617779229123083*^9}, 3.6258068345197124`*^9, {3.69892974587824*^9, 
   3.698929767917033*^9}},ExpressionUUID->"2effd100-c50a-4b8e-a9dd-\
2a132c718ee5"],

Cell[BoxData[
 RowBox[{"?", "tvf"}]], "Input",
 CellChangeTimes->{{3.623655892201733*^9, 3.623656206283085*^9}, 
   3.625806839108121*^9, {3.625809953468012*^9, 
   3.6258099614396257`*^9}},ExpressionUUID->"82bbc425-344b-4998-ac71-\
fbcd9b9341ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tvf", "[", "\[Xi]_", "]"}], "[", "ff_", "]"}], ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "i", "]"}], "[", "ff", "]"}], "[", "##", "]"}], 
      "*", 
      RowBox[{
       RowBox[{"\[Xi]", "[", "i", "]"}], "[", "##", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "##", "}"}], "]"}]}], "}"}]}], "]"}], "&"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.594878617606615*^9, 3.5948787620316687`*^9}, 
   3.5948789981848836`*^9, {3.594879140737934*^9, 3.5948791442167397`*^9}, {
   3.594879176649197*^9, 3.5948793408394856`*^9}, {3.5948830153635397`*^9, 
   3.594883020963949*^9}, {3.594885506703515*^9, 3.594885512210325*^9}, {
   3.595322968315078*^9, 3.5953229945305777`*^9}, {3.59532303128568*^9, 
   3.595323059653302*^9}, {3.5955707720675707`*^9, 3.595570783931249*^9}, {
   3.5955708177081814`*^9, 3.5955708618827076`*^9}, {3.595570944371426*^9, 
   3.595570972020007*^9}, {3.5955737481397924`*^9, 3.5955738706988025`*^9}, {
   3.5955826733812866`*^9, 3.5955827043000555`*^9}, {3.6234046181574306`*^9, 
   3.6234046236486397`*^9}, {3.623579901734145*^9, 3.623579907131755*^9}, {
   3.6235800037115245`*^9, 3.623580008017132*^9}, 3.625806836844117*^9, 
   3.6258094752933683`*^9},ExpressionUUID->"448c40d4-7e93-40b4-b619-\
5a275ea7fda4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{
    RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6235799730106707`*^9, 3.623579976832677*^9}, {
   3.6235800202943535`*^9, 3.6235800728352456`*^9}, {3.623580191801055*^9, 
   3.6235801931426573`*^9}, 3.62358022914752*^9, {3.698929790860372*^9, 
   3.6989297919162807`*^9}, {3.698929858000516*^9, 
   3.698929862203252*^9}},ExpressionUUID->"af8401c8-8eaa-488d-b5e4-\
a4ba53c3806a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dim", "=", " ", "4"}], ";", 
   RowBox[{
    RowBox[{
     RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.594879354302309*^9, 3.594879363319125*^9}, {
   3.5948795443418427`*^9, 3.5948795935287294`*^9}, 3.5955708665119724`*^9, 
   3.6177792687627525`*^9, 3.6234047748129053`*^9, {3.6234051653439913`*^9, 
   3.6234051814120197`*^9}, {3.62357967113454*^9, 3.6235796763293495`*^9}, 
   3.6235802785060067`*^9},ExpressionUUID->"dfd2999d-f64b-4825-b36a-\
ecd5c32b1fee"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}], ".", 
  RowBox[{
   RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6234048675082684`*^9, 3.62340494812921*^9}, {
   3.623405058452604*^9, 3.623405088747857*^9}, {3.623405211036472*^9, 
   3.6234052117852736`*^9}, {3.6234053308602824`*^9, 3.623405342061102*^9}, {
   3.6234056947621217`*^9, 3.6234057012829328`*^9}, {3.6235803733853736`*^9, 
   3.6235804249590645`*^9}, 3.6235805052056055`*^9, {3.698929930218712*^9, 
   3.698929956522727*^9}},ExpressionUUID->"f69fdbce-cc5d-405e-8154-\
3bbcbd669880"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "-", "%%"}], "]"}]], "Input",
 CellChangeTimes->{{3.623405577044315*^9, 
  3.6234056031431603`*^9}},ExpressionUUID->"d88f98d9-603a-4e19-8b41-\
8db0a62a1a34"],

Cell["\<\
Tangent vectors of an m-surface are contained in the Euclidean n-space;  thus \
their scalar square and scalar products are defined:\
\>", "Text",
 CellChangeTimes->{{3.59488630057331*^9, 3.5948863791818476`*^9}, {
   3.623656329919303*^9, 3.623656349544137*^9}, 
   3.623763282962326*^9},ExpressionUUID->"7e615752-8122-4c95-ac4a-\
c3e382846ef6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5948797188749495`*^9, 
  3.594879784707065*^9}},ExpressionUUID->"58bb803d-3329-4f7a-92c4-\
cbeb18627b56"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5948797188749495`*^9, 3.594879784707065*^9}, {
  3.594879824565135*^9, 
  3.5948798413663645`*^9}},ExpressionUUID->"bb92c58f-3ff1-4f13-8590-\
d6da525ede10"],

Cell[TextData[{
 "This scalar product may be expressed by the ",
 StyleBox["first fundamental form ",
  FontColor->RGBColor[0, 0, 1]],
 "of the immersion, whose coordinates are defined by"
}], "Text",
 CellChangeTimes->{{3.5948864658712*^9, 3.5948865299093122`*^9}},
 CellTags->"fund1",ExpressionUUID->"72ae63ed-a570-42d3-b1c5-fb41d8c67501"],

Cell[BoxData[
 RowBox[{"?", "rgT"}]], "Input",
 CellChangeTimes->{{3.618641453594998*^9, 3.6186414580102506`*^9}, 
   3.6186415127083793`*^9, 
   3.6186416655541215`*^9},ExpressionUUID->"cead7f15-4d70-401c-837f-\
0c9f16161cd3"],

Cell["\<\
which we used already defining the first fundamental form of a surface.\
\>", "Text",
 CellChangeTimes->{{3.5948866048830442`*^9, 3.5948866612615433`*^9}, {
  3.596526134112959*^9, 3.596526134119959*^9}, {3.618641727448662*^9, 
  3.61864176011153*^9}},ExpressionUUID->"64746e18-674b-4d43-a733-\
fa31e4ae0ede"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rgT", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.595574517864818*^9, 3.5955745322806425`*^9}, 
   3.5955746182335587`*^9, {3.6186415960341454`*^9, 3.6186415985062866`*^9}, {
   3.625810531560831*^9, 
   3.6258105364592395`*^9}},ExpressionUUID->"df41a4a5-b2f0-44b2-bd4a-\
70efe3fbc9c6"],

Cell[BoxData[
 RowBox[{"?", "fund1"}]], "Input",
 CellChangeTimes->{{3.618641875834149*^9, 3.618641879318348*^9}, 
   3.623382204357234*^9},ExpressionUUID->"a984be3b-54e9-45c9-9967-\
05651117cb4d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund1", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"s", ",", "2"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"t", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5948833076300526`*^9, 3.594883417126645*^9}, {
   3.5955757454070296`*^9, 3.5955757569936924`*^9}, 
   3.6186420187383223`*^9},ExpressionUUID->"ec73bb02-744c-44a2-8190-\
017c4a0fa859"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fund1", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"s", ",", "4"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"t", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{3.5955757777128773`*^9, 3.5955767298893385`*^9, 
  3.5955769062254243`*^9, 
  3.6186426934259124`*^9},ExpressionUUID->"7da094c1-63f3-4941-a7b0-\
aab22a48d035"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Xi]", "[", "i", "]"}], "[", 
         RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Eta]", "[", "i", "]"}], "[", 
         RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.594881401478305*^9, 3.594881598647051*^9}, {
   3.5948856462925606`*^9, 3.594885672282206*^9}, {3.594886933372821*^9, 
   3.594887200928891*^9}, {3.595576973645281*^9, 3.595576983931869*^9}, {
   3.5955828729667025`*^9, 3.595582949996108*^9}, {3.614861861547143*^9, 
   3.614861861547143*^9}, {3.614863501921224*^9, 3.614863501921224*^9}, 
   3.618642037261382*^9},ExpressionUUID->"eab6ddfd-bc4c-4966-9738-\
fc05a73efbe9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ".", 
     RowBox[{
      RowBox[{
       RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], " ", "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"fund1", "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{
       RowBox[{"vv", "[", "\[Eta]", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.594881401478305*^9, 3.594881598647051*^9}, {
   3.5948856462925606`*^9, 3.594885672282206*^9}, {3.594886933372821*^9, 
   3.594887200928891*^9}, {3.595576973645281*^9, 3.595576983931869*^9}, {
   3.5955828729667025`*^9, 3.595582949996108*^9}, {3.595912402636463*^9, 
   3.5959124815258017`*^9}, 
   3.61864269513101*^9},ExpressionUUID->"0103e7e5-5178-4c5d-9d6d-\
7bd936ee702a"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], ",", 
     RowBox[{
      RowBox[{"vv", "[", "\[Eta]", "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{
     RowBox[{
      RowBox[{"tvf", "[", "\[Eta]", "]"}], "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.594881903097186*^9, 3.594881929071232*^9}, {
   3.594882044995035*^9, 3.59488209889313*^9}, {3.5948821483140163`*^9, 
   3.594882356324782*^9}, {3.5948857787367935`*^9, 3.5948858214808683`*^9}, 
   3.5948858581253324`*^9, {3.5948859196674404`*^9, 3.5948859277326546`*^9}, {
   3.5948859703207293`*^9, 3.594885975078738*^9}, {3.5955830629015665`*^9, 
   3.59558310002969*^9}, {3.595912582457979*^9, 
   3.595912628056859*^9}},ExpressionUUID->"445b5e0b-96a3-473c-935e-\
ad01722dd058"],

Cell[TextData[{
 "The first fundamental form of an immersion into the Euclidean space is a \
field of positive definite symmetric bilinear forms \
{\[Gamma]\[Gamma][i,j][u]}, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "\[Element]", 
    SuperscriptBox["X", "m"]}], TraditionalForm]],ExpressionUUID->
  "57ffa687-c8f6-42c5-8654-ca48e952250f"],
 ", where"
}], "Text",
 CellChangeTimes->{{3.5948875759067497`*^9, 3.5948877670538855`*^9}, 
   3.5949654316930485`*^9, 3.59496549099144*^9, {3.5949655491507664`*^9, 
   3.594965571823063*^9}, {3.594965717170377*^9, 3.5949657764947696`*^9}, {
   3.5949658208473063`*^9, 3.5949658766384974`*^9}, {3.5949659519598055`*^9, 
   3.5949659549429765`*^9}, {3.5949659930951586`*^9, 3.594966157918586*^9}, {
   3.5949661988769283`*^9, 3.59496644716713*^9}, {3.594966913414798*^9, 
   3.5949669701430426`*^9}, {3.5949716038810773`*^9, 
   3.5949716559840574`*^9}, {3.594971695811335*^9, 3.594971695811335*^9}, {
   3.5949717640392375`*^9, 3.594971771551667*^9}, {3.594971806319656*^9, 
   3.5949718596817083`*^9}, 3.5949729245216136`*^9, {3.595912681892554*^9, 
   3.5959127142470107`*^9}, {3.6130225413702154`*^9, 
   3.6130226045328283`*^9}, {3.6130226479333105`*^9, 
   3.6130227443038225`*^9}, {3.6130227886943617`*^9, 3.613022899241685*^9}, {
   3.613023003626655*^9, 3.613023014945303*^9}, {3.6170765536963167`*^9, 
   3.617076559561927*^9}, {3.6170773490949135`*^9, 3.617077383617774*^9}, {
   3.6170774835983496`*^9, 3.6170775130668015`*^9}, {3.6258117536571884`*^9, 
   3.6258117695380163`*^9}, 3.625811801834073*^9, {3.707887310404984*^9, 
   3.707887330963336*^9}},ExpressionUUID->"f504624e-141c-4923-8c5c-\
79fdf22df31e"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Gamma]\[Gamma]", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "[", "u", "]"}], "}"}], " ", ":=", 
    "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "f", "]"}], "[", "u", "]"}], 
     "}"}]}], ",", "     ", 
   FormBox[
    RowBox[{"u", "\[Element]", 
     SuperscriptBox["X", "m"]}],
    TraditionalForm], ",", " "}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.617077552878072*^9, 3.617077649535841*^9}, 
   3.6186421722731037`*^9, 3.6186423423668327`*^9, {3.698934714357387*^9, 
   3.698934733412805*^9}},ExpressionUUID->"76fd8578-c4e4-44e2-806d-\
cb0e2772208d"],

Cell[TextData[{
 "is the  pulling back of the Euclidean  metric  from the m-subspace ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["df", "u"], TraditionalForm]],ExpressionUUID->
  "77a51e64-0ecb-4dc6-a576-a179519c1b2f"],
 "(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "u"], TraditionalForm]],ExpressionUUID->
  "c68eaa89-5ddb-447f-bc10-1275d4cd9631"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "f6cd0880-913e-4be4-b07f-aacc22a9a2fb"],
 Cell[BoxData[
  FormBox[
   RowBox[{")", " ", "\[Subset]", " ", 
    RowBox[{
     SubscriptBox["T", 
      RowBox[{"f", "(", "u", ")"}]], 
     SuperscriptBox["Y", "n"]}]}], TraditionalForm]],ExpressionUUID->
  "fa80130c-b967-49fc-9461-c329e1672f55"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "3110c753-8c94-4e63-904a-6ab0a28623e4"],
 " by the differential ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["df", "u"], TraditionalForm]],ExpressionUUID->
  "85bf85ff-b292-4685-89fd-428812e285ce"],
 ". "
}], "Text",
 CellChangeTimes->{{3.5948875759067497`*^9, 3.5948877670538855`*^9}, 
   3.5949654316930485`*^9, 3.59496549099144*^9, {3.5949655491507664`*^9, 
   3.594965571823063*^9}, {3.594965717170377*^9, 3.5949657764947696`*^9}, {
   3.5949658208473063`*^9, 3.5949658766384974`*^9}, {3.5949659519598055`*^9, 
   3.5949659549429765`*^9}, {3.5949659930951586`*^9, 3.594966157918586*^9}, {
   3.5949661988769283`*^9, 3.59496644716713*^9}, {3.594966913414798*^9, 
   3.5949669701430426`*^9}, {3.5949716038810773`*^9, 
   3.5949716559840574`*^9}, {3.594971695811335*^9, 3.594971695811335*^9}, {
   3.5949717640392375`*^9, 3.594971771551667*^9}, {3.594971806319656*^9, 
   3.5949718596817083`*^9}, 3.5949729245216136`*^9, {3.595912681892554*^9, 
   3.5959127142470107`*^9}, {3.6130225413702154`*^9, 
   3.6130226045328283`*^9}, {3.6130226479333105`*^9, 
   3.6130227443038225`*^9}, {3.6130227886943617`*^9, 3.613022899241685*^9}, {
   3.613023003626655*^9, 3.613023014945303*^9}, {3.6170765536963167`*^9, 
   3.617076559561927*^9}, {3.6170773490949135`*^9, 3.617077383617774*^9}, 
   3.6170774835983496`*^9, {3.6170777038083363`*^9, 3.617077761263238*^9}, {
   3.6170784969761295`*^9, 3.617078513543359*^9}, {3.617078545913416*^9, 
   3.6170786173303413`*^9}, 3.6258118668921876`*^9, {3.625815875551713*^9, 
   3.625815876737315*^9}},ExpressionUUID->"597aeb70-0ed9-479f-bb7c-\
0cfae59c018b"],

Cell[TextData[{
 "If a field {\[Gamma]\[Gamma][i,j][u]} of symmetric non-degenerate bilinear \
forms on the manifold ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "4683f70c-85e0-4de4-946b-0002f029a352"],
 "is given  one names the pair \n[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "12ead084-fc66-4568-b02d-2186867fea6b"],
 ", \[Gamma]\[Gamma]] a ",
 StyleBox["pseudo-Riemannian manifold",
  FontColor->RGBColor[0, 0, 1]],
 ". With the scalar product defined by {\[Gamma]\[Gamma][i,j][u]}, any \
tangent space ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "u"], TraditionalForm]],ExpressionUUID->
  "d12a1945-0327-4a33-8146-05e93b556717"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "89c51f64-1e72-4004-a960-588c7ae67420"],
 " becomes an m-dimensional pseudo-Euclidean space; the norm of vectors and \
angles between vectors are defined by this scalar product. The index of the \
local scalar products  {\[Gamma]\[Gamma][i,j][u]}  is assumed to be constant; \
it is called the ",
 StyleBox["index",
  FontColor->RGBColor[0, 0, 1]],
 " of the pseudo-Riemannian manifold. The most important manifolds are those \
with index zero; they are called ",
 StyleBox["Riemannian manifolds",
  FontColor->RGBColor[0, 0, 1]],
 ". In particular the scalar products rgT induced by an immersion into a \
Euclidean space are positive definite and define Riemannian manifolds."
}], "Text",
 CellChangeTimes->{{3.5948875759067497`*^9, 3.5948877670538855`*^9}, 
   3.5949654316930485`*^9, 3.59496549099144*^9, {3.5949655491507664`*^9, 
   3.594965571823063*^9}, {3.594965717170377*^9, 3.5949657764947696`*^9}, {
   3.5949658208473063`*^9, 3.5949658766384974`*^9}, {3.5949659519598055`*^9, 
   3.5949659549429765`*^9}, {3.5949659930951586`*^9, 3.594966157918586*^9}, {
   3.5949661988769283`*^9, 3.59496644716713*^9}, {3.594966913414798*^9, 
   3.5949669701430426`*^9}, {3.5949716038810773`*^9, 
   3.5949716559840574`*^9}, {3.594971695811335*^9, 3.594971695811335*^9}, {
   3.5949717640392375`*^9, 3.594971771551667*^9}, {3.594971806319656*^9, 
   3.5949718596817083`*^9}, 3.5949729245216136`*^9, {3.595912681892554*^9, 
   3.5959127142470107`*^9}, {3.6130225413702154`*^9, 
   3.6130226045328283`*^9}, {3.6130226479333105`*^9, 
   3.6130227443038225`*^9}, {3.6130227886943617`*^9, 3.613022899241685*^9}, {
   3.613023003626655*^9, 3.613023014945303*^9}, {3.6170765536963167`*^9, 
   3.617076559561927*^9}, {3.6170773490949135`*^9, 3.617077383617774*^9}, {
   3.6170774835983496`*^9, 3.6170775130668015`*^9}, {3.6258117536571884`*^9, 
   3.6258117695380163`*^9}, 3.625811801834073*^9, {3.625811978816785*^9, 
   3.625811980501588*^9}, {3.6258120438768997`*^9, 3.625812054500518*^9}, {
   3.6258120938613873`*^9, 3.625812312019572*^9}, {3.6258159056773663`*^9, 
   3.6258159765512905`*^9}, {3.625816064881646*^9, 3.6258160695772543`*^9}, {
   3.625816122838748*^9, 3.6258161535396023`*^9}, {3.6258162567855835`*^9, 
   3.625816409453452*^9}, {3.625816475960369*^9, 3.6258165313580666`*^9}, {
   3.625816581249954*^9, 3.625816701779766*^9}, {3.62581676073427*^9, 
   3.625816773293292*^9}},ExpressionUUID->"4cc30722-f366-4cd7-b143-\
6a272827153a"],

Cell[TextData[{
 "Since the pseudo-Riemannian metric is non-degenerate,  the ",
 StyleBox["volume element  ",
  FontColor->RGBColor[0, 0, 1]],
 "dVol[ \[Gamma]\[Gamma]]",
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 "of  a pseudo-Riemannian manifold {",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Y", "m"], TraditionalForm]],ExpressionUUID->
  "ed1534a1-2b56-4366-8670-3b5fea087531"],
 ", \[Gamma]\[Gamma]}  is defined by (in eudiffgeov3.m)"
}], "Text",
 CellChangeTimes->{{3.5948875759067497`*^9, 3.5948877670538855`*^9}, 
   3.5949654316930485`*^9, 3.59496549099144*^9, {3.5949655491507664`*^9, 
   3.594965571823063*^9}, {3.594965717170377*^9, 3.5949657764947696`*^9}, {
   3.5949658208473063`*^9, 3.5949658766384974`*^9}, {3.5949659519598055`*^9, 
   3.5949659549429765`*^9}, {3.5949659930951586`*^9, 3.594966157918586*^9}, {
   3.5949661988769283`*^9, 3.59496644716713*^9}, {3.594966913414798*^9, 
   3.5949669701430426`*^9}, {3.5949716038810773`*^9, 
   3.5949716559840574`*^9}, {3.594971695811335*^9, 3.594971695811335*^9}, {
   3.5949717640392375`*^9, 3.594971771551667*^9}, {3.594971806319656*^9, 
   3.5949718596817083`*^9}, 3.5949729245216136`*^9, {3.595912681892554*^9, 
   3.5959127142470107`*^9}, {3.6130225413702154`*^9, 
   3.6130226045328283`*^9}, {3.6130226479333105`*^9, 
   3.6130227443038225`*^9}, {3.6130227886943617`*^9, 3.613022899241685*^9}, {
   3.613023003626655*^9, 3.613023014945303*^9}, {3.6170765536963167`*^9, 
   3.617076559561927*^9}, {3.6170773490949135`*^9, 3.617077383617774*^9}, 
   3.6170774835983496`*^9, {3.6170777038083363`*^9, 3.617077761263238*^9}, {
   3.6170784969761295`*^9, 3.617078513543359*^9}, {3.617078545913416*^9, 
   3.6170786173303413`*^9}, 3.6258118668921876`*^9, {3.625817552158662*^9, 
   3.6258175941091356`*^9}, {3.6258176391006145`*^9, 3.625817729435774*^9}, {
   3.6258178182175303`*^9, 3.625817837111163*^9}, 
   3.686289017969981*^9},ExpressionUUID->"9927d65b-26eb-4497-8cc7-\
ec35d6987363"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dVol", "[", "\[Gamma]\[Gamma]_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "i", ",", "j"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", " ", "=", " ", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "##", "}"}], "]"}]}], ";", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{"Det", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Gamma]\[Gamma]", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "[", "##", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "m"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}], "]"}], "]"}]}]}], 
    "]"}], "&"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5721028398629103`*^9, 3.5721030771549273`*^9}, 
   3.5721031379326334`*^9, {3.586074746853404*^9, 3.5860747605491877`*^9}, {
   3.5860748158453503`*^9, 3.586074825492902*^9}, {3.5861549510774903`*^9, 
   3.586154964603264*^9}, {3.5862629631854534`*^9, 3.586262985017702*^9}, {
   3.5862630295142474`*^9, 3.5862630744648185`*^9}, {3.586604010786734*^9, 
   3.5866040355439777`*^9}, {3.594966564323831*^9, 3.5949665841789665`*^9}, {
   3.5949666975964537`*^9, 3.5949667458112116`*^9}, 3.5949668161242332`*^9, 
   3.594966903781247*^9, {3.595577348814739*^9, 3.5955774292283382`*^9}, {
   3.5955775238277493`*^9, 3.5955775729545593`*^9}, 3.5955776895562286`*^9, {
   3.614861861562743*^9, 3.614861861562743*^9}, 3.614863501936824*^9, 
   3.6149177932621636`*^9, {3.6170779225207205`*^9, 3.6170779402423515`*^9}, {
   3.6170779947644477`*^9, 3.617078006308468*^9}, {3.625817907532687*^9, 
   3.625817912181495*^9}, {3.62581797757981*^9, 3.6258180044898577`*^9}, {
   3.625818061994559*^9, 3.6258180965194197`*^9}, {3.6258186558124037`*^9, 
   3.625818718479714*^9}, 
   3.6258332272109594`*^9},ExpressionUUID->"e2c7944f-b832-4a53-a82e-\
ffacb068e699"],

Cell[BoxData[
 RowBox[{"?", "dVol"}]], "Input",
 CellChangeTimes->{{3.6258322301038055`*^9, 3.6258323374973946`*^9}, {
  3.6258324021937084`*^9, 3.6258324903514633`*^9}, {3.62583280084221*^9, 
  3.6258328070042205`*^9}},ExpressionUUID->"46eed605-c581-4601-b7bf-\
a33f83e1b82e"],

Cell["\<\
For immersion, or more general for pseudo-Riemannian manifolds of even index, \
the determinant of the bilinear form is always positive and the absolute \
function appearing in this definition may be omitted.  In particular, for \
immersions into Euclidean spaces the volume element may be defined by\
\>", "Text",
 CellChangeTimes->{{3.617078649513198*^9, 3.617078658857614*^9}, {
  3.6258183771069136`*^9, 3.6258186052185144`*^9}, {3.626855291683429*^9, 
  3.6268553122482653`*^9}},ExpressionUUID->"48c498c0-0758-4743-82b7-\
0d1265609919"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dV", "[", "ff_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "i", ",", "j"}], "}"}], ",", 
     RowBox[{
      RowBox[{"m", " ", "=", " ", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "##", "}"}], "]"}]}], ";", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Det", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"rgT", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", "##", 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "m"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}], "]"}]}]}], "]"}], 
   "&"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5721028398629103`*^9, 3.5721030771549273`*^9}, 
   3.5721031379326334`*^9, {3.586074746853404*^9, 3.5860747605491877`*^9}, {
   3.5860748158453503`*^9, 3.586074825492902*^9}, {3.5861549510774903`*^9, 
   3.586154964603264*^9}, {3.5862629631854534`*^9, 3.586262985017702*^9}, {
   3.5862630295142474`*^9, 3.5862630744648185`*^9}, {3.586604010786734*^9, 
   3.5866040355439777`*^9}, {3.594966564323831*^9, 3.5949665841789665`*^9}, {
   3.5949666975964537`*^9, 3.5949667458112116`*^9}, 3.5949668161242332`*^9, 
   3.594966903781247*^9, {3.595577348814739*^9, 3.5955774292283382`*^9}, {
   3.5955775238277493`*^9, 3.5955775729545593`*^9}, 3.5955776895562286`*^9, {
   3.614861861562743*^9, 3.614861861562743*^9}, 3.614863501936824*^9, 
   3.6149177932621636`*^9, 3.6186421734671726`*^9, 3.6186423423708334`*^9, {
   3.625818195005393*^9, 3.6258181994670005`*^9}, {3.6258182295136538`*^9, 
   3.625818249528488*^9}},ExpressionUUID->"c9b21717-7a9a-4d2a-a9ca-\
14abfe309547"],

Cell[BoxData[
 RowBox[{"?", "dV"}]], "Input",
 CellChangeTimes->{{3.6258322301038055`*^9, 3.6258323374973946`*^9}, {
  3.6258324021937084`*^9, 3.6258324903514633`*^9}, {3.625832564594994*^9, 
  3.6258326752645884`*^9}, {3.62583293735345*^9, 
  3.6258329454030643`*^9}},ExpressionUUID->"65db0e4d-862a-40e5-bd40-\
3531b74135f0"],

Cell["Indeed, if \[Gamma]\[Gamma] is induced by an immersion smf,e.g.:", \
"Text",
 CellChangeTimes->{{3.617078676626045*^9, 3.617078760897393*^9}, {
   3.6258188542839527`*^9, 3.6258188724111843`*^9}, 
   3.6258334034806695`*^9},ExpressionUUID->"e36a6b53-4e65-42e4-b2e1-\
e511a14a4c1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.6258190103994274`*^9, 
  3.62581901746624*^9}},ExpressionUUID->"4002f14f-bc58-43b8-a04f-\
40300ca02fb8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]sf", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_", ",", "w_"}], "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6170782340688677`*^9, 3.617078330508237*^9}, 
   3.6186421747842474`*^9, 3.618642342374833*^9, {3.625818771242007*^9, 
   3.6258187717880077`*^9}, {3.62581880727907*^9, 3.625818843439934*^9}, {
   3.6258191084017997`*^9, 
   3.6258191112254047`*^9}},ExpressionUUID->"c0b8be54-ae75-41cd-be95-\
f2cefb468c3d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rgT", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.6258190843143573`*^9, 3.625819086343361*^9}, {
  3.6258191323966417`*^9, 
  3.6258191372482505`*^9}},ExpressionUUID->"dceb4031-274d-48c4-9e4a-\
7e665783d36d"],

Cell["one has", "Text",
 CellChangeTimes->{{3.6170787827530317`*^9, 3.617078809553879*^9}, 
   3.625818885641008*^9},ExpressionUUID->"d45704e3-7640-42c8-b8a3-\
4e2722b79ea1"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dVol", "[", "\[Gamma]sf", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], "^", "2"}], " ", "\[Equal]", 
     " ", 
     RowBox[{
      RowBox[{
       RowBox[{"dV", "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], "^", "2"}]}], " ", ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{"Det", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Gamma]sf", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "[", 
            RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}], ">", "0"}],
       ")"}], "\[Equal]", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6170783477618675`*^9, 3.617078415216386*^9}, {
   3.6258189088382483`*^9, 3.6258189615839415`*^9}, {3.625819192925748*^9, 
   3.6258192254538054`*^9}, 3.6258192694468827`*^9, {3.6258193283711863`*^9, 
   3.625819416467541*^9}, {3.6258243272556973`*^9, 3.62582434538173*^9}, {
   3.625824436614691*^9, 3.6258244606553335`*^9}, {3.625824533884862*^9, 
   3.6258245362092657`*^9}, {3.625828022791994*^9, 3.62582805438305*^9}, 
   3.6258281042271376`*^9, {3.6258281517302213`*^9, 3.625828256784806*^9}, {
   3.707883943673613*^9, 3.707884022835291*^9}, {3.707884164860938*^9, 
   3.7078841721601686`*^9}, 3.70788444038468*^9, {3.7078866746335363`*^9, 
   3.707886692378708*^9}},ExpressionUUID->"7191e61c-986d-4619-9b42-\
9758f7db524e"],

Cell[TextData[{
 "after waiting a long time. Obviously, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has problems to verify this identity being True, comparfe the arguments"
}], "Text",
 CellChangeTimes->{{3.6170788288355126`*^9, 3.617078860394368*^9}, 
   3.617079026144659*^9, 3.6233823332446604`*^9, {3.625832093318765*^9, 
   3.625832164847891*^9}, {3.6258332563216105`*^9, 3.6258333000504875`*^9}, 
   3.626855323591485*^9, {3.7078864343276253`*^9, 3.7078864794578342`*^9}, {
   3.707886842385178*^9, 
   3.7078868730238237`*^9}},ExpressionUUID->"06428679-a5cb-4375-9d43-\
051b997d50d6"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]sf", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "]"}], "==", 
   RowBox[{
    RowBox[{
     RowBox[{"dV", "[", 
      RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v", ",", "w"}], "]"}], "^", "2"}]}], " ", 
  "]"}]], "Input",
 CellChangeTimes->{{3.707886946595707*^9, 3.7078869736307383`*^9}, 
   3.707887030512607*^9},ExpressionUUID->"b3205c90-f9de-4242-97d9-\
017706a98288"],

Cell["The reason seems to be the function Abas in the definition", "Text",
 CellChangeTimes->{{3.707887089501513*^9, 
  3.7078871169411993`*^9}},ExpressionUUID->"f80315e0-8b59-407f-8870-\
52dce8941a28"],

Cell[BoxData[
 RowBox[{"??", "dVol"}]], "Input",
 CellChangeTimes->{{3.7078864988796463`*^9, 
  3.707886512337698*^9}},ExpressionUUID->"c9424cc9-bce5-4ce4-a6c5-\
c994467992fa"],

Cell["The area element of a surface is a special case of dV:", "Text",
 CellChangeTimes->{{3.6170788288355126`*^9, 3.617078860394368*^9}, 
   3.617079026144659*^9, 3.6233823332446604`*^9, {3.625832093318765*^9, 
   3.625832164847891*^9}, {3.6258332563216105`*^9, 3.6258333000504875`*^9}, 
   3.626855323591485*^9, 3.7078864343276253`*^9, {3.707886555993285*^9, 
   3.7078866363136787`*^9}, {3.707887146318742*^9, 
   3.707887148278352*^9}},ExpressionUUID->"4857f664-9e02-4d44-977e-\
7dffbec00ff9"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dV", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"dA", "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6170789222952766`*^9, 3.6170789370061026`*^9}, {
  3.617078990623397*^9, 
  3.6170790012158155`*^9}},ExpressionUUID->"100acb7a-9238-4295-88ef-\
df7f962824db"],

Cell[TextData[{
 StyleBox["Example 1. ",
  FontColor->RGBColor[0, 0, 1]],
 "The volume of a 3-sphere in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]],ExpressionUUID->
  "6d154164-2ad6-4f7d-bb71-76ab1a5f73f8"],
 "."
}], "Text",
 CellChangeTimes->{{3.5949671433639503`*^9, 3.594967173390668*^9}, {
   3.5949684739990582`*^9, 3.5949685574148293`*^9}, {3.6989350330895042`*^9, 
   3.698935036689815*^9}, {3.69900926308281*^9, 3.6990092635949793`*^9}, 
   3.6990093186904716`*^9},ExpressionUUID->"1d5a51bb-357e-4996-925a-\
9bebe59c8e9f"],

Cell[BoxData[
 RowBox[{"?", "unit"}]], "Input",
 CellChangeTimes->{{3.5949685635881824`*^9, 
  3.594968565453289*^9}},ExpressionUUID->"2e87946a-af41-4ad8-b82f-\
d85d397f5ea1"],

Cell[BoxData[
 RowBox[{"unit", "[", 
  RowBox[{"{", 
   RowBox[{"u", ",", "v", ",", "w"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5949674880876675`*^9, 3.5949675122890515`*^9}, 
   3.698935194780549*^9},ExpressionUUID->"12a33ff5-3c19-49e6-820f-\
5136e97493d3"],

Cell[TextData[{
 "The hypersphere of radius r in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]],ExpressionUUID->
  "bf1d9f3a-d6c8-402b-a915-a3aa8b92f38b"],
 " has the parameter representation"
}], "Text",
 CellChangeTimes->{{3.5949719474467278`*^9, 3.594972008231205*^9}, {
   3.5950507705444202`*^9, 3.5950507770028315`*^9}, 
   3.617441114508457*^9},ExpressionUUID->"dd35dcc3-7d5c-425f-abbe-\
5ef9616e0801"],

Cell[BoxData[
 RowBox[{"?", "unit"}]], "Input",
 CellChangeTimes->{{3.698935151215313*^9, 
  3.698935155072403*^9}},ExpressionUUID->"f08d47f6-0ddb-4b8c-af67-\
7b6cbaaa433c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"smh", "[", 
   RowBox[{"u_", ",", "v_", ",", "w_"}], "]"}], " ", "=", " ", 
  RowBox[{"r", "*", 
   RowBox[{"unit", "[", 
    RowBox[{"{", 
     RowBox[{"u", ",", "v", ",", "w"}], "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5949675673111987`*^9, 3.594967639842347*^9}, {
   3.5955784262413645`*^9, 3.59557843927311*^9}, 
   3.698935241853138*^9},ExpressionUUID->"5caf8a13-ba2e-4ca3-8b9b-\
b995417a913c"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "smh", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.594967668807004*^9, 3.5949677562520056`*^9}, 
   3.5955784605383263`*^9, 3.6148618615783434`*^9, 3.614863501952424*^9, 
   3.618642175840308*^9, 
   3.618642342378834*^9},ExpressionUUID->"5c2a1ea4-0d62-432f-a67a-\
ab7274db9a9d"],

Cell[TextData[{
 "Indeed, all the upper - left submatrices have positive determinants, see ",
 ButtonBox["Math World",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathworld.wolfram.com/PositiveDefiniteMatrix.html"], None},
  ButtonNote->"http://mathworld.wolfram.com/PositiveDefiniteMatrix.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.5949682501832566`*^9, 3.594968307255521*^9}, 
   3.5949683821998076`*^9, {3.5949684253162737`*^9, 3.594968425324274*^9}, 
   3.6174411573479075`*^9},ExpressionUUID->"f5667d33-0686-4dd8-b02d-\
be4f19e866c8"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "smh", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5948873343559256`*^9, 3.5948874290636916`*^9}, 
   3.5949677892268915`*^9, {3.594967824028882*^9, 3.5949678300432262`*^9}, 
   3.5955785446821384`*^9, 3.614861861593943*^9, 3.6148635019680243`*^9, 
   3.6186421768573666`*^9, 
   3.6186423423828335`*^9},ExpressionUUID->"cd8bb374-beef-4448-9b51-\
004e8076d8fc"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "smh", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5948873343559256`*^9, 3.5948874290636916`*^9}, {
   3.5948874685785613`*^9, 3.5948875091386323`*^9}, 3.5949678425159397`*^9, 
   3.59557854662525*^9, 3.614861861609543*^9, 3.6148635019836245`*^9, 
   3.6186421777854195`*^9, 
   3.618642342387834*^9},ExpressionUUID->"9ff7aacb-cdaa-4f8c-9d18-\
9776cf203836"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dV", "[", "smh", "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5950508613521795`*^9, 3.5950508830986176`*^9}, {
   3.5950509142830725`*^9, 3.5950509198678827`*^9}, 
   3.5955785474242954`*^9},ExpressionUUID->"d289c1e8-f8e6-48e6-8093-\
ba066eefcedd"],

Cell["The volume of the 3-sphere is obtained by an Integration:", "Text",
 CellChangeTimes->{{3.595051020410059*^9, 3.595051070501747*^9}, {
  3.6170769795926647`*^9, 
  3.6170769810434675`*^9}},ExpressionUUID->"4e6162c4-42d8-4d6b-a61b-\
975e15a78084"],

Cell[BoxData[
 RowBox[{"?", "Integrate"}]], "Input",
 CellChangeTimes->{{3.5949685955800123`*^9, 3.5949686029754353`*^9}, 
   3.594970020744527*^9},ExpressionUUID->"19b92b45-7af9-4317-8b89-\
a7a7bacc5e24"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"2", "*", "Pi"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], 
      RowBox[{"Pi", "/", "2"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{
        RowBox[{"-", "Pi"}], "/", "2"}], 
       RowBox[{"Pi", "/", "2"}]], 
      RowBox[{
       RowBox[{
        RowBox[{"dV", "[", "smh", "]"}], "[", 
        RowBox[{"u", ",", "v", ",", "w"}], "]"}], 
       RowBox[{"\[DifferentialD]", "u"}], 
       RowBox[{"\[DifferentialD]", "v"}], 
       RowBox[{"\[DifferentialD]", "w"}]}]}]}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5949688159786186`*^9, 3.5949688817713814`*^9}, {
   3.5949689981080356`*^9, 3.5949690241395245`*^9}, {3.594969101804967*^9, 
   3.594969106379228*^9}, {3.5949691409732065`*^9, 3.594969173772083*^9}, 
   3.595578548961384*^9, {3.6130230655571976`*^9, 
   3.613023096004939*^9}},ExpressionUUID->"c4da9fb4-9f2b-4970-af1a-\
d6ba8216c613"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6234030159098167`*^9, 
  3.6234030159098167`*^9}},ExpressionUUID->"39dc236c-6c92-4508-9121-\
b889175b0fe3"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2. Absolute  Differential of Tangent Vector Fields", "Subsection",
 CellChangeTimes->{{3.5949730418953266`*^9, 3.5949731082711234`*^9}, {
   3.595077070522224*^9, 3.5950771362139397`*^9}, 3.613023169371135*^9, 
   3.6130232430183477`*^9, 3.6132201257627344`*^9, {3.6186449363901987`*^9, 
   3.6186449391503563`*^9}, 3.618719499291278*^9, {3.6237633284052057`*^9, 
   3.623763333506415*^9}, 3.624285203784027*^9, {3.62583352307448*^9, 
   3.625833526615686*^9}, 3.6260741531985583`*^9, {3.698935381414978*^9, 
   3.698935383351055*^9}, 3.699008267834877*^9, 3.707887441611555*^9, 
   3.707887513331686*^9},ExpressionUUID->"2e4a8a4e-f278-4288-b82f-\
376858181454"],

Cell["\<\
We consider a general immersion smf[f[u...] into the n-dimensional Euclidean \
space, n = dim, e.g.\
\>", "Text",
 CellChangeTimes->{{3.595077178240413*^9, 3.595077208239266*^9}, {
   3.5951342404834337`*^9, 3.595134291859373*^9}, {3.595134540339585*^9, 
   3.595134634923995*^9}, {3.5953172126101613`*^9, 3.5953174521128597`*^9}, 
   3.596550784997245*^9, {3.596550826181317*^9, 3.596550833123329*^9}, {
   3.6128504259769535`*^9, 3.6128504380646443`*^9}, 3.6130232789364023`*^9, {
   3.6205365554152803`*^9, 
   3.620536569598091*^9}},ExpressionUUID->"5c2cc25d-b509-41d9-9e8b-\
e2f4ea58a32e"],

Cell[BoxData[
 RowBox[{"?", "smf"}]], "Input",
 CellChangeTimes->{{3.6128502638746815`*^9, 
  3.612850266340822*^9}},ExpressionUUID->"efb7ea1f-46f8-416a-8b5e-\
2a23e2931e1d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", 
  RowBox[{
   RowBox[{"smf", "[", "f", "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612850301110811*^9, 3.612850367250594*^9}, {
   3.625893471726448*^9, 3.6258934976848936`*^9}, 
   3.627287506611168*^9},ExpressionUUID->"a3fcfa9b-5380-4695-98c1-\
6b07fd16d1ae"],

Cell[CellGroupData[{

Cell["4.2.1. The Total Differential of a Tangent Vector Field", \
"Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, {
   3.595600920663969*^9, 3.5956009641674576`*^9}, {3.59560157753554*^9, 
   3.595601600231838*^9}, 3.613023249569722*^9, 3.613127844538868*^9, {
   3.6237634734230604`*^9, 3.6237634788362703`*^9}, 3.623765148910754*^9, 
   3.7078875195231943`*^9, {3.70790465671204*^9, 3.707904667976939*^9}, 
   3.707904698512167*^9},ExpressionUUID->"9e11b5e3-9154-4863-b121-\
e2b9743aaacd"],

Cell["\<\
To demonstrate the calculations we consider in this subsection a general \
surface in the 4-dimensional Euclidean space:\
\>", "Text",
 CellChangeTimes->{{3.699007268635129*^9, 
  3.6990073611066227`*^9}},ExpressionUUID->"c4038bcd-e4eb-482e-9105-\
9e70d27c88c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"dim", ",", "f"}], "]"}], ";", 
  RowBox[{"dim", "  ", "=", " ", "4"}], ";", 
  RowBox[{"mf", " ", "=", "2"}], ";", 
  RowBox[{
   RowBox[{"smf", "[", "f", "]"}], "[", 
   RowBox[{
    RowBox[{"u", "[", "1", "]"}], ",", 
    RowBox[{"u", "[", "2", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5953179973180437`*^9, 3.595318037226327*^9}, {
   3.595318077618637*^9, 3.5953182349966383`*^9}, {3.5953190274689655`*^9, 
   3.5953190679322796`*^9}, {3.5953233167050047`*^9, 3.595323324640459*^9}, 
   3.595918668773734*^9, {3.5959188539148593`*^9, 3.59591887143369*^9}, {
   3.698997384008793*^9, 
   3.6989973879949617`*^9}},ExpressionUUID->"efe326ea-32f3-4ea0-a448-\
c3c79f97dea7"],

Cell["A general  tangent vector field on this surface", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.5953235604669476`*^9, 3.595323569649472*^9}, {
   3.5953236189212904`*^9, 3.5953236679780965`*^9}, 3.595323711259572*^9, {
   3.5953239422667847`*^9, 3.5953239750656605`*^9}, {3.5955788337836742`*^9, 
   3.5955788569419994`*^9}, 3.613023988817005*^9, {3.699007436202113*^9, 
   3.6990074904253063`*^9}, 
   3.699009686303121*^9},ExpressionUUID->"dc443a1f-f65a-4ef4-a697-\
533804fe10d1"],

Cell[BoxData[
 RowBox[{"?", "tvf"}]], "Input",
 CellChangeTimes->{{3.6989115254330187`*^9, 
  3.698911545523973*^9}},ExpressionUUID->"6717af7f-bb2c-46b4-b90a-\
4fdf2d442a4f"],

Cell["is given by", "Text",
 CellChangeTimes->{{3.699007513091764*^9, 
  3.699007526297662*^9}},ExpressionUUID->"187aa895-2543-47b5-954a-\
4f086d5940e5"],

Cell[BoxData[
 RowBox[{"vx", ":=", " ", 
  RowBox[{
   RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5958287448867464`*^9, 3.595828758252511*^9}, {
  3.595828837669053*^9, 
  3.5958288760612493`*^9}},ExpressionUUID->"b798724b-8a93-4b59-a4fa-\
ab82d4f74fd5"],

Cell[BoxData[
 RowBox[{"vx", "[", 
  RowBox[{
   RowBox[{"u", "[", "1", "]"}], ",", 
   RowBox[{"u", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5953239886694393`*^9, 3.595324018282133*^9}, {
  3.698995577928173*^9, 
  3.698995611290169*^9}},ExpressionUUID->"0500925d-d422-4058-bda4-\
89d2a6d293c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "1", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "2", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
       RowBox[{
        RowBox[{"u", "[", "1", "]"}], ",", 
        RowBox[{"u", "[", "2", "]"}]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"u", "[", "1", "]"}], ",", 
        RowBox[{"u", "[", "2", "]"}]}], "]"}]}], "+", 
     RowBox[{"Clear", "[", 
      RowBox[{"dim", ",", "f"}], "]"}]}], ";", 
    RowBox[{"dim", "  ", "=", " ", "4"}], ";", 
    RowBox[{"mf", " ", "=", "2"}], ";", 
    RowBox[{
     RowBox[{
      RowBox[{"smf", "[", "f", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], 
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "3", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "4", "]"}], 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}]}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.707904098313611*^9, 
  3.70790409836856*^9}},ExpressionUUID->"8471c876-dae2-402d-9373-\
f95465b51445"],

Cell[TextData[{
 "The  ",
 StyleBox["total differential",
  FontColor->RGBColor[0, 0, 1]],
 " d[vx][u[1],u[2]] of the vector field vx is not tangential since it \
contains derivatives of second order of the immersion smf[f]:"
}], "Text",
 CellChangeTimes->{{3.5955793572066126`*^9, 3.5955793920946083`*^9}, {
   3.595579591878035*^9, 3.595579659893925*^9}, {3.595918977841477*^9, 
   3.595919013191139*^9}, {3.6131269223805656`*^9, 3.6131269457806063`*^9}, 
   3.61744117906815*^9, {3.623131398410351*^9, 3.623131400765955*^9}, {
   3.698995648265358*^9, 
   3.698995653689046*^9}},ExpressionUUID->"b01f6264-7b03-4d39-bf8c-\
b4f213cb121d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", "vx", "]"}], "[", 
  RowBox[{
   RowBox[{"u", "[", "1", "]"}], ",", 
   RowBox[{"u", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.595324180746425*^9, 3.5953242505304165`*^9}, {
  3.69899567056424*^9, 
  3.698995676003022*^9}},ExpressionUUID->"b5f5a934-fb40-4dc2-9b30-\
21e19f909a8e"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.596089846720524*^9, 
  3.5960898684981613`*^9}},ExpressionUUID->"c2d80f76-0997-45b9-b1f2-\
f32a7fb43348"],

Cell["It may be created also with the built-in operation D", "Text",
 CellChangeTimes->{{3.612856097673535*^9, 3.6128561379208364`*^9}, {
   3.6128563706971507`*^9, 3.612856373881333*^9}, {3.623131453249448*^9, 
   3.6231314831879005`*^9}, 3.623764212879959*^9, {3.6990065452179728`*^9, 
   3.699006555401863*^9}},ExpressionUUID->"69a3fcf6-05f0-45b3-a1a2-\
71092e3e97d2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "vx", "]"}], "[", 
   RowBox[{
    RowBox[{"u", "[", "1", "]"}], ",", 
    RowBox[{"u", "[", "2", "]"}]}], "]"}], "==", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"vx", "[", 
     RowBox[{
      RowBox[{"u", "[", "1", "]"}], ",", 
      RowBox[{"u", "[", "2", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "}"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.595324180746425*^9, 3.5953242505304165`*^9}, {
  3.595324337972418*^9, 3.5953243435797386`*^9}, {3.698995715114272*^9, 
  3.6989957437964907`*^9}},ExpressionUUID->"9795bfc4-b966-4869-9a47-\
30a687c37ebd"],

Cell["\<\
This is a field of linear maps depending on the point smf[f][u[1],u[2]] of \
the immersion; for the variable tangent vector of the immersion defined at \
this point by\
\>", "Text",
 CellChangeTimes->{{3.5955801071185055`*^9, 3.5955803651262627`*^9}, {
  3.613127181434941*^9, 3.6131271871302667`*^9}, {3.6989972592937*^9, 
  3.698997262415344*^9}, {3.698999008050437*^9, 3.698999049440728*^9}, {
  3.6990076297604713`*^9, 3.699007634808413*^9}, {3.707888287399136*^9, 
  3.707888427300087*^9}},ExpressionUUID->"9109b17c-ce2f-4400-b88e-\
7811abb07c2e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{"s", ",", "mf"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.698999053319072*^9, 3.698999053320809*^9}, {
  3.699007836908072*^9, 
  3.699007837647204*^9}},ExpressionUUID->"78a50c4d-5f56-42d3-8ad8-\
843edaef6e69"],

Cell["the value", "Text",
 CellChangeTimes->{{3.707888499837099*^9, 
  3.7078885052364693`*^9}},ExpressionUUID->"447a4385-7e0f-4f00-a671-\
7c153a2703d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "vx", "]"}], "[", 
   RowBox[{
    RowBox[{"u", "[", "1", "]"}], ",", 
    RowBox[{"u", "[", "2", "]"}]}], "]"}], ".", 
  RowBox[{"vec", "[", 
   RowBox[{"s", ",", "mf"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.699007695392446*^9, 3.699007717689005*^9}, {
  3.6990078541407146`*^9, 
  3.69900785667908*^9}},ExpressionUUID->"b961d682-bb87-4afe-a008-\
1a35c90ca7ee"],

Cell[TextData[{
 "is a vector in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]],ExpressionUUID->
  "b9814f29-156a-4673-8bf6-ae19b6215427"],
 ". Applying the differentiation rules we obtain the  ",
 StyleBox["formula",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5955984005678277`*^9, 3.595598438158978*^9}, 
   3.6990077577912083`*^9, {3.707888519926742*^9, 3.707888540891564*^9}},
 CellTags->"dtt(1)",ExpressionUUID->"9f6db39f-e9cc-4637-990d-0526d5a66653"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{"d", "[", "vx", "]"}], " ", "\[Equal]", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", "1", "mf"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"d", "[", 
          RowBox[{
           RowBox[{"tv", "[", "i", "]"}], "[", 
           RowBox[{"smf", "[", "f", "]"}], "]"}], "]"}], ")"}], "*", 
        RowBox[{"\[Xi]", "[", "i", "]"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"tv", "[", "i", "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "*", 
        RowBox[{"d", "[", 
         RowBox[{"\[Xi]", "[", "i", "]"}], 
         StyleBox["]", "Input"]}]}]}], ")"}], "                                      ", 
     RowBox[{"(", "1", ")"}], " "}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595598463490427*^9, 3.5955984931051207`*^9}, {
   3.5955985511484404`*^9, 3.595598594362912*^9}, {3.5955986327071056`*^9, 
   3.5955986452108207`*^9}, {3.595598683170992*^9, 3.595598691723481*^9}, {
   3.595598737060074*^9, 3.595598913628173*^9}, 3.595599919420701*^9, 
   3.5956003320353017`*^9, {3.595920206461307*^9, 3.595920210028511*^9}, {
   3.6258068411361246`*^9, 3.6258068421813264`*^9}, {3.699006737715747*^9, 
   3.699006774121251*^9}, {3.7078888842471657`*^9, 
   3.707888934442313*^9}},ExpressionUUID->"a0a1cf26-2052-48ac-8b87-\
e7142018e88e"],

Cell["\<\
Evaluating both sides of equation (1) for the tangent vector vec[s,mf] yields\
\>", "Text",
 CellChangeTimes->{{3.59559905624033*^9, 3.595599109839396*^9}, {
  3.6237644692070093`*^9, 3.6237644911874485`*^9}, {3.698999868265614*^9, 
  3.698999891489276*^9}, {3.70789323124993*^9, 
  3.707893317058155*^9}},ExpressionUUID->"98cb3cd5-c822-455d-8ab9-\
e54331af8221"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "vx", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], ".", 
     RowBox[{"vec", "[", 
      RowBox[{"s", ",", "mf"}], "]"}]}], "==", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"d", "[", 
             RowBox[{
              RowBox[{"tv", "[", "i", "]"}], "[", 
              RowBox[{"smf", "[", "f", "]"}], "]"}], "]"}], "[", 
            RowBox[{
             RowBox[{"u", "[", "1", "]"}], ",", 
             RowBox[{"u", "[", "2", "]"}]}], "]"}], ".", 
           RowBox[{"vec", "[", 
            RowBox[{"s", ",", "mf"}], "]"}]}], ")"}], "*", 
         RowBox[{
          RowBox[{"\[Xi]", "[", "i", "]"}], "[", 
          RowBox[{
           RowBox[{"u", "[", "1", "]"}], ",", 
           RowBox[{"u", "[", "2", "]"}]}], "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"tv", "[", "i", "]"}], "[", 
           RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
          RowBox[{
           RowBox[{"u", "[", "1", "]"}], ",", 
           RowBox[{"u", "[", "2", "]"}]}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"d", "[", 
             RowBox[{"\[Xi]", "[", "i", "]"}], 
             StyleBox["]", "Input"]}], "[", 
            RowBox[{
             RowBox[{"u", "[", "1", "]"}], ",", 
             RowBox[{"u", "[", "2", "]"}]}], "]"}], ".", 
           RowBox[{"vec", "[", 
            RowBox[{"s", ",", "mf"}], "]"}]}], 
          StyleBox[")", "Input"]}]}]}], 
       StyleBox[")", "Input"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}]}], "]"}]}], " ", "]"}], "  "}]], "Input",
 CellChangeTimes->{{3.70788884366216*^9, 3.707888844984083*^9}, {
   3.7078889422779016`*^9, 3.707888947905059*^9}, 3.707888981397821*^9, 
   3.707889051349318*^9, 3.707889098281761*^9, 3.707889152377779*^9, {
   3.707889188891906*^9, 3.70788921800791*^9}, 3.707889362392819*^9, 
   3.707889750908505*^9, 3.707889790143712*^9, {3.7078898327409163`*^9, 
   3.707889911125952*^9}, {3.707891460325528*^9, 3.7078914718181343`*^9}, 
   3.707891533122959*^9, {3.707891747809173*^9, 3.707891772359824*^9}, {
   3.707891991754108*^9, 3.707892005159162*^9}, {3.707892035902925*^9, 
   3.7078920439075203`*^9}, {3.7078924267102327`*^9, 3.707892510941432*^9}, {
   3.7078925415972633`*^9, 3.7078926076591043`*^9}, {3.707892776835189*^9, 
   3.707892851923212*^9}, {3.707892997981181*^9, 
   3.707893053171929*^9}},ExpressionUUID->"8003902a-b4a4-4c96-8846-\
77419f3d7ff5"],

Cell["confirming formula (1). Thus we proved", "Text",
 CellChangeTimes->{{3.707893388290432*^9, 3.707893403625861*^9}, {
  3.707903692591434*^9, 
  3.707903720599468*^9}},ExpressionUUID->"ef7b550e-2c3b-4859-b2c2-\
2e18d1d9c21c"],

Cell[TextData[{
 StyleBox["Lemma 2",
  FontColor->RGBColor[0, 0, 1]],
 ". The total differential of a tangent vector field vx satisfies formula \
(1). \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.595600549015712*^9, 3.5956005533359594`*^9}, {
   3.5959200264320097`*^9, 3.5959200392477427`*^9}, {3.595920071487587*^9, 
   3.5959201138950124`*^9}, {3.5959202427443824`*^9, 
   3.5959202716950383`*^9}, {3.6990095820325603`*^9, 3.69900958501655*^9}, 
   3.707903684935355*^9, 3.707903730623453*^9, {3.707904515372527*^9, 
   3.70790454192873*^9}},ExpressionUUID->"5cf87b02-44ae-45b7-b56f-\
3e2aee319898"],

Cell["\<\
 In this formula the second derivatives of the immersion  are hidden, e,g,\
\>", "Text",
 CellChangeTimes->{{3.596090908988789*^9, 
  3.596090974852105*^9}},ExpressionUUID->"79b1e99d-6897-4922-a4aa-\
1b3aef6602ac"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{
     RowBox[{"tv", "[", "1", "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5960904708776197`*^9, 3.5960905722621975`*^9}, {
   3.596090780007763*^9, 3.5960908043126054`*^9}, 
   3.6258068490765386`*^9},ExpressionUUID->"05f46994-2e30-4215-838e-\
9f8e6ddb4dda"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.2. The Absolute Differential of a Tangent Vector Field", \
"Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, 
   3.613127853739394*^9, 3.6132229815716324`*^9, 3.618719633997514*^9, 
   3.6187568869796286`*^9, 3.623765154089963*^9, 3.624285176327979*^9, 
   3.699008293571306*^9, 3.6990968987727747`*^9, 3.7079047065295687`*^9, 
   3.7079693100696363`*^9},ExpressionUUID->"e21f3bee-c927-47ce-8691-\
208ccf655c05"],

Cell[TextData[{
 "For immersions the absolute differential will be defined as the orthogonal \
projection of the total differential of the vector field into the tangent \
space of the immersion at each point. First we describe this projection \
algebraically. Let ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]],ExpressionUUID->
  "af1e9aa0-b8b7-4a25-9000-1d86e937067a"],
 " \[Subset] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["E", "n"], " "}], TraditionalForm]],ExpressionUUID->
  "9651ff2f-7e05-47c0-b4af-c9a217159b15"],
 "be an m.dimensional subspace of the Euclidean n-space, and {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]],ExpressionUUID->
  "b4a0fd98-2f42-43b9-b588-5ff84fef5a18"],
 "},  i = 1,...,m, an arbitrary basis of  ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]],ExpressionUUID->
  "06173832-c6df-4b27-8e80-d6d620287a3f"],
 " with scalar products"
}], "Text",
 CellChangeTimes->{{3.5956512820004816`*^9, 3.5956514597471943`*^9}, {
  3.59565153142932*^9, 3.595651640785512*^9}, {3.5956516917040014`*^9, 
  3.595651910665986*^9}, {3.5956520363086066`*^9, 3.595652063702255*^9}, {
  3.5956521682536383`*^9, 3.5956522065673056`*^9}, {3.5959237048705378`*^9, 
  3.595923706157612*^9}, {3.596521616120858*^9, 
  3.5965216273216777`*^9}},ExpressionUUID->"9f4cfc8f-87bb-43bc-b23e-\
85abab9eee39"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["g", "ij"], ":=", " ", 
  RowBox[{
   FormBox[
    SubscriptBox["b", "i"],
    TraditionalForm], ".", 
   FormBox[
    SubscriptBox["b", "j"],
    TraditionalForm]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5956521183335505`*^9, 3.595652155602016*^9}, {
  3.595652235962557*^9, 3.595652270813018*^9}, {3.5956523113418894`*^9, 
  3.595652327425517*^9}, {3.6238395209583635`*^9, 3.6238395286491766`*^9}, {
  3.623839642966178*^9, 
  3.6238396435901785`*^9}},ExpressionUUID->"f63fe126-7c27-44d5-9bce-\
c7fa94078afc"],

Cell[TextData[{
 "Since the matrix {",
 Cell[BoxData[
  SubscriptBox["g", "ij"]],
  CellChangeTimes->{{3.5956521183335505`*^9, 3.595652155602016*^9}, {
   3.595652235962557*^9, 3.595652270813018*^9}, {3.5956523113418894`*^9, 
   3.595652327425517*^9}},ExpressionUUID->
  "87521b9a-2ecd-4a58-b1c4-33e45fb7a84e"],
 "} is symmetric and positive definite, it has positive determinant: "
}], "Text",
 CellChangeTimes->{{3.5956523740071993`*^9, 3.5956524288724957`*^9}, 
   3.595652518980466*^9, {3.5956526437956047`*^9, 3.595652659380496*^9}, 
   3.699079387677319*^9},ExpressionUUID->"ef54a6d3-a474-401e-a491-\
11c37682de18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Det", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["g", 
      RowBox[{"i", ",", "j"}]], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "m"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", "m"}], "}"}]}], "]"}], "]"}], ">", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5956525363104568`*^9, 3.5956526283587217`*^9}, 
   3.614861861687543*^9, 3.6148635019836245`*^9, {3.6187389427887344`*^9, 
   3.6187389469851418`*^9}, 3.623839545216406*^9, {3.699079899532947*^9, 
   3.699079901009775*^9}},ExpressionUUID->"86b07100-f371-4735-9959-\
6a52a783ac7e"],

Cell[TextData[{
 "Let vy = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "T"], TraditionalForm]],ExpressionUUID->
  "a31115a2-2127-47bb-85c9-107b3eb5a4cc"],
 "[vw]  \[Element] ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]],ExpressionUUID->
  "ef70a082-2276-4f48-9666-a66d32b5f099"],
 " be the orthogonal projection  of the vector  vw \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]],ExpressionUUID->
  "9b1e6bf3-e33b-43ed-aa96-655bd622d646"],
 ". Then the vector \nvy - vw is orthogonal to ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]],ExpressionUUID->
  "3ae0ba67-204b-49fd-bfa6-acf1c50b8935"],
 " :"
}], "Text",
 CellChangeTimes->{{3.595653006355342*^9, 3.595653056932235*^9}, {
   3.5956530998836913`*^9, 3.595653233396328*^9}, 3.595653599732281*^9, {
   3.5956536758766365`*^9, 3.5956537832277765`*^9}, {3.595830077103945*^9, 
   3.5958300802491245`*^9}, 
   3.597207643518685*^9},ExpressionUUID->"b58f7618-c4df-4767-8fd1-\
4b065e8b157d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"vy", "-", "vw"}], ")"}], ".", 
    SubscriptBox["b", "i"]}], " ", "\[Equal]", " ", "0"}], ",", " ", 
  RowBox[{
   RowBox[{
    StyleBox["or",
     FontColor->GrayLevel[0]], "  ", 
    RowBox[{"vy", ".", 
     SubscriptBox["b", "i"]}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"vw", ".", 
     SubscriptBox["b", "i"]}], "  ", "for", " ", "i", " ", 
    StyleBox[
     RowBox[{"=", " ", "1"}],
     FontColor->RGBColor[0, 0, 1]]}]}], 
  StyleBox[",",
   FontColor->RGBColor[0, 0, 1]], 
  StyleBox["  ",
   FontColor->RGBColor[0, 0, 1]], 
  StyleBox["...",
   FontColor->RGBColor[0, 0, 1]], 
  StyleBox[",",
   FontColor->RGBColor[0, 0, 1]], 
  StyleBox[" ",
   FontColor->RGBColor[0, 0, 1]], 
  RowBox[{
   StyleBox["m",
    FontColor->RGBColor[0, 0, 1]], "."}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595653794627428*^9, 3.5956538074371614`*^9}, {
   3.595653843238209*^9, 3.595653924069832*^9}, {3.5958300813321867`*^9, 
   3.5958300830922875`*^9}, 3.6187390440329123`*^9, 
   3.699079915165524*^9},ExpressionUUID->"dac7f6d6-9c4b-40e8-a932-\
b149c2c5b001"],

Cell["Let the basis decomposition of vy be", "Text",
 CellChangeTimes->{{3.595654502819935*^9, 
  3.595654532756647*^9}},ExpressionUUID->"6d974933-c4ea-4ee3-970b-\
6e98ad7f4578"],

Cell[BoxData[
 RowBox[{"vy", " ", ":=", " ", 
  RowBox[{
   SubsuperscriptBox["\[Sum]", "1", "m"], " ", 
   RowBox[{
    SubscriptBox["b", "i"], " ", 
    SubscriptBox["\[Eta]", "i"]}]}]}]], "Input",
 CellChangeTimes->{{3.5956545443553104`*^9, 3.595654548765563*^9}, {
   3.595654614775338*^9, 3.595654647116188*^9}, {3.5956547153400903`*^9, 
   3.595654823176258*^9}, {3.618739087650589*^9, 3.618739097431806*^9}, {
   3.618739128663061*^9, 3.618739144497089*^9}, 
   3.69907991675704*^9},ExpressionUUID->"58fcef83-c115-42a4-a4f7-\
eba0efc77480"],

Cell["Then vy is defined by the linear system", "Text",
 CellChangeTimes->{{3.5956548684278464`*^9, 
  3.595654892356215*^9}},ExpressionUUID->"5b1f7b5a-513f-4e34-a2b0-\
e66c8980c7a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vy", ".", 
   SubscriptBox["b", "j"]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["\[CapitalSigma]", "1", "m"], " ", 
     SubscriptBox["b", "i"], " ", 
     SubscriptBox["\[Eta]", "i"]}], ")"}], ".", 
   SubscriptBox["b", "j"]}], " ", "\[Equal]", " ", 
  RowBox[{"vw", ".", 
   SubscriptBox["b", "j"]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.595654941781042*^9, {3.595654975757985*^9, 3.5956550229336834`*^9}, {
   3.595655087159357*^9, 3.595655097189931*^9}, 
   3.5958300846603775`*^9},ExpressionUUID->"45880239-f097-49f6-b26c-\
765c1ed92c93"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[CapitalSigma]", 
     RowBox[{"i", "=", "1"}], "m"], " ", 
    SubscriptBox["g", "ji"], " ", 
    SubscriptBox["\[Eta]", "i"]}], " ", "\[Equal]", " ", 
   RowBox[{"vw", ".", 
    SubscriptBox["b", "j"]}]}], ",", " ", 
  RowBox[{"j", " ", "=", " ", "1"}], ",", "  ", "...", ",", " ", 
  RowBox[{"m", "."}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.595655150854*^9, {3.595655192325372*^9, 3.595655205189108*^9}, {
   3.595655252685825*^9, 3.595655302854694*^9}, {3.595655373710747*^9, 
   3.5956553766539154`*^9}, 3.5958300860184546`*^9, {3.699079614208394*^9, 
   3.699079616739855*^9}},ExpressionUUID->"e29c256f-bb9a-4010-a1cf-\
06a4a46532d2"],

Cell[TextData[{
 "Now let {",
 Cell[BoxData[
  SubscriptBox["h", "ki"]],
  CellChangeTimes->{
   3.595655150854*^9, {3.595655192325372*^9, 3.595655205189108*^9}, {
    3.595655252685825*^9, 3.595655302854694*^9}, {3.595655373710747*^9, 
    3.5956553766539154`*^9}},ExpressionUUID->
  "3513af7f-31af-4240-8dbc-9d86a5ca15c6"],
 "} = Invers",
 "e[",
 "{",
 Cell[BoxData[
  SubscriptBox["g", "ji"]],
  CellChangeTimes->{
   3.595655150854*^9, {3.595655192325372*^9, 3.595655205189108*^9}, {
    3.595655252685825*^9, 3.595655302854694*^9}, {3.595655373710747*^9, 
    3.5956553766539154`*^9}},ExpressionUUID->
  "d63e6eac-bfca-4824-993f-98d44c720fd0"],
 "}] be the inverse matrix:"
}], "Text",
 CellChangeTimes->{{3.595655385316411*^9, 3.5956555192920732`*^9}, 
   3.6148618617187433`*^9, 
   3.6149177933713636`*^9},ExpressionUUID->"a92c64d6-e5c5-4696-a4d2-\
0c1088750125"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[CapitalSigma]", 
     RowBox[{"j", "=", "1"}], "m"], " ", 
    SubscriptBox["h", "kj"], " ", 
    SubscriptBox["g", "ji"]}], " ", "\[Equal]", " ", 
   SubscriptBox["\[Delta]", "ki"]}], ",", " ", "k", ",", 
  RowBox[{"i", " ", "=", " ", "1"}], ",", "...", ",", "m", ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5956555563181915`*^9, 3.5956556989513493`*^9}, {
  3.597207858081462*^9, 
  3.5972078683930798`*^9}},ExpressionUUID->"fb5b0a89-b721-4ac4-b6a8-\
047a0e69d8d6"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  SubscriptBox["\[Delta]", "ki"]],
  CellChangeTimes->{{3.595655736429493*^9, 3.595655758124734*^9}, {
   3.595655816518074*^9, 3.5956558518540955`*^9}},ExpressionUUID->
  "9447a603-4412-471f-8baf-d185ab97a6f9"],
 " are the coefficients of the identity matrix"
}], "Text",
 CellChangeTimes->{{3.5956562970605593`*^9, 3.5956563376038785`*^9}, {
  3.5972078829323053`*^9, 
  3.5972078829323053`*^9}},ExpressionUUID->"790ca107-e74f-42ca-bad3-\
2d56a2e1a3eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Delta]", "ki"], " ", ":=", " ", 
   RowBox[{"KroneckerDelta", "[", 
    RowBox[{"k", ",", "i"}], "]"}]}], ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595655736429493*^9, 3.595655758124734*^9}, {
  3.595655816518074*^9, 3.5956558518540955`*^9}, {3.597207915848363*^9, 
  3.5972079246779785`*^9}},ExpressionUUID->"6237afd7-0622-4db9-ba0c-\
ac4580c3d53f"],

Cell[BoxData[
 RowBox[{"KroneckerDelta", "[", 
  RowBox[{"k", ",", "k"}], "]"}]], "Input",
 CellChangeTimes->{
  3.595655988030884*^9},ExpressionUUID->"52c103ff-2472-4224-a30b-\
1495dd8b4759"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"k", " ", "\[NotEqual]", " ", "j"}], ",", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"KroneckerDelta", "[", 
     RowBox[{"k", ",", "j"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5956560378387327`*^9, 3.595656081358222*^9}, {
  3.5956561420766945`*^9, 
  3.5956562544131203`*^9}},ExpressionUUID->"6b7003c7-78d7-4fb6-b80f-\
a0e36eac6ae1"],

Cell["Then it follows", "Text",
 CellChangeTimes->{{3.595656395755204*^9, 
  3.5956564124361587`*^9}},ExpressionUUID->"98887cef-1a8a-46bf-9088-\
18b2a0c7becc"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Eta]", "k"], " ", "\[Equal]", " ", 
  RowBox[{
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"j", "=", "1"}], "m"], " ", 
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"i", "=", "1"}], "m"], 
   SubscriptBox["h", "kj"], " ", 
   SubscriptBox["g", "ji"], 
   SubscriptBox["\[Eta]", "i"]}], " ", "\[Equal]", " ", 
  RowBox[{
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"j", "=", "1"}], "m"], " ", 
   SubscriptBox["h", "kj"], 
   RowBox[{"(", 
    RowBox[{"vw", ".", 
     SubscriptBox["b", "j"]}], ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595656458933818*^9, 3.595656464461134*^9}, {
  3.595656501646261*^9, 3.595656551702124*^9}, {3.5956565823028746`*^9, 
  3.5956566318537083`*^9}, {3.595656665518634*^9, 3.5956566976144695`*^9}, {
  3.5958299906780014`*^9, 3.5958299933341537`*^9}, {3.618739232044442*^9, 
  3.6187392404840574`*^9}, {3.699079917871642*^9, 
  3.6990799204052067`*^9}},ExpressionUUID->"f91da7f6-8c6d-43b4-aa3c-\
2bd40560e6ca"],

Cell[TextData[{
 StyleBox["Lemma 3.",
  FontColor->RGBColor[0, 0, 1]],
 " With the notations fixed above the orthogonal projection of vw \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", 
    RowBox[{"n", "  "}]], TraditionalForm]],ExpressionUUID->
  "8962dd39-5c66-41ed-8838-0423f6ee5869"],
 "into ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["T", "x", "m"], TraditionalForm]],ExpressionUUID->
  "f35e71fa-e68e-46fb-b9f3-13e8c39613fb"],
 "   has the basis representation"
}], "Text",
 CellChangeTimes->{{3.5956567484743786`*^9, 3.5956567748518877`*^9}, {
   3.5956569489718466`*^9, 3.5956569986676893`*^9}, {3.5956570412541246`*^9, 
   3.5956570613162727`*^9}, {3.595658913543214*^9, 3.595658946260085*^9}, 
   3.5958299735670233`*^9, {3.5964511553473406`*^9, 3.596451158732547*^9}, {
   3.623840032748462*^9, 3.623840036289668*^9}, {3.6258953252125034`*^9, 
   3.6258953525593514`*^9}, {3.699009617688549*^9, 
   3.6990096185520773`*^9}},ExpressionUUID->"5a09168b-2444-4fb3-b22b-\
9bac445acacd"],

Cell[BoxData[
 RowBox[{"vy", " ", "\[Equal]", " ", 
  RowBox[{
   SubscriptBox["p", 
    RowBox[{
    "T", Cell["",ExpressionUUID->"2576497b-7a99-40dd-b8ba-a8ebea32ec33"]}]], 
   "[", "vw", "]"}], " ", "\[Equal]", "   ", 
  RowBox[{
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"k", "=", "1"}], "m"], 
   SubscriptBox["b", "k"], 
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"j", "=", "1"}], "m"], " ", 
   SubscriptBox["h", "kj"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"vw", ".", 
      SubscriptBox["b", "j"]}], ")"}], ".", 
    StyleBox["\[FilledSquare]",
     FontColor->GrayLevel[0]]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5956570679866543`*^9, 3.595657161678013*^9}, 
   3.5956572516071568`*^9, {3.595657289167305*^9, 3.595657366046702*^9}, {
   3.5958300874755383`*^9, 3.595830088452594*^9}, {3.5964511915706043`*^9, 
   3.596451239915089*^9}, {3.5964513203956304`*^9, 
   3.596451327946044*^9}},ExpressionUUID->"e1821d45-05dd-4412-9534-\
bf9f9d914e2c"],

Cell["\<\
We need the inverse  of the matrix {rgT[i,j][sf]} to define the projections \
into the tangent spaces:\
\>", "Text",
 CellChangeTimes->{
  3.5960911255015697`*^9, {3.5965226917583475`*^9, 3.596522735204424*^9}, {
   3.5965227667944794`*^9, 3.5965227936733265`*^9}, 3.613128297635784*^9, 
   3.6186421820496635`*^9, 3.618642342405835*^9, {3.660714637086093*^9, 
   3.660714644646209*^9}},ExpressionUUID->"0d97f242-9668-4cfa-9ca2-\
7fc050f6b765"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"inverse", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], "[", "g_", "]"}], "[", "u__", "]"}], ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", " ", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "u", "}"}], "]"}]}], ",", "k", ",", "h", ",", "mM"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"mM", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"g", "[", 
          RowBox[{"h", ",", "k"}], "]"}], "[", "u", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"h", ",", "m"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "m"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Inverse", "[", "mM", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.62417013795344*^9, 3.62417016631429*^9}, {
   3.6241702057979593`*^9, 3.6241704585808034`*^9}, 3.624170521495714*^9, {
   3.6241705601837816`*^9, 3.624170561010583*^9}, {3.6241706254230967`*^9, 
   3.6241706872616053`*^9}, {3.624170740254898*^9, 3.624170785058177*^9}, 
   3.6241708448530817`*^9},ExpressionUUID->"d737e8fe-1cba-44ea-a61a-\
63f8faf2d8b5"],

Cell[BoxData[
 RowBox[{"?", "inverse"}]], "Input",
 CellChangeTimes->{{3.62417231871247*^9, 3.624172440673485*^9}, {
   3.6241725619012976`*^9, 3.6241727013655424`*^9}, {3.6241727407712116`*^9, 
   3.6241728849934654`*^9}, 3.6241729245239344`*^9, {3.6259030986192017`*^9, 
   3.6259031014740067`*^9}},ExpressionUUID->"a50ed442-315e-4373-a7f9-\
39bcea5bdcc0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"invrgT", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], "[", "ff_", "]"}], "[", "u__", "]"}], ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"gg", ",", 
      RowBox[{"m", " ", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "u", "}"}], "]"}]}], ",", "k", ",", "h", ",", "v"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"gg", "[", 
        RowBox[{"h_", ",", "k_"}], "]"}], "[", "v__", "]"}], " ", ":=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"h", ",", "k"}], "]"}], "[", "ff", "]"}], "[", "v", "]"}]}], 
     " ", ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"inverse", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "[", "gg", "]"}], "[", "u", "]"}]}]}],
    "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.624170884040351*^9, 3.624170900295579*^9}, {
   3.624171093969919*^9, 3.6241711500052176`*^9}, {3.6241713588583846`*^9, 
   3.6241714807257986`*^9}, {3.6241715200222673`*^9, 
   3.6241715235322742`*^9}, {3.6241715692559543`*^9, 3.624171601516811*^9}, {
   3.624171647536892*^9, 3.62417169243377*^9}, {3.624172071452036*^9, 
   3.624172114539312*^9}, 3.6241721566281857`*^9, 
   3.624172272286789*^9},ExpressionUUID->"5437c38e-6a19-49a4-95c2-\
c6839234ff4f"],

Cell[BoxData[
 RowBox[{"?", "invrgT"}]], "Input",
 CellChangeTimes->{{3.623840427694356*^9, 3.623840456975607*^9}, {
   3.623840585831834*^9, 3.623840703877241*^9}, {3.623840781300177*^9, 
   3.623840815011836*^9}, {3.623840848551895*^9, 3.6238411098991537`*^9}, 
   3.623841177712473*^9, {3.6259035933450727`*^9, 
   3.6259035959814777`*^9}},ExpressionUUID->"d5e69197-9216-4a36-8d11-\
99034ec8b931"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"invrgT", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6241717142582088`*^9, 3.62417181163358*^9}, {
   3.624171854845656*^9, 3.624171911426955*^9}, 3.624171986026286*^9, 
   3.6241721716042123`*^9},ExpressionUUID->"c354d8a2-d197-4ed9-af21-\
2affe1a25d63"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"invrgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ".", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.624172975380024*^9, 3.6241729882812467`*^9}, {
  3.6241730189821005`*^9, 3.6241730980586395`*^9}, {3.6241731311462975`*^9, 
  3.6241733147118196`*^9}, {3.6990799218276978`*^9, 
  3.699079962145689*^9}},ExpressionUUID->"a4a5e15d-bc26-4b6f-87e0-\
b9097f525e8f"],

Cell[TextData[{
 StyleBox["Example 2.",
  FontColor->RGBColor[0, 0, 1]],
 " The sphere of radius r>0:"
}], "Text",
 CellChangeTimes->{{3.5965221197053423`*^9, 3.596522145663788*^9}, {
   3.596522200887885*^9, 3.596522218531516*^9}, {3.699009046964218*^9, 
   3.699009048116315*^9}, 
   3.699009364706068*^9},ExpressionUUID->"15fd1c59-c255-4ec1-baa0-\
9b154abc331b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"r", ">", "0"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.595660633590595*^9, 3.595660656702917*^9}, {
   3.595660697216234*^9, 3.595660726782925*^9}, {3.5956608079675684`*^9, 
   3.595660835895166*^9}, {3.596451415196997*^9, 3.5964514249782143`*^9}, {
   3.5965217603899117`*^9, 3.5965217906227646`*^9}, {3.5965219904279156`*^9, 
   3.5965220433744087`*^9}, {3.596522159454212*^9, 3.5965221709046326`*^9}, {
   3.5965222567671833`*^9, 3.5965222569387836`*^9}, 3.6148618617655435`*^9, 
   3.6148635020148244`*^9, 3.61864220699609*^9, 
   3.6186423424318366`*^9},ExpressionUUID->"5f3dec69-9549-46a4-ad7d-\
91aa6404c29a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"invrgT", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"r", ">", "0"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.595660633590595*^9, 3.595660656702917*^9}, {
   3.595660697216234*^9, 3.595660726782925*^9}, {3.5956608079675684`*^9, 
   3.595660835895166*^9}, {3.596451415196997*^9, 3.5964514249782143`*^9}, {
   3.5965217603899117`*^9, 3.5965217906227646`*^9}, {3.5965219904279156`*^9, 
   3.5965220433744087`*^9}, {3.596522159454212*^9, 3.5965221709046326`*^9}, 
   3.6148618617811437`*^9, 3.614863502030424*^9, 
   3.6187394898816953`*^9},ExpressionUUID->"78492d6d-ef49-4217-8b2a-\
4606e4f528a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", ".", "%%"}], ",", 
    RowBox[{"r", ">", "0"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.595660633590595*^9, 3.595660656702917*^9}, {
  3.595660697216234*^9, 3.595660726782925*^9}, {3.5956608079675684`*^9, 
  3.595660835895166*^9}, {3.596451415196997*^9, 3.5964514249782143`*^9}, {
  3.5965217603899117`*^9, 3.5965217906227646`*^9}, {3.5965219904279156`*^9, 
  3.5965220433744087`*^9}, {3.596522159454212*^9, 3.5965221709046326`*^9}, {
  3.5965222864852357`*^9, 
  3.5965223097448764`*^9}},ExpressionUUID->"5ead49f2-080a-4552-aef8-\
9dd8f332aa9f"],

Cell["\<\
OK. \[FilledRectangle]
\
\>", "Text",
 CellChangeTimes->{{3.596522418243067*^9, 
  3.596522439427904*^9}},ExpressionUUID->"29963d93-8694-4492-97ed-\
91431b4b61ce"],

Cell[TextData[{
 "Here is the definition of the ",
 StyleBox["field of tangent projections",
  FontColor->RGBColor[0, 0, 1]],
 " of the immersion ff[x...]:"
}], "Text",
 CellChangeTimes->{{3.5965229764900475`*^9, 3.596522995631281*^9}, {
  3.596523070556733*^9, 
  3.596523132165257*^9}},ExpressionUUID->"f5abfa98-4dda-45f0-bc47-\
374d3455dfbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pT", "[", "ff_", "]"}], "[", "x__", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "k", "]"}], "[", "ff", "]"}], "[", "x", "]"}], "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"invrgT", "[", 
            RowBox[{"k", ",", "j"}], "]"}], "[", "ff", "]"}], "[", "x", "]"}],
          "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"tv", "[", "j", "]"}], "[", "ff", "]"}], "[", "x", "]"}],
            ".", "#"}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}], "&"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5956711982508154`*^9, 3.5956714584426975`*^9}, {
   3.5956714915405903`*^9, 3.5956715370841956`*^9}, {3.595671585747979*^9, 
   3.595671613340557*^9}, {3.595671665565544*^9, 3.595671740565834*^9}, 
   3.6187394924557*^9, {3.6258068501217403`*^9, 
   3.625806851603743*^9}},ExpressionUUID->"363ae18f-d952-4779-b183-\
8b21c4c6be50"],

Cell[BoxData[
 RowBox[{"?", "pT"}]], "Input",
 CellChangeTimes->{{3.623914453021508*^9, 3.6239147640236545`*^9}, 
   3.6239148609466248`*^9, {3.6259037669777794`*^9, 
   3.6259037710493865`*^9}},ExpressionUUID->"d1484664-7896-4e1a-a2ed-\
1541e3d4eca5"],

Cell[TextData[{
 StyleBox["Example 3.",
  FontColor->RGBColor[0, 0, 1]],
 " The unit sphere"
}], "Text",
 CellChangeTimes->{{3.6239149035814996`*^9, 3.623914907855907*^9}, {
   3.62391617373573*^9, 3.623916180974143*^9}, {3.699009066508185*^9, 
   3.699009067588231*^9}, 
   3.6990093794980593`*^9},ExpressionUUID->"fc860fa6-4797-47f9-97b5-\
fe866dd9eb3d"],

Cell["The projection of a tangent vector is the vector itself:", "Text",
 CellChangeTimes->{{3.6239163166475816`*^9, 
  3.623916342044426*^9}},ExpressionUUID->"e2334918-a14e-4f87-aeee-\
a4504fb8a990"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pTsph", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"pT", "[", 
       RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "1", "]"}], "[", 
       RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", ">", "0"}], ",", 
      RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6238523551404347`*^9, 3.623852415481341*^9}, {
  3.6238524574298143`*^9, 3.623852489550271*^9}, {3.623852532185146*^9, 
  3.6238525727764173`*^9}, {3.623852900501793*^9, 3.6238529160082197`*^9}, {
  3.6238546605091753`*^9, 3.6238546765772033`*^9}, {3.6238555562667484`*^9, 
  3.6238556039716325`*^9}, {3.623855655077322*^9, 
  3.623855675497758*^9}},ExpressionUUID->"dfe75475-3779-4861-b6d9-\
fcb64ddc36b4"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "1", "]"}], "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.623855727180649*^9, 3.6238557502842894`*^9}, {
  3.623916232891034*^9, 
  3.623916258365879*^9}},ExpressionUUID->"20b95051-36b7-4c65-8e0f-\
87c665a08762"],

Cell["The projection of the normal vector is the null vector:", "Text",
 CellChangeTimes->{{3.6239163694068737`*^9, 3.623916397408923*^9}, {
  3.6239164858454785`*^9, 
  3.623916505673114*^9}},ExpressionUUID->"280121e8-bbcb-4a92-bf96-\
17d6f8cefa38"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pTsph", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"pT", "[", 
       RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"amf", "[", "3", "]"}], "[", 
       RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", ">", "0"}], ",", 
      RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6238523551404347`*^9, 3.623852415481341*^9}, {
  3.6238524574298143`*^9, 3.623852489550271*^9}, {3.623852532185146*^9, 
  3.6238525727764173`*^9}, {3.623852900501793*^9, 3.6238529160082197`*^9}, {
  3.6238546605091753`*^9, 3.6238546765772033`*^9}, {3.6238555562667484`*^9, 
  3.6238556039716325`*^9}, {3.623855655077322*^9, 3.623855675497758*^9}, {
  3.623855894679143*^9, 
  3.623855916862382*^9}},ExpressionUUID->"581eae12-6bd7-4ac5-9ff4-\
80009ffa86a7"],

Cell["Here is a random vector", "Text",
 CellChangeTimes->{{3.623918289782647*^9, 
  3.623918299517064*^9}},ExpressionUUID->"3e6b5709-0e5a-45fe-b551-\
8b8fcfb8cbd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{"vr", " ", "=", " ", 
   RowBox[{"randomv", "[", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.623916512864726*^9, 3.6239165278563523`*^9}, {
  3.625895946421194*^9, 
  3.625895951959204*^9}},ExpressionUUID->"c5925cfb-28ab-42a3-8342-\
23f33907fdf3"],

Cell["Its projection at the point sphero[1][u,v] is", "Text",
 CellChangeTimes->{{3.623918317160695*^9, 
  3.623918347237548*^9}},ExpressionUUID->"32bfbce0-f9a6-4bb1-b864-\
4ab232cfdd0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pTsph", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"pT", "[", 
       RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "[", "vr", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", ">", "0"}], ",", 
      RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6238523551404347`*^9, 3.623852415481341*^9}, {
   3.6238524574298143`*^9, 3.623852489550271*^9}, {3.623852532185146*^9, 
   3.6238525727764173`*^9}, {3.623852900501793*^9, 3.6238529160082197`*^9}, {
   3.6238546605091753`*^9, 3.6238546765772033`*^9}, {3.6238555562667484`*^9, 
   3.6238556039716325`*^9}, {3.623855655077322*^9, 3.623855675497758*^9}, {
   3.623855894679143*^9, 3.623855916862382*^9}, 3.623856005816738*^9, {
   3.623856100042904*^9, 3.623856105986514*^9}, {3.623916544860382*^9, 
   3.623916545359583*^9}, {3.6239179299368153`*^9, 3.6239179399988327`*^9}, {
   3.623918078558276*^9, 
   3.6239180790262775`*^9}},ExpressionUUID->"e1c35533-1930-4bfe-89a5-\
4f86060c9abb"],

Cell["\<\
The projections form a tangent vector field; we represent it by the arrows in \
the tangent planes:\
\>", "Text",
 CellChangeTimes->{{3.6239183852080145`*^9, 3.6239184414305134`*^9}, 
   3.625895918746746*^9},ExpressionUUID->"33f7914c-3786-40ff-991c-\
076a2e38c8b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"arr", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{"{", 
    RowBox[{"Red", ",", 
     RowBox[{"Arrowheads", "[", "0.03", "]"}], ",", 
     RowBox[{"Arrow", "[", 
      RowBox[{"Tube", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"sphero", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], ",", 
          RowBox[{
           RowBox[{"pTsph", "[", 
            RowBox[{"u", ",", "v"}], "]"}], "+", 
           RowBox[{
            RowBox[{"sphero", "[", "1", "]"}], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], "}"}], ",", "0.003"}], "]"}], 
      "]"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6238531941127977`*^9, 3.623853197966005*^9}, {
   3.6238543177141733`*^9, 3.623854450439206*^9}, {3.6238545220589323`*^9, 
   3.623854538423361*^9}, {3.623856261245988*^9, 3.6238562702160034`*^9}, {
   3.6238564022118354`*^9, 3.623856413896256*^9}, {3.6238564857393827`*^9, 
   3.6238565058478174`*^9}, {3.6239168142852554`*^9, 3.6239168464525123`*^9}, 
   3.6239168776837673`*^9, 3.6239169372758713`*^9, 3.6239169803475475`*^9, 
   3.6239170519360733`*^9, {3.6239171102645755`*^9, 3.6239171148353834`*^9}, 
   3.6239171473614407`*^9, {3.6239172534572268`*^9, 3.6239173025505133`*^9}, {
   3.623917342299383*^9, 3.6239173434849854`*^9}, 3.6239174393783536`*^9, 
   3.62391823446495*^9},ExpressionUUID->"cee5371a-f42a-4212-9a4a-\
4cccd558f18c"],

Cell[BoxData[
 RowBox[{"arr", "[", 
  RowBox[{"0", ",", 
   RowBox[{"-", ".4"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6238545919938545`*^9, 3.623854609309885*^9}, {
   3.6238547609733515`*^9, 3.6238547685705647`*^9}, 3.623854808366235*^9, 
   3.623854918455628*^9, {3.623856316610485*^9, 3.6238563203700914`*^9}, {
   3.6238565596991124`*^9, 3.623856588685963*^9}, 3.6238566793573227`*^9, 
   3.623917383764256*^9, {3.6239181891936703`*^9, 
   3.623918209302106*^9}},ExpressionUUID->"cd0cbe8f-a267-4a59-adc1-\
3c473e037335"],

Cell["Here is the picture of some vectors of this field:", "Text",
 CellChangeTimes->{{3.623918500975818*^9, 
  3.6239185237986584`*^9}},ExpressionUUID->"3954121a-bb02-4c78-9d5f-\
ce30cad6c0db"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"arr", "[", 
        RowBox[{"u", ",", "v"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", "0", ",", 
         RowBox[{"2", "*", "Pi"}], ",", " ", ".5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", 
         RowBox[{
          RowBox[{"-", "Pi"}], "/", "2"}], ",", 
         RowBox[{"Pi", "/", "2"}], ",", ".5"}], "}"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6238547317077*^9, 3.6238547444841223`*^9}, {
   3.6238548325618773`*^9, 3.623854852311512*^9}, {3.623854937628062*^9, 
   3.623854955848894*^9}, 3.6238550661606874`*^9, {3.6238563348157167`*^9, 
   3.623856337998122*^9}, {3.6238565368918724`*^9, 3.623856541883881*^9}, {
   3.6238566029151883`*^9, 3.6238566052551928`*^9}, 3.6238566950665503`*^9, 
   3.6239173995670834`*^9, 3.623917477972821*^9, {3.6239175532273536`*^9, 
   3.623917691833597*^9}, {3.6239178577866883`*^9, 3.6239178646351004`*^9}, {
   3.623917992212125*^9, 3.623917996845333*^9}, {3.7079058873122396`*^9, 
   3.707905900262321*^9}},ExpressionUUID->"00333cc7-98e7-47bf-919d-\
c0e1165c2bc8"],

Cell[TextData[{
 "\[FilledSquare]",
 "\nNow we return to the general surface in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]],ExpressionUUID->
  "150c9319-d41d-4c4d-809a-959fb0bcde68"],
 " considered in the previous subsection: "
}], "Text",
 CellChangeTimes->{{3.595658977275859*^9, 3.59565902746873*^9}, {
  3.595660122941387*^9, 3.5956601380842533`*^9}, {3.59609110855994*^9, 
  3.5960911150339513`*^9}, {3.62400946336747*^9, 3.624009479934699*^9}, {
  3.6240096123165317`*^9, 
  3.624009617698541*^9}},ExpressionUUID->"85267b1f-ae8d-4967-89a4-\
778746cb91fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", " ", 
  RowBox[{"mf", " ", "=", " ", "2"}], ";", " ", 
  RowBox[{"vx", " ", ":=", " ", 
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5956590461387978`*^9, 3.5956590587255173`*^9}, 
   3.595924528295635*^9},ExpressionUUID->"fb4264d2-fd28-4fc8-a41e-\
3ab74bd24ad7"],

Cell[BoxData[
 RowBox[{"vx", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6241734515396605`*^9, 
  3.624173473254898*^9}},ExpressionUUID->"659f26c3-c25c-4a46-983e-\
d5944c713e70"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv", "[", "s", "]"}], "[", 
  RowBox[{
   RowBox[{"u", "[", "1", "]"}], ",", 
   RowBox[{"u", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6989973302187033`*^9, 
  3.698997331202124*^9}},ExpressionUUID->"7ca31709-7496-4cd7-874e-\
11374c0f2927"],

Cell["\<\
The orthogonal projection of the total differential yields hardly to handle \
expressions:\
\>", "Text",
 CellChangeTimes->{{3.595924809229704*^9, 
  3.595924857997493*^9}},ExpressionUUID->"a13fd87a-54a0-461b-8ffb-\
a3b41e3817de"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pT", "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"x", "[", "1", "]"}], ",", 
    RowBox[{"x", "[", "2", "]"}]}], "]"}], "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "vx", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}], ".", 
   RowBox[{
    RowBox[{"vv", "[", "s", "]"}], "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5956718156521287`*^9, 3.595671916986925*^9}, {
  3.595924878553669*^9, 3.5959248845610123`*^9}, {3.5959249303306303`*^9, 
  3.5959249361379623`*^9}},ExpressionUUID->"ed8c3d29-8802-4393-9454-\
5470d1684dc7"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Together", "[", "%", "]"}], ",", 
    RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.707906211383251*^9, 
  3.7079063046808968`*^9}},ExpressionUUID->"fa062b14-8205-40af-8477-\
6717ca7d82ca"],

Cell["\<\
The simplification of this Output needed 859.44 s, but brought little \
insight. We try the sphere example;\
\>", "Text",
 CellChangeTimes->{{3.5965233231091785`*^9, 3.5965233415892353`*^9}, {
  3.5965234585939274`*^9, 3.5965234706766186`*^9}, {3.5965236058293495`*^9, 
  3.5965236548851547`*^9}, {3.5965239391284127`*^9, 3.5965240097254505`*^9}, {
  3.596524051661849*^9, 3.5965240656206474`*^9}, {3.596524116821576*^9, 
  3.596524116826576*^9}, {3.596524164133282*^9, 3.596524171508704*^9}, {
  3.5965243170540285`*^9, 3.5965243252935*^9}, {3.62384177355552*^9, 
  3.623841797922763*^9}, {3.7079075546361933`*^9, 
  3.707907609891347*^9}},ExpressionUUID->"9a0c3c04-c20e-4550-bd94-\
4fe31998640e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{"wx", ":=", " ", 
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.623845509043992*^9, 3.623845583502923*^9}, {
  3.6238459238331203`*^9, 
  3.6238459275615273`*^9}},ExpressionUUID->"1cbed6d6-a01c-4fa1-bb25-\
1476db106c05"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "wx", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{
   RowBox[{"vv", "[", "s", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6238461248862734`*^9, 3.623846133559889*^9}, {
  3.6238461841039777`*^9, 3.623846196162799*^9}, {3.699080737667152*^9, 
  3.699080744894594*^9}},ExpressionUUID->"a8afc248-6791-4728-bef8-\
c88c4991c865"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"pT", "[", 
      RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", "%", "]"}], ",", " ", 
   RowBox[{"r", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.623846233665265*^9, 3.623846306813793*^9}, {
  3.6238463410558534`*^9, 
  3.6238463519602723`*^9}},ExpressionUUID->"285d5e33-4efb-4795-a626-\
e4fc192338ae"],

Cell[TextData[{
 "Now we return to to the general surface in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]],ExpressionUUID->
  "0a67598c-669f-46b9-9cdb-a5b75af88f4e"],
 " and apply  ",
 ButtonBox["formula (1)",
  BaseStyle->"Hyperlink",
  ButtonData->"dtt(1)"],
 " of the last subsection. We first calculate the tangential components of \
the total differentials of the  tangent basis vectors:"
}], "Text",
 CellChangeTimes->{{3.5965233231091785`*^9, 3.5965233415892353`*^9}, {
   3.5965234585939274`*^9, 3.5965234706766186`*^9}, {3.5965236058293495`*^9, 
   3.5965236548851547`*^9}, {3.5965239391284127`*^9, 
   3.5965240097254505`*^9}, {3.596524051661849*^9, 3.5965240656206474`*^9}, {
   3.596524116821576*^9, 3.596524116826576*^9}, {3.596524164133282*^9, 
   3.596524171508704*^9}, {3.5965243170540285`*^9, 3.5965243252935*^9}, 
   3.62384177355552*^9, {3.6238465789718714`*^9, 3.62384662976556*^9}, {
   3.6238467043960915`*^9, 
   3.6238467398393536`*^9}},ExpressionUUID->"d9dc683f-b3cb-4839-8819-\
948533834020"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", " ", 
  RowBox[{"mf", " ", "=", " ", "2"}], ";", " ", 
  RowBox[{"vx", " ", ":=", " ", 
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
    RowBox[{"smf", "[", "f", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5956590461387978`*^9, 3.5956590587255173`*^9}, 
   3.595924528295635*^9},ExpressionUUID->"9dad46f0-ef91-4fdd-b4f8-\
e98999eeca5f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]", "[", 
     RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], "[", "ff_", "]"}], "[", 
   "x__", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"tv", "[", "i", "]"}], "[", "ff", "]"}], "[", "x", "]"}], 
      ")"}], ".", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{
        RowBox[{"tv", "[", "j", "]"}], "[", "ff", "]"}], "]"}], "[", "x", 
      "]"}]}], ")"}], "[", 
   RowBox[{"[", "k", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.595832267149208*^9, 3.5958323721202126`*^9}, {
   3.595832428807455*^9, 3.595832442513239*^9}, {3.595832489464924*^9, 
   3.5958325992172017`*^9}, {3.5958328395459476`*^9, 
   3.5958329541655035`*^9}, {3.5958329857303085`*^9, 3.5958329927137084`*^9}, 
   3.595833066441925*^9, {3.595833151066766*^9, 3.595833202040681*^9}, {
   3.595833410761619*^9, 3.595833418537064*^9}, {3.5958337753454723`*^9, 
   3.5958337836169453`*^9}, 3.5958373746493406`*^9, {3.6258068531481457`*^9, 
   3.625806853896947*^9}},ExpressionUUID->"c3dfff4d-eb05-45bb-9c84-\
c538e42fde72"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", 
    RowBox[{"1", ",", "2", ",", "1"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5958326835090227`*^9, 3.5958327630155706`*^9}, {
  3.595832965609158*^9, 3.5958329706304455`*^9}, {3.5958330067045083`*^9, 
  3.5958330097426825`*^9}},ExpressionUUID->"9657f918-80bf-43e6-b44a-\
f67faee02173"],

Cell["\[Gamma][i,j,k] is symmetric with respect to the last two indices:", \
"Text",
 CellChangeTimes->{{3.5958375539165945`*^9, 
  3.595837581947198*^9}},ExpressionUUID->"271d7f86-1bc6-45f6-a54c-\
cb4779caa15c"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"k", ",", "j", ",", "i"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "mf"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.59583346776388*^9, 3.595833575697053*^9}, {
   3.5958336323142915`*^9, 3.5958336479051833`*^9}, {3.5958336849463015`*^9, 
   3.5958337057534924`*^9}, {3.5958338055792017`*^9, 
   3.5958338282264967`*^9}, {3.596466574435828*^9, 3.5964666093798895`*^9}, 
   3.6148618620151443`*^9, 
   3.6148635020460243`*^9},ExpressionUUID->"082edac4-a509-41ec-b754-\
d8197cdd88e4"],

Cell["\<\
The \[Gamma][i,j,k] may be expressed as the scalar product of the derivatives\
\>", "Text",
 CellChangeTimes->{{3.5958376134359984`*^9, 3.595837671195302*^9}, 
   3.596466437498788*^9},ExpressionUUID->"07cdc9ad-d4a5-47eb-94cc-\
ed1c91a79fe8"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], "-", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", "l", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "i", "]"}]}], "]"}], "*", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", "l", "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "j", "]"}], ",", 
          RowBox[{"x", "[", "k", "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "dim"}], "}"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "mf"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.595834301153547*^9, 3.595834330847245*^9}, {
   3.5958344074156246`*^9, 3.5958344117198706`*^9}, {3.595834470991261*^9, 
   3.595834498791851*^9}, {3.5958345504088035`*^9, 3.5958346806322517`*^9}, {
   3.5958347237637186`*^9, 3.5958347699433603`*^9}, {3.5958348271236305`*^9, 
   3.5958348924843693`*^9}, 3.614861862030744*^9, 
   3.6148635020616245`*^9},ExpressionUUID->"d5741546-b8e4-48e2-a942-\
4a7c93d68150"],

Cell["It follows that \[Gamma][i,j,k] may be defined by", "Text",
 CellChangeTimes->{{3.595835714644394*^9, 
  3.595835766867381*^9}},ExpressionUUID->"5f1d74cc-3649-4d7a-94d1-\
dbe8a3b0bbff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]\[Gamma]\[Gamma]", "[", 
     RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], "[", "ff_", "]"}], " ", "[",
    "x__", "]"}], ":=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"ff", "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ".", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"ff", "[", "x", "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "j", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.5958360751920156`*^9, {3.5958362670469894`*^9, 3.595836268018045*^9}, {
   3.595836315208744*^9, 3.59583637003388*^9}, {3.5958366145528655`*^9, 
   3.595836615136899*^9}, {3.595836913992993*^9, 3.595837072362051*^9}, 
   3.595837191258851*^9, 
   3.5958373185941343`*^9},ExpressionUUID->"1a0f17ad-22f1-47b9-9acd-\
da24c5a8bf84"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]\[Gamma]\[Gamma]", "[", 
    RowBox[{"1", ",", "1", ",", "2"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.59583648699857*^9, 
  3.5958364893347034`*^9}},ExpressionUUID->"dfd2d8cb-15bf-41ff-8066-\
21236ebf6eb6"],

Cell["Check the statement:", "Text",
 CellChangeTimes->{{3.5965245375496407`*^9, 
  3.5965245477652245`*^9}},ExpressionUUID->"0414ecca-ad25-4725-909c-\
0a5c8388fca0"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]\[Gamma]\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "mf"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "mf"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.595834301153547*^9, 3.595834330847245*^9}, {
   3.5958344074156246`*^9, 3.5958344117198706`*^9}, {3.595834470991261*^9, 
   3.595834498791851*^9}, {3.5958345504088035`*^9, 3.5958346806322517`*^9}, {
   3.5958347237637186`*^9, 3.5958347699433603`*^9}, {3.5958348271236305`*^9, 
   3.5958348924843693`*^9}, {3.5958361198955727`*^9, 
   3.5958361451940203`*^9}, {3.5958361819391212`*^9, 3.5958361936667924`*^9}, 
   3.5958362941475396`*^9, 3.614861862046344*^9, 
   3.6148635020616245`*^9},ExpressionUUID->"1c1fc155-070d-4f16-8f51-\
e76c2d9a7e5f"],

Cell[TextData[{
 "Now we remember the definition of the",
 ButtonBox[" first fundamental form",
  BaseStyle->"Hyperlink",
  ButtonData->"fund1"],
 " and  verify"
}], "Text",
 CellChangeTimes->{{3.595941251019602*^9, 3.5959412698656797`*^9}, {
  3.5964666958040414`*^9, 3.596466724040091*^9}, {3.596526324159829*^9, 
  3.5965263241648293`*^9}},ExpressionUUID->"44710d84-41c9-4d27-95d6-\
674d0ba9706d"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"rgT", "[", 
          RowBox[{"i", ",", "j"}], "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
       RowBox[{"x", "[", "k", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"i", ",", "k", ",", "j"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"j", ",", "k", ",", "i"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5959412900918365`*^9, 3.595941430860888*^9}, {
   3.5959414627807136`*^9, 3.5959414712411976`*^9}, {3.5959415379840155`*^9, 
   3.595941634457533*^9}, 
   3.6186423861793385`*^9},ExpressionUUID->"17911ed8-5933-47b5-9576-\
dc4a23e8597f"],

Cell["Thus we have the relation (omitting the arguments)", "Text",
 CellChangeTimes->{{3.5959417091768064`*^9, 3.595941736120348*^9}, 
   3.5959433441283207`*^9},ExpressionUUID->"ad2fcea6-f242-4521-88e0-\
5d6491aed54f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[PartialD]", "k"], 
   SubscriptBox["g", 
    RowBox[{"ij", " "}]]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"\[Gamma]", "[", 
    RowBox[{"i", ",", "k", ",", "j"}], "]"}], " ", "+", 
   RowBox[{"\[Gamma]", "[", 
    RowBox[{"j", ",", "k", ",", "i"}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5959417619478254`*^9, 3.5959417867222424`*^9}, {
  3.595941835226016*^9, 
  3.5959418868279676`*^9}},ExpressionUUID->"c9c0bf38-0920-4a90-81e8-\
3117b9ab6fb1"],

Cell["\<\
Permuting in this identity the indices i, j, k twice cyclically and calculate\
\>", "Text",
 CellChangeTimes->{{3.5959428318930225`*^9, 3.5959429012729907`*^9}, 
   3.595943368160695*^9},ExpressionUUID->"06e3e81f-d72f-4221-b1f3-\
418a40174a02"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "k"], 
     SubscriptBox["g", 
      RowBox[{"ij", " "}]]}], " ", "+", 
    RowBox[{
     SubscriptBox["\[PartialD]", "i"], 
     SubscriptBox["g", 
      RowBox[{"jk", " "}]]}], " ", "-", 
    RowBox[{
     SubscriptBox["\[PartialD]", "j"], 
     SubscriptBox["g", 
      RowBox[{"ki", " "}]]}]}], ")"}], "/", "2"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595942934100868*^9, 3.5959429691548734`*^9}, {
  3.5959429992345943`*^9, 
  3.5959430300903587`*^9}},ExpressionUUID->"4dbc5b98-4e14-48ab-95b7-\
cf0a333fed83"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"rgT", "[", 
             RowBox[{"i", ",", "j"}], "]"}], "[", 
            RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "k", "]"}]}], "]"}], " ", "+", " ", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"rgT", "[", 
             RowBox[{"j", ",", "k"}], "]"}], "[", 
            RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "i", "]"}]}], "]"}], "-", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"rgT", "[", 
             RowBox[{"k", ",", "i"}], "]"}], "[", 
            RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
           RowBox[{
            RowBox[{"x", "[", "1", "]"}], ",", 
            RowBox[{"x", "[", "2", "]"}]}], "]"}], ",", 
          RowBox[{"x", "[", "j", "]"}]}], "]"}]}], ")"}], "/", "2"}], " ", 
     "-", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"j", ",", "k", ",", "i"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5959412900918365`*^9, 3.595941430860888*^9}, {
  3.5959414627807136`*^9, 3.5959414712411976`*^9}, {3.5959415379840155`*^9, 
  3.595941634457533*^9}, {3.595941961554242*^9, 3.595942003374634*^9}, {
  3.595942053413496*^9, 3.595942106702544*^9}, {3.5959421530311937`*^9, 
  3.595942184531996*^9}, {3.5959422245002813`*^9, 3.595942227412448*^9}, {
  3.5959423193967094`*^9, 3.5959423524365993`*^9}, {3.595943123101679*^9, 
  3.5959431250367894`*^9}, {3.6186423875404167`*^9, 
  3.6186423896215353`*^9}},ExpressionUUID->"a7f90dcc-5fbf-4ce2-a686-\
c2f0942e718c"],

Cell["We obtain ", "Text",
 CellChangeTimes->{{3.5959430503845196`*^9, 
  3.59594305948804*^9}},ExpressionUUID->"f40fe4bb-56b3-4d51-8793-\
ec88991c301e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", 
   RowBox[{"j", ",", "k", ",", "i"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "k"], 
      SubscriptBox["g", 
       RowBox[{"ij", " "}]]}], " ", "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "i"], 
      SubscriptBox["g", 
       RowBox[{"jk", " "}]]}], " ", "-", 
     RowBox[{
      SubscriptBox["\[PartialD]", "j"], 
      SubscriptBox["g", 
       RowBox[{"ki", " "}]]}]}], ")"}], "/", "2"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595943183946159*^9, 3.5959431903385243`*^9}, 
   3.5959432283076963`*^9},ExpressionUUID->"4c1a64e5-60b0-4bb3-a9e7-\
5abd885dbd2e"],

Cell["\<\
To get this result we used the symmetry of the \[Gamma][j,k,i] in the last \
two indices. We come to the  final definition of the \[Gamma]-symbols:\
\>", "Text",
 CellChangeTimes->{{3.595943419848652*^9, 3.5959434605369787`*^9}, {
   3.624174307341563*^9, 3.6241743281364*^9}, {3.6241743619728594`*^9, 
   3.6241743751704826`*^9}, {3.6241744088197412`*^9, 3.6241744186321588`*^9}, 
   3.624174449629413*^9, {3.699082167014739*^9, 
   3.699082170782775*^9}},ExpressionUUID->"e636f093-d5e0-4e7c-993b-\
450f113dcd25"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"christoffel1", "[", 
     RowBox[{"j_", ",", "k_", ",", "i_"}], "]"}], "[", "g_", "]"}], "[", 
   "x__", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"i", ",", "j"}], "]"}], "[", "x", "]"}], ",", 
       RowBox[{
        RowBox[{"{", "x", "}"}], "[", 
        RowBox[{"[", "k", "]"}], "]"}]}], "]"}], " ", "+", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"j", ",", "k"}], "]"}], "[", "x", "]"}], ",", 
       RowBox[{
        RowBox[{"{", "x", "}"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], " ", "-", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"k", ",", "i"}], "]"}], "[", "x", "]"}], ",", 
       RowBox[{
        RowBox[{"{", "x", "}"}], "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ")"}], "/", 
   "2"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.624174812798051*^9, 3.624174820644865*^9}, {
   3.624174855292526*^9, 3.6241748801745696`*^9}, {3.624174913621028*^9, 
   3.6241749353518667`*^9}, {3.6241750065035915`*^9, 3.6241750833181267`*^9}, 
   3.6241751637362676`*^9, {3.6241766686732793`*^9, 
   3.6241766761456923`*^9}},ExpressionUUID->"c5190282-64e8-48c2-9e1c-\
c242de0e8ef4"],

Cell[BoxData[
 RowBox[{"?", "christoffel1"}]], "Input",
 CellChangeTimes->{{3.6241751753270884`*^9, 3.624175231611987*^9}, {
   3.6241752747148623`*^9, 3.6241753353209686`*^9}, {3.6241754714593754`*^9, 
   3.624175537417291*^9}, 3.6241756021740046`*^9, 3.6241886148000774`*^9, {
   3.625904141139639*^9, 3.625904146958449*^9}, {3.699082179951199*^9, 
   3.6990821819429483`*^9}},ExpressionUUID->"f73b5441-39ac-4d7b-96fc-\
bceddfc5e08d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Gamma]\[Gamma]", "[", 
     RowBox[{"j_", ",", "k_", ",", "i_"}], "]"}], "[", "ff_", "]"}], "[", 
   "x__", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"g", ",", "ii", ",", "jj", ",", "y"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{"ii_", ",", "jj_"}], "]"}], "[", "y__", "]"}], ":=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"rgT", "[", 
         RowBox[{"ii", ",", "jj"}], "]"}], "[", "ff", "]"}], "[", "y", 
       "]"}]}], ";", 
     RowBox[{
      RowBox[{
       RowBox[{"christoffel1", "[", 
        RowBox[{"j", ",", "k", ",", "i"}], "]"}], "[", "g", "]"}], "[", "x", 
      "]"}]}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.595943691303178*^9, 3.595943720562852*^9}, {
   3.595943755629857*^9, 3.5959438156432896`*^9}, {3.5959438577156963`*^9, 
   3.5959439199962587`*^9}, {3.595943963596752*^9, 3.5959440729940095`*^9}, {
   3.5959453340161357`*^9, 3.59594563392929*^9}, {3.5959456985059834`*^9, 
   3.5959457283136883`*^9}, {3.5959460610257187`*^9, 
   3.5959460813358803`*^9}, {3.618642390708598*^9, 3.6186423931307364`*^9}, {
   3.624176205742466*^9, 3.6241762142132807`*^9}, 
   3.624188702815432*^9},ExpressionUUID->"d0610fc6-b6c8-4bc7-9f4b-\
70dc08100fd3"],

Cell[BoxData[
 RowBox[{"?", "\[Gamma]\[Gamma]"}]], "Input",
 CellChangeTimes->{{3.624188909578195*^9, 3.624188987047931*^9}, {
  3.6241890186691866`*^9, 3.6241890327872114`*^9}, {3.624189070258477*^9, 
  3.6241891921882915`*^9}, {3.624189232982363*^9, 3.6241892484107904`*^9}, {
  3.6259042402732134`*^9, 
  3.625904263922855*^9}},ExpressionUUID->"ea5c4a49-5b72-46d7-b7f7-\
bce2a366ec5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]\[Gamma]", "[", 
    RowBox[{"1", ",", "1", ",", "2"}], "]"}], "[", 
   RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5959443675718584`*^9, 
  3.5959443703800187`*^9}},ExpressionUUID->"795d2fe9-8a7c-4127-a976-\
30b8de37059a"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Table", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}], "-", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}], ",", 
       RowBox[{"x", "[", "3", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5959440956543055`*^9, 3.595944199291233*^9}, {
   3.595944229936986*^9, 3.595944247207974*^9}, 3.5959443002400074`*^9, {
   3.624176360291938*^9, 3.624176362366741*^9}, {3.6241887502551155`*^9, 
   3.6241888414840755`*^9}},ExpressionUUID->"c0d587cc-3274-4999-bd9b-\
afafed352be8"],

Cell[BoxData[
 RowBox[{"?", "inverse"}]], "Input",
 CellChangeTimes->{{3.6241894129608793`*^9, 
  3.624189416626886*^9}},ExpressionUUID->"624e183b-b91f-4070-bbaf-\
f65cda492347"],

Cell[TextData[{
 "The ",
 StyleBox["Christoffel symbols of the second kind",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[CapitalGamma]", "ij", "k"], TraditionalForm]],
  ExpressionUUID->"756d7607-dc1c-496c-a41e-d0b308ba400e"],
 " (== \[CapitalGamma][k,i,j]) are defined by",
 StyleBox[" ",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["raising",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" the index ",
  FontColor->RGBColor[0, 0, 1]],
 "k of \[Gamma][k, i, j]:"
}], "Text",
 CellChangeTimes->{{3.5962632168845243`*^9, 3.59626338482813*^9}, {
   3.596263485246873*^9, 3.596263521619954*^9}, 3.596263699773144*^9, {
   3.624189284384454*^9, 3.6241892917788663`*^9}, {3.625898375657461*^9, 
   3.6258983965302978`*^9}},ExpressionUUID->"3ff2888e-7b8f-466f-a45a-\
5d2e680de68d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalGamma]", "[", 
    RowBox[{"k_", ",", "i_", ",", "j_"}], "]"}], "[", "g_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"inverse", "[", 
         RowBox[{"k", ",", "l"}], "]"}], "[", "g", "]"}], "[", "##", "]"}], 
      "*", 
      RowBox[{
       RowBox[{
        RowBox[{"christoffel1", "[", 
         RowBox[{"l", ",", "i", ",", "j"}], "]"}], "[", "g", "]"}], "[", "##",
        "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "##", "}"}], "]"}]}], "}"}]}], "]"}], "&"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5960018598938203`*^9, 3.596002000216067*^9}, {
   3.5960020444421444`*^9, 3.5960021548903384`*^9}, 3.596002568119464*^9, {
   3.5962627214502306`*^9, 3.5962627274874415`*^9}, {3.5962627993099675`*^9, 
   3.5962628115559893`*^9}, {3.59626286325448*^9, 3.596262865719284*^9}, 
   3.596355750517495*^9, 3.618739494686504*^9, {3.6241893439931583`*^9, 
   3.624189372213608*^9}, {3.6241894590775604`*^9, 3.6241894613395643`*^9}, 
   3.624189493818822*^9, 3.6241895469525146`*^9, {3.6241896057982187`*^9, 
   3.624189613957033*^9}, {3.6241896785743465`*^9, 3.6241896860467596`*^9}, 
   3.6241897275896325`*^9, {3.6241995606420655`*^9, 
   3.624199613325358*^9}},ExpressionUUID->"aade3001-e6cf-41a4-a959-\
d718d80c9dd5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "\[CapitalGamma]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6241996712094603`*^9, 3.6241997055139203`*^9}, {
  3.624199745939592*^9, 3.6241998411535597`*^9}, {3.624261050068605*^9, 
  3.6242610515506077`*^9}, {3.6259045747672033`*^9, 
  3.625904585207622*^9}},ExpressionUUID->"fcfc0797-eb18-4e53-961f-\
9e374c46e095"],

Cell[BoxData[
 StyleBox["\<\"\[CapitalGamma][k,i,j][x,y,...] denotes the \
\[CapitalGamma]-symbols of a general unspecified linear connection.\\n\
\[CapitalGamma][k,i,j][g][x,y,...] are the Christoffel symbols of the second \
kind of the \\npseudo-Riemannian metric {g[i,j][x,y,...]} in local \
coordinates x,y,...\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.708321853295436*^9},
 CellTags->
  "Info873708329053-6824778",ExpressionUUID->"616128de-0eac-45b2-9bee-\
f48bf4d355da"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalGamma]rgT", "[", 
    RowBox[{"k_", ",", "i_", ",", "j_"}], "]"}], "[", "ff_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"invrgT", "[", 
         RowBox[{"k", ",", "l"}], "]"}], "[", "ff", "]"}], "[", "##", "]"}], 
      "*", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]\[Gamma]", "[", 
         RowBox[{"l", ",", "i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
       "##", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "##", "}"}], "]"}]}], "}"}]}], "]"}], "&"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{
  3.624190278873401*^9, {3.624190400230015*^9, 3.6241904118676353`*^9}, {
   3.62419044278889*^9, 3.6241904443176923`*^9}, 3.6241904896417723`*^9, {
   3.6241996330487933`*^9, 
   3.624199634000395*^9}},ExpressionUUID->"c15fe460-9f86-4efb-bb36-\
dd988cb5a9c2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "\[CapitalGamma]rgT"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6242003660714846`*^9, 3.6242003976987405`*^9}, {
  3.624200439589814*^9, 3.624200449638232*^9}, {3.6242004811366873`*^9, 
  3.6242006614090047`*^9}, {3.6242006917706585`*^9, 3.6242006954366646`*^9}, {
  3.6259046928120117`*^9, 
  3.6259046977572203`*^9}},ExpressionUUID->"8176e70c-804c-4510-8f93-\
5880654e6eb4"],

Cell[BoxData[
 StyleBox["\<\"\[CapitalGamma]rgT[j,k,i][f][x,y,...]  are the Christoffel \
symbols of the second  kind of the \\nRiemannian metric rgT[i,j][f][x,y,...] \
of the immersion f[x,y,...] into the Euclidean n-space.\"\>", "MSG"]], "Print",\
 "PrintUsage",
 CellChangeTimes->{3.708321853464106*^9},
 CellTags->
  "Info883708329053-6824778",ExpressionUUID->"80527308-c6dd-4277-8ecb-\
d92bd0935294"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "gg", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"gg", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], "[", 
    RowBox[{"u_", ",", "v_", ",", "w_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6241897744053144`*^9, 3.6241898451378393`*^9}, {
  3.624189973762065*^9, 3.624190035740974*^9}, {3.62420018766817*^9, 
  3.62420022169783*^9}},ExpressionUUID->"b13cd6d9-0cb5-46be-bb44-\
a15a3c5a796b"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalGamma]", "[", 
       RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "gg", "]"}], "[", 
     RowBox[{"u", ",", "v", ",", "w"}], "]"}], "-", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalGamma]rgT", "[", 
       RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
      RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6241899016879387`*^9, 3.6241899274279833`*^9}, {
  3.6241900617326193`*^9, 3.624190151200777*^9}, {3.624200113359239*^9, 
  3.624200174064946*^9}, {3.624200235269854*^9, 
  3.624200317038598*^9}},ExpressionUUID->"5449cbfd-8b51-4a69-b09b-\
777a8f8ab3df"],

Cell["\<\
Clearly, the Christoffel symbols of the second kind are symmetric in the last \
two indices:\
\>", "Text",
 CellChangeTimes->{{3.62420089672362*^9, 
  3.6242009553107233`*^9}},ExpressionUUID->"a857f704-24f9-49ee-9c38-\
bc3fc93affb2"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "gg", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}], "-", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"i", ",", "k", ",", "j"}], "]"}], "[", "gg", "]"}], "[", 
      RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6241899016879387`*^9, 3.6241899274279833`*^9}, {
  3.6241900617326193`*^9, 3.624190151200777*^9}, {3.624200113359239*^9, 
  3.624200174064946*^9}, {3.624200235269854*^9, 3.624200317038598*^9}, {
  3.6242007774696093`*^9, 3.6242008250616937`*^9}, {3.7079084649480677`*^9, 
  3.707908483628231*^9}},ExpressionUUID->"3f7ed0bb-65e5-49a1-92bb-\
a6173e71fd14"],

Cell[BoxData[
 RowBox[{"Clear", "[", "gg", "]"}]], "Input",
 CellChangeTimes->{{3.626010613026805*^9, 
  3.6260106180656137`*^9}},ExpressionUUID->"f0cf634f-3695-4170-b02d-\
dca74bcf1506"],

Cell[TextData[{
 StyleBox["Lemma 4. ",
  FontColor->RGBColor[0, 0, 1]],
 "The Christoffel symbols are defined  by the Riemannian metric rgT[i,j] \
only: isometric Riemannian manifolds (or immersions) have the same \
Christoffel symbols, if the isometry ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "iso"], TraditionalForm]],ExpressionUUID->
  "c290a756-d943-403e-93aa-f7c1afb86376"],
 " is defined by equal coordinates: "
}], "Text",
 CellChangeTimes->{{3.596263795220603*^9, 3.5962638134276443`*^9}, {
   3.5962638465165367`*^9, 3.596263997252158*^9}, {3.5964667908862085`*^9, 
   3.596466795909417*^9}, 3.6186423947728305`*^9, {3.624201102529583*^9, 
   3.6242012044449625`*^9}, 
   3.699083226246477*^9},ExpressionUUID->"51c560ce-9ed9-475f-b808-\
189538766a6c"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "iso"], "[", 
    RowBox[{"x", "[", 
     RowBox[{"u", ",", "v", ",", "..."}], "]"}], "]"}], " ", "=", 
   RowBox[{"y", "[", 
    RowBox[{"u", ",", "v", ",", "..."}], "]"}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6242013672094502`*^9, 
  3.6242014345169687`*^9}},ExpressionUUID->"2da7ecfb-6eb9-4a2d-8cf5-\
746096b61db1"],

Cell["They are symmetric with respect to the last two indices:", "Text",
 CellChangeTimes->{{3.596263795220603*^9, 3.5962638134276443`*^9}, {
   3.5962638465165367`*^9, 3.596263997252158*^9}, {3.5964667908862085`*^9, 
   3.596466795909417*^9}, 3.6186423947728305`*^9, {3.624201102529583*^9, 
   3.6242012044449625`*^9}},ExpressionUUID->"e570ebd8-c24b-451f-bc3e-\
ad2a2f41f4fd"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]rgT", "[", 
        RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}], " ", "-", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]rgT", "[", 
        RowBox[{"k", ",", "j", ",", "i"}], "]"}], "[", 
       RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"x", "[", "1", "]"}], ",", 
       RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.596092519613618*^9, 3.596092710557954*^9}, {
   3.5960927565312347`*^9, 3.5960927874972887`*^9}, {3.5960928282913604`*^9, 
   3.596092857510212*^9}, {3.5962629222849836`*^9, 3.596262936371808*^9}, 
   3.614861862061944*^9, 3.6148635020772247`*^9, {3.624201028498452*^9, 
   3.6242010438070793`*^9}},ExpressionUUID->"487926a8-acad-4d70-a996-\
bed34c36378d"],

Cell["\[FilledRectangle]", "Text",
 CellChangeTimes->{{3.596526684213423*^9, 
  3.596526684219423*^9}},ExpressionUUID->"2f91ab32-6478-41da-bbbd-\
c7777124bde8"],

Cell[TextData[{
 StyleBox["Example 4",
  FontColor->RGBColor[0, 0, 1]],
 ". The Christoffel symbols of the unit sphere:"
}], "Text",
 CellChangeTimes->{{3.596264188339088*^9, 3.5962642170837317`*^9}, {
   3.5964670000357757`*^9, 3.5964670129369984`*^9}, {3.699009107556012*^9, 
   3.699009135851678*^9}, 3.6990833759086437`*^9, {3.699083417228229*^9, 
   3.699083440540011*^9}},ExpressionUUID->"c393565e-55f7-4806-b6ab-\
60db6b3bea9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], " ", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]rgT", "[", 
         RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", 
        RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "2"}], "}"}]}], "]"}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.5964375688386*^9, 3.59643760902427*^9}, {
   3.5964376738579845`*^9, 3.596437674918786*^9}, {3.5964377439645076`*^9, 
   3.5964377584257326`*^9}, {3.5964378236026473`*^9, 3.5964378310594606`*^9}, 
   3.614861862077544*^9, 3.6148635020928245`*^9, 
   3.6242015198193197`*^9},ExpressionUUID->"f5717359-5152-4c78-af4c-\
6acfb506aeb7"],

Cell[TextData[{
 "\[FilledRectangle]\n",
 StyleBox["Example 5",
  FontColor->RGBColor[0, 0, 1]],
 ". A general surface:"
}], "Text",
 CellChangeTimes->{{3.596467059924281*^9, 3.5964670689566965`*^9}, {
  3.5965268092775755`*^9, 3.5965268485568223`*^9}, {3.699083478203642*^9, 
  3.699083480803627*^9}},ExpressionUUID->"d8c72afd-ec2e-46e7-a622-\
11b9393be8b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", " ", "3"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]rgT", "[", 
      RowBox[{"1", ",", "2", ",", "1"}], "]"}], "[", "sf", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.596002193906007*^9, 3.596002239302087*^9}, {
   3.596002307755007*^9, 3.5960023288774443`*^9}, 3.5960023753967257`*^9, {
   3.59600297016337*^9, 3.596002973298976*^9}, {3.596003011160242*^9, 
   3.5960030221738615`*^9}, {3.6187502576699853`*^9, 3.6187502629271946`*^9}, 
   3.6242015231421256`*^9},ExpressionUUID->"5ede2d37-a891-4be8-b970-\
d9ba033475ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]rgT", "[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.596002193906007*^9, 3.596002239302087*^9}, {
   3.596002307755007*^9, 3.5960023288774443`*^9}, 3.5960023753967257`*^9, {
   3.59600297016337*^9, 3.596002973298976*^9}, {3.596003011160242*^9, 
   3.5960030221738615`*^9}, {3.5960030787083607`*^9, 3.5960031412332706`*^9}, 
   3.596003187549752*^9, {3.596264292944071*^9, 3.5962643306622286`*^9}, 
   3.624201525138929*^9},ExpressionUUID->"756d6177-6ba9-47de-a77f-\
b5d602f9a315"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], 
           RowBox[{
            RowBox[{"Clear", "[", "gg", "]"}], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.7079094805527983`*^9, 
  3.7079094805755033`*^9}},ExpressionUUID->"c6f2c6b2-6b8e-44ab-9f02-\
fc1939475bf0"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", "%%"}]], "Input",
 CellChangeTimes->{{3.5962643468541546`*^9, 
  3.5962643502293477`*^9}},ExpressionUUID->"ee3db67f-288b-46c0-b2c0-\
93ac08881396"],

Cell[BoxData[
 RowBox[{"Clear", "[", "gg", "]"}]], "Input",
 CellChangeTimes->{{3.7079094809499693`*^9, 3.70790948096411*^9}, 
   3.707967934403997*^9},ExpressionUUID->"4c505ea7-47c4-4e15-9a51-\
c433060614a6"],

Cell[TextData[{
 "\[FilledRectangle]",
 StyleBox["\nExample 6",
  FontColor->RGBColor[0, 0, 1]],
 ". The Euclidean space :"
}], "Text",
 CellChangeTimes->{{3.596438847572846*^9, 3.5964388776808987`*^9}, {
  3.5965269169567347`*^9, 3.5965269247021775`*^9}, {3.699083551619301*^9, 
  3.6990835543789988`*^9}},ExpressionUUID->"801e8a05-00a8-40cc-b104-\
513537c2cacc"],

Cell["\<\
The Euclidean space is immersed onto itself by the identity map\
\>", "Text",
 CellChangeTimes->{{3.596439093117277*^9, 
  3.596439130713343*^9}},ExpressionUUID->"f7f48f49-d925-45b2-87b1-\
cb29b8887d17"],

Cell[BoxData[
 RowBox[{"identity", "[", 
  RowBox[{
   RowBox[{"x", "[", "1", "]"}], ",", 
   RowBox[{"x", "[", "2", "]"}], ",", 
   RowBox[{"x", "[", "3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.62401515192708*^9, 
  3.6240151854827394`*^9}},ExpressionUUID->"8eacf414-541e-4467-90bd-\
ba9a3eca2da7"],

Cell["The metric has the standard orthonormal shape", "Text",
 CellChangeTimes->{{3.5964391499637775`*^9, 
  3.596439188792245*^9}},ExpressionUUID->"1fb1d299-c9b5-4693-a331-\
a3eaa5b1497d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"rgT", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "[", "identity", "]"}], "[", 
     RowBox[{
      RowBox[{"x", "[", "1", "]"}], ",", 
      RowBox[{"x", "[", "2", "]"}], ",", 
      RowBox[{"x", "[", "3", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.5964381997037077`*^9, 3.596438289575466*^9}, {
   3.5964383447839627`*^9, 3.596438428010109*^9}, 3.5964384869314127`*^9, {
   3.5964386078784246`*^9, 3.596438784392735*^9}, {3.5965269616812925`*^9, 
   3.5965269678126435`*^9}, 3.6148618621087437`*^9, 3.614863502108424*^9, 
   3.6186423963049183`*^9, {3.6240152531712584`*^9, 
   3.624015256759265*^9}},ExpressionUUID->"b3363579-9e3c-47ac-9a2e-\
ae20e932f792"],

Cell["Thus we define", "Text",
 CellChangeTimes->{{3.6242620209831104`*^9, 
  3.624262025787919*^9}},ExpressionUUID->"25fa41b8-b133-49e1-9a46-\
df3432036eb6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"euclid", "[", 
   RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"rgT", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "[", "identity", "]"}], "[", "##", 
    "]"}], "&"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6242616834453173`*^9, 3.624261702336951*^9}, {
  3.62426179294191*^9, 3.624261831770378*^9}, {3.699083603941855*^9, 
  3.699083609643115*^9}},ExpressionUUID->"71599fc3-8932-4b8e-a384-\
7e24c0c1cf5f"],

Cell[BoxData[
 RowBox[{"?", "euclid"}]], "Input",
 CellChangeTimes->{{3.624339607984866*^9, 3.6243396885278077`*^9}, 
   3.624339719977463*^9, {3.6259047650607386`*^9, 
   3.6259047709731493`*^9}},ExpressionUUID->"cd99e749-8fe3-466d-a053-\
5540dd002c0a"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"euclid", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6242618459352026`*^9, 
  3.624261910160516*^9}},ExpressionUUID->"01fe6a2f-8817-4af5-8099-\
e33e2d277b24"],

Cell["All the Christoffel symbols are zero:", "Text",
 CellChangeTimes->{{3.5964392202731004`*^9, 
  3.5964392394299345`*^9}},ExpressionUUID->"200c7d31-4f69-46e7-9311-\
efb9e2a747be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], " ", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]rgT", "[", 
         RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "identity", "]"}], 
       "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.5964375688386*^9, 3.59643760902427*^9}, {
   3.5964376738579845`*^9, 3.596437674918786*^9}, {3.5964377439645076`*^9, 
   3.5964377584257326`*^9}, {3.5964378236026473`*^9, 
   3.5964378310594606`*^9}, {3.596438962045847*^9, 3.596438993760703*^9}, 
   3.614861862124344*^9, 3.614863502108424*^9, {3.624015286555317*^9, 
   3.624015289472522*^9}, 
   3.624201528633335*^9},ExpressionUUID->"87416862-ca47-4874-872f-\
a565f6728bd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], " ", "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "euclid", "]"}], "[", 
       RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.5964375688386*^9, 3.59643760902427*^9}, {
   3.5964376738579845`*^9, 3.596437674918786*^9}, {3.5964377439645076`*^9, 
   3.5964377584257326`*^9}, {3.5964378236026473`*^9, 
   3.5964378310594606`*^9}, {3.596438962045847*^9, 3.596438993760703*^9}, 
   3.614861862124344*^9, 3.614863502108424*^9, {3.624015286555317*^9, 
   3.624015289472522*^9}, 3.624201528633335*^9, {3.6242620661295896`*^9, 
   3.624262087985228*^9}},ExpressionUUID->"ddf6d83c-b55b-450d-b1f3-\
bf7ef8516092"],

Cell[TextData[{
 "\[FilledRectangle]\nNow we define the ",
 StyleBox["absolute differential",
  FontColor->RGBColor[0, 0, 1]],
 "  of a tangent vector field \nvw[x[1], x[2],... ] on the pseudo-Riemannian \
manifold with metric tensor \ng[i,j][x[1], x[2],... ] and local coordinates \
x[1], x[2],...:"
}], "Text",
 CellChangeTimes->{{3.5964393669757586`*^9, 3.5964394522767076`*^9}, {
   3.5964394822911606`*^9, 3.5964395605564985`*^9}, {3.596439649164654*^9, 
   3.5964396694290895`*^9}, {3.5964397029067483`*^9, 
   3.5964397744796743`*^9}, {3.596441447099012*^9, 3.596441496660299*^9}, {
   3.5964615275749636`*^9, 3.596461551396206*^9}, {3.5965270574777718`*^9, 
   3.5965270926457834`*^9}, 3.61744122138057*^9, 3.6242781546884165`*^9, {
   3.624278690346557*^9, 3.6242787603594804`*^9}, {3.6242787958183427`*^9, 
   3.624278806285961*^9}, {3.625904908828992*^9, 3.625904913821001*^9}, {
   3.699095287429229*^9, 
   3.6990953076351748`*^9}},ExpressionUUID->"16d9967c-bcc0-48f0-a79a-\
037fdea5bc44"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DD", "[", "g_", "]"}], "[", "vw_", "]"}], "[", "x__", "]"}], ":=",
   " ", 
  RowBox[{"Transpose", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"vw", "[", "x", "]"}], "[", 
          RowBox[{"[", "k", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"{", "x", "}"}], "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "+", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]", "[", 
             RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "g", "]"}], "[", 
           "x", "]"}], "*", 
          RowBox[{
           RowBox[{"vw", "[", "x", "]"}], "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "x", "}"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}], "]"}], 
   "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.596267909001898*^9, 3.596268002502246*^9}, {
   3.596268233767473*^9, 3.5962682417899323`*^9}, 3.596268272390682*^9, {
   3.5962683739424906`*^9, 3.596268434579959*^9}, {3.596268467832861*^9, 
   3.596268467847862*^9}, {3.596268546079336*^9, 3.59626858233541*^9}, {
   3.5962686311192007`*^9, 3.596268685327301*^9}, {3.596268721063345*^9, 
   3.5962687800967216`*^9}, {3.5962688200340056`*^9, 3.5962689711946516`*^9}, 
   3.596270942293791*^9, {3.5962709724375153`*^9, 3.5962709908775697`*^9}, {
   3.5962711252152534`*^9, 3.596271142601248*^9}, {3.5962712161694555`*^9, 
   3.5962712481452847`*^9}, {3.596271295953019*^9, 3.5962712978171253`*^9}, {
   3.5962714903281364`*^9, 3.5962715032818775`*^9}, {3.5962715560498953`*^9, 
   3.5962715738429136`*^9}, {3.5963609856954927`*^9, 
   3.5963610055046253`*^9}, {3.596361147280734*^9, 3.5963611482237883`*^9}, 
   3.5963690709758096`*^9, {3.59636910944601*^9, 3.5963691235168147`*^9}, {
   3.5963691564216967`*^9, 3.5963691658852386`*^9}, {3.5963695531093864`*^9, 
   3.5963695911245604`*^9}, {3.596369833029397*^9, 3.596369836182577*^9}, {
   3.5963701344546375`*^9, 3.5963701758290033`*^9}, {3.5963707897741194`*^9, 
   3.5963708379418745`*^9}, {3.5963708850625696`*^9, 
   3.5963709097469816`*^9}, {3.5963733257331676`*^9, 3.5963733297783995`*^9}, 
   3.614861862139944*^9, 3.6148635021240244`*^9, {3.624263265459696*^9, 
   3.6242632860049324`*^9}, {3.624280333201043*^9, 3.6242803452910643`*^9}, 
   3.625904928750227*^9},ExpressionUUID->"6e2e4439-85bb-42c2-a412-\
c709cb4f90ca"],

Cell[BoxData[
 RowBox[{"?", "DD"}]], "Input",
 CellChangeTimes->{{3.624284255422332*^9, 3.624284423185026*^9}, {
  3.624284507189603*^9, 3.624284581883534*^9}, {3.6259048914153614`*^9, 
  3.6259048955181684`*^9}, {3.625905113178152*^9, 
  3.6259051175149593`*^9}},ExpressionUUID->"0d6ac3d5-33bf-485b-b25e-\
7344dc50b248"],

Cell[TextData[{
 StyleBox["Example 7",
  FontColor->RGBColor[0, 0, 1]],
 ". Euclidean space\nIn this case the absolute differential coincides with \
the total differential of the vector field:"
}], "Text",
 CellChangeTimes->{{3.624263117477836*^9, 3.6242632398756514`*^9}, 
   3.624278292811059*^9, 3.6242783440883493`*^9, {3.624280409781577*^9, 
   3.6242804190947933`*^9}, {3.699095438017839*^9, 
   3.699095455625984*^9}},ExpressionUUID->"3ec7a5f3-a8d9-4199-a814-\
70daf17e7080"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",ExpressionUUID->"3f403b69-2d41-\
4eaf-a104-7b8b81cd9b8e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "euclid", "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.624262310051618*^9, 
  3.6242623672413187`*^9}},ExpressionUUID->"acddab62-9929-4a38-98dd-\
1c7b00719bb1"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6242626554206247`*^9, 3.6242627572264037`*^9}, {
  3.6242628996390533`*^9, 3.6242629758139877`*^9}, {3.6242803663979015`*^9, 
  3.624280374385115*^9}},ExpressionUUID->"e07a2f2b-c077-4820-ad9d-\
9da7aac42814"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", "%%"}]], "Input",
 CellChangeTimes->{{3.624262981398797*^9, 
  3.624262983504801*^9}},ExpressionUUID->"de2ac9ca-af06-4efb-8e19-\
d86a134c9912"],

Cell[TextData[{
 "\[FilledSquare]\n",
 "The tangent",
 StyleBox[" vector field",
  FontColor->RGBColor[0, 0, 1]],
 " on a surface in the Euclidean space is"
}], "Text",
 CellChangeTimes->{{3.5964653794113293`*^9, 3.5964654199402003`*^9}, 
   3.6130241204895363`*^9, 3.6238485533893394`*^9, {3.624263382725102*^9, 
   3.6242633857359076`*^9}},ExpressionUUID->"fae62adc-1693-4555-8a73-\
2f9aeced3922"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.5963696782625446`*^9, 3.596370011736618*^9, {3.596370260543849*^9, 
   3.5963702620869374`*^9}, 3.5963713146021376`*^9, 3.5963734001034217`*^9, 
   3.59643714724786*^9, {3.5964415386243725`*^9, 3.596441564068017*^9}, {
   3.5964625091130877`*^9, 3.596462532559929*^9}, {3.5964647726950636`*^9, 
   3.5964647751910677`*^9}},ExpressionUUID->"814f6ad6-73f9-4acd-aa4e-\
adf15fe0c6e5"],

Cell["\<\
This is the image of the tangent vector field vv[\[Xi]][u,v] under the \
differential of the immersion:\
\>", "Text",
 CellChangeTimes->{{3.5964655028543463`*^9, 3.5964655765332756`*^9}, 
   3.6130241253778157`*^9},ExpressionUUID->"250b861c-952f-4e15-aeb6-\
7cac4d5feb07"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{
   RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5964629299238267`*^9, 3.5964629384414415`*^9}, {
   3.596464531128639*^9, 3.596464582265529*^9}, 
   3.699095572017611*^9},ExpressionUUID->"03e14296-bba3-4666-90be-\
5837b2dbcb81"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5964645962899537`*^9, 
  3.5964646521848516`*^9}},ExpressionUUID->"902bc017-8509-4203-a122-\
6d2207cce959"],

Cell[TextData[{
 StyleBox["Example 8",
  FontColor->RGBColor[0, 0, 1]],
 ". A tangent vector field on the unit sphere.\nWe calculate its total \
differential"
}], "Text",
 CellChangeTimes->{{3.5964656072653294`*^9, 3.59646561355214*^9}, {
   3.5964671233539925`*^9, 3.596467138548419*^9}, 3.5964671699824743`*^9, {
   3.5964673422847767`*^9, 3.596467345123982*^9}, 3.5965274369334755`*^9, {
   3.5965274799579363`*^9, 3.5965274962528687`*^9}, 3.6132221202317195`*^9, {
   3.6990956722962112`*^9, 
   3.699095674040133*^9}},ExpressionUUID->"b9a93e91-5d6b-44ec-966b-\
97f426f42049"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
  RowBox[{"{", 
   RowBox[{"s1", ",", "s2"}], "}"}]}]], "Input",ExpressionUUID->"59104804-\
3068-4a9c-b20c-097b2a26658d"],

Cell[TextData[{
 StyleBox["Statement.",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 "\n",
 StyleBox["The absolute differential coincides with the tangent projection of \
the total differential:",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.5965275477568145`*^9, 3.5965275515490313`*^9}, {
   3.5965276068371935`*^9, 3.5965277272290792`*^9}, {3.5965280286613207`*^9, 
   3.5965280371008034`*^9}, 3.623848619034254*^9, 
   3.6242634401488028`*^9},ExpressionUUID->"1f7aaa13-8451-45f0-884d-\
8b40923f5b84"],

Cell["Here is the mentioned tangent projection:", "Text",
 CellChangeTimes->{{3.6238487892461534`*^9, 3.6238488119129934`*^9}, 
   3.624279022985942*^9},ExpressionUUID->"15375085-a20e-4d75-8484-\
000eb4246752"],

Cell[BoxData[
 RowBox[{"pdv", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"pT", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{
         RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", 
         RowBox[{"sphero", "[", "1", "]"}], "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.596461679628431*^9, {3.596461809795059*^9, 3.5964618218694806`*^9}, {
   3.596461958931321*^9, 3.5964619847337666`*^9}, {3.596462552715164*^9, 
   3.596462554743168*^9}, {3.5964636994287786`*^9, 3.5964637060743904`*^9}, {
   3.596463879593495*^9, 3.596463881980299*^9}, 
   3.5964639847844796`*^9},ExpressionUUID->"68916d8c-1697-43b2-a171-\
2203537b5055"],

Cell["\<\
Calculate now the the absolute differential. The Riemannian metric is\
\>", "Text",
 CellChangeTimes->{{3.596527770333545*^9, 3.596527809484784*^9}, 
   3.6238487734745255`*^9, {3.624279040769973*^9, 3.6242790508787904`*^9}, 
   3.624279195350644*^9},ExpressionUUID->"1c4ea1d1-af35-49b2-b560-\
4bacde03cc30"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gsph", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5962709980749817`*^9, 3.5962711091643353`*^9}, {
   3.59627160561073*^9, 3.596271620220566*^9}, {3.596370417199809*^9, 
   3.5963704177608414`*^9}, 3.5963713429137573`*^9, 3.596373557527426*^9, 
   3.596437289161309*^9, 3.5964418711857567`*^9, {3.596441937485873*^9, 
   3.596441940169078*^9}, {3.5964626737089767`*^9, 3.596462691680208*^9}, {
   3.5964640216941442`*^9, 3.5964640283085566`*^9}, {3.624263661653592*^9, 
   3.6242637508545485`*^9}, {3.624263795439427*^9, 3.6242638781819725`*^9}, {
   3.6242639871013637`*^9, 3.624263995837379*^9}, {3.6242640661623025`*^9, 
   3.62426407049911*^9}},ExpressionUUID->"291f0e7b-d122-47ca-a241-\
f217158ae0ec"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"gsph", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6242640079586*^9, 3.6242640447278647`*^9}, {
  3.699095817996634*^9, 
  3.699095831439514*^9}},ExpressionUUID->"a7fa3975-2dfe-43e7-b2cf-\
49984957967a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "gsph", "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5962709980749817`*^9, 3.5962711091643353`*^9}, {
   3.59627160561073*^9, 3.596271620220566*^9}, {3.596370417199809*^9, 
   3.5963704177608414`*^9}, 3.5963713429137573`*^9, 3.596373557527426*^9, 
   3.596437289161309*^9, 3.5964418711857567`*^9, {3.596441937485873*^9, 
   3.596441940169078*^9}, {3.5964626737089767`*^9, 3.596462691680208*^9}, {
   3.5964640216941442`*^9, 3.5964640283085566`*^9}, {3.624263661653592*^9, 
   3.6242637508545485`*^9}, {3.624263795439427*^9, 3.6242638781819725`*^9}, {
   3.6242639871013637`*^9, 
   3.624263995837379*^9}},ExpressionUUID->"5f04c305-190a-4411-b9de-\
73f3e3593e81"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DD", "[", "gsph", "]"}], "[", 
    RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], ".", 
  RowBox[{"{", 
   RowBox[{"s1", ",", "s2"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5964627858575735`*^9, 3.5964628284456487`*^9}, 
   3.59646406489062*^9, {3.5964641314715376`*^9, 3.5964641589587855`*^9}, {
   3.596465191508999*^9, 3.5964652077018275`*^9}, 3.6148618621711445`*^9, 
   3.6149177936677647`*^9, {3.624277320835752*^9, 3.6242773228949556`*^9}, {
   3.624280472665288*^9, 
   3.6242804907925196`*^9}},ExpressionUUID->"a8fd9044-3531-4cfd-8cd8-\
77b6501382b2"],

Cell["Its image under the differential of the immersion is", "Text",
 CellChangeTimes->{{3.5965278541893415`*^9, 3.5965279038131795`*^9}, {
  3.6238489243111906`*^9, 
  3.623848953436442*^9}},ExpressionUUID->"0c7c9300-35d1-42b4-8d87-\
172d9630817a"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.596462848039283*^9, 3.5964628573992996`*^9}, {
   3.596462905369384*^9, 3.596462918832207*^9}, {3.5964629656010895`*^9, 
   3.5964630031659555`*^9}, 3.5964633152157035`*^9, {3.5964641983800545`*^9, 
   3.5964642202824936`*^9}},ExpressionUUID->"301da551-71d4-40bf-b94a-\
24af9386c8e1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"diff\[Xi]", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.5964630273147984`*^9, 
  3.596463049482437*^9}},ExpressionUUID->"e011af82-9076-4a7b-af9e-\
98911e39069d"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "diff\[Xi]", "]"}]], "Input",
 CellChangeTimes->{{3.624282151805437*^9, 
  3.6242821789338846`*^9}},ExpressionUUID->"d1e23a40-b7b1-4073-b5f1-\
565816dc189c"],

Cell["Check the statement:", "Text",
 CellChangeTimes->{{3.596528165477146*^9, 
  3.5965281754927187`*^9}},ExpressionUUID->"fb58dbc1-6b9f-4519-89c2-\
c4066b9eec11"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"diff\[Xi]", " ", "-", "pdv"}], "]"}]], "Input",
 CellChangeTimes->{{3.596463140479797*^9, 3.5964631670622435`*^9}, {
  3.5964632076067147`*^9, 
  3.596463212895124*^9}},ExpressionUUID->"9c8dac1b-0ced-488b-9e03-\
5eb34bac1cc5"],

Cell[TextData[{
 "\[FilledRectangle]",
 StyleBox["\nExample 9",
  FontColor->RGBColor[0, 0, 1]],
 ". An arbitrary tangent vector field on a general surface\nWe repeat the \
last example for a general surface."
}], "Text",
 CellChangeTimes->{{3.5964656072653294`*^9, 3.59646561355214*^9}, {
  3.596467189139308*^9, 3.5964672158777547`*^9}, {3.5964673572296033`*^9, 
  3.596467407992092*^9}, {3.5965281927807074`*^9, 3.5965281982890224`*^9}, {
  3.624281781819587*^9, 3.6242818810981617`*^9}, {3.699095951349942*^9, 
  3.6990959525337257`*^9}},ExpressionUUID->"1d0b20fa-bd3f-4a7a-9873-\
58e455dc55cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{
      RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
  RowBox[{"{", 
   RowBox[{"s1", ",", "s2"}], "}"}]}]], "Input",
 CellChangeTimes->{3.596465746994775*^9, 
  3.6238490139801483`*^9},ExpressionUUID->"91e9d36c-be0f-476f-a3f0-\
19fa67c92732"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pdvsf", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"pT", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{
         RowBox[{"tvf", "[", "\[Xi]", "]"}], "[", "sf", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.596461679628431*^9, {3.596461809795059*^9, 3.5964618218694806`*^9}, {
   3.596461958931321*^9, 3.5964619847337666`*^9}, {3.596462552715164*^9, 
   3.596462554743168*^9}, {3.5964636994287786`*^9, 3.5964637060743904`*^9}, {
   3.596463879593495*^9, 3.596463881980299*^9}, 3.5964639847844796`*^9, {
   3.5964657542643876`*^9, 3.596465755200389*^9}, 3.6238490139801483`*^9, {
   3.624282327087345*^9, 3.6242823275397453`*^9}, {3.699096192801387*^9, 
   3.699096203252537*^9}},ExpressionUUID->"aed68443-cfef-48fd-981f-\
2fbde20e59d4"],

Cell["The Riemannian metric remains unspecified:", "Text",
 CellChangeTimes->{{3.624279277235188*^9, 
  3.6242793228340683`*^9}},ExpressionUUID->"50b3926f-09e6-4311-868f-\
33bb551bd5bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"gsf", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"rgT", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6242775807322083`*^9, 3.624277624412285*^9}, {
  3.624277687077595*^9, 
  3.6242776970148125`*^9}},ExpressionUUID->"28ac3056-cd94-4729-978d-\
9cf8dde47076"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "gsf", "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5962709980749817`*^9, 3.5962711091643353`*^9}, {
   3.59627160561073*^9, 3.596271620220566*^9}, {3.596370417199809*^9, 
   3.5963704177608414`*^9}, 3.5963713429137573`*^9, 3.596373557527426*^9, 
   3.596437289161309*^9, 3.5964418711857567`*^9, {3.596441937485873*^9, 
   3.596441940169078*^9}, {3.5964626737089767`*^9, 3.596462691680208*^9}, {
   3.5964640216941442`*^9, 3.5964640283085566`*^9}, 3.596465760769599*^9, 
   3.623849014042548*^9, 
   3.624277712131239*^9},ExpressionUUID->"27121b49-446b-4702-80ba-\
688c7ca35975"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.6242801242854757`*^9, 
  3.6242801338014927`*^9}},ExpressionUUID->"229bde07-7409-45ff-9ba6-\
2995a7681ad9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"resa", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"DD", "[", "gsf", "]"}], "[", 
      RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5964627858575735`*^9, 3.5964628284456487`*^9}, 
   3.59646406489062*^9, {3.5964641314715376`*^9, 3.5964641589587855`*^9}, {
   3.596465191508999*^9, 3.5964652077018275`*^9}, 3.596465764420006*^9, 
   3.6148618623271446`*^9, 3.6149177938081646`*^9, 3.623849014042548*^9, 
   3.6242777709901423`*^9, {3.624280734558548*^9, 3.6242807405957584`*^9}, {
   3.699096303138917*^9, 3.6990963089954147`*^9}, 
   3.69916047485326*^9},ExpressionUUID->"2aa63bea-daa8-41cb-9c86-\
94d2eabba43b"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "resa", "]"}]], "Input",
 CellChangeTimes->{{3.6187544994890356`*^9, 3.6187545076634502`*^9}, 
   3.6238490140581484`*^9},ExpressionUUID->"18daa086-eaeb-4c96-b3c8-\
c850fb3ff065"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{
   RowBox[{"d", "[", "sf", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6187545853515863`*^9, 3.6187546150072384`*^9}, 
   3.6238490140581484`*^9},ExpressionUUID->"a2907017-85c3-4462-ae7b-\
8280f081180b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"diff\[Xi]sf", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"d", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], ")"}], ".", "resa"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.596462848039283*^9, 3.5964628573992996`*^9}, {
   3.596462905369384*^9, 3.596462918832207*^9}, {3.5964629656010895`*^9, 
   3.5964630031659555`*^9}, 3.5964633152157035`*^9, {3.5964641983800545`*^9, 
   3.5964642202824936`*^9}, 3.5964657672904105`*^9, {3.6187545440739136`*^9, 
   3.6187545479583206`*^9}, {3.6187546327444696`*^9, 3.618754654662508*^9}, 
   3.6238490140581484`*^9, {3.699096399034436*^9, 3.699096415794224*^9}, 
   3.699096467649961*^9},ExpressionUUID->"97a947fd-38dd-46a0-adc2-\
bd000e3cd882"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", "s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"2", " ", "s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"s2", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                    RowBox[{"s1", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"s1", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"s2", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                    RowBox[{"s1", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
         RowBox[{"s1", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"s2", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                    RowBox[{"s1", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"s1", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
               RowBox[{"s1", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
         RowBox[{"s1", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", "s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{"2", " ", "s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"\[Xi]", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"s2", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                    RowBox[{"s1", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.5964628601761045`*^9, 3.5964629208758106`*^9, 
  3.5964630043827577`*^9, 3.5964642259765034`*^9, 3.596465155488536*^9, 
  3.5964652184190464`*^9, 3.5964659045394516`*^9, 3.6132225529608793`*^9, 
  3.6187536418307295`*^9, 3.6187543484183702`*^9, 3.618756635460387*^9, 
  3.6238490140737486`*^9, 3.6238492111176944`*^9, 3.624277877319929*^9, 
  3.6242808193134966`*^9, 3.6242838893364887`*^9, 
  3.62589922391602*^9},ExpressionUUID->"ee047e3c-b981-413a-86ac-5a26660b276f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", "s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"2", " ", "s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"s2", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                    RowBox[{"s1", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"s1", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "2", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"s2", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                    RowBox[{"s1", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
         RowBox[{"s1", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"s2", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                    RowBox[{"s1", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"s1", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
               RowBox[{"s1", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "3", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "-", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "1", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
         RowBox[{"s1", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "s2", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", "s1", " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "3", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Xi]", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s2", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "2", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"f", "[", "2", "]"}], 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "-", 
         RowBox[{"2", " ", "s1", " ", 
          RowBox[{
           RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}]}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"]}], "-", 
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{"2", " ", "s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"f", "[", "1", "]"}], 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "-", 
               RowBox[{"2", " ", "s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"s2", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{"s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "s1", " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"\[Xi]", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
                    RowBox[{"u", ",", "v"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"s2", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}], "+", 
                    RowBox[{"s1", " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"]}], "+", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "3", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Xi]", "[", "2", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s2", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "-", 
            RowBox[{"s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox[
                RowBox[{"f", "[", "1", "]"}], 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"2", " ", "s1", " ", 
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s2", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{"s1", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Xi]", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"u", ",", "v"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
              RowBox[{"u", ",", "v"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}], "+", 
               RowBox[{"s1", " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "3", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "3", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "1", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "3", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "2", "]"}], 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "v"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "2", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "1", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"f", "[", "1", "]"}], 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "2", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"f", "[", "3", "]"}], 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"u", ",", "v"}], "]"}], "2"]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.5964628601761045`*^9, 3.5964629208758106`*^9, 
  3.5964630043827577`*^9, 3.5964642259765034`*^9, 3.596465155488536*^9, 
  3.5964652184190464`*^9, 3.5964659045394516`*^9, 3.6132225529608793`*^9, 
  3.6187536418307295`*^9, 3.6187543484183702`*^9, 3.618756635460387*^9, 
  3.6238490140737486`*^9, 3.6238492111176944`*^9, 3.624277877319929*^9, 
  3.6242808193134966`*^9, 
  3.6242838893364887`*^9},ExpressionUUID->"00896805-ccc6-40d1-acc6-\
d0d85649ea55"]
}, Closed]],

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"diff\[Xi]sf", " ", "-", "pdvsf"}], "]"}]], "Input",
 CellChangeTimes->{{3.596463140479797*^9, 3.5964631670622435`*^9}, {
   3.5964632076067147`*^9, 3.596463212895124*^9}, 3.6238490140737486`*^9, {
   3.624283873986062*^9, 3.6242838788532705`*^9}, 
   3.6990964904575787`*^9},ExpressionUUID->"cf787b0e-4b47-4ba4-950a-\
3433bf3445a0"],

Cell["\[FilledRectangle]", "Text",
 CellChangeTimes->{{3.5965283114394946`*^9, 3.5965283970773926`*^9}, {
  3.624279440973076*^9, 
  3.62427944351588*^9}},ExpressionUUID->"c4f1459e-4aa3-42df-aaec-\
8c3a11f7e906"],

Cell["We consider now", "Text",
 CellChangeTimes->{{3.699096786854076*^9, 
  3.6990967951422997`*^9}},ExpressionUUID->"1186225f-606c-4c1a-b207-\
53043338fd75"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DDimm"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.624284255422332*^9, 3.624284423185026*^9}, {
  3.624284507189603*^9, 3.624284581883534*^9}, {3.6242846431604414`*^9, 
  3.624284701379744*^9}, {3.6242847889294987`*^9, 3.6242848901288767`*^9}, {
  3.6242850307485237`*^9, 3.62428506862539*^9}, {3.6259053262975273`*^9, 
  3.6259053324751387`*^9}},ExpressionUUID->"f52722f6-a892-40b5-83bf-\
9bcb4ed2dfa1"],

Cell[BoxData[
 StyleBox["\<\"DDimm[[f][vw][x,y,...] is the absolute Differential of the \
vector field vw[x,y,...] \\non an immersion f[x,y,...]into the Euclidean \
n-space; here vw is a vector field on the \\nparameter manifold. and the \
images of DDim lie in the Euclidean n-space.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.708321853649848*^9},
 CellTags->
  "Info893708329053-6824778",ExpressionUUID->"18686a5e-5560-4bb2-9b0d-\
5684365b14c0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DDimm", "[", "f_", "]"}], "[", "vw_", "]"}], "[", "x__", "]"}], ":=",
   " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "f", "]"}], "[", "x", "]"}], ".", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"vw", "[", "x", "]"}], "[", 
           RowBox[{"[", "k", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"{", "x", "}"}], "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[CapitalGamma]rgT", "[", 
              RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "f", "]"}], "[", 
            "x", "]"}], "*", 
           RowBox[{
            RowBox[{"vw", "[", "x", "]"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"{", "x", "}"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}], "]"}], 
    "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.624280924910082*^9, 3.6242809373433037`*^9}, {
   3.6242810276050625`*^9, 3.62428108878837*^9}, 3.6242812758014984`*^9, {
   3.6242813418832145`*^9, 3.6242813572648416`*^9}, {3.6242814124577384`*^9, 
   3.6242814491802025`*^9}},ExpressionUUID->"c32e0cdb-1298-40b3-a238-\
b86851f222c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6242815731068206`*^9},ExpressionUUID->"77ea0968-dd89-4730-a635-\
40a456422fcb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DDimm", "[", 
    RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6242814735630455`*^9, 3.624281483952664*^9}, {
  3.624281590500851*^9, 
  3.624281632667725*^9}},ExpressionUUID->"b7ecf55d-c013-4257-b2e4-\
8e14642ff808"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ddsph", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.624281676347802*^9, 
  3.6242816864722195`*^9}},ExpressionUUID->"74437b0a-e542-4497-86d6-\
f19dfb307eaf"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "ddsph", "]"}]], "Input",
 CellChangeTimes->{{3.624281691261428*^9, 
  3.624281700637045*^9}},ExpressionUUID->"32f23e2a-fa8e-4b8f-9370-\
710e15bc102b"],

Cell["\<\
The result coincides with the vector field diff\[Xi] calculated by another \
method above:\
\>", "Text",
 CellChangeTimes->{{3.6242840929636464`*^9, 
  3.6242841567053585`*^9}},ExpressionUUID->"f6d78e53-083c-4764-b837-\
f161825249d7"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"ddsph", ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], " ", "\[Equal]", " ", "diff\[Xi]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.624281886308571*^9, 3.6242819463842764`*^9}, {
  3.6242819862891464`*^9, 3.6242819870379477`*^9}, {3.624282094210136*^9, 
  3.6242821195445805`*^9}, {3.6242822001031218`*^9, 
  3.6242822196187563`*^9}},ExpressionUUID->"94e7f7dc-3d0b-4e3d-8d7e-\
2c132e24ef26"],

Cell["The analogue calculation in case of a general surface:", "Text",
 CellChangeTimes->{{3.6242865842022524`*^9, 
  3.6242866075428934`*^9}},ExpressionUUID->"50f76b85-0efb-4729-93e0-\
caf06df43dec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"DDimm", "[", "sf", "]"}], "[", 
     RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.624286240391248*^9, 3.6242862966761475`*^9}, 
   3.699096677256263*^9},ExpressionUUID->"b9692574-abbf-47f6-9ffa-\
02cd85bfcee1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ddsf", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6242863394378223`*^9, 
  3.624286354710249*^9}},ExpressionUUID->"b771f7e0-baf5-4a02-87a9-\
aec16be095ba"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"ddsf", ".", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], "\[Equal]", " ", "diff\[Xi]sf"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.624286411463149*^9, 
  3.624286493690893*^9}},ExpressionUUID->"f95db393-dde9-474d-8177-\
43ce4492dafb"],

Cell["OK! ", "Text",
 CellChangeTimes->{{3.6242866321909366`*^9, 3.624286635934943*^9}, 
   3.699096735910624*^9},ExpressionUUID->"78384840-7c5c-4501-a648-\
62a720b09644"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.3. Absolute Parallel Vector Fields", "Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, {
   3.5972984401750546`*^9, 3.59729846072029*^9}, {3.5972984954771514`*^9, 
   3.5972985062723703`*^9}, {3.5973320886172123`*^9, 3.5973320905123205`*^9}, 
   3.5973952636966553`*^9, 3.6132229905260477`*^9, 3.6132797959577127`*^9, 
   3.6171013236210327`*^9, 3.6171717453084965`*^9, {3.6188032063086033`*^9, 
   3.6188032409562645`*^9}, 3.618817261348339*^9, 3.6990969050943604`*^9, 
   3.69916681456492*^9, 3.707969319068659*^9, 
   3.7080926585788107`*^9},ExpressionUUID->"4fc4849b-bd74-4838-adc5-\
d657f6126f6c"],

Cell["\<\
Considering immersions we often will omit the word \
\[OpenCurlyDoubleQuote]tangent\[CloseCurlyDoubleQuote]; if not emphasized \
explicitly, e.g. the normal vector field e{3][sf][u,v], a vector field on an \
immersion is always meant to be a tangent vector field. Such a vector field \
\>", "Text",
 CellChangeTimes->{{3.5972985733524885`*^9, 3.5972986623350444`*^9}, {
   3.5972987038467174`*^9, 3.597298884011434*^9}, 3.5972989562083607`*^9, 
   3.6132230395101337`*^9},ExpressionUUID->"6b4dd21f-1889-4491-a6b9-\
4e9c8dc1fb3b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";", " ", 
  RowBox[{"mf", " ", "=", " ", "2"}], ";", " ", 
  RowBox[{
   RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
   RowBox[{
    RowBox[{"u", "[", "1", "]"}], ",", 
    RowBox[{"u", "[", "2", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5956590461387978`*^9, 3.5956590587255173`*^9}, 
   3.595924528295635*^9, {3.597299146747095*^9, 3.5972992078212023`*^9}, {
   3.597300291508306*^9, 3.5973003191827545`*^9}, {3.5973004499577847`*^9, 
   3.5973004648714104`*^9}, 
   3.699097366109448*^9},ExpressionUUID->"714f09aa-de32-4cd8-b855-\
c5c031d29d8a"],

Cell[TextData[{
 "is said to be ",
 StyleBox["absolute parallel",
  FontColor->RGBColor[0, 0, 1]],
 " if"
}], "Text",
 CellChangeTimes->{
  3.5972989670035796`*^9, {3.597299243826066*^9, 
   3.5972992583808913`*^9}},ExpressionUUID->"ef13bbf3-0b25-4b95-8376-\
d1d25f679fd6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DDimm", "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
    RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"u", "[", "1", "]"}], ",", 
    RowBox[{"u", "[", "2", "]"}]}], "]"}], "\[Equal]", " ", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5972993146657906`*^9, 3.5972993494538517`*^9}, {
   3.597299402821545*^9, 3.597299430792394*^9}, 3.5972995294157677`*^9, 
   3.5973003459836016`*^9, 3.6132230887126207`*^9, {3.624339079502738*^9, 
   3.62433908661635*^9}, {3.699097439826119*^9, 
   3.699097452432804*^9}},ExpressionUUID->"f0064214-8e5b-44be-92d6-\
3dbf60f62360"],

Cell["\<\
Here the 0 at the right side stands for the corresponding \
\[OpenCurlyDoubleQuote]null tensor\[CloseCurlyDoubleQuote], appearing as the \
null square matrix of order mf. Analogously the absolute parallel vector \
fields on a Riemannian manifold are defined:\
\>", "Text",
 CellChangeTimes->{{3.5973005157118998`*^9, 3.5973006704641714`*^9}, 
   3.5973830346646786`*^9, 3.6171684676959395`*^9, {3.624339772502755*^9, 
   3.6243398263072495`*^9}, {3.6990976688066998`*^9, 
   3.699097671078691*^9}},ExpressionUUID->"6aa8d685-2acf-439b-ab51-\
f543d32c60f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DD", "[", "g", "]"}], "[", 
    RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"u", "[", "1", "]"}], ",", 
    RowBox[{"u", "[", "2", "]"}]}], "]"}], "\[Equal]", " ", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5972993146657906`*^9, 3.5972993494538517`*^9}, {
   3.597299402821545*^9, 3.597299430792394*^9}, 3.5972995294157677`*^9, 
   3.5973003459836016`*^9, 3.6132230887126207`*^9, {3.624339079502738*^9, 
   3.62433908661635*^9}, {3.624339889799361*^9, 3.6243399149310055`*^9}, {
   3.699097471833721*^9, 
   3.6990975009684973`*^9}},ExpressionUUID->"314a7573-7154-4087-b49e-\
ba54acfc2174"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"DDimm", "[", 
     RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
    RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
   RowBox[{
    RowBox[{"u", "[", "1", "]"}], ",", 
    RowBox[{"u", "[", "2", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973000987231674`*^9, 3.597300125648815*^9}, 
   3.597300366778438*^9, 3.597300478474634*^9, {3.6243394226409407`*^9, 
   3.624339423452142*^9}, 
   3.699097533838522*^9},ExpressionUUID->"7904fa50-9bf4-45a9-b676-\
8a62801a3862"],

Cell[TextData[{
 StyleBox["Example 10",
  FontColor->RGBColor[0, 0, 1]],
 ". For the ",
 StyleBox["Euclidean space",
  FontColor->RGBColor[0, 0, 1]],
 " the absolute differential coincides with the total differential. Therefore \
the absolute parallel vector fields are the vector fields with constant \
Cartesian coordinates:"
}], "Text",
 CellChangeTimes->{{3.5973040529501977`*^9, 3.597304222288495*^9}, {
  3.699097717422679*^9, 3.6990977198144617`*^9}, {3.7080665700821533`*^9, 
  3.708066571569912*^9}},ExpressionUUID->"2f3a2359-7867-4943-b6ed-\
aa3bbe77acea"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "euclid", "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.59730430471904*^9, 
  3.5973043671191497`*^9}},ExpressionUUID->"6920750d-97e9-4968-9e52-\
09e40c499f42"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"u", ",", "v"}], "}"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6244463836798086`*^9, 3.6244463859574127`*^9}, {
   3.624446476546771*^9, 3.624446525858458*^9}, 
   3.6244466760711217`*^9},ExpressionUUID->"5cfe9d8f-8ec2-4d7e-a31d-\
acd44d66801c"],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.624340005551564*^9, 
  3.6243400125091763`*^9}},ExpressionUUID->"d949ea10-5b81-4b9f-a497-\
c024f7013b2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "1", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", "a1"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "2", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", "a2"}], ";", 
  RowBox[{
   RowBox[{"vv", "[", "c", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5972997287685175`*^9, 3.597299731280122*^9}, {
  3.597299801963846*^9, 
  3.5972999486041036`*^9}},ExpressionUUID->"daa5f51a-5183-48cb-947c-\
3063052f316e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "euclid", "]"}], "[", 
   RowBox[{"vv", "[", "c", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.5972999616457267`*^9, 
  3.5972999994601927`*^9}},ExpressionUUID->"1b04bcfd-542e-499e-a67b-\
241255cbb7b8"],

Cell["\<\
\[FilledRectangle]
Now we define a general pseudo-Riemannian metric:\
\>", "Text",
 CellChangeTimes->{{3.5973044572093077`*^9, 3.597304457224908*^9}, {
   3.597304491498168*^9, 3.59730455511508*^9}, 3.5973046113063784`*^9, {
   3.5973061652563076`*^9, 3.597306219747204*^9}, {3.597306396932315*^9, 
   3.597306402064724*^9}, 3.617441250860256*^9, 3.6244561042991996`*^9, {
   3.6244561896937494`*^9, 
   3.6244562186006002`*^9}},ExpressionUUID->"987ddbfc-4e08-4bfc-a3d1-\
ad84e2475e05"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"i", ",", "j", ",", "grg", ",", "GRG", ",", "gen"}], "]"}], ";", 
  RowBox[{
   RowBox[{"GRG", "[", "x__", "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", "=", " ", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "x", "}"}], "]"}]}], "}"}], ",", 
     RowBox[{"Normal", "[", 
      RowBox[{"SymmetrizedArray", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}], "\[Rule]", " ", 
         RowBox[{
          RowBox[{"gen", "[", 
           RowBox[{"i", ",", "j"}], "]"}], "[", "x", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "n"}], "}"}], ",", 
        RowBox[{"Symmetric", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}], "]"}]}], "]"}], "]"}]}], "]"}]}], 
  ";", 
  RowBox[{
   RowBox[{
    RowBox[{"grg", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], "[", "x__", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"GRG", "[", "x", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7080826436222363`*^9, 3.7080826885549517`*^9}, {
   3.708082772521269*^9, 3.7080828612177677`*^9}, {3.708083005776368*^9, 
   3.708083023335504*^9}, 3.708083116664041*^9, {3.708083148971849*^9, 
   3.708083167361814*^9}, {3.7080834643033953`*^9, 3.708083514118593*^9}, {
   3.708083544192184*^9, 3.7080835458882008`*^9}, {3.708083632399563*^9, 
   3.708083839773929*^9}, {3.708083915828342*^9, 3.708083921331189*^9}, {
   3.708084119788309*^9, 3.7080841371537046`*^9}, {3.708085367688692*^9, 
   3.70808541540047*^9}, {3.708085514017055*^9, 3.708085545640855*^9}, {
   3.708085583631152*^9, 3.708085624677394*^9}, {3.7080857563270683`*^9, 
   3.70808582086475*^9}, {3.708086435925187*^9, 
   3.7080864382042418`*^9}},ExpressionUUID->"5676ae84-17dc-4ac7-beef-\
97ce721ed764"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"grg", "::", "usage"}], " ", "=", " ", 
   "\"\<grg[i,j][x,y,...] is a general, unspecified pseudo-Riemannian metric \
with respect to local coordinates {x,y,...};\nGRG[x,y,...] is the symmetric \
matrix of the components grg\[RightArrow]i.j][x,y,...].\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6245190611007977`*^9, 3.6245192090046577`*^9}, 
   3.6245192630275526`*^9, {3.6260057896070085`*^9, 3.626005797953023*^9}, {
   3.708086478848032*^9, 
   3.708086572422893*^9}},ExpressionUUID->"21a90fa9-74a4-42bf-a79e-\
3c44e33da8cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"grg", "[", 
   RowBox[{"3", ",", "1"}], "]"}], "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.6244548894002657`*^9, 3.624454901459087*^9}, {
   3.624455275578944*^9, 3.624455279510151*^9}, 3.6244562481470523`*^9, 
   3.6260058374210925`*^9, {3.70808659941325*^9, 
   3.708086602190092*^9}},ExpressionUUID->"c79a4c10-e2b4-4fb9-a651-\
379cb7986dcd"],

Cell[BoxData[
 RowBox[{"%", "==", 
  RowBox[{
   RowBox[{"grg", "[", 
    RowBox[{"3", ",", "1"}], "]"}], "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.708086621779991*^9, 
  3.7080866360282516`*^9}},ExpressionUUID->"28008baa-5846-4148-ac2b-\
9d84a1881596"],

Cell[BoxData[
 RowBox[{"TensorSymmetry", "[", 
  RowBox[{"GRG", "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.708086639475366*^9, 
  3.7080867226508102`*^9}},ExpressionUUID->"ce2087b4-751d-443d-81a9-\
adac0980de6e"],

Cell[TextData[{
 StyleBox["Warning.",
  FontColor->RGBColor[1, 0, 0]],
 " Mathematica gives the rank of a symbolic Matrix as maximal"
}], "Text",
 CellChangeTimes->{{3.699098334176528*^9, 
  3.699098407320217*^9}},ExpressionUUID->"e14416b3-d6ee-4be1-9f03-\
4fb40525d4ea"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"grg", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "[", 
     RowBox[{"u", ",", "v", ",", "w"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.699097856134583*^9, 3.699097893556993*^9}, {
  3.6990979357967443`*^9, 
  3.6990980269645*^9}},ExpressionUUID->"2f1c3a39-3854-4ed1-82fc-4ee282c72aa8"],

Cell[BoxData[
 RowBox[{"MatrixRank", "[", 
  RowBox[{"GRG", "[", 
   RowBox[{"u", ",", "v", ",", "w"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.699097856134583*^9, 3.699097893556993*^9}, {
  3.6990979357967443`*^9, 3.6990980269645*^9}, {3.708086757642027*^9, 
  3.70808678963491*^9}},ExpressionUUID->"c0d1e679-abd4-42db-8c8f-\
06f2cc6c06bb"],

Cell["in spite of the fact that this will not be true, in general:", "Text",
 CellChangeTimes->{{3.6990984250641108`*^9, 
  3.699098465271896*^9}},ExpressionUUID->"cc10033c-0b6c-4011-a60c-\
94f7f2263410"],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"GRG", "[", 
     RowBox[{"u", ",", "v", ",", "w"}], "]"}], "]"}], "\[NotEqual]", " ", 
   "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.699097856134583*^9, 3.699097893556993*^9}, {
   3.6990979357967443`*^9, 3.6990980853875504`*^9}, {3.699098116394725*^9, 
   3.69909813825167*^9}, 
   3.708086828807819*^9},ExpressionUUID->"0bd20ee3-33c7-4379-8061-\
2b7b8c8ceb4d"],

Cell["\<\
For the general pseudo-Riemannian metric this property has to be assumed.\
\>", "Text",
 CellChangeTimes->{{3.699098571606823*^9, 
  3.699098631222538*^9}},ExpressionUUID->"c5c8cb35-497b-4c56-83b9-\
3e3d06d7f837"],

Cell["\[FilledSquare]", "Text",
 CellChangeTimes->{{3.699098513881525*^9, 
  3.699098513883862*^9}},ExpressionUUID->"1629cb4e-61f8-42b9-b7c0-\
bcb6a3be3360"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"1", ",", "2", ",", "1"}], "]"}], "[", "grg", "]"}], "[", 
    RowBox[{
     RowBox[{"u", "[", "1", "]"}], ",", 
     RowBox[{"u", "[", "2", "]"}]}], "]"}], "-", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "[", "grg", "]"}], "[", 
    RowBox[{
     RowBox[{"u", "[", "1", "]"}], ",", 
     RowBox[{"u", "[", "2", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.624453316667903*^9, 3.624453341019546*^9}, {
   3.6244544473266892`*^9, 3.624454513892006*^9}, 3.624454598475355*^9, {
   3.6244548284041586`*^9, 3.624454852599801*^9}, {3.626010744332236*^9, 
   3.6260107453462377`*^9}, {3.699097599310055*^9, 
   3.699097602320469*^9}},ExpressionUUID->"52789f4d-a459-4502-a54e-\
23645d6c2b41"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalGamma]", "[", 
     RowBox[{"1", ",", "2", ",", "1"}], "]"}], "[", "grg", "]"}], "[", 
   RowBox[{
    RowBox[{"u", "[", "1", "]"}], ",", 
    RowBox[{"u", "[", "2", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.624455445120042*^9, 3.6260107469374404`*^9, 
  3.699097603904583*^9},ExpressionUUID->"4555ae42-4dc4-417f-a99b-\
98739c59a78b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"grg", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.6244536869813538`*^9, 3.6244536974957724`*^9}, {
   3.6244537298034286`*^9, 3.624453735107438*^9}, {3.6244538621228614`*^9, 
   3.624453865071266*^9}, {3.6244563513724337`*^9, 3.6244563585172462`*^9}, {
   3.6244564158005466`*^9, 3.6244564548318152`*^9}, 
   3.626005839277496*^9},ExpressionUUID->"790f4815-5496-42de-a44e-\
69e5a85cd0dd"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Det", "[", "%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6244538793608913`*^9, 3.624453931511783*^9}, {
  3.624453984551876*^9, 3.624453987656282*^9}, {3.6244564941906843`*^9, 
  3.624456510445913*^9}},ExpressionUUID->"e366296c-130f-47ea-9fad-\
63d9b82c2d6c"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Inverse", "[", "%%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6244566684585905`*^9, 
  3.6244566901894283`*^9}},ExpressionUUID->"fe51af70-0351-402d-ab1b-\
784f0f0815ed"],

Cell["\<\
Now we consider this general case and ask whether there exist absolute \
parallel vector fields. The system of linear partial differential equations \
of first order to find them is:\
\>", "Text",
 CellChangeTimes->{
  3.6244561411776648`*^9, {3.6244578001781783`*^9, 
   3.6244578152010045`*^9}},ExpressionUUID->"aba78785-9e53-4beb-a2e9-\
fce63879bea1"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"DD", "[", "grg", "]"}], "[", 
       RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "1", "]"}], ",", 
       RowBox[{"u", "[", "2", "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Equal]", " ", "0"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "mf"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "mf"}], "}"}]}], "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973046678096776`*^9, 3.5973048127651324`*^9}, 
   3.597305117074867*^9, {3.5973055552952366`*^9, 3.597305559070443*^9}, 
   3.614861862498745*^9, 3.6148635021396246`*^9, 3.6188037315971227`*^9, 
   3.6188037658630824`*^9, {3.624355033463996*^9, 3.624355045413617*^9}, 
   3.624355133787772*^9, {3.624456851836912*^9, 3.6244568734897504`*^9}, {
   3.624456941880271*^9, 3.6244569555926948`*^9}, 3.624457008055587*^9, 
   3.626010748996644*^9, 3.699097606495988*^9, {3.708066978036764*^9, 
   3.7080669911456623`*^9}},ExpressionUUID->"51dfc519-4fa0-4fad-95c7-\
fa51a7ec7d86"],

Cell["Remembering", "Text",
 CellChangeTimes->{{3.597306271258494*^9, 3.5973063053289537`*^9}, {
  3.6244579809980955`*^9, 
  3.6244579846017017`*^9}},ExpressionUUID->"442758f4-b837-44f5-84a3-\
a24274b3c86d"],

Cell[BoxData["mf"], "Input",
 CellChangeTimes->{{3.624457115180975*^9, 
  3.6244571177705793`*^9}},ExpressionUUID->"e54d5174-d4c7-437f-8cb2-\
39a5e0d3f926"],

Cell["\<\
and using the definition of the absolute differential we may rewrite this \
system as\
\>", "Text",
 CellChangeTimes->{{3.597306271258494*^9, 3.5973063053289537`*^9}, {
  3.6244579954437213`*^9, 
  3.624457998626127*^9}},ExpressionUUID->"c64b70b4-0281-4f5b-9f58-\
bcfea9b5acab"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
        RowBox[{
         RowBox[{"u", "[", "1", "]"}], ",", 
         RowBox[{"u", "[", "2", "]"}]}], "]"}], "[", 
       RowBox[{"[", "k", "]"}], "]"}], ",", 
      RowBox[{"x", "[", "j", "]"}]}], "]"}], "\[Equal]", " ", 
    RowBox[{"-", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "grg", "]"}], "[", 
         RowBox[{
          RowBox[{"u", "[", "1", "]"}], ",", 
          RowBox[{"u", "[", "2", "]"}]}], "]"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
          RowBox[{
           RowBox[{"u", "[", "1", "]"}], ",", 
           RowBox[{"u", "[", "2", "]"}]}], "]"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "mf"}], "}"}]}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "mf"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "mf"}], "}"}]}], "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973052297070646`*^9, 3.597305240642684*^9}, {
   3.5973052727631407`*^9, 3.5973053555524855`*^9}, {3.5973054039593706`*^9, 
   3.597305412757786*^9}, 3.5973054583410664`*^9, {3.597305510507558*^9, 
   3.5973055337047987`*^9}, {3.59730556880486*^9, 3.597305581394082*^9}, 
   3.597305692388277*^9, 3.6148618625143447`*^9, 3.614863502155225*^9, 
   3.6243547514291005`*^9, {3.6243551505578012`*^9, 3.624355151930604*^9}, 
   3.624355192272275*^9, {3.6244570688644934`*^9, 3.624457077054508*^9}, 
   3.6244576396850967`*^9, 3.6260107522414494`*^9, {3.699097608431253*^9, 
   3.699097610703239*^9}, {3.708067069693516*^9, 
   3.7080670760598907`*^9}},ExpressionUUID->"85687b17-ced2-4068-a8f8-\
646526d65b40"],

Cell[TextData[{
 "or, in traditional form, as a system of differential equations for the \
coordinates ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}]],
  Evaluatable->False,
  CellChangeTimes->{{3.5973058712737913`*^9, 3.5973059305226955`*^9}, {
   3.597305962658752*^9, 3.5973060124072394`*^9}, {3.5973060436228943`*^9, 
   3.5973060926225805`*^9}},ExpressionUUID->
  "f97c2d14-5874-4d6e-acfa-12bb7ca73d36"],
 " of the vector field "
}], "Text",
 CellChangeTimes->{{3.5973063359986076`*^9, 3.597306379600684*^9}, {
  3.5973064171031504`*^9, 
  3.597306458396423*^9}},ExpressionUUID->"fadcbedb-84a5-4d26-a943-\
7b8350ccaabc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "j"], 
    RowBox[{
     SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{
    RowBox[{"-", " ", 
     SubsuperscriptBox["\[CapitalSigma]", 
      RowBox[{"i", "=", "1"}], "mf"]}], 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalGamma]", "[", 
       RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "grg", "]"}], "[", "x", 
     "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}], ",", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"k", ",", "j", ",", "1", ",", "..", ",", "m"}], ")"}], "                                                                       ", 
   RowBox[{"(", "1", ")"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973058712737913`*^9, 3.5973059305226955`*^9}, {
   3.597305962658752*^9, 3.5973060124072394`*^9}, {3.5973060436228943`*^9, 
   3.5973060926225805`*^9}, {3.5973064685364404`*^9, 3.597306522949336*^9}, {
   3.5973134928002768`*^9, 3.597313703088646*^9}, {3.6243553099588814`*^9, 
   3.624355313094487*^9}, 3.6244574499575634`*^9, 3.6244577130520253`*^9, {
   3.6244580529610224`*^9, 3.624458069403451*^9}, 3.626010754051053*^9, {
   3.7080671444317904`*^9, 3.708067217983221*^9}, {3.708067255496758*^9, 
   3.7080672599104977`*^9}},ExpressionUUID->"48c3a4f9-e721-4b42-92c1-\
0c37a0cfeabe"],

Cell[TextData[{
 "Assume that we found a solution (",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}], ",", " ", 
   RowBox[{"k", " ", "=", " ", "1"}], ",", "...", ",", "m"}]],
  Evaluatable->False,
  CellChangeTimes->{{3.5973058712737913`*^9, 3.5973059305226955`*^9}, {
   3.597305962658752*^9, 3.5973060124072394`*^9}, {3.5973060436228943`*^9, 
   3.5973060926225805`*^9}, {3.5973064685364404`*^9, 3.597306522949336*^9}},
  ExpressionUUID->"28e79b9b-b30a-4e07-a0d2-182518045a45"],
 "f) of this system. Then these functions satisfy also the following \
derivations of the equations:"
}], "Text",
 CellChangeTimes->{{3.5973065921510572`*^9, 3.5973067715513725`*^9}, 
   3.5973137235558815`*^9},ExpressionUUID->"24103ed5-dcd1-4b95-b62d-\
fc9b715104a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[PartialD]", "h"], 
   RowBox[{
    SubscriptBox["\[PartialD]", "j"], 
    RowBox[{
     SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}]}]}], " ", "\[Equal]", " ", 
  RowBox[{"-", " ", 
   RowBox[{
    SubscriptBox["\[PartialD]", "h"], 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["\[CapitalSigma]", 
       RowBox[{"i", "=", "1"}], "mf"], 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalGamma]", "[", 
         RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "grg", "]"}], "[", 
       "x", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}], ")"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973058712737913`*^9, 3.5973059305226955`*^9}, {
   3.597305962658752*^9, 3.5973060124072394`*^9}, {3.5973060436228943`*^9, 
   3.5973060926225805`*^9}, {3.5973064685364404`*^9, 3.597306522949336*^9}, {
   3.597313407951728*^9, 3.5973134700554366`*^9}, {3.597313752103932*^9, 
   3.5973138567021155`*^9}, {3.5973138906945753`*^9, 3.5973138933309803`*^9}, 
   3.62445771568843*^9, 3.626010757545459*^9},
 FontSize->16,ExpressionUUID->"bdea39d4-3d9f-4df2-9602-aba92e688e53"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"\[Equal]", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["\[CapitalSigma]", 
       RowBox[{"i", "=", "1"}], "mf"]}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", "h"], 
       RowBox[{
        RowBox[{
         RowBox[{"\[CapitalGamma]", "[", 
          RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "grg", "]"}], "[", 
        "x", "]"}]}], ")"}], 
     RowBox[{
      SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}], "-", " ", 
    RowBox[{
     SubsuperscriptBox["\[CapitalSigma]", 
      RowBox[{"i", "=", "1"}], "mf"], 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "grg", "]"}], "[", "x",
       "]"}], " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "h"], 
      RowBox[{
       SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.597313955278689*^9, 3.5973139664483085`*^9}, {
   3.5973140016887703`*^9, 3.597314030439621*^9}, {3.5973140614368753`*^9, 
   3.597314082777713*^9}, 3.5973141235249844`*^9, 3.597314177547879*^9, {
   3.5973142101831365`*^9, 3.597314235361581*^9}, {3.597315982396927*^9, 
   3.5973159873392096`*^9}, {3.6243553651517787`*^9, 
   3.6243553788330026`*^9}, {3.6244574555423727`*^9, 
   3.6244574570555754`*^9}, {3.624457717810034*^9, 3.624457722209241*^9}, {
   3.6260107592926617`*^9, 3.6260107606186647`*^9}},
 FontSize->16,ExpressionUUID->"900ddc85-c4e7-4466-af67-2519ad45d693"],

Cell["\<\
for  j ,k ,h= 1,..,mf. Inserting equation (1) with renamed indices  \
\>", "Text",
 CellChangeTimes->{{3.5973139027065964`*^9, 3.597313937791058*^9}, {
   3.5973141374558086`*^9, 3.597314150653432*^9}, 3.5973145527441382`*^9, {
   3.597314592071807*^9, 3.597314653442315*^9}, 3.597314768898118*^9, 
   3.597315097138294*^9, {3.617168754455643*^9, 3.61716875815285*^9}, 
   3.6171688253109674`*^9},ExpressionUUID->"0562415b-38d7-4724-920a-\
7a1ca7a58376"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[PartialD]", "h"], 
   RowBox[{
    SuperscriptBox["\[Xi]", "l"], "[", "x", "]"}]}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"-", 
    StyleBox[
     SubsuperscriptBox["\[CapitalSigma]", 
      RowBox[{"i", "=", "1"}], "mf"],
     FontSize->14]}], 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", "grg", "]"}], "[", "x", 
    "]"}], 
   RowBox[{
    SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.597314922839188*^9, 3.597314928517598*^9}, 
   3.5973149670652657`*^9, {3.5973150064397354`*^9, 3.5973150128513465`*^9}, {
   3.597315389576408*^9, 3.5973154186548595`*^9}, 3.5973156631852884`*^9, {
   3.624355399549839*^9, 3.6243554015622425`*^9}, 3.624457465822791*^9, 
   3.6244577240812445`*^9, 3.6260107708366823`*^9},
 FontSize->16,ExpressionUUID->"22302b5b-dee5-433a-8357-01039427801b"],

Cell["into the second term we obtain for the this term", "Text",
 CellChangeTimes->{
  3.597315106404711*^9, {3.6171688319097795`*^9, 
   3.6171688324869804`*^9}},ExpressionUUID->"a71a5515-4298-48b7-8fb9-\
3fddd478ea91"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", " ", 
    SubsuperscriptBox["\[CapitalSigma]", 
     RowBox[{"l", "=", "1"}], "mf"]}], 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", "grg", "]"}], "[", "x", 
    "]"}], " ", 
   RowBox[{
    SubscriptBox["\[PartialD]", "h"], 
    RowBox[{
     SuperscriptBox["\[Xi]", "l"], "[", "x", "]"}]}]}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"+", 
    SubsuperscriptBox["\[CapitalSigma]", 
     RowBox[{"l", "=", "1"}], "mf"]}], 
   SubsuperscriptBox["\[CapitalSigma]", 
    RowBox[{"i", "=", "1"}], "mf"], 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", "grg", "]"}], "[", "x", 
    "]"}], 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", "grg", "]"}], "[", "x", 
    "]"}], 
   RowBox[{
    SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973146918963823`*^9, 3.597314697137992*^9}, {
   3.5973147316608524`*^9, 3.597314749491684*^9}, 3.597314788897353*^9, {
   3.5973148208618093`*^9, 3.597314844620651*^9}, 3.5973150316181793`*^9, {
   3.5973154540045214`*^9, 3.5973154840501738`*^9}, {3.597315550833891*^9, 
   3.597315574561533*^9}, {3.5973156251212215`*^9, 3.597315676570112*^9}, {
   3.6243554243694825`*^9, 3.624355459876145*^9}, {3.6244574673671937`*^9, 
   3.6244574700191984`*^9}, {3.6244577257816477`*^9, 
   3.6244577292916536`*^9}, {3.626010772287485*^9, 
   3.6260107749862895`*^9}},ExpressionUUID->"6a951e3a-6719-463a-8de3-\
e51034a8fc60"],

Cell[TextData[{
 "Adding the results for the two terms and collecting the terms at ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]],
  CellChangeTimes->{{3.5973146918963823`*^9, 3.597314697137992*^9}, {
    3.5973147316608524`*^9, 3.597314749491684*^9}, 3.597314788897353*^9, {
    3.5973148208618093`*^9, 3.597314844620651*^9}, 3.5973150316181793`*^9, {
    3.5973154540045214`*^9, 3.5973154840501738`*^9}, {3.597315550833891*^9, 
    3.597315574561533*^9}, {3.5973156251212215`*^9, 3.597315676570112*^9}},
  ExpressionUUID->"8e70cc71-c54b-4390-9238-a8637c861b15"],
 " yields"
}], "Text",
 CellChangeTimes->{{3.597315754383049*^9, 3.5973157695774755`*^9}, {
  3.597315915735114*^9, 
  3.597315949999074*^9}},ExpressionUUID->"700ec548-0347-4f31-a0cb-\
5af6dcd509c1"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "h"], 
    RowBox[{
     SubscriptBox["\[PartialD]", "j"], 
     RowBox[{
      SuperscriptBox["\[Xi]", "k"], "[", "x", "]"}]}]}], "\[Equal]", 
   "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{"-", " ", 
     RowBox[{
      SubsuperscriptBox["\[CapitalSigma]", 
       RowBox[{"i", "=", "1"}], "mf"], "(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "h"], 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "grg", "]"}], "[", 
         "x", "]"}]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[CapitalSigma]", 
         RowBox[{"l", "=", "1"}], "mf"], 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", "grg", "]"}], "[", 
         "x", "]"}], 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", "grg", "]"}], "[", 
         "x", "]"}]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973160039211583`*^9, 3.5973160378971014`*^9}, {
   3.5973160743631873`*^9, 3.5973160847617817`*^9}, {3.597316129803358*^9, 
   3.5973162206325536`*^9}, {3.5973162523453674`*^9, 
   3.5973163002021046`*^9}, {3.5973163303778305`*^9, 3.597316379267627*^9}, {
   3.624355489484997*^9, 3.624355507643429*^9}, {3.624457473201604*^9, 
   3.624457475775608*^9}, {3.6244577309452567`*^9, 3.6244577351572638`*^9}, {
   3.6260107762030916`*^9, 3.6260107782622957`*^9}, {3.708067553167365*^9, 
   3.708067559853549*^9}, {3.7080676027016363`*^9, 3.7080676110133553`*^9}, {
   3.7080678295570374`*^9, 3.70806787594722*^9}, 3.708067935768055*^9, {
   3.7080680014516172`*^9, 3.7080680014540033`*^9}, 
   3.708068095087574*^9},ExpressionUUID->"92328f1a-1c0d-4c10-bc30-\
0af6af3e189e"],

Cell[TextData[{
 "Permuting h and j and subtracting from the last equation the left side \
becomes zero, and we obtain a system of linear equations for the coordinates ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]],
  CellChangeTimes->{{3.5973160039211583`*^9, 3.5973160378971014`*^9}, {
   3.5973160743631873`*^9, 3.5973160847617817`*^9}, {3.597316129803358*^9, 
   3.5973162206325536`*^9}, {3.5973162523453674`*^9, 
   3.5973163002021046`*^9}, {3.5973163303778305`*^9, 3.597316379267627*^9}},
  ExpressionUUID->"cf641a8a-52b9-4261-93ea-d6b8016d2d10"],
 ":"
}], "Text",
 CellChangeTimes->{{3.5973174735432158`*^9, 3.5973175753910413`*^9}, {
   3.5973176149943066`*^9, 3.597317622350727*^9}, 3.5973279986752806`*^9, 
   3.61744129428474*^9, {3.618804143009654*^9, 3.618804146752868*^9}, 
   3.6188232318984947`*^9},ExpressionUUID->"712ccddd-3856-4397-9103-\
97b66766db0b"],

Cell[BoxData[
 RowBox[{"0", " ", "=", 
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "1"}], "mf"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "h"], 
       RowBox[{
        RowBox[{
         RowBox[{"\[CapitalGamma]", "[", 
          RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "grg", "]"}], "[", 
        "x", "]"}]}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", "j"], 
       RowBox[{
        RowBox[{
         RowBox[{"\[CapitalGamma]", "[", 
          RowBox[{"k", ",", "i", ",", "h"}], "]"}], "[", "grg", "]"}], "[", 
        "x", "]"}]}], "-", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"l", "=", "1"}], "mf"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]", "[", 
             RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", "grg", "]"}], "[",
            "x", "]"}], 
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]", "[", 
             RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", "grg", "]"}], "[",
            "x", "]"}]}], "-", " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]", "[", 
             RowBox[{"k", ",", "l", ",", "h"}], "]"}], "[", "grg", "]"}], "[",
            "x", "]"}], 
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]", "[", 
             RowBox[{"l", ",", "i", ",", "j"}], "]"}], "[", "grg", "]"}], "[",
            "x", "]"}]}]}], ")"}]}]}], ")"}], "*", 
    RowBox[{
     SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973280116780243`*^9, 3.5973280157692585`*^9}, {
   3.597328075913699*^9, 3.5973280771907716`*^9}, {3.597328179819642*^9, 
   3.5973283575508075`*^9}, 3.597328398054124*^9, {3.6243555266598625`*^9, 
   3.6243555695755377`*^9}, {3.624457481126418*^9, 3.624457494230441*^9}, {
   3.624457739135271*^9, 3.6244577508508916`*^9}, {3.62599134814475*^9, 
   3.625991350297554*^9}, {3.625991389609623*^9, 3.6259914949098077`*^9}, {
   3.6259915253142614`*^9, 3.625991539354286*^9}, 3.625991618711625*^9, {
   3.6259916918601537`*^9, 3.6259917018441715`*^9}, {3.625991864521257*^9, 
   3.6259918794816833`*^9}, 3.6259922141334715`*^9, 3.625992261089554*^9, {
   3.625992315455649*^9, 3.6259923329744797`*^9}, {3.625992396872192*^9, 
   3.6259924242658405`*^9}, 3.6260011022667756`*^9, {3.6260011462432528`*^9, 
   3.626001173870901*^9}, {3.626001322273962*^9, 3.6260013379519897`*^9}, {
   3.6260013718040495`*^9, 3.6260014063581095`*^9}, {3.6260014403193693`*^9, 
   3.626001453704193*^9}, {3.6260107796350975`*^9, 
   3.6260107865303097`*^9}},ExpressionUUID->"e9f09745-503a-42c6-b964-\
c1e5c81de896"],

Cell[TextData[{
 "The coefficients of this linear system are the coordinates of the",
 StyleBox[" Riemannian curvature tensor",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[", ",
  FontColor->GrayLevel[0]],
 "defined for a pseudo-Riemannian space with metric tensor g[i,j][x,y,...]"
}], "Text",
 CellChangeTimes->{{3.5973884413774414`*^9, 3.597388472552224*^9}, {
   3.5973885165367403`*^9, 3.5973885696807795`*^9}, 3.5973913039921737`*^9, {
   3.624355928769169*^9, 3.6243559380511847`*^9}, {3.6244583522007475`*^9, 
   3.62445836482117*^9}, {3.6244585643767204`*^9, 
   3.6244586082907977`*^9}},ExpressionUUID->"f929a056-f022-45e3-bfe1-\
f19d729b65f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"R", "[", 
     RowBox[{"k_", ",", "i_", ",", "h_", ",", "j_"}], "]"}], "[", "g_", "]"}],
    "[", "x__", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "g", "]"}], "[", "x", 
      "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "h", "]"}], "]"}]}], "]"}], " ", "-", "  ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"k", ",", "i", ",", "h"}], "]"}], "[", "g", "]"}], "[", "x", 
      "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], " ", "-", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", "g", "]"}], "[", 
         "x", "]"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", "g", "]"}], "[", 
         "x", "]"}]}], "-", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"k", ",", "l", ",", "h"}], "]"}], "[", "g", "]"}], "[", 
         "x", "]"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"l", ",", "i", ",", "j"}], "]"}], "[", "g", "]"}], "[", 
         "x", "]"}]}]}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973286677245483`*^9, 3.5973289520468106`*^9}, {
   3.597328985941749*^9, 3.5973290042307954`*^9}, 3.5973290495683885`*^9, {
   3.597329079818119*^9, 3.597329268394905*^9}, {3.624355833702602*^9, 
   3.624355897210313*^9}},ExpressionUUID->"f992379c-b0c0-4e22-994f-\
94cb1dde1aa0"],

Cell[BoxData[
 RowBox[{"?", "R"}]], "Input",
 CellChangeTimes->{{3.6243685480756545`*^9, 3.624368611786166*^9}, {
  3.6243687165583916`*^9, 3.6243687976161337`*^9}, {3.624368838581806*^9, 
  3.6243689280011625`*^9}, {3.625925143972164*^9, 
  3.6259251490421734`*^9}},ExpressionUUID->"cb2a9f8e-61f7-4404-8d90-\
d45287d09444"],

Cell[TextData[{
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 ". This well known expression coincides with the formula contained in \
Proposition 7.6, p.145 in \n",
 ButtonBox["S. Kobayashi, K. Nomizu I",
  BaseStyle->"Hyperlink",
  ButtonData->"K-N1"],
 ".\n\nThe integrability condition:"
}], "Text",
 CellChangeTimes->{{3.5973885997855015`*^9, 3.5973886194826283`*^9}, {
   3.5973886805381203`*^9, 3.597388763016838*^9}, {3.597388807320372*^9, 
   3.5973888593523483`*^9}, {3.5973892481165843`*^9, 3.597389248119584*^9}, {
   3.5974686722211447`*^9, 3.5974687529512863`*^9}, 3.597471054875729*^9, {
   3.6259248594520626`*^9, 3.625924876177292*^9}, {3.626001672478977*^9, 
   3.6260016794989896`*^9}, {3.6991007418451777`*^9, 3.6991007452367563`*^9}, 
   3.6991050169588537`*^9},ExpressionUUID->"e4ccc134-21ca-40bc-ab3c-\
fdd26fd53ebd"],

Cell[TextData[{
 StyleBox["Proposition 1",
  FontColor->RGBColor[0, 0, 1]],
 ". An absolute parallel vector field with coordinates ",
 Cell[BoxData[
  SubscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}], ")"}], 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"--", 
     RowBox[{",", "m"}]}]}]]],
  CellChangeTimes->{{3.5973280116780243`*^9, 3.5973280157692585`*^9}, {
    3.597328075913699*^9, 3.5973280771907716`*^9}, {3.597328179819642*^9, 
    3.5973283575508075`*^9}, 3.597328398054124*^9},ExpressionUUID->
  "2077fc1a-fb30-4ea6-b3c1-55eaa65c89ae"],
 "  on a pseudo- Riemannian manifold ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", "m"], TraditionalForm]],ExpressionUUID->
  "4f4860e3-2550-4dc6-ba0d-8b2a04c3c485"],
 " satisfies the system of linear equations"
}], "Text",
 CellChangeTimes->{{3.597468651223508*^9, 3.5974686651231318`*^9}, {
  3.5974687616873016`*^9, 3.5974687668353105`*^9}, {3.59746886327468*^9, 
  3.5974690072941327`*^9}, {3.5974692417313447`*^9, 3.5974692445393496`*^9}, {
  3.59746943280048*^9, 3.59746948360977*^9}, {3.59747449972058*^9, 
  3.5974745004849815`*^9}, {3.624458646869665*^9, 3.6244587141837835`*^9}, {
  3.699104892940201*^9, 
  3.6991049091522903`*^9}},ExpressionUUID->"a81e666f-b314-4b55-a478-\
cd5e35900b57"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "m"], 
    RowBox[{
     RowBox[{"R", "[", 
      RowBox[{"k", ",", "i", ",", "j", ",", "h"}], "]"}], 
     RowBox[{
      SuperscriptBox["\[Xi]", "i"], "[", "x", "]"}]}]}], "\[Equal]", " ", 
   "0"}], ",", "           ", 
  RowBox[{"(", 
   RowBox[{"k", ",", " ", "j", ",", " ", 
    RowBox[{"h", " ", "\[Equal]", " ", "1"}], ",", "...", ",", "m"}], 
   ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5974690605526266`*^9, 3.5974691322035522`*^9}, {
  3.597469170220819*^9, 3.5974692133236947`*^9}, {3.5974693011986494`*^9, 
  3.5974693148330727`*^9}},ExpressionUUID->"85c40db5-a316-444a-8259-\
cd86c6ac29c7"],

Cell["\<\
A necessary condition for the existence of such a non zero vector field is \
that the rank of this system is less the dimension m of the manifold. \
Obviously, the set of all absolute parallel vector fields is a finite \
dimensional vector space under pointwise addition and multiplication with \
real numbers. \[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.597469516494627*^9, 3.597469627332822*^9}, 
   3.597471074609764*^9, {3.597471155386706*^9, 3.5974713113089795`*^9}, 
   3.624458742887834*^9, 
   3.699104965038293*^9},ExpressionUUID->"9cc2ab81-068a-4ffd-bed8-\
db5ea93d45ee"],

Cell[TextData[{
 "Repeating this considerations with the Riemannian metric rgT[f][x,y,...], \
DD replaced by DDimm and \[CapitalGamma] by \[CapitalGamma]rgT one obtains \
the result of Proposition 1 where the curvature tensor is now given by \nthe",
 StyleBox[" curvature tensor of the immersion",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" f, ",
  FontColor->GrayLevel[0]],
 "defined as"
}], "Text",
 CellChangeTimes->{{3.6244573675114183`*^9, 3.624457369913822*^9}, {
   3.624458808236349*^9, 3.6244588092191505`*^9}, {3.6244588694976563`*^9, 
   3.6244591352285233`*^9}, 3.624459228485487*^9, {3.624459263975549*^9, 
   3.6244592902303953`*^9}},ExpressionUUID->"a1724591-c349-430a-8a4c-\
6d7bf6d5d0eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Rimm", "[", 
     RowBox[{"k_", ",", "i_", ",", "h_", ",", "j_"}], "]"}], "[", "ff_", 
    "]"}], "[", "x__", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]rgT", "[", 
        RowBox[{"k", ",", "i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", "x", 
      "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "h", "]"}], "]"}]}], "]"}], " ", "-", "  ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]rgT", "[", 
        RowBox[{"k", ",", "i", ",", "h"}], "]"}], "[", "ff", "]"}], "[", "x", 
      "]"}], ",", 
     RowBox[{
      RowBox[{"{", "x", "}"}], "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], " ", "-", " ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]rgT", "[", 
           RowBox[{"k", ",", "l", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
         "x", "]"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]rgT", "[", 
           RowBox[{"l", ",", "i", ",", "h"}], "]"}], "[", "ff", "]"}], "[", 
         "x", "]"}]}], "-", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]rgT", "[", 
           RowBox[{"k", ",", "l", ",", "h"}], "]"}], "[", "ff", "]"}], "[", 
         "x", "]"}], "*", 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]rgT", "[", 
           RowBox[{"l", ",", "i", ",", "j"}], "]"}], "[", "ff", "]"}], "[", 
         "x", "]"}]}]}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.624355724048009*^9, 
  3.6243558027521477`*^9}},ExpressionUUID->"19f0426b-6709-4ec5-ad2d-\
59f9b9eb6a3c"],

Cell[BoxData[
 RowBox[{"?", "Rimm"}]], "Input",
 CellChangeTimes->{{3.6243685480756545`*^9, 3.624368611786166*^9}, {
  3.6243687165583916`*^9, 3.6243687976161337`*^9}, {3.6259252523283553`*^9, 
  3.6259252596321683`*^9}},ExpressionUUID->"2d761383-7f4e-420b-83f7-\
3ec46019d44f"],

Cell[TextData[{
 StyleBox["Example 11",
  FontColor->RGBColor[0, 0, 1]],
 ". The spheres"
}], "Text",
 CellChangeTimes->{{3.5973893009176044`*^9, 3.597389332593416*^9}, 
   3.597391353152985*^9, {3.69910515768132*^9, 
   3.6991051608735*^9}},ExpressionUUID->"aedc9154-fef2-4121-ad63-\
59573848bf1a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Rimm", "[", 
      RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5973293281183205`*^9, 3.5973294162033587`*^9}, {
   3.5973295020032663`*^9, 3.597329553733225*^9}, 3.597329586043073*^9, 
   3.5973303088194137`*^9, 3.5973304210758343`*^9, {3.5973306909162683`*^9, 
   3.597330716155712*^9}, {3.6243690461245704`*^9, 3.6243690467953715`*^9}, {
   3.624517408340295*^9, 
   3.62451742267672*^9}},ExpressionUUID->"783f98ac-7ebc-4d68-abaa-\
9b1f156ff6a0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Rimm", "[", 
     RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "]"}], "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973307960902843`*^9, 3.597330833107401*^9}, {
  3.6243690742670197`*^9, 
  3.624369074859821*^9}},ExpressionUUID->"3db4edbe-12ad-4ffb-9a30-\
ffb710c2f82d"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Rimm", "[", 
     RowBox[{"2", ",", "1", ",", "1", ",", "2"}], "]"}], "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973307960902843`*^9, 3.597330869385476*^9}, {
  3.6243690925034523`*^9, 
  3.6243690934394536`*^9}},ExpressionUUID->"73d5e8a4-c2d3-4b30-a14c-\
1ebd0fb71822"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Rimm", "[", 
     RowBox[{"2", ",", "2", ",", "1", ",", "2"}], "]"}], "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973307960902843`*^9, 3.597330869385476*^9}, {
  3.5973308994891977`*^9, 3.597330908523715*^9}, {3.6243691063562765`*^9, 
  3.6243691332351236`*^9}},ExpressionUUID->"afd85407-5f45-479c-a1b4-\
ca978aa6e38e"],

Cell["\<\
The coefficients  R[k, i, h, j] are anti-symmetric with respect to the last \
two  indices h, j:\
\>", "Text",
 CellChangeTimes->{{3.597389423456613*^9, 3.597389486240204*^9}, {
  3.5973895586333447`*^9, 3.5973896440652313`*^9}, {3.597389952256859*^9, 
  3.597389976545248*^9}},ExpressionUUID->"358c78ef-fd5c-4df8-b86b-\
de5716656d69"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Rimm", "[", 
        RowBox[{"1", ",", "2", ",", "h", ",", "j"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"Rimm", "[", 
        RowBox[{"1", ",", "2", ",", "j", ",", "h"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"h", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.597330933249129*^9, 3.5973310703899727`*^9}, 
   3.597384757134715*^9, {3.5973896545658317`*^9, 3.5973896918149624`*^9}, 
   3.6148618625455446`*^9, 3.614863502170825*^9, {3.6243691561515636`*^9, 
   3.6243691657143803`*^9}},ExpressionUUID->"ac150b32-71ce-463f-b5a3-\
a401a3da31ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Rimm", "[", 
        RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.597330933249129*^9, 3.5973310703899727`*^9}, 
   3.597384757134715*^9, {3.5973896545658317`*^9, 3.59738979650895*^9}, {
   3.597389835566184*^9, 3.5973898447817116`*^9}, 3.614861862561145*^9, 
   3.614863502170825*^9, {3.6243691827340107`*^9, 
   3.624369183779212*^9}},ExpressionUUID->"a56c693e-6f95-439d-8d52-\
ae69a2eb011f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Rimm", "[", 
         RowBox[{"1", ",", "i", ",", "1", ",", "2"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "]"}], "*", 
     RowBox[{"\[Xi]", "[", "i", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}]}], "]"}], "\[Equal]", "0"}]], "Input",
 CellChangeTimes->{{3.5974714282935853`*^9, 3.59747143094559*^9}, {
  3.597471488338091*^9, 3.5974715248577547`*^9}, {3.597471588677467*^9, 
  3.597471677597623*^9}, {3.597471867231556*^9, 3.597471873611967*^9}, {
  3.6243692021560445`*^9, 
  3.6243692034352465`*^9}},ExpressionUUID->"c8b423f4-e3bc-48dc-ae74-\
62920e57d2a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Rimm", "[", 
         RowBox[{"2", ",", "i", ",", "1", ",", "2"}], "]"}], "[", 
        RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "]"}], "*", 
     RowBox[{"\[Xi]", "[", "i", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}]}], "]"}], "\[Equal]", "0"}]], "Input",
 CellChangeTimes->{{3.5974714282935853`*^9, 3.59747143094559*^9}, {
   3.597471488338091*^9, 3.5974715248577547`*^9}, {3.597471588677467*^9, 
   3.597471677597623*^9}, {3.597471793537027*^9, 3.5974718058298483`*^9}, 
   3.597471891193198*^9, {3.624369244198118*^9, 
   3.6243692455085206`*^9}},ExpressionUUID->"62c2f3fc-3616-48e2-8f68-\
d57e8f8f2340"],

Cell["\<\
It follows: The only absolute parallel vector field on the sphere of radius r \
is the zero vector field.\[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.59747198351416*^9, 3.597472062653099*^9}, {
  3.6132240301052513`*^9, 
  3.6132240472582326`*^9}},ExpressionUUID->"272768ae-5e32-4119-bfc3-\
74f8e459a280"],

Cell[TextData[{
 "Often one uses the covariant form of the curvature tensor defined by",
 StyleBox[" lowering the index",
  FontColor->RGBColor[0, 0, 1]],
 " k:"
}], "Text",
 CellChangeTimes->{{3.5973901479610524`*^9, 
  3.5973902036652384`*^9}},ExpressionUUID->"e8d6dbb0-0def-4afa-a335-\
b97839813d0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"covR", "[", 
      RowBox[{"k_", ",", "i_", ",", "h_", ",", "j_"}], "]"}], "[", "g_", 
     "]"}], "[", "x__", "]"}], " ", ":=", "  ", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{"k", ",", "l"}], "]"}], "[", "x", "]"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{"R", "[", 
         RowBox[{"l", ",", "i", ",", "h", ",", "j"}], "]"}], "[", "g", "]"}], 
       "[", "x", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973286677245483`*^9, 3.5973289520468106`*^9}, {
   3.597328985941749*^9, 3.5973290042307954`*^9}, 3.5973290495683885`*^9, {
   3.597329079818119*^9, 3.597329268394905*^9}, {3.5973312970269356`*^9, 
   3.5973313689200478`*^9}, {3.5973314099923973`*^9, 3.597331434333789*^9}, 
   3.6186424048824086`*^9, {3.6243692892509975`*^9, 3.624369290296199*^9}, {
   3.6243710854089527`*^9, 3.624371086376154*^9}, 3.6245177926157703`*^9, {
   3.6245178256566277`*^9, 3.624517890256342*^9}, {3.624518944880594*^9, 
   3.6245189560970135`*^9}, 3.6260058406658983`*^9, 
   3.699161208874292*^9},ExpressionUUID->"643c1929-4c46-4166-884c-\
1fe099d2abda"],

Cell[BoxData[
 RowBox[{"?", "covR"}]], "Input",
 CellChangeTimes->{{3.6245182784786234`*^9, 3.624518408161651*^9}, {
   3.624518443339713*^9, 3.6245184629177475`*^9}, 3.6245185108878317`*^9, {
   3.624518967344633*^9, 3.624518972835843*^9}, {3.6259257471472282`*^9, 
   3.6259257502360334`*^9}},ExpressionUUID->"53050f01-fffc-467f-b4b3-\
85c3ad7eb7f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"covRimm", "[", 
     RowBox[{"k_", ",", "i_", ",", "h_", ",", "j_"}], "]"}], "[", "ff_", 
    "]"}], "[", "x__", "]"}], " ", ":=", "  ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"rgT", "[", 
        RowBox[{"k", ",", "l"}], "]"}], "[", "ff", "]"}], "[", "x", "]"}], 
     "*", 
     RowBox[{
      RowBox[{
       RowBox[{"Rimm", "[", 
        RowBox[{"l", ",", "i", ",", "h", ",", "j"}], "]"}], "[", "ff", "]"}], 
      "[", "x", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"l", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"{", "x", "}"}], "]"}]}], "}"}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5973286677245483`*^9, 3.5973289520468106`*^9}, {
   3.597328985941749*^9, 3.5973290042307954`*^9}, 3.5973290495683885`*^9, {
   3.597329079818119*^9, 3.597329268394905*^9}, {3.5973312970269356`*^9, 
   3.5973313689200478`*^9}, {3.5973314099923973`*^9, 3.597331434333789*^9}, 
   3.6186424048824086`*^9, {3.6243692892509975`*^9, 3.624369290296199*^9}, {
   3.6243710854089527`*^9, 
   3.624371086376154*^9}},ExpressionUUID->"96ec8204-0640-4586-9789-\
48961aaddf22"],

Cell[BoxData[
 RowBox[{"?", "covRimm"}]], "Input",
 CellChangeTimes->{{3.6245182784786234`*^9, 3.624518408161651*^9}, {
   3.624518443339713*^9, 3.6245184629177475`*^9}, {3.6245185399038825`*^9, 
   3.6245186395568576`*^9}, 3.624518684718937*^9, {3.625925729140796*^9, 
   3.625925736523609*^9}},ExpressionUUID->"a0cdd543-b172-496b-8f5a-\
b5dca1e50c9f"],

Cell["\<\
The coefficients covR[h, j, 1, 2] are also antisymmetric with respect to the \
first two indices:\
\>", "Text",
 CellChangeTimes->{{3.597391451864631*^9, 
  3.5973916154249864`*^9}},ExpressionUUID->"8f4316b0-bfec-4966-a6c4-\
a616cd89ee9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"covRimm", "[", 
        RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", 
       RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.597330933249129*^9, 3.5973310703899727`*^9}, 
   3.597384757134715*^9, {3.5973896545658317`*^9, 3.59738979650895*^9}, {
   3.597389835566184*^9, 3.5973898447817116`*^9}, {3.5973903233100815`*^9, 
   3.597390324033123*^9}, 3.614861862576745*^9, 3.6148635021864247`*^9, {
   3.6243693300918694`*^9, 
   3.6243693315114717`*^9}},ExpressionUUID->"5a0369d3-90a3-4a3d-9946-\
9f9ee90c7d1d"],

Cell["This is true for a general surface:", "Text",
 CellChangeTimes->{{3.597391626064595*^9, 
  3.59739163960837*^9}},ExpressionUUID->"fda5858b-d1c0-425f-8bdb-\
08d2c491e0cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"covRimm", "[", 
         RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", "sf", "]"}],
        "[", 
       RowBox[{"u", ",", "v"}], "]"}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"covRimm", "[", 
         RowBox[{"j", ",", "h", ",", "1", ",", "2"}], "]"}], "[", "sf", "]"}],
        "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"h", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.597330933249129*^9, 3.5973310703899727`*^9}, 
   3.597384757134715*^9, {3.5973896545658317`*^9, 3.59738979650895*^9}, {
   3.597389835566184*^9, 3.5973898447817116`*^9}, {3.5973903233100815`*^9, 
   3.597390324033123*^9}, {3.5973904566657095`*^9, 3.597390511477844*^9}, 
   3.6148618625923448`*^9, 3.6148635022020245`*^9, {3.624369447232475*^9, 
   3.6243694839861393`*^9}},ExpressionUUID->"264bf2a6-84cc-4880-b3c9-\
5c2167ec7ba6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", "4"}], ";", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"covRimm", "[", 
          RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "+", 
       RowBox[{
        RowBox[{
         RowBox[{"covRimm", "[", 
          RowBox[{"j", ",", "h", ",", "1", ",", "2"}], "]"}], "[", 
         RowBox[{"smf", "[", "f", "]"}], "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.5973905920774546`*^9, 3.5973907262311277`*^9}, {
   3.5973927065273943`*^9, 3.5973927241184*^9}, 3.597392767086858*^9, {
   3.6132779599386983`*^9, 3.6132779817299447`*^9}, 3.6148618626079445`*^9, 
   3.6148635022176247`*^9, {3.624519396813388*^9, 3.6245194394326625`*^9}, 
   3.6260046936582837`*^9, 3.6260047272139425`*^9, 3.626004777633231*^9, {
   3.708078662650703*^9, 
   3.708078696301594*^9}},ExpressionUUID->"82e41dac-d387-425f-8088-\
df73ab7565de"],

Cell["and for the general pseudo-Riemannian space:", "Text",
 CellChangeTimes->{{3.597392845137322*^9, 3.597392874136981*^9}, {
  3.6245187925307264`*^9, 
  3.624518832341996*^9}},ExpressionUUID->"f9490d24-422a-405a-beb0-\
7198ca526a67"],

Cell[BoxData[
 RowBox[{"??", "grg"}]], "Input",
 CellChangeTimes->{{3.6260051421434712`*^9, 3.626005143079473*^9}, 
   3.626005860275133*^9},ExpressionUUID->"443a1825-1b51-4881-a776-\
f51830057833"],

Cell[BoxData[
 RowBox[{"Context", "[", "grg", "]"}]], "Input",
 CellChangeTimes->{{3.6260052092547894`*^9, 3.6260052163060017`*^9}, 
   3.626005397219519*^9, 3.6260058737223563`*^9, {3.708083078992804*^9, 
   3.708083109574252*^9}},ExpressionUUID->"6c884d47-df82-4cbb-a26f-\
e826d4c80232"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "3"}], ";", 
  RowBox[{"Timing", "[", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"covR", "[", 
           RowBox[{"h", ",", "j", ",", "1", ",", "2"}], "]"}], "[", "grg", 
          "]"}], "[", 
         RowBox[{"u", ",", "v", ",", "w"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"covR", "[", 
           RowBox[{"j", ",", "h", ",", "1", ",", "2"}], "]"}], "[", "grg", 
          "]"}], "[", 
         RowBox[{"u", ",", "v", ",", "w"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"h", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", 
     RowBox[{"TimeConstraint", "\[Rule]", "Infinity"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5973905920774546`*^9, 3.5973907262311277`*^9}, {
   3.5973927065273943`*^9, 3.5973927241184*^9}, 3.597392767086858*^9, {
   3.6132779599386983`*^9, 3.6132779737894907`*^9}, 3.6148618626235447`*^9, 
   3.614863502233225*^9, {3.6245194827539387`*^9, 3.6245195430324445`*^9}, {
   3.6260042812715592`*^9, 3.6260043001475925`*^9}, 3.626004421781006*^9, {
   3.626005918525635*^9, 3.626005921770441*^9}, {3.6260112284634857`*^9, 
   3.6260112853255863`*^9}, {3.708079005544613*^9, 3.708079059170352*^9}, {
   3.708079183607985*^9, 3.708079241098913*^9}, {3.708079279254908*^9, 
   3.708079281526951*^9}, {3.70808210909715*^9, 
   3.708082114250799*^9}},ExpressionUUID->"63673c34-e660-481d-9bf4-\
8e4fb8d1de8f"],

Cell[TextData[{
 "Mathematica v. 9.0.1.0 needed96.22 s., v. 11.1.1.0 needed 25.148 s. only.\n\
It follows\n",
 StyleBox["Lemma 5",
  FontColor->RGBColor[0, 0, 1]],
 ". The only essential component of the covariant curvature tensor of a \
surface smf[u,v] in the n-dimensional Euclidean space is \ncovRimm[1,2,1,2 \
][smf][u,v]. \[FilledSquare]"
}], "Text",
 CellChangeTimes->{{3.5973929512323904`*^9, 3.597393035953236*^9}, {
   3.5973930819938693`*^9, 3.5973930855450726`*^9}, {3.597474539173049*^9, 
   3.5974745400154505`*^9}, {3.699106611137372*^9, 3.699106613209489*^9}, {
   3.699161367685833*^9, 3.699161441037196*^9}, 3.699162326630559*^9, {
   3.699162407485935*^9, 3.6991624126193657`*^9}, {3.7080896909684753`*^9, 
   3.708089786183476*^9}},ExpressionUUID->"cc2775ba-f66a-45b8-8b06-\
2d8c523586ae"],

Cell[TextData[{
 "We return to dimension 3 and show\n",
 StyleBox["Lemma 6",
  FontColor->RGBColor[0, 0, 1]],
 ". The essential component of the curvature tensor of a surface in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"E", " "}], 
    RowBox[{"3", " "}]], TraditionalForm]],ExpressionUUID->
  "e22ec907-2786-4945-8bbb-e9d22cee4148"],
 " is  related to the Gaussian curvature by the following formula"
}], "Text",
 CellChangeTimes->{{3.5973928878887672`*^9, 3.59739289807335*^9}, {
   3.5973932554967933`*^9, 3.597393345600947*^9}, {3.597393403425254*^9, 
   3.5973934148809094`*^9}, {3.597395110080869*^9, 3.5973951371294165`*^9}, {
   3.5974745575810814`*^9, 3.597474558517083*^9}, {3.613278341997551*^9, 
   3.613278344620701*^9}, 3.699111329696951*^9, {3.699162523893032*^9, 
   3.699162585244295*^9}},ExpressionUUID->"88f709d3-2a57-4a95-8620-\
16a1a41c7e5b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"covRimm", "[", 
     RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", "sf", "]"}], 
   "[", 
   RowBox[{"u", ",", "v"}], "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{".", " ", 
    RowBox[{
     RowBox[{"gauss", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "*", 
   RowBox[{
    RowBox[{
     RowBox[{"dA", "[", "sf", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "^", "2."}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6991626490288982`*^9, 
  3.6991626927080803`*^9}},ExpressionUUID->"04a4ca04-42ab-4c6a-8354-\
0d37bd714501"],

Cell["We prove this Lemma by a symbolic calculation:", "Text",
 CellChangeTimes->{{3.6991627287230253`*^9, 
  3.6991627640590057`*^9}},ExpressionUUID->"1144cbf6-2137-4165-8fac-\
7e3f5e2c47b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", " ", 
  RowBox[{"sf", "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6991660865230503`*^9, 
  3.699166095698936*^9}},ExpressionUUID->"a8819b17-5163-430c-8231-\
2f93e7332835"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"covRimm", "[", 
        RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", "sf", "]"}], 
      "[", 
      RowBox[{"u", ",", "v"}], "]"}], "-", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"gauss", "[", "sf", "]"}], "[", 
       RowBox[{"u", ",", "v"}], "]"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{"dA", "[", "sf", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "^", "2"}]}]}], ",", 
    RowBox[{"TimeConstraint", " ", "\[Rule]", "  ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5973933860842624`*^9, 3.59739338866141*^9}, {
   3.597393435294077*^9, 3.597393445980688*^9}, 3.5973951782147665`*^9, {
   3.617169970290579*^9, 3.617170009321847*^9}, {3.6245210195906377`*^9, 
   3.62452102080744*^9}, {3.624526591111689*^9, 3.6245265993641033`*^9}, {
   3.624531878234537*^9, 3.6245319201674104`*^9}, {3.6991628397151213`*^9, 
   3.699162862299539*^9}, 
   3.699166075182816*^9},ExpressionUUID->"f84ef3aa-fcc8-4f18-be81-\
ad3ae4602c45"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" 9.0.1.0  needed 2.428 s, but ",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Mathematica",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" 11.1.1.0 needed 2512.48 s  \[TildeTilde] 42 min for this \
calculation!",
  FontColor->RGBColor[1, 0, 0]],
 "\nIndeed the expressions to compare are large: "
}], "Text",
 CellChangeTimes->{{3.6991657500525017`*^9, 3.699165908579628*^9}, {
  3.708088807776367*^9, 3.7080888281045303`*^9}, {3.708088858727169*^9, 
  3.708088961271718*^9}, {3.708092476172554*^9, 3.708092491035857*^9}, {
  3.708092540765156*^9, 
  3.708092566259413*^9}},ExpressionUUID->"69aa5253-08cd-4526-b4b1-\
1e23fcbe7e24"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covRimm", "[", 
    RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.699162385001768*^9, 
  3.699165984368498*^9},ExpressionUUID->"c7adce41-6692-4f43-a4cc-\
2b207b720af4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dA", "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",ExpressionUUID->"9d44baf8-3039-\
4177-8d69-70ee79c57b46"],

Cell[BoxData[
 RowBox[{"?", "gauss"}]], "Input",
 CellChangeTimes->{{3.6245215843896303`*^9, 
  3.6245215880868363`*^9}},ExpressionUUID->"4875874a-96c8-4a0d-af48-\
56e4d41b14db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gauss", "[", "sf", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",ExpressionUUID->"7ff4aa55-97bb-\
4e34-ad35-1a1cb89f3253"],

Cell["OK. \[FilledRectangle]", "Text",
 CellChangeTimes->{{3.5973951992669706`*^9, 3.5973951992739706`*^9}, {
  3.699166024922724*^9, 
  3.699166028506706*^9}},ExpressionUUID->"41269ff6-f411-4d94-ba06-\
43eaf155a58d"],

Cell["For the spheres we have", "Text",
 CellChangeTimes->{{3.597395222457297*^9, 
  3.597395232160852*^9}},ExpressionUUID->"9c5277ff-351b-4dec-9e0d-\
77917eb7919c"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"covRimm", "[", 
      RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", 
     RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "/", 
   RowBox[{
    RowBox[{
     RowBox[{"dA", "[", 
      RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5973866631347313`*^9, 3.5973866754074335`*^9}, {
   3.597386706204195*^9, 3.597386716163765*^9}, {3.5973867934351845`*^9, 
   3.597386821596795*^9}, 3.597386857140828*^9, {3.624521039511873*^9, 
   3.6245210410094757`*^9}},ExpressionUUID->"290bdaba-278f-416a-8296-\
553c4afa69ab"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"gauss", "[", 
    RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5973307960902843`*^9, 3.597330833107401*^9}, {
  3.5973319086279173`*^9, 
  3.597331910039998*^9}},ExpressionUUID->"b0abf5d1-855e-4207-848e-\
8c57c8467b8a"],

Cell["\<\
For a surface in the Euclidean 3-space the necessary conditions of \
proposition 1 are equivalent to\
\>", "Text",
 CellChangeTimes->{{3.597472852045686*^9, 3.59747288294934*^9}, {
  3.699166233385392*^9, 
  3.699166273249263*^9}},ExpressionUUID->"5b999392-bbe2-4087-bc40-\
8ffc38894e50"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"covRimm", "[", 
          RowBox[{"k", ",", "i", ",", "1", ",", "2"}], "]"}], "[", "sf", 
         "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "/", 
       RowBox[{
        RowBox[{
         RowBox[{"dA", "[", "sf", "]"}], "[", 
         RowBox[{"u", ",", "v"}], "]"}], "^", "2"}]}], "*", 
      RowBox[{"\[Xi]", "[", "i", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}], "\[Equal]", " ", "0"}], ",", 
  " "}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.597472280023881*^9, 3.597472380628458*^9}, 
   3.5974726087632585`*^9, {3.597472647560527*^9, 3.5974726521625347`*^9}, {
   3.597472682535788*^9, 3.597472689774201*^9}, 3.597473403163454*^9, {
   3.5974734804459896`*^9, 3.5974735828601694`*^9}, 3.597473647475483*^9, {
   3.624521070977128*^9, 
   3.624521071569929*^9}},ExpressionUUID->"308cb8ac-c7e5-4270-81e1-\
71ba719ccca2"],

Cell["\<\
k = 1, 2. Denote the Gaussian curvature of the surface by K[u,v].. Using the \
last two Lemmas the system of equations reduce to\
\>", "Text",
 CellChangeTimes->{{3.5974736605327063`*^9, 3.5974738002309513`*^9}, {
  3.6174414045010443`*^9, 
  3.6174414118204627`*^9}},ExpressionUUID->"c4799b9c-ffea-4ecb-afd5-\
d51b880f2d0d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"K", "[", 
     RowBox[{"u", ",", "v"}], "]"}], 
    RowBox[{"\[Xi]", "[", "2", "]"}]}], "\[Equal]", " ", "0"}], ",", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"K", "[", 
      RowBox[{"u", ",", "v"}], "]"}]}], 
    RowBox[{"\[Xi]", "[", "1", "]"}]}], "\[Equal]", " ", "0"}], 
  ","}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5974738192629848`*^9, 3.597473901693529*^9}, 
   3.5974739416139994`*^9, {3.708089064882111*^9, 
   3.7080890687862787`*^9}},ExpressionUUID->"9a6eff27-0339-4cd0-b340-\
1826f15dea08"],

Cell["and it follows:", "Text",
 CellChangeTimes->{{3.597474011439722*^9, 3.597474151465568*^9}, 
   3.6132794864470096`*^9},ExpressionUUID->"e2127653-b641-4062-bbc1-\
aef81e0553b0"],

Cell[TextData[{
 StyleBox["Proposition 2",
  FontColor->RGBColor[0, 0, 1]],
 ". On a surface in the Euclidean 3-space exist non zero absolute parallel \
vector fields if and only if the surface is developable: K[u,v]\[Congruent] 0."
}], "Text",
 CellChangeTimes->{{3.597474011439722*^9, 3.597474151465568*^9}, {
  3.6132794864470096`*^9, 3.613279503380978*^9}, {3.613279693620859*^9, 
  3.613279711748896*^9}},ExpressionUUID->"01da7f71-49c4-40d1-9a66-\
5700f5bdf2ab"],

Cell[TextData[{
 StyleBox["Proof.",
  FontColor->RGBColor[0, 0, 1]],
 " By Proposition 1 the condition is necessary. On the other hand, if it is \
satisfied, the surface is developable, thus locally isometric to an open \
region of the Euclidean plane; the images of constant vector fields are \
absolute parallel. \[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.597474207298066*^9, 3.597474365856745*^9}, {
  3.597474445042484*^9, 3.5974744834809513`*^9}, {3.6174414537648616`*^9, 
  3.617441462916385*^9}},ExpressionUUID->"ed42be5a-81bc-4de4-b794-\
cb6c60349aa3"],

Cell[TextData[{
 StyleBox["Example 12.",
  FontColor->RGBColor[0, 0, 1]],
 " Flat tori in the  4-space."
}], "Text",
 CellChangeTimes->{{3.621077682746496*^9, 3.6210777464251385`*^9}, 
   3.621077781153125*^9, {3.699166520846904*^9, 
   3.6991665222632732`*^9}},ExpressionUUID->"1cd71d4c-d1a5-44d3-a688-\
f680da76af89"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"torus4", "[", "b_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "b", "]"}], " ", 
     RowBox[{"Cos", "[", "u", "]"}]}], ",", 
    RowBox[{
     RowBox[{"Cos", "[", "b", "]"}], " ", 
     RowBox[{"Sin", "[", "u", "]"}]}], ",", 
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "b", "]"}]}], ",", 
    RowBox[{
     RowBox[{"Sin", "[", "b", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.454219651578125*^9, 3.45421967153125*^9}, 
   3.541836408381708*^9, 3.541836718180749*^9, {3.621077791602722*^9, 
   3.621077829255876*^9}},ExpressionUUID->"fc3ffcd7-aa38-45e3-af0c-\
c17112e2ad70"],

Cell["\<\
The stereographic projection permits to plot a conformal picture of this \
surface which isn\[CloseCurlyQuote]t flat, of course:\
\>", "Text",
 CellChangeTimes->{{3.621079052049816*^9, 
  3.621079126698086*^9}},ExpressionUUID->"240fcfaf-9af3-434c-a1d1-\
3f18240e3030"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sterproj", "[", 
    RowBox[{
     RowBox[{"torus4", "[", "0.3", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6210788544805155`*^9, 3.6210790255993032`*^9}, {
  3.6210797172378626`*^9, 3.6210797199650183`*^9}, {3.6210797528539*^9, 
  3.6210797595082803`*^9}},ExpressionUUID->"e091e03c-6717-4212-ab2c-\
94fd3b84d7d4"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund1", "[", 
     RowBox[{"torus4", "[", "b", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s1", ",", "s2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.62107784855398*^9, 
  3.6210779697319107`*^9}},ExpressionUUID->"0d1737d7-258f-4500-a1e6-\
19a142991fe7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Rimm", "[", 
    RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", 
   RowBox[{"torus4", "[", "b", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6210782245524855`*^9, 3.621078269756071*^9}, 
   3.6210785762195997`*^9, {3.621078617363953*^9, 3.6210786268834977`*^9}, 
   3.62108009099024*^9, {3.6245273680710535`*^9, 
   3.624527368695055*^9}},ExpressionUUID->"7f05cf4c-50ee-4082-ab87-\
030837d4b077"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covRimm", "[", 
    RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "[", 
   RowBox[{"torus4", "[", "b", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6210782245524855`*^9, 3.621078269756071*^9}, 
   3.6210785762195997`*^9, {3.621078617363953*^9, 3.6210786268834977`*^9}, {
   3.621078673464162*^9, 3.6210786822146626`*^9}, {3.624527384607083*^9, 
   3.6245273853402843`*^9}},ExpressionUUID->"b0bd2257-72ba-4691-b3dc-\
97eff57591dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.621080447851651*^9, 
  3.6210804499227695`*^9}},ExpressionUUID->"7b833cd4-f087-41bb-8cbc-\
6c7d8fab2ecf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]", "[", "1", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", "s1"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]", "[", "2", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", "s2"}], ";", 
  RowBox[{
   RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.62108019186901*^9, 3.6210801920270185`*^9}, {
  3.6210802857313786`*^9, 3.6210804271744685`*^9}, {3.621080459316307*^9, 
  3.621080521363856*^9}},ExpressionUUID->"01c506e6-5845-41cb-abed-\
24ba1f623ef8"],

Cell["\<\
The vector fields with constant local coordinates are absolute parallel:\
\>", "Text",
 CellChangeTimes->{{3.621080579673191*^9, 
  3.6210806403776627`*^9}},ExpressionUUID->"6e3b85b9-3215-43a6-bd99-\
226aed196154"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DDimm", "[", 
    RowBox[{"torus4", "[", "b", "]"}], "]"}], "[", 
   RowBox[{"vv", "[", "\[Xi]", "]"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6210801247241693`*^9, 3.6210801373638926`*^9}, {
  3.624527416524739*^9, 
  3.62452741732034*^9}},ExpressionUUID->"e83e3ede-ce66-4cce-81e0-\
442629c361d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "\[Xi]", "]"}], ";", 
  RowBox[{
   RowBox[{"vv", "[", "\[Xi]", "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.621080660575818*^9, 
  3.6210806980599623`*^9}},ExpressionUUID->"e4487f16-9bc4-4500-b739-\
a5c832b22620"],

Cell["\<\
Thus the Riemann curvature tensor of this surface in the Euclidean 4-space is \
the null tensor, the surface is flat. Find a local isometry with the \
Euclidean plane. \[FilledSquare]\
\>", "Text",
 CellChangeTimes->{{3.6210795146792765`*^9, 3.6210795226497326`*^9}, {
   3.6210795725615873`*^9, 3.6210796670099897`*^9}, {3.6210798513535337`*^9, 
   3.6210798707376423`*^9}, 
   3.6259237255423155`*^9},ExpressionUUID->"7d37fd6b-a53b-4129-88c2-\
115c39ede2aa"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.4. Parallel Displacement Along Curves", "Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, {
   3.5972984401750546`*^9, 3.59729846072029*^9}, {3.5972984954771514`*^9, 
   3.5972985062723703`*^9}, {3.5973320886172123`*^9, 3.5973320905123205`*^9}, 
   3.5973952636966553`*^9, {3.597729800827932*^9, 3.59772986233884*^9}, 
   3.6132798036301517`*^9, 3.6132847212454233`*^9, 3.6171717529369097`*^9, 
   3.61717393361794*^9, 3.6188231691395845`*^9, 3.6188258241208286`*^9, {
   3.6245360039693832`*^9, 3.6245360091017923`*^9}, 3.6245420308786135`*^9, 
   3.69916682574935*^9, 3.699170414943467*^9, 3.708092664755835*^9, 
   3.7081486104485903`*^9},ExpressionUUID->"7ff9f871-2845-4bcc-a312-\
729b8838577a"],

Cell["\<\
In the last subsection we have seen that non zero absolute parallel vector \
fields exist only under certain integrability conditions expressed as \
restrictions to the curvature tensor. In dimension 1 these conditions don\
\[CloseCurlyQuote]t appear, Thus it is possible to define parallel vector \
functions along curves on the immersion (or Riemannian manifold). Aiming at \
this we first define the absolute derivative of a tangent vector function \
along a curve. For simplicity we consider curves on surfaces; the definition \
can be adapted with little change to immersions of arbitrary, not too high,  \
finite dimensions.
Let\
\>", "Text",
 CellChangeTimes->{{3.597735507062501*^9, 3.5977355331009903`*^9}, {
  3.5977355962056*^9, 3.597735634300779*^9}, {3.5977358303089895`*^9, 
  3.5977359083014507`*^9}, {3.59773603346961*^9, 3.597736128501045*^9}, {
  3.5977362858940477`*^9, 3.5977364648612843`*^9}, {3.5978475796643496`*^9, 
  3.5978476595364895`*^9}, {3.6132799006777024`*^9, 3.613279904972948*^9}, {
  3.6260716008312755`*^9, 
  3.626071601205676*^9}},ExpressionUUID->"656789cb-f014-423d-9161-\
5a793bd88058"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cu", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "[", "t", "]"}], ",", 
    RowBox[{"v", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5977318613653574`*^9, 3.597731863773495*^9}, {
   3.597736504464549*^9, 3.597736506142645*^9}, 3.597736550155163*^9, {
   3.6245408600029573`*^9, 
   3.6245408613757596`*^9}},ExpressionUUID->"c851cccc-6569-4970-ab8f-\
a5a72777ed48"],

Cell["be a smooth curve on the surface", "Text",
 CellChangeTimes->{{3.5977365672371397`*^9, 
  3.5977365831090474`*^9}},ExpressionUUID->"b574d32c-252d-448a-82f7-\
adf54fdfc84a"],

Cell[BoxData[
 RowBox[{"sf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.597738312935988*^9, 3.597738318614313*^9}, {
  3.597817180004476*^9, 
  3.5978171949961023`*^9}},ExpressionUUID->"5fef6807-f580-4282-8f80-\
5c6ecb4a82a5"],

Cell[TextData[{
 "We defined in eudiffgeov3.m the ",
 StyleBox["absolute derivative ",
  FontColor->RGBColor[0, 0, 1]],
 "DD1 of a vector function vw[t] given along a curve cu[t] of the surface:"
}], "Text",
 CellChangeTimes->{{3.5978243856151857`*^9, 3.597824491751256*^9}, 
   3.597847681766528*^9, 3.624540411361769*^9, 3.6245407807392178`*^9, {
   3.6260721218721905`*^9, 3.626072135865415*^9}, 
   3.686289023294538*^9},ExpressionUUID->"2fe02b2c-56a0-4625-b721-\
23b9fe0381a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{"ff_", ",", "cu_", ",", "vw_"}], "]"}], "[", "t_", "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "mf", ",", "\[CapitalGamma]\[CapitalGamma]", ",", "s", ",", " ", "i", 
      ",", "j", ",", "k", ",", "u", ",", "v"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"mf", " ", "=", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"cu", "[", "t", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalGamma]\[CapitalGamma]", "[", 
        RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], "[", "s_", "]"}], ":=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[CapitalGamma]rgT", "[", 
          RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "ff", "]"}], "[", 
        RowBox[{"u", ",", "v"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"u", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"cu", "[", "s", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", 
         RowBox[{"v", "->", 
          RowBox[{
           RowBox[{"cu", "[", "s", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"vw", "[", "t", "]"}], ",", "t"}], "]"}], " ", "+", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[CapitalGamma]\[CapitalGamma]", "[", 
             RowBox[{"i", ",", "j", ",", "k"}], "]"}], "[", "t", "]"}], "*", 
           RowBox[{
            RowBox[{"vw", "[", "t", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"cu", "[", "t", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}], ",", "t"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "mf"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "mf"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "mf"}], "}"}]}], "]"}]}]}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5977308704166784`*^9, 3.5977309528863955`*^9}, {
   3.597730990067522*^9, 3.5977310541191854`*^9}, {3.5977311130875587`*^9, 
   3.597731171388893*^9}, {3.5977312247049427`*^9, 3.5977316965809326`*^9}, {
   3.59773244291862*^9, 3.597732454294271*^9}, {3.597736676816407*^9, 
   3.5977366770154185`*^9}, 3.5977367373498697`*^9, {3.597736775207035*^9, 
   3.5977367948381577`*^9}, {3.597737366309844*^9, 3.5977374333886805`*^9}, 
   3.597737547742221*^9, {3.5977375864544353`*^9, 3.5977376044944677`*^9}, {
   3.5977379689903154`*^9, 3.5977380117027583`*^9}, {3.59773809127831*^9, 
   3.597738147071501*^9}, {3.597738183294573*^9, 3.5977381938471766`*^9}, {
   3.5977382930868526`*^9, 3.5977383028234096`*^9}, 3.597738333062139*^9, {
   3.59773856211124*^9, 3.597738563639327*^9}, {3.597738626846943*^9, 
   3.5977386858323164`*^9}, 3.597738739184368*^9, {3.597739039800562*^9, 
   3.597739048865081*^9}, 3.597739103775221*^9, {3.5977391974875813`*^9, 
   3.5977392430151854`*^9}, {3.5977416344573517`*^9, 
   3.5977416832421427`*^9}, {3.5977417284907303`*^9, 
   3.5977417331069946`*^9}, {3.597741787564109*^9, 3.5977418090453377`*^9}, 
   3.597742020350424*^9, {3.597742051182187*^9, 3.597742090246422*^9}, {
   3.5977421906331635`*^9, 3.5977421946103907`*^9}, 3.5977614023163023`*^9, 
   3.5977615118596945`*^9, {3.5977615457429543`*^9, 3.5977615563509727`*^9}, {
   3.5977616156154766`*^9, 3.597761781989769*^9}, {3.5977618977731724`*^9, 
   3.5977621593544316`*^9}, {3.5977621933936915`*^9, 3.597762210085721*^9}, {
   3.597762336165142*^9, 3.597762354136374*^9}, {3.597762521743068*^9, 
   3.597762586623582*^9}, 3.5977626705829296`*^9, 3.5977627045441895`*^9, 
   3.597762821466395*^9, {3.597762857174857*^9, 3.597762946890615*^9}, {
   3.597763103031289*^9, 3.597763144230962*^9}, 3.597763243556336*^9, {
   3.5977633091544514`*^9, 3.5977633095132523`*^9}, {3.597763359058939*^9, 
   3.5977635199420214`*^9}, {3.5977637409788094`*^9, 
   3.5977637779820747`*^9}, {3.597763824875757*^9, 3.5977638472461967`*^9}, {
   3.597763964184002*^9, 3.597764059406569*^9}, {3.5977641187802734`*^9, 
   3.5977641373911057`*^9}, 3.597764334138652*^9, 3.597764391999153*^9, {
   3.5977644843825154`*^9, 3.597764518515375*^9}, 3.5977645786378813`*^9, 
   3.5978143208626547`*^9, 3.597814672690072*^9, {3.5978148033247013`*^9, 
   3.5978148102199135`*^9}, {3.597814841201568*^9, 3.597814950963361*^9}, 
   3.5978151119556437`*^9, {3.5978152110938177`*^9, 3.5978152698903213`*^9}, {
   3.5978163646534443`*^9, 3.597816390253089*^9}, 3.5978164326227636`*^9, {
   3.5978164684872265`*^9, 3.5978164759596395`*^9}, {3.5978165061924925`*^9, 
   3.5978166048782663`*^9}, {3.597816688494413*^9, 3.5978167555121307`*^9}, 
   3.5978209977279816`*^9, {3.5978242016266623`*^9, 3.5978242030427427`*^9}, {
   3.5979349765451393`*^9, 3.5979350763378468`*^9}, {3.597935149242017*^9, 
   3.597935178465688*^9}, {3.61328063931495*^9, 3.613280694826125*^9}, {
   3.614861862639145*^9, 3.614861862654745*^9}, 3.614863502248825*^9, 
   3.614917793995365*^9, {3.6245410126180253`*^9, 3.6245410144432287`*^9}, 
   3.6991687847519617`*^9},ExpressionUUID->"870bf701-6177-426e-9d33-\
eceb3397be3c"],

Cell[BoxData[
 RowBox[{"?", "DD1"}]], "Input",
 CellChangeTimes->{{3.597847771310686*^9, 3.597847775990694*^9}, 
   3.597847810685155*^9, 3.597931689455128*^9, {3.6245404552134457`*^9, 
   3.6245404956175175`*^9}, 3.6245407109290953`*^9, {3.624540760833583*^9, 
   3.6245407743588066`*^9}, 3.624540881811795*^9, 3.62454095280752*^9, {
   3.626072002859582*^9, 
   3.626072006369588*^9}},ExpressionUUID->"891d1681-24b3-4d38-9034-\
727df8a8908a"],

Cell["\<\
Some special cases:
The sphere:\
\>", "Text",
 CellChangeTimes->{{3.69916917058527*^9, 
  3.699169217489011*^9}},ExpressionUUID->"b48f8874-bfbb-432c-a10a-\
9e84e9f3b9df"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"\[Xi]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s1", "[", "t", "]"}], ",", 
     RowBox[{"s2", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], ",", "\[Gamma]", ",", "\[Xi]"}], 
     "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5977317427255716`*^9, 3.5977317893472385`*^9}, {
   3.597731905438878*^9, 3.5977319912867885`*^9}, 3.5977320952957373`*^9, {
   3.5977321323428564`*^9, 3.5977321664548073`*^9}, {3.597732200380748*^9, 
   3.59773233731258*^9}, {3.5977323700014496`*^9, 3.5977323837522364`*^9}, 
   3.5977615795014133`*^9, {3.5977631817334275`*^9, 3.597763189424241*^9}, 
   3.597814977779808*^9, {3.5978168288634596`*^9, 
   3.5978168347290697`*^9}},ExpressionUUID->"796c0c08-2801-4389-a92e-\
a2df04e9737f"],

Cell["A general surface:", "Text",
 CellChangeTimes->{{3.699169244264358*^9, 
  3.699169255656582*^9}},ExpressionUUID->"add475ba-1b8e-4512-837a-\
ba950f11824b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"\[Xi]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s1", "[", "t", "]"}], ",", 
     RowBox[{"s2", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{"sf", ",", "\[Gamma]", ",", "\[Xi]"}], "]"}], "[", "t", "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5977317427255716`*^9, 3.5977317893472385`*^9}, {
   3.597731905438878*^9, 3.5977319912867885`*^9}, 3.5977320952957373`*^9, {
   3.5977321323428564`*^9, 3.5977321664548073`*^9}, {3.597732200380748*^9, 
   3.59773233731258*^9}, {3.5977323700014496`*^9, 3.5977323837522364`*^9}, 
   3.5977615795014133`*^9, {3.5977631817334275`*^9, 3.597763189424241*^9}, 
   3.597814977779808*^9, {3.5978153495284615`*^9, 3.5978153652688885`*^9}, 
   3.5978169355832467`*^9, 3.5978170612258673`*^9, 3.5978210148724117`*^9, 
   3.5978210893157425`*^9, 3.6171725651055365`*^9, 3.6171730417487736`*^9, 
   3.6245411324262357`*^9},ExpressionUUID->"c25da73b-934a-4b48-a0c4-\
ba04a9bef646"],

Cell["The Euclidean plane:", "Text",
 CellChangeTimes->{{3.6991693764631033`*^9, 
  3.6991693836793623`*^9}},ExpressionUUID->"f2768431-db6d-4e17-bef6-\
291c335f4328"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"\[Xi]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s1", "[", "t", "]"}], ",", 
     RowBox[{"s2", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{"identity", ",", "\[Gamma]", ",", "\[Xi]"}], "]"}], "[", "t", 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5977317427255716`*^9, 3.5977317893472385`*^9}, {
   3.597731905438878*^9, 3.5977319912867885`*^9}, 3.5977320952957373`*^9, {
   3.5977321323428564`*^9, 3.5977321664548073`*^9}, {3.597732200380748*^9, 
   3.59773233731258*^9}, {3.5977323700014496`*^9, 3.5977323837522364`*^9}, 
   3.5977615795014133`*^9, {3.5977631817334275`*^9, 3.597763189424241*^9}, 
   3.597814977779808*^9, {3.5978153495284615`*^9, 3.5978153652688885`*^9}, {
   3.5978154316938057`*^9, 3.5978154432534256`*^9}, 3.597816947501668*^9, {
   3.624541491679267*^9, 
   3.624541495501273*^9}},ExpressionUUID->"63280837-9edc-4e57-8ac6-\
961901912688"],

Cell["\<\
In the Euclidean plane with Cartesian coordinates the absolute derivative \
coincides with the standard derivative.
\[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.597824599532421*^9, 
  3.5978246899355917`*^9}},ExpressionUUID->"2a7d9e5f-d3f8-4b96-a155-\
7d5976b0c353"],

Cell[TextData[{
 StyleBox["Definition",
  FontColor->RGBColor[0, 0, 1]],
 ". The vector vw[t] is said to be",
 StyleBox[" parallel displaced",
  FontColor->RGBColor[0, 0, 1]],
 " along the curve \[Gamma][t], if its absolute derivative is zero: DD1[ff,\
\[Gamma],vw][t] \[Congruent] 0."
}], "Text",
 CellChangeTimes->{{3.597824912191304*^9, 3.5978250944877305`*^9}, {
  3.5978251325839095`*^9, 3.5978253947519045`*^9}, {3.613282563068982*^9, 
  3.6132825845572114`*^9}},ExpressionUUID->"61916386-fdf6-4b7f-92bc-\
7d00e3b12ff2"],

Cell[TextData[{
 StyleBox["Proposition 3",
  FontColor->RGBColor[0, 0, 1]],
 ". Let \[Gamma][t0, t1] be the segment of the curve \[Gamma] between \
\[Gamma][t0], \[Gamma][t1]. Then for any tangent vector \n\[Xi]  \[Element] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"ff", "[", 
     RowBox[{"\[Gamma]", "[", "t0", "]"}], "]"}]], TraditionalForm]],
  ExpressionUUID->"3124dfde-3472-47d8-81b3-c3d10fd017fe"],
 " with coordinates {s1, s2} there exists a uniquely defined vector function \
\[Xi][t], parallel displaced along \[Gamma][t], with  \[Xi][t0] == \[Xi].  \
The map"
}], "Text",
 CellChangeTimes->{{3.5978254006782436`*^9, 3.597825430982977*^9}, {
   3.5978254653109407`*^9, 3.5978256295313334`*^9}, {3.597827809533633*^9, 
   3.5978281050655365`*^9}, {3.597828142609684*^9, 3.5978284203455696`*^9}, 
   3.597848111297683*^9, {3.5978482153030653`*^9, 3.5978482290622897`*^9}, {
   3.597909746031082*^9, 3.597909760134889*^9}, {3.6132826504209785`*^9, 
   3.6132826656368484`*^9}, 3.617441476236147*^9, {3.699169487887068*^9, 
   3.699169489223061*^9}, {3.6991696085504217`*^9, 
   3.699169612494035*^9}},ExpressionUUID->"8b95db23-6117-42d4-afdd-\
2ea737b3638d"],

Cell[TextData[{
 "\[Gamma][t0, t1]:   \[Xi]  \[Element] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"ff", "[", 
     RowBox[{"\[Gamma]", "[", "t0", "]"}], "]"}]], TraditionalForm]],
  ExpressionUUID->"f5bf6c89-cd8e-49ea-ab34-7c81320fb68f"],
 "  \[RightTeeArrow] \[Xi][t1] \[Element] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", 
    RowBox[{"ff", "[", 
     RowBox[{"\[Gamma]", "[", "t1", "]"}], "]"}]], TraditionalForm]],
  ExpressionUUID->"3ebe334b-d075-4a2c-b1d7-65b256faaf1a"]
}], "Text",
 CellChangeTimes->{{3.5978254006782436`*^9, 3.597825430982977*^9}, {
  3.5978254653109407`*^9, 3.5978256295313334`*^9}, {3.597827809533633*^9, 
  3.5978281050655365`*^9}, {3.597828142609684*^9, 3.5978284203455696`*^9}, {
  3.597848111297683*^9, 3.5978481458205433`*^9}, {3.5978491789011583`*^9, 
  3.597849186342371*^9}},ExpressionUUID->"d7eb01f1-723f-419b-8469-\
e10a04d553da"],

Cell["\<\
is an isometry of Euclidean vector spaces, depending on the curve \[Gamma].\
\>", "Text",
 CellChangeTimes->{{3.5978254006782436`*^9, 3.597825430982977*^9}, {
  3.5978254653109407`*^9, 3.5978256295313334`*^9}, {3.597827809533633*^9, 
  3.5978281050655365`*^9}, {3.597828142609684*^9, 3.5978284203455696`*^9}, {
  3.597848111297683*^9, 
  3.59784815508696*^9}},ExpressionUUID->"2213f011-2501-475a-8420-\
34124c5262fa"],

Cell[TextData[{
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 ". Analyzing the definition or looking at the examples we see that the \
equation "
}], "Text",
 CellChangeTimes->{{3.5978482749731703`*^9, 3.5978482821647835`*^9}, {
  3.597848335095676*^9, 3.5978483637373266`*^9}, {3.5978484072926025`*^9, 
  3.597848416122218*^9}},ExpressionUUID->"d357e833-552e-44da-93b8-\
0bbe9408ed6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{"ff", ",", "\[Gamma]", ",", "\[Xi]"}], "]"}], "[", "t", "]"}], 
  " ", "\[Equal]", "  ", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.597848445029069*^9, 
  3.5978484840291376`*^9}},ExpressionUUID->"97cb304e-3cf7-4cfa-ba93-\
f23eeb6f560f"],

Cell["\<\
Is a homogeneous system of ordinary linear differential equations of first \
order for the coordinates s[i][t] of \[Xi][t}. Therefore the solutions are \
uniquely defined by the initial conditions. Since\
\>", "Text",
 CellChangeTimes->{{3.597848493233154*^9, 3.597848651495432*^9}, {
  3.597848698732315*^9, 3.597848732397174*^9}, {3.618824036118561*^9, 
  3.618824043533985*^9}},ExpressionUUID->"cdec83e7-2f9f-44c0-8f81-\
40f7e142fc33"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{"\[Xi]", "+", "\[Eta]"}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{"DD1", "[", "\[Xi]", "]"}], "+", 
    RowBox[{"DD1", "[", "\[Eta]", "]"}]}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["and",
     FontColor->GrayLevel[0]], " ", 
    RowBox[{"DD1", "[", 
     RowBox[{"a", " ", "\[Xi]"}], "]"}]}], "==", 
   RowBox[{"a", " ", 
    RowBox[{"DD1", "[", "\[Xi]", "]"}], " ", 
    StyleBox["for",
     FontColor->GrayLevel[0]], " ", "a"}]}], "\[Element]", 
  "\[DoubleStruckCapitalR]"}]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.597848753691211*^9, 3.5978489453375483`*^9}, {
  3.5978490043368516`*^9, 3.59784902028008*^9}, {3.699169693653981*^9, 
  3.6991697031493177`*^9}, {3.6991697554855328`*^9, 
  3.6991698368677893`*^9}},ExpressionUUID->"1ca4c62c-203a-4bcb-b01d-\
23afa7946173"],

Cell[TextData[{
 "the map \[Gamma][t0, t1] defined above is a linear isomorphism. To show \
that it is an isometry we first consider an  ",
 StyleBox["Example.",
  FontColor->GrayLevel[0]],
 " With"
}], "Text",
 CellChangeTimes->{{3.5978492407084665`*^9, 3.597849289240152*^9}, {
  3.597903092985965*^9, 3.597903098055974*^9}, {3.5979033790748672`*^9, 
  3.5979034785094423`*^9}, {3.597904186319085*^9, 3.597904199182821*^9}, {
  3.6260729171615877`*^9, 3.6260729195327916`*^9}, {3.699169903475678*^9, 
  3.699169974362887*^9}},ExpressionUUID->"9eb12464-a61c-47c4-b2ce-\
b18a22b637fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"\[Xi]", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s1", "[", "t", "]"}], ",", 
     RowBox[{"s2", "[", "t", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.5978494117939672`*^9, 3.597849528528972*^9, {3.5978500298826528`*^9, 
   3.597850040709072*^9}, 
   3.5978504492269893`*^9},ExpressionUUID->"add1aa9f-1c3d-44b2-b8de-\
851b0c97a83a"],

Cell["we calculate", "Text",
 CellChangeTimes->{
  3.5979035304575334`*^9},ExpressionUUID->"f736342b-dde0-420a-b6ee-\
2c9d3955f1d6"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "r", "]"}], ",", "\[Gamma]", ",", "\[Xi]"}], 
    "]"}], "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.597850718343062*^9, 
  3.59785075125912*^9}},ExpressionUUID->"81f03b3d-bd50-4f9b-8fe1-\
733b7aa8f329"],

Cell["Using this result we define the ReplaceAll rules", "Text",
 CellChangeTimes->{{3.597903833581666*^9, 3.597903862207716*^9}, {
  3.597905596638751*^9, 
  3.597905628239558*^9}},ExpressionUUID->"1bacaf99-52d3-46a4-98f5-\
2b9d892c59fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"srule", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["s1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Tan", "[", 
        RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"s2", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{
          RowBox[{"s1", "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["v", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["s2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}]}], " ", 
       RowBox[{"s1", "[", "t", "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5979020770185804`*^9, 3.5979021128986435`*^9}, 
   3.597903879695347*^9},ExpressionUUID->"b47a01e8-f20a-4b72-add0-\
73365cd45156"],

Cell["\<\
Now we get the stated result: The scalar square of a parallel transferred \
vector is constant:\
\>", "Text",
 CellChangeTimes->{{3.5979039146550083`*^9, 3.5979039775387187`*^9}, {
  3.59790405527059*^9, 
  3.5979040727025867`*^9}},ExpressionUUID->"025143f2-a834-4d27-8a12-\
896325f97ed0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"rgT", "[", 
            RowBox[{"i", ",", "j"}], "]"}], "[", 
           RowBox[{"sphero", "[", "r", "]"}], "]"}], "[", 
          RowBox[{
           RowBox[{"u", "[", "t", "]"}], ",", 
           RowBox[{"v", "[", "t", "]"}]}], "]"}], "*", 
         RowBox[{
          RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*", 
         RowBox[{
          RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "t"}], "]"}], "/.",
    "srule"}], "]"}]], "Input",
 CellChangeTimes->{{3.5978492968529654`*^9, 3.5978493357282333`*^9}, {
   3.597849486299698*^9, 3.597849492602109*^9}, {3.5978495746270533`*^9, 
   3.59784975499457*^9}, {3.597850066464717*^9, 3.5978502509506407`*^9}, {
   3.597850302680332*^9, 3.5978503672956457`*^9}, {3.59785081986804*^9, 
   3.5978508536888995`*^9}, {3.5978510248056*^9, 3.597851033338815*^9}, {
   3.597903144169655*^9, 3.5979031639816895`*^9}, {3.597903226725*^9, 
   3.5979032503122416`*^9}, 
   3.6186424061704826`*^9},ExpressionUUID->"c5af48c2-20d4-4444-9498-\
e263a3d077ee"],

Cell["\<\
\[FilledRectangle]
Now we consider the general case:\
\>", "Text",
 CellChangeTimes->{{3.597904117111127*^9, 
  3.597904155526324*^9}},ExpressionUUID->"55b5cd2c-9038-4002-869b-\
b087c8711175"],

Cell["\<\
We define the ReplaceAll rules, analyzing the definition of DD1 and using \
DD1[sf,\[Gamma],\[Xi]][t]== 0:\
\>", "Text",
 CellChangeTimes->{{3.597903833581666*^9, 3.597903862207716*^9}, 
   3.597904443750809*^9, {3.5979055757595563`*^9, 3.597905583951025*^9}, {
   3.597905758415004*^9, 3.5979057915028963`*^9}, {3.5979058467290554`*^9, 
   3.5979058754867*^9}},ExpressionUUID->"bc617187-4751-415e-b4b9-\
4353ff61ea9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfrule", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["s1", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", " ", 
       RowBox[{"-", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[CapitalGamma]rgT", "[", 
              RowBox[{"1", ",", "j", ",", "k"}], "]"}], "[", "sf", "]"}], "[", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], ",", 
             RowBox[{"v", "[", "t", "]"}]}], "]"}], "*", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Gamma]", "[", "t", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}], ",", "t"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "2"}], "}"}]}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["s2", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"-", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[CapitalGamma]rgT", "[", 
              RowBox[{"2", ",", "j", ",", "k"}], "]"}], "[", "sf", "]"}], "[", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], ",", 
             RowBox[{"v", "[", "t", "]"}]}], "]"}], "*", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Gamma]", "[", "t", "]"}], "[", 
              RowBox[{"[", "k", "]"}], "]"}], ",", "t"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "2"}], "}"}]}], "]"}]}]}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5979020770185804`*^9, 3.5979021128986435`*^9}, 
   3.597903879695347*^9, {3.5979044647410097`*^9, 3.5979044846771502`*^9}, {
   3.597904582635753*^9, 3.5979045980226336`*^9}, {3.59790463887097*^9, 
   3.597904648016493*^9}, {3.5979047164724083`*^9, 3.5979047360215263`*^9}, {
   3.597904808967698*^9, 3.5979048424166117`*^9}, {3.5979049171378856`*^9, 
   3.5979049321717453`*^9}, {3.597904975754238*^9, 3.597904989111002*^9}, {
   3.597905042449053*^9, 3.5979051553695116`*^9}, {3.5979052400023527`*^9, 
   3.597905252930092*^9}, {3.597905312498499*^9, 3.597905345545389*^9}, {
   3.6245418616027164`*^9, 3.6245418728191357`*^9}, 
   3.708148493094777*^9},ExpressionUUID->"69541330-93a4-4d9a-bce7-\
d21e97b150f4"],

Cell[TextData[{
 "Now we get the stated result: ",
 StyleBox["The scalar square of a parallel transferred vector is constant:",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.5979039146550083`*^9, 3.5979039775387187`*^9}, {
  3.59790405527059*^9, 
  3.5979040727025867`*^9}},ExpressionUUID->"edd2e1b5-6a05-4da7-b094-\
b1fa8c84cd19"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"rgT", "[", 
              RowBox[{"i", ",", "j"}], "]"}], "[", "sf", "]"}], "[", 
            RowBox[{
             RowBox[{"u", "[", "t", "]"}], ",", 
             RowBox[{"v", "[", "t", "]"}]}], "]"}], "*", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
            RowBox[{"[", "i", "]"}], "]"}], "*", 
           RowBox[{
            RowBox[{"\[Xi]", "[", "t", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "t"}], "]"}], 
     "/.", "sfrule"}], ",", 
    RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5978492968529654`*^9, 3.5978493357282333`*^9}, {
   3.597849486299698*^9, 3.597849492602109*^9}, {3.5978495746270533`*^9, 
   3.59784975499457*^9}, {3.597850066464717*^9, 3.5978502509506407`*^9}, {
   3.597850302680332*^9, 3.5978503672956457`*^9}, {3.59785081986804*^9, 
   3.5978508536888995`*^9}, {3.5978510248056*^9, 3.597851033338815*^9}, {
   3.597903144169655*^9, 3.5979031639816895`*^9}, {3.597903226725*^9, 
   3.5979032503122416`*^9}, {3.5979053910299907`*^9, 3.59790541252422*^9}, 
   3.618642567905733*^9, {3.699170164497806*^9, 3.699170171172275*^9}, {
   3.699170224802231*^9, 
   3.699170251466016*^9}},ExpressionUUID->"509442e3-dd19-4d13-ad7a-\
aa484adea199"],

Cell["\<\
Thus the map \[Gamma][t0, t1] defined above is an isometry, and therefore an \
isomorphy of Euclidean vector spaces.  All the algebraic properties defined \
using the first fundamental form are preserved, Remember the general identity \
for bilinear symmetric biforms, e.g. the Dot product:\
\>", "Text",
 CellChangeTimes->{{3.5979059861190276`*^9, 3.5979059936304574`*^9}, {
  3.597906034262781*^9, 3.597906090607004*^9}, {3.5979061594869437`*^9, 
  3.59790626781514*^9}, {3.5979064815023623`*^9, 
  3.5979064905028768`*^9}},ExpressionUUID->"0f7bebd7-b264-4f33-923a-\
53bc2f273c1f"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", "x", "]"}], ".", 
    RowBox[{"vec", "[", "y", "]"}]}], " ", "\[Equal]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "x", "]"}], "+", 
         RowBox[{"vec", "[", "y", "]"}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "x", "]"}], "+", 
         RowBox[{"vec", "[", "y", "]"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "x", "]"}], "-", 
         RowBox[{"vec", "[", "y", "]"}]}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vec", "[", "x", "]"}], "-", 
         RowBox[{"vec", "[", "y", "]"}]}], ")"}]}]}], ")"}], "/", "4"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.59790628075488*^9, 3.5979063105735855`*^9}, {
  3.5979063426894226`*^9, 
  3.5979064649564157`*^9}},ExpressionUUID->"6d279e69-069a-459d-bbbd-\
66d57010387c"],

Cell[TextData[{
 "We conclude\n",
 StyleBox["Corollary .",
  FontColor->RGBColor[0, 0, 1]],
 " Norm, angle and determinant, i.e. the area of the parallelogram spanned by \
the vectors, are invariant under parallel displacements.\n\[FilledRectangle]\n\
This result is a special case of ",
 ButtonBox["Ricci\[CloseCurlyQuote]s Lemma, ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://cms.math.ca/cjm/v16/cjm1964v16.0549-0560.pdf"], None},
  ButtonNote->"http://cms.math.ca/cjm/v16/cjm1964v16.0549-0560.pdf"],
 "see also ",
 ButtonBox["[B-R] ",
  BaseStyle->"Hyperlink",
  ButtonData->"B-R"],
 ", p.154, ",
 ButtonBox["[Kr]",
  BaseStyle->"Hyperlink",
  ButtonData->"Kr"],
 ", p.272."
}], "Text",
 CellChangeTimes->{{3.5979066223184166`*^9, 3.5979066356951814`*^9}, {
   3.597906685975057*^9, 3.597906703455057*^9}, {3.5979067557670493`*^9, 
   3.5979067829666047`*^9}, {3.597906823142903*^9, 3.5979068499664373`*^9}, {
   3.5979068902067385`*^9, 3.5979069783297787`*^9}, {3.5979070671908617`*^9, 
   3.5979070893111267`*^9}, {3.5979075377137737`*^9, 3.597907537721774*^9}, 
   3.59790761091096*^9, {3.597909307655009*^9, 3.59790933652666*^9}, {
   3.597909476022639*^9, 3.597909526774542*^9}, {3.5979100570878735`*^9, 
   3.5979100798951783`*^9}, {3.5979101121640244`*^9, 3.597910112173024*^9}, {
   3.597929142213434*^9, 3.597929152244008*^9}, 
   3.699170338240498*^9},ExpressionUUID->"5c85aab6-0dab-402f-bd64-\
1d610692e125"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.5. Geodesics as Auto-Parallel Curves", "Subsubsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, {
   3.5972984401750546`*^9, 3.59729846072029*^9}, {3.5972984954771514`*^9, 
   3.5972985062723703`*^9}, {3.5973320886172123`*^9, 3.5973320905123205`*^9}, 
   3.5973952636966553`*^9, {3.597729800827932*^9, 3.59772986233884*^9}, {
   3.597910399537461*^9, 3.597910436118553*^9}, {3.5979116271266747`*^9, 
   3.5979116482228813`*^9}, 3.613284728941863*^9, 3.6132874017987423`*^9, 
   3.6171739408407526`*^9, 3.617195815150076*^9, 3.6188258784059334`*^9, 
   3.618830173270586*^9, 3.6245420369782248`*^9, 3.6245441638235598`*^9, 
   3.699170423695874*^9, 3.6992503158291407`*^9, 3.708148617504583*^9, 
   3.7081512311738863`*^9},ExpressionUUID->"c89517ad-0d6c-466a-8865-\
801183c76d07"],

Cell[TextData[{
 StyleBox["Definition",
  FontColor->RGBColor[0, 0, 1]],
 ". A curve \[Gamma][t] on an immersion or in a Riemannian manifold is said \
to be ",
 StyleBox["auto-parallel",
  FontColor->RGBColor[0, 0, 1]],
 " or more commonly, a ",
 StyleBox["geodesic",
  FontColor->RGBColor[0, 0, 1]],
 ", if its tangent vector is parallel displaced along the curve.\n\n",
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 ". Since the norm  of the   tangent vector depends on the parameter \
representation, the condition of the definition fixes also the type of the \
parameter t of the curve. In Riemannian geometry it is natural to assume that \
t is the arc length of the curve; remember that this is equivalent to the \
fact that the tangent vector has constant norm 1."
}], "Text",
 CellChangeTimes->{{3.597911657441409*^9, 3.597911675247427*^9}, {
   3.597911706147195*^9, 3.59791200922353*^9}, {3.597928848436631*^9, 
   3.5979288904770355`*^9}, {3.597928956356804*^9, 3.5979290724444437`*^9}, {
   3.6132847851830797`*^9, 3.6132847983008304`*^9}, 3.6132848615014453`*^9, 
   3.617441713205701*^9},ExpressionUUID->"dac21393-ebe5-403e-a077-\
e8953cebd07c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"u", "[", "t", "]"}], ",", 
    RowBox[{"v", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5977318613653574`*^9, 3.597731863773495*^9}, {
   3.597736504464549*^9, 3.597736506142645*^9}, 
   3.597736550155163*^9},ExpressionUUID->"c9efa8cc-c175-45b5-93be-\
0afcd25cc9bc"],

Cell[TextData[{
 StyleBox["Example 13",
  FontColor->RGBColor[0, 0, 1]],
 ". The Euclidean plane"
}], "Text",
 CellChangeTimes->{{3.5979304075968103`*^9, 3.5979304432118473`*^9}, {
  3.69917062718139*^9, 
  3.699170629293233*^9}},ExpressionUUID->"68b85a0d-7d51-4db5-bbbc-\
ee5779089282"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{"identity", ",", "\[Gamma]", ",", 
     SuperscriptBox["\[Gamma]", "\[Prime]",
      MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5979292059430795`*^9, 3.5979292420701456`*^9}, {
  3.597929272325876*^9, 3.597929298654382*^9}, {3.597929354638584*^9, 
  3.597929492815488*^9}, {3.597930356399882*^9, 3.597930367070492*^9}, {
  3.624543465207533*^9, 
  3.6245434701371417`*^9}},ExpressionUUID->"6786d2b3-38e9-4113-8a03-\
eb56ef082cde"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.597929563264517*^9, 3.597929568107794*^9}, {
   3.5979298729262285`*^9, 3.597929965494523*^9}, 3.614861862717145*^9, 
   3.6148646599580584`*^9},ExpressionUUID->"1b6589b9-8524-486d-a916-\
89c516a063c8"],

Cell["\<\
In the Euclidean plane the lines with natural affine parameter t are the \
geodesics. \[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.5979305555082703`*^9, 3.5979306105174165`*^9}, {
  3.597930665788578*^9, 
  3.597930668044707*^9}},ExpressionUUID->"1b0e5adb-d8f2-4f2c-a2fb-\
dd4d8320b909"],

Cell[TextData[{
 StyleBox["Example 14",
  FontColor->RGBColor[0, 0, 1]],
 ". The spheres."
}], "Text",
 CellChangeTimes->{{3.597930716372471*^9, 3.597930736028595*^9}, {
  3.699170718436659*^9, 
  3.699170720404767*^9}},ExpressionUUID->"9323a19a-38dc-4304-8eaa-\
b0d54278d31f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "r", "]"}], ",", "\[Gamma]", ",", 
     SuperscriptBox["\[Gamma]", "\[Prime]",
      MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5979292059430795`*^9, 3.5979292420701456`*^9}, {
  3.597929272325876*^9, 3.597929298654382*^9}, {3.597929354638584*^9, 
  3.597929492815488*^9}},ExpressionUUID->"444dde31-1e04-436f-8223-\
e70b88cdeea7"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.597929563264517*^9, 3.597929568107794*^9}, {
   3.5979298729262285`*^9, 3.597929965494523*^9}, 3.614861862732745*^9, 
   3.614864659973658*^9},ExpressionUUID->"8d9e4cbe-72fd-4fd3-926a-\
31cb8af88b43"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], "}"}], "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.614861862732745*^9, 3.6148618627483454`*^9}, 
   3.6148646599892583`*^9},ExpressionUUID->"3cfaaf74-85c9-493e-b22d-\
df4167ed1beb"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", " ", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], " ", "\[Equal]", " ", 
      "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.597930017299486*^9, 3.597930054979642*^9}, {
   3.5979301545233355`*^9, 3.5979301739564466`*^9}, 3.5989403761220384`*^9, 
   3.614861862763945*^9, 
   3.6148646599892583`*^9},ExpressionUUID->"4d26e2cb-729d-46d2-aa98-\
fad3d38af2dc"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.614861862763945*^9, 3.6148618627795453`*^9}, 
   3.6148646600048585`*^9},ExpressionUUID->"684587ec-5aba-4a9e-ac9d-\
39eaffc0cac8"],

Cell["DSolve cannot solve these equations, NDSolve can:", "Text",
 CellChangeTimes->{{3.598011256632723*^9, 
  3.5980113116540194`*^9}},ExpressionUUID->"3b9ccfd2-0977-4013-88c1-\
4d0e5c56d72d"],

Cell[BoxData[
 RowBox[{"NDSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Tan", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["v", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"v", "[", "t", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", " ", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], " ", "\[Equal]", " ", 
      "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.597930017299486*^9, 3.597930054979642*^9}, {
   3.5979301545233355`*^9, 3.5979302685808587`*^9}, 3.5980094359535255`*^9, {
   3.5980104154168453`*^9, 3.598010433559677*^9}, 3.598010516442623*^9, {
   3.598011025658717*^9, 3.598011037826739*^9}, {3.59894033925093*^9, 
   3.5989403593400784`*^9}, 3.6148618627795453`*^9, 
   3.614864660020458*^9},ExpressionUUID->"499d7a80-2e79-439e-bdac-\
fb5d82985de2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fu", "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"u", "[", "t", "]"}], "/.", 
   RowBox[{
    RowBox[{"Flatten", "[", "%", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980105673455124`*^9, 3.598010700881747*^9}, {
  3.5980110599163775`*^9, 
  3.59801106141398*^9}},ExpressionUUID->"3755f3b8-4cb7-4c0b-8d95-\
6e3e5ab6838a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gu", "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"v", "[", "t", "]"}], "/.", 
   RowBox[{
    RowBox[{"Flatten", "[", "%%", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980105673455124`*^9, 3.5980107410050173`*^9}, {
  3.598011081772016*^9, 
  3.598011083410019*^9}},ExpressionUUID->"6c7f709c-1afb-4b37-90c0-\
9102cf87661b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", "1"}], ";", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sphero", "[", "r", "]"}], "[", 
     RowBox[{
      RowBox[{"fu", "[", "t", "]"}], ",", 
      RowBox[{"gu", "[", "t", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.59793530857513*^9, 3.597935328999298*^9}, {
   3.597935372503786*^9, 3.597935416552306*^9}, 3.5979361503762784`*^9, {
   3.5980107984599185`*^9, 3.5980108206743574`*^9}, {3.5980108954452887`*^9, 
   3.5980109588282003`*^9}, {3.5980111031908536`*^9, 
   3.5980111599125533`*^9}},ExpressionUUID->"0e31f306-c942-4381-acc8-\
13f1d05ddf28"],

Cell[BoxData[
 RowBox[{
  RowBox[{"equat1", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.618826674612474*^9, 
  3.618826692702509*^9}},ExpressionUUID->"06ba0972-11ba-4bbf-9570-\
9fe1843ce8d2"],

Cell[TextData[{
 StyleBox["T",
  FontSlant->"Italic"],
 "he spherical geodesics are the great circles,e.g. the equator"
}], "Text",
 CellChangeTimes->{{3.5979308517002115`*^9, 3.597930938316166*^9}, {
  3.59793601385347*^9, 3.5979360207808657`*^9}, {3.598011469978698*^9, 
  3.598011482271519*^9}},ExpressionUUID->"c3f9def9-e3b1-47e9-ac01-\
eff9fa4912ce"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "t_", "]"}], ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"v", "[", "t_", "]"}], ":=", "0"}], ";", 
  RowBox[{"\[Gamma]", "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.597936287551124*^9, 3.5979362931424437`*^9}, {
  3.626074872047821*^9, 
  3.6260748756514273`*^9}},ExpressionUUID->"b7e7bcfd-b2f2-476a-8961-\
91404faaa70f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", "1"}], ";", 
  RowBox[{
   RowBox[{"u", "[", "s_", "]"}], ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"v", "[", "t_", "]"}], ":=", "0"}], ";", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sphero", "[", "r", "]"}], "[", 
     RowBox[{
      RowBox[{"u", "[", "t", "]"}], ",", 
      RowBox[{"v", "[", "t", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", "Red"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.59793530857513*^9, 3.597935328999298*^9}, {
   3.597935372503786*^9, 3.597935416552306*^9}, 3.5979361503762784`*^9, {
   3.618826730962697*^9, 3.618826739615192*^9}, {3.62607489978467*^9, 
   3.6260749054786797`*^9}},ExpressionUUID->"e1122735-6c01-45d9-895f-\
16f4ed8c1fbc"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "equat1"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.618826747940668*^9, 
  3.618826776361294*^9}},ExpressionUUID->"e338d706-269e-48a3-a115-\
feadc35b7f2c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "=", "1"}], ";", 
  RowBox[{
   RowBox[{"u", "[", "s_", "]"}], ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"v", "[", "s_", "]"}], ":=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"norm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], "[", 
      RowBox[{
       RowBox[{"fu", "[", "t", "]"}], ",", 
       RowBox[{"gu", "[", "t", "]"}]}], "]"}], "-", 
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], "[", 
      RowBox[{
       RowBox[{"u", "[", "t", "]"}], ",", 
       RowBox[{"v", "[", "t", "]"}]}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6188268763600135`*^9, 3.618826890079798*^9}, {
  3.6188269471670637`*^9, 3.618826984440195*^9}, {3.61882710743423*^9, 
  3.6188271184888625`*^9}, {3.6188271596792183`*^9, 3.6188271684097176`*^9}, {
  3.6188272292031946`*^9, 3.6188272362896004`*^9}},
 NumberMarks->False,ExpressionUUID->"e7f3bc11-417c-4f9f-aa83-957f95c54f7c"],

Cell["\<\
The numeric solution is quite near to the exact equator. Of course, explicit \
calculation confirmes that the equator is a geodesic:\
\>", "Text",
 CellChangeTimes->{{3.618828015437165*^9, 3.618828058413623*^9}, 
   3.6260749487843556`*^9, {3.6260749908732295`*^9, 
   3.6260750310745*^9}},ExpressionUUID->"98f33cf5-7fe4-48aa-9e88-\
900a61f76b10"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "s_", "]"}], ":=", "s"}], ";", 
  RowBox[{
   RowBox[{"v", "[", "s_", "]"}], ":=", "0"}], ";", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"sphero", "[", "r", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.597930990691161*^9, 3.597931042054099*^9}, {
   3.5979310726468487`*^9, 3.597931145472014*^9}, 3.5979312951205735`*^9, {
   3.597931409520117*^9, 3.5979314723207088`*^9}, {3.597931552368287*^9, 
   3.59793155713656*^9}, 3.598011520257586*^9, 
   3.6188279817532387`*^9},ExpressionUUID->"73ad7c2d-1227-4847-a364-\
1c8415ca806d"],

Cell["\<\
It follows: The equator and therefore all the great circles, are the \
geodesics of the sphere, since the rotation group preserving the sphere acts \
transitively on the set of all great circles. \[FilledRectangle]\
\>", "Text",
 CellChangeTimes->{{3.5979354457009735`*^9, 3.5979355381972637`*^9}, {
   3.5979361835101733`*^9, 3.597936190844593*^9}, 
   3.597936521357497*^9},ExpressionUUID->"1fd39c81-0ef1-4541-a5db-\
aa22d1516b78"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"r", ",", "u", ",", "v", ",", "s", ",", "t", ",", "fu", ",", "gu"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.597935683989602*^9, 3.597935730415258*^9}, 
   3.597936386831803*^9, {3.59801155100524*^9, 
   3.598011556324849*^9}},ExpressionUUID->"f730c8c8-3164-45e0-9e48-\
93eac4e874bc"],

Cell[TextData[{
 "Applying the existence and uniqueness theorem for differential equations, \
we may state\n\n",
 StyleBox["Proposition 4",
  FontColor->RGBColor[0, 0, 1]],
 ". Through any point x of an immersion (or a Riemannian manifold ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "762d998b-7361-4a9f-a274-9db15eb9a9c2"],
 ")  and any tangent unit vector vt \[Epsilon]",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["T", "x"]}], TraditionalForm]],ExpressionUUID->
  "fcda188f-b42d-493d-b53d-c822c2b43262"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["X", "m"], TraditionalForm]],ExpressionUUID->
  "45f3a7fb-9d16-4029-a8b7-bcb131afdce5"],
 " there exists one and only one geodesic \[Gamma][t],  \[Gamma][0] = x, ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Prime]",
    MultilineFunction->None], "[", "0", "]"}]],
  CellChangeTimes->{{3.5979292059430795`*^9, 3.5979292420701456`*^9}, {
   3.597929272325876*^9, 3.597929298654382*^9}, {3.597929354638584*^9, 
   3.597929492815488*^9}},ExpressionUUID->
  "eacaeed3-efe2-4e8f-8479-3a531c8f086b"],
 " = vt, defined for a maximal interval of values t, t the arc length of \
\[Gamma]."
}], "Text",
 CellChangeTimes->{{3.598076949768775*^9, 3.598077205905425*^9}, {
   3.598077253769163*^9, 3.598077273273278*^9}, {3.598077357521097*^9, 
   3.598077557343526*^9}, {3.5980775930175667`*^9, 3.5980777053379908`*^9}, {
   3.5980777669065123`*^9, 3.598077838916631*^9}, {3.5980778699544067`*^9, 
   3.598077876921805*^9}, {3.598077921365347*^9, 3.598077950626021*^9}, 
   3.5980779864740715`*^9, 3.6132850698693633`*^9, 3.6174417193890543`*^9, {
   3.699171246433537*^9, 
   3.699171249521449*^9}},ExpressionUUID->"fa09bed2-7e44-45e5-9848-\
751ca7bfc5ae"],

Cell[TextData[{
 StyleBox[" Example 15",
  FontColor->RGBColor[0, 0, 1]],
 ". Ruled surfaces."
}], "Text",
 CellChangeTimes->{{3.598013618960472*^9, 3.5980136605033455`*^9}, {
   3.5980775178572674`*^9, 3.5980775195133624`*^9}, 3.5980780173128347`*^9, {
   3.699171608141796*^9, 
   3.699171610854067*^9}},ExpressionUUID->"cd4cf5fa-6caf-448c-8e88-\
ab3e58a5211f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.618828782127017*^9, 
  3.6188287890304117`*^9}},ExpressionUUID->"3b084ec9-4aa1-4335-8b2a-\
9f4378dc56d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ruled", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"x", "[", "v", "]"}], "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"y", "[", "v", "]"}], "]"}], "*", " ", "u"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5872799484616065`*^9, 
  3.5872801346102533`*^9}},ExpressionUUID->"049af2d1-fe81-4d30-bf39-\
529341b93352"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"ruled", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5980123012573576`*^9, 
  3.598012356419055*^9}},ExpressionUUID->"a638c74f-df8c-4db5-89f7-\
30ade3805259"],

Cell[BoxData[
 RowBox[{"rsf", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.598012474604862*^9, 
  3.598012479799671*^9}},ExpressionUUID->"2f393dd5-9eec-4c3a-bb26-\
0f9597c5d84e"],

Cell["\<\
The generating lines are geodesics; later we shall see that any line \
contained in a surface is a geodesic.\
\>", "Text",
 CellChangeTimes->{{3.598013751248705*^9, 
  3.5980138273924384`*^9}},ExpressionUUID->"e3256b18-a200-405c-aa09-\
45aa13782fe8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "v0"}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"DD1", "[", 
    RowBox[{"rsf", ",", "\[Gamma]", ",", 
     SuperscriptBox["\[Gamma]", "\[Prime]",
      MultilineFunction->None]}], "]"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.5980125593598113`*^9, 3.598012620574319*^9}, {
   3.5980126618363914`*^9, 3.598012676874818*^9}, 
   3.626075159634326*^9},ExpressionUUID->"1f18bc4a-879a-4645-824d-\
2322dccab16f"],

Cell["\<\
Now we calculate the absolute derivative of the tangent vector at the \
directrix vec[x[v]]:\
\>", "Text",
 CellChangeTimes->{{3.5980139213202033`*^9, 3.598013941553439*^9}, {
   3.598015594407542*^9, 3.598015602878357*^9}, {3.5980744477356434`*^9, 
   3.5980745343625956`*^9}, 3.6174417367160454`*^9, {3.6188281664378014`*^9, 
   3.6188281699900045`*^9}},ExpressionUUID->"b38e1e8d-50fb-496a-b4bb-\
a031a87cd1e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "t"}], "}"}]}], ";", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{"rsf", ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5980125593598113`*^9, 3.598012620574319*^9}, {
   3.5980126618363914`*^9, 3.598012676874818*^9}, {3.598012716576887*^9, 
   3.5980127313969135`*^9}, {3.5980139548914623`*^9, 3.598013988774722*^9}, 
   3.598015612097973*^9},ExpressionUUID->"2c7783f8-c1b8-4f4b-812f-\
701b0d394f20"],

Cell["\<\
We assume that v= t is the arc length of x, that y[v] is orthogonal to x\
\[CloseCurlyQuote], and that y.y ==1 is a unit vector, i.e. that the ruled \
surface is generated by a family of normals of the curve x[v]. This is \
equivalent to the Conditions\
\>", "Text",
 CellChangeTimes->{{3.598014139954587*^9, 3.5980141739002466`*^9}, {
   3.5980142117459135`*^9, 3.598014350960558*^9}, {3.598015630428005*^9, 
   3.598015689708109*^9}, 3.5980745908658953`*^9, 
   3.617174467076477*^9},ExpressionUUID->"6ea6a9a8-cc30-46ae-9de0-\
68c7ece69104"],

Cell[BoxData[
 RowBox[{
  RowBox[{"conds", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], "2"], 
        "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], 
         "2"]}], ")"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], "2"]}], ")"}], 
      "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
       ")"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "1", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "1", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "2", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "t", "]"}], "[", "3", "]"}], " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "[", "3", "]"}]}]}], 
       ")"}], "\[Equal]", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.598014358713772*^9, 3.5980144816731873`*^9}, {
   3.5980145294872713`*^9, 3.5980145784713573`*^9}, {3.5980146324630527`*^9, 
   3.59801463676866*^9}, {3.5980146712447205`*^9, 3.5980146860647464`*^9}, 
   3.598014725454816*^9, {3.5980147633784823`*^9, 3.5980147646732845`*^9}, {
   3.598014867867466*^9, 
   3.598014871814273*^9}},ExpressionUUID->"80ef18b0-4c9c-437f-9596-\
7215a298e764"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%%", ",", "conds"}], "]"}]], "Input",
 CellChangeTimes->{{3.598012757495759*^9, 3.5980127705529823`*^9}, {
   3.5980128218770723`*^9, 3.5980128789263725`*^9}, {3.5980148996915216`*^9, 
   3.5980149121091433`*^9}, 3.5980150010449*^9, {3.5980150367065625`*^9, 
   3.5980150390309663`*^9}, {3.5980157411413994`*^9, 
   3.5980157424830017`*^9}, {3.613285257919119*^9, 3.613285263830457*^9}, {
   3.6171931026017113`*^9, 3.6171931109477262`*^9}, {3.618828710063895*^9, 
   3.618828731983149*^9}},ExpressionUUID->"731bea64-d10e-49c4-a1f2-\
73861028a010"],

Cell[TextData[{
 "Now vec[",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]],
  CellChangeTimes->{{3.598015889934461*^9, 3.598015935782942*^9}},
  ExpressionUUID->"1e5c069c-6dbf-491e-885c-0399d3c1e4f7"],
 "] == k[t] *n[t] is the curvature vector of the curve vec[x[t]]; it is \
proportional to the principal normal vector n[t] with the curvature k[t] as \
factor; remember: t is the arc length. Since vec[y[t] is a unit normal \
vector. we have the interpretation where \[Alpha][t] denotes the angle \
between n[t] and vec[y[t]:"
}], "Text",
 CellChangeTimes->{{3.59801595197577*^9, 3.598016040630726*^9}, {
   3.5980160729071827`*^9, 3.598016191560991*^9}, {3.598016348949667*^9, 
   3.5980163923177433`*^9}, {3.5980746508636007`*^9, 3.598074668429231*^9}, 
   3.6171744572796593`*^9, {3.617193389361415*^9, 
   3.6171934129954567`*^9}},ExpressionUUID->"383d6bd6-7997-4b43-a4d0-\
929dee2e2d86"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "t"}], "}"}]}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{"rsf", ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "\[Equal]", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"k", "[", "t", "]"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Alpha]", "[", "t", "]"}], "]"}]}], ",", "0"}], 
    "}"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5980164417854304`*^9, 3.5980164693506784`*^9}, {
  3.598016626224554*^9, 3.598016666847026*^9}, {3.6171932823608274`*^9, 
  3.617193289053239*^9}, {3.699171918780612*^9, 
  3.6991719250275383`*^9}},ExpressionUUID->"c9b64ef3-d2f4-4564-a2c3-\
c6a25dc4798c"],

Cell[TextData[{
 "It follows: ",
 StyleBox["Any curve is a geodesic on the normal surface generated by its \
binormals. ",
  FontColor->RGBColor[0, 0, 1]],
 "\[FilledRectangle]"
}], "Text",
 CellChangeTimes->{{3.598016655053405*^9, 3.598016715659511*^9}, 
   3.5980167597451887`*^9, {3.5980169228434753`*^9, 3.5980169797367754`*^9}, {
   3.5980170368952756`*^9, 3.5980170459588914`*^9}, {3.5980183077359076`*^9, 
   3.598018313476718*^9}, {3.598074739939757*^9, 3.598074742295361*^9}, 
   3.613285387981558*^9, 
   3.617193376413392*^9},ExpressionUUID->"92bea876-5fe5-41fa-ac83-\
dcd1e1de86c0"],

Cell["\<\
Now we consider the special ruled surface generated by normals of the x-axis:\
\>", "Text",
 CellChangeTimes->{{3.6171938010149384`*^9, 
  3.617193859561841*^9}},ExpressionUUID->"9553c577-838b-448d-b874-\
37b99d2c21fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rsf", "[", "w_", "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", 
  RowBox[{"{", 
   RowBox[{"u", ",", " ", 
    RowBox[{"v", "*", 
     RowBox[{"Cos", "[", 
      RowBox[{"w", "[", "u", "]"}], "]"}]}], ",", 
    RowBox[{"v", "*", 
     RowBox[{"Sin", "[", 
      RowBox[{"w", "[", "u", "]"}], "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.598018362570004*^9, 3.5980185772263813`*^9}, 
   3.598074791778648*^9},ExpressionUUID->"45eddcba-06d9-4ceb-b76c-\
6e4f1fc4e74f"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"amf", "[", "3", "]"}], "[", 
    RowBox[{"rsf", "[", "w", "]"}], "]"}], "[", 
   RowBox[{"u", ",", "v"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.59801860508803*^9, 3.5980186424188957`*^9}, {
   3.598074818563895*^9, 3.5980748315275173`*^9}, 3.6148618628107452`*^9, 
   3.614917794104565*^9, {3.6171935611489167`*^9, 
   3.6171935620381184`*^9}},ExpressionUUID->"5e7e4324-0253-44e8-a2d9-\
54af7314cebc"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Norm", "[", "%", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980186576289225`*^9, 
  3.5980186982669935`*^9}},ExpressionUUID->"7c0d98a3-5534-442f-b542-\
659f8a05f6a0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"w", "[", "u", "]"}], "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", " ", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["w", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "\[Element]", " ", 
      "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5980187581554985`*^9, 3.5980188628628826`*^9}, {
   3.598074896969633*^9, 3.598074903755645*^9}, 3.5980751467728715`*^9, {
   3.598075207238578*^9, 
   3.598075224086607*^9}},ExpressionUUID->"644a3e5a-7260-4435-ac50-\
b9ea42eb5fa2"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"rsf", "[", "w", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"w", "[", "u", "]"}], "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"v", " ", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["w", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "\[Element]", " ", 
      "Reals"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5980189149669743`*^9, 3.598018950675437*^9}, 
   3.598018999519123*^9, 3.5980749646425514`*^9, {3.5980752585314674`*^9, 
   3.598075273632294*^9}},ExpressionUUID->"8a05e77a-12ec-4abf-b51b-\
c61848343082"],

Cell[TextData[{
 "It follows: ",
 StyleBox["The surface is developable, namely a part of a plane, iff w(u) == \
const.",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.59807502072465*^9, 
  3.598075092843577*^9}},ExpressionUUID->"2d4beffa-6aac-4c72-9e59-\
26f46711aeb6"],

Cell["\<\
Of course, the x-axis and the generating lines are geodesics:\
\>", "Text",
 CellChangeTimes->{{3.5980755458014727`*^9, 3.5980755807694726`*^9}, 
   3.613286069453536*^9},ExpressionUUID->"d832fc82-159a-440a-83a7-\
9a99bd754eae"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0"}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.598019304281258*^9, 3.5980193805497923`*^9}, {
  3.5980194122022476`*^9, 
  3.598019418036658*^9}},ExpressionUUID->"ccc81151-81fb-418f-8752-\
0ea58c38e7e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"uo", ",", "t"}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.598019304281258*^9, 3.5980193805497923`*^9}, {
  3.5980194122022476`*^9, 3.598019418036658*^9}, {3.598019521090439*^9, 
  3.5980195443968797`*^9}},ExpressionUUID->"2c28af90-a725-434e-ae8e-\
e6c7ffdfb068"],

Cell["Let", "Text",
 CellChangeTimes->{{3.5980758476497374`*^9, 3.598075856841263*^9}, {
  3.6132867770860105`*^9, 
  3.613286807238735*^9}},ExpressionUUID->"3e76af11-813e-42b3-a523-\
cb3880d5a1ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", "u_", "]"}], " ", ":=", " ", "u"}]], "Input",
 CellChangeTimes->{{3.613286962941641*^9, 
  3.613286976054391*^9}},ExpressionUUID->"b48e4313-cc8a-46de-af49-\
7f5ada6026fb"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rsf", "[", "w", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613287147781213*^9, 
  3.6132872376243515`*^9}},ExpressionUUID->"16225da9-f380-4b10-9d0f-\
06249c2847fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf1", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6132872841090107`*^9, 
  3.6132872905983815`*^9}},ExpressionUUID->"67b23996-f7b2-4e64-8f10-\
afd27dd9e016"],

Cell["We consider the curve", "Text",
 CellChangeTimes->{{3.5980758476497374`*^9, 3.598075856841263*^9}, {
  3.6132867770860105`*^9, 3.613286807238735*^9}, {3.617193967841631*^9, 
  3.617193970571636*^9}},ExpressionUUID->"735a6b6c-4786-4052-884a-\
ccec7a69f147"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsf", "[", "w", "]"}], "[", 
  RowBox[{"t", ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{
  3.613286393944096*^9},ExpressionUUID->"05a72f93-665c-4bc3-902a-\
3799ad546f36"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rsf", "[", "w", "]"}], "[", 
    RowBox[{"t", ",", "1"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6132869979946456`*^9, 
  3.6132870553199244`*^9}},ExpressionUUID->"72ffa205-369f-42f4-aa1c-\
ac46c139a97d"],

Cell["It isn\[CloseCurlyQuote]t a geodesic:", "Text",
 CellChangeTimes->{{3.5980761396094365`*^9, 3.598076149833021*^9}, {
   3.613286460212886*^9, 3.6132864682773476`*^9}, 
   3.6132870776131997`*^9},ExpressionUUID->"f2d135d5-d479-47a5-b304-\
0396f52a7436"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "1"}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.598019304281258*^9, 3.5980193805497923`*^9}, {
  3.5980194122022476`*^9, 3.598019418036658*^9}, {3.598019521090439*^9, 
  3.5980195443968797`*^9}, {3.598019590884961*^9, 
  3.5980196226154175`*^9}},ExpressionUUID->"397d732c-33e8-494f-9d5c-\
1857097e6f74"],

Cell["We try to find some geodesics.", "Text",
 CellChangeTimes->{{3.5980768531292477`*^9, 
  3.598076874889492*^9}},ExpressionUUID->"60f54103-62cf-44e9-9c5a-\
819c509549cf"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.617194795048684*^9, 
  3.617194806343104*^9}},ExpressionUUID->"7b21b514-43e6-4ddc-98b2-\
38692468aaa0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"dabs", "[", "t_", "]"}], " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"DD1", "[", 
      RowBox[{
       RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
       SuperscriptBox["\[Gamma]", "\[Prime]",
        MultilineFunction->None]}], "]"}], "[", "t", "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980199572984047`*^9, 3.598020047950164*^9}, {
   3.5980782588376493`*^9, 3.598078279077807*^9}, {3.6171941205814996`*^9, 
   3.617194139551133*^9}, 3.6171942578929405`*^9, {3.617194540331437*^9, 
   3.617194543716643*^9}, {3.617194818901126*^9, 
   3.6171948227699327`*^9}},ExpressionUUID->"055152e1-651d-4ac4-b095-\
42dd8ea6545b"],

Cell["Again a symbolic solution isn\[CloseCurlyQuote]t  available:", "Text",
 CellChangeTimes->{{3.598078644105685*^9, 
  3.5980786681610613`*^9}},ExpressionUUID->"b677cd3c-4ee1-439a-9897-\
854969464c48"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", " ", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", " ", ".2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980200989310536`*^9, 3.598020171689582*^9}, {
   3.5980202241992736`*^9, 3.59802039280437*^9}, {3.598020424176025*^9, 
   3.5980205019109616`*^9}, {3.5980205409734297`*^9, 
   3.5980205616278667`*^9}, {3.5980209521589527`*^9, 3.598020953484955*^9}, {
   3.5980210114702563`*^9, 3.598021015027063*^9}, 3.5980781057668943`*^9, {
   3.598078143270039*^9, 3.598078158902933*^9}, 3.614861862841945*^9, 
   3.6148646600360584`*^9, {3.6171945812503085`*^9, 3.6171945997987413`*^9}, {
   3.6171948391343613`*^9, 
   3.617194848946779*^9}},ExpressionUUID->"0c828471-c5fc-40fe-9062-\
718ac6b39186"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0.2`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.614861862841945*^9, 3.6148618628575454`*^9}, 
   3.6148646600516586`*^9},ExpressionUUID->"0e6c166f-8f2f-4618-8a2f-\
0fe4efc0e217"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", " ", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", " ", ".2"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", " ", "1"}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", " ", "1"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980200989310536`*^9, 3.598020171689582*^9}, {
   3.5980202241992736`*^9, 3.59802039280437*^9}, {3.598020424176025*^9, 
   3.5980205019109616`*^9}, {3.5980205409734297`*^9, 
   3.5980205616278667`*^9}, {3.5980209521589527`*^9, 3.598020953484955*^9}, {
   3.5980210114702563`*^9, 3.598021015027063*^9}, 3.5980781057668943`*^9, {
   3.598078143270039*^9, 3.598078158902933*^9}, {3.598079224186864*^9, 
   3.5980792763758492`*^9}, 3.614861862873145*^9, 
   3.6148646600672584`*^9},ExpressionUUID->"6ea92b6a-6294-4b59-8f50-\
314a432981e9"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", "0.2`"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", "1"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.614861862873145*^9, 3.6148618628887453`*^9}, 
   3.614864660082858*^9},ExpressionUUID->"fe1afb1c-a9c3-4a6e-93dd-\
c7e149aa7429"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980200989310536`*^9, 3.598020171689582*^9}, {
   3.5980202241992736`*^9, 3.59802039280437*^9}, {3.598020424176025*^9, 
   3.5980205019109616`*^9}, {3.5980205409734297`*^9, 
   3.5980205616278667`*^9}, {3.5980209521589527`*^9, 3.598020953484955*^9}, {
   3.5980210114702563`*^9, 3.598021015027063*^9}, 3.5980781057668943`*^9, {
   3.598078143270039*^9, 3.598078158902933*^9}, {3.598079224186864*^9, 
   3.598079328933855*^9}, 3.6148618628887453`*^9, 
   3.6148646600984583`*^9},ExpressionUUID->"6cda59cb-6ba9-45da-9fcb-\
91d971d8b308"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"v", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["v", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"v", "[", "t", "]"}], "2"]}]], "+", 
       RowBox[{
        SuperscriptBox["u", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"v", "[", "t", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["u", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["v", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6148618628887453`*^9, 3.6148618629043455`*^9}, 
   3.6148646600984583`*^9},ExpressionUUID->"a222c0b7-ae34-4a93-b383-\
c08fc80bdc88"],

Cell["We find a numeric solution:", "Text",
 CellChangeTimes->{{3.598078687809185*^9, 
  3.5980787026570344`*^9}},ExpressionUUID->"99fa5435-4793-4a56-b863-\
0d7f0af70a3e"],

Cell[BoxData[
 RowBox[{"NDSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"dabs", "[", "t", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"u", "[", "0", "]"}], "\[Equal]", " ", "1."}], ",", 
     RowBox[{
      RowBox[{"v", "[", "0", "]"}], "\[Equal]", " ", ".2"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", " ", "1."}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["v", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "\[Equal]", " ", "1."}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", "t", "]"}], ",", 
     RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5980200989310536`*^9, 3.598020171689582*^9}, {
   3.5980202241992736`*^9, 3.59802039280437*^9}, {3.598020424176025*^9, 
   3.5980205019109616`*^9}, {3.5980205409734297`*^9, 
   3.5980205616278667`*^9}, {3.5980209521589527`*^9, 3.598020953484955*^9}, {
   3.5980210114702563`*^9, 3.598021015027063*^9}, {3.5980783063833685`*^9, 
   3.5980783360160637`*^9}, {3.613286573172347*^9, 3.6132866043161287`*^9}, 
   3.6148618629043455`*^9, 
   3.6148646601140585`*^9},ExpressionUUID->"ad37a4a4-1fdd-4333-b62b-\
996d4e240918"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fu", "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"u", "[", "t", "]"}], "/.", 
   RowBox[{
    RowBox[{"Flatten", "[", "%", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980105673455124`*^9, 3.598010700881747*^9}, {
  3.5980110599163775`*^9, 
  3.59801106141398*^9}},ExpressionUUID->"e9a0dbed-8da6-4569-a73a-\
d10ce2863fc5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gu", "[", "t_", "]"}], " ", "=", 
  RowBox[{
   RowBox[{"v", "[", "t", "]"}], "/.", 
   RowBox[{
    RowBox[{"Flatten", "[", "%%", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5980105673455124`*^9, 3.5980107410050173`*^9}, {
  3.598011081772016*^9, 
  3.598011083410019*^9}},ExpressionUUID->"3ce0d5a3-2874-4dfa-8f4b-\
f5b7b0de4706"],

Cell["Here is the geodesic:", "Text",
 CellChangeTimes->{{3.5980787235852313`*^9, 
  3.5980787307136393`*^9}},ExpressionUUID->"3de08f69-f7c1-44f7-88cf-\
c1b0c8fa6814"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rsf", "[", "w", "]"}], "[", 
    RowBox[{
     RowBox[{"fu", "[", "t", "]"}], ",", 
     RowBox[{"gu", "[", "t", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.59793530857513*^9, 3.597935328999298*^9}, {
   3.597935372503786*^9, 3.597935416552306*^9}, 3.5979361503762784`*^9, {
   3.5980107984599185`*^9, 3.5980108206743574`*^9}, {3.5980108954452887`*^9, 
   3.5980109588282003`*^9}, {3.5980111031908536`*^9, 
   3.5980111599125533`*^9}, {3.598020677192869*^9, 3.598020773601039*^9}, {
   3.6132873225702105`*^9, 3.613287327424488*^9}, {3.617195528998773*^9, 
   3.617195531619578*^9}},ExpressionUUID->"da724969-080b-4cd1-99bf-\
c97c44e3cbab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"geod1", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.598020793662674*^9, 
  3.5980208002614856`*^9}},ExpressionUUID->"e0e91eb8-08aa-4ebe-8bff-\
989af929619b"],

Cell["Its position on the surface is shown here:", "Text",
 CellChangeTimes->{{3.5980788702026176`*^9, 
  3.5980788941529875`*^9}},ExpressionUUID->"72b256f0-a708-4ea5-845d-\
80d8a5876450"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"rsf1", ",", "geod1"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.5980208669204025`*^9, 
  3.5980208873408384`*^9}},ExpressionUUID->"a5df6f26-1d6a-4b5e-9448-\
4836426ef423"],

Cell["\<\
We control the deviation of the absolute differential from the null vector:\
\>", "Text",
 CellChangeTimes->{{3.6171956229421387`*^9, 
  3.6171956730962267`*^9}},ExpressionUUID->"12120a50-70a8-46eb-bc47-\
66f665595460"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "[", "t_", "]"}], "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fu", "[", "t", "]"}], ",", 
     RowBox[{"gu", "[", "t", "]"}]}], "}"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"DD1", "[", 
     RowBox[{
      RowBox[{"rsf", "[", "w", "]"}], ",", "\[Gamma]", ",", 
      SuperscriptBox["\[Gamma]", "\[Prime]",
       MultilineFunction->None]}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.617195036006707*^9, 3.617195039142313*^9}, 
   3.6171950857239947`*^9, {3.61719513417768*^9, 
   3.617195172038946*^9}},ExpressionUUID->"fe4a55bb-c5b4-4ee3-b7c7-\
2186a6b60314"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"%", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"%", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617195254859492*^9, 3.617195319771206*^9}, {
  3.6171953742309017`*^9, 3.6171953918901324`*^9}, {3.6171954242757893`*^9, 
  3.617195429735799*^9}},ExpressionUUID->"f9efdf84-d7a5-47a0-8d37-\
c74db9ddef26"],

Cell["\<\
The deviation is comparatively small.
Find more geodesics with other initial conditions.\
\>", "Text",
 CellChangeTimes->{{3.5980789447378807`*^9, 3.598078967265169*^9}, {
  3.6171956903654566`*^9, 
  3.6171957148886995`*^9}},ExpressionUUID->"c081089f-03aa-4b21-acb1-\
61b07b28e4e9"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3. Geodesic Curvature", "Subsection",
 CellChangeTimes->{{3.595076945363204*^9, 3.5950769905720835`*^9}, 
   3.5953174793534184`*^9, {3.5953175263051033`*^9, 3.595317587064579*^9}, 
   3.5956008724322104`*^9, {3.5965213907316623`*^9, 3.5965214041788855`*^9}, {
   3.5972984401750546`*^9, 3.59729846072029*^9}, {3.5972984954771514`*^9, 
   3.5972985062723703`*^9}, {3.5973320886172123`*^9, 3.5973320905123205`*^9}, 
   3.5973952636966553`*^9, {3.597729800827932*^9, 3.59772986233884*^9}, {
   3.597910399537461*^9, 3.597910436118553*^9}, {3.5979116271266747`*^9, 
   3.5979116482228813`*^9}, {3.5988859626392813`*^9, 3.5988859896078234`*^9}, 
   3.613287406886033*^9, 3.6145881974242153`*^9, 3.6171958241200914`*^9, 
   3.617440712305024*^9, 3.624544170874772*^9, 3.6262678827716866`*^9, 
   3.626534442696803*^9, {3.626535821629798*^9, 3.6265358232210007`*^9}, 
   3.6267862094512415`*^9, 3.699250325938855*^9, 
   3.6992532196826687`*^9},ExpressionUUID->"40a50a71-8646-4b05-93b0-\
ae0ea552bf87"],

Cell[TextData[{
 "Already in Section 3.5 we introduced the ",
 ButtonBox["geodesic curvature",
  BaseStyle->"Hyperlink",
  ButtonData->"geodc"],
 " of a curve on the surface sf[u;v]:"
}], "Text",
 CellChangeTimes->{{3.598943532606222*^9, 3.598943598786008*^9}, {
   3.5989437640264587`*^9, 3.59894377804226*^9}, {3.598943994802658*^9, 
   3.5989440320987916`*^9}, {3.614313265943533*^9, 3.6143132659465327`*^9}, 
   3.699251258571834*^9},ExpressionUUID->"653583f3-4e87-421a-b3a1-\
524165d1689d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "3"}], ";", 
  RowBox[{
   RowBox[{"cx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{"sf", "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{
   RowBox[{"\[Gamma]", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5911639056057415`*^9, 3.5911639586847773`*^9}, 
   3.5911644865179677`*^9, 3.618135579701305*^9, {3.6188395679109087`*^9, 
   3.618839573838919*^9}, 3.6188396059437757`*^9, {3.626534531721961*^9, 
   3.626534548803991*^9}, {3.699251288490798*^9, 
   3.699251294530113*^9}},ExpressionUUID->"6bc99560-5bf9-49eb-9dd3-\
f7dd287886ad"],

Cell["\<\
as the norm of the tangential projection of its curvature vector. We name it \
the \[OpenCurlyDoubleQuote]outer\[CloseCurlyDoubleQuote] definition of the \
geodesic curvature, since the embedding of the curve into the Euclidean space \
is explicitly used. In this section we will give the \
\[OpenCurlyDoubleQuote]inner\[CloseCurlyDoubleQuote] definition of the \
geodesic curvature  which is the norm of the absolute derivative of its \
tangent unit vector with respect to its arc length. This definition uses the \
Riemannian metric of  the surface only and can be easily generalized to \
curves in Riemannian spaces.  We show that both definitions yield the same \
geodesic curvature In the case of curves on surfaces in the Euclidean 3-space.\
\>", "Text",
 CellChangeTimes->{{3.5990257160305843`*^9, 3.5990257932975206`*^9}, 
   3.5990258639656444`*^9, 3.618135581074107*^9, {3.6181360567969427`*^9, 
   3.6181360986986165`*^9}, {3.6246050786922965`*^9, 3.624605079066697*^9}, {
   3.626534612011298*^9, 3.6265346489365625`*^9}, {3.6265347162274814`*^9, 
   3.6265347908056126`*^9}, {3.6265348261968427`*^9, 
   3.6265350229895887`*^9}, {3.626535059747254*^9, 3.626535096118918*^9}, {
   3.6265351591666293`*^9, 3.6265352018835044`*^9}, {3.6265352450391808`*^9, 
   3.626535258207604*^9}, {3.626535289427259*^9, 3.6265354337787137`*^9}, 
   3.6265354828*^9, 3.626535515033657*^9, 3.6268544534557924`*^9, 
   3.699251362042226*^9},ExpressionUUID->"5222e34d-b655-4545-8a0f-\
aeff98067f2b"],

Cell[CellGroupData[{

Cell["4.3.1. The Inner Definition of the Geodesic Curvature", "Subsubsection",
 CellChangeTimes->{{3.6265355476105146`*^9, 3.6265355961034*^9}, 
   3.699253229890786*^9, 3.699284060574942*^9, 3.7081512413334627`*^9, 
   3.708188618452277*^9},ExpressionUUID->"e988f97d-8174-41e9-9199-\
cefce8798f07"],

Cell[TextData[{
 "\nWe calculate the curvature vector of the curve cx[s] \[Element] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["E", "3"], ",", " "}], TraditionalForm]],ExpressionUUID->
  "d3ea6195-9b47-453a-bc8a-973dea1386bf"],
 "s the arc length, under this assumption:"
}], "Text",
 CellChangeTimes->{{3.5990257160305843`*^9, 3.5990257932975206`*^9}, 
   3.5990258639656444`*^9, 3.618135581074107*^9, {3.6181360567969427`*^9, 
   3.6181360986986165`*^9}, {3.6246050786922965`*^9, 3.624605079066697*^9}, {
   3.626534612011298*^9, 3.6265346489365625`*^9}, {3.6265347162274814`*^9, 
   3.6265347908056126`*^9}, {3.6265348261968427`*^9, 
   3.6265350229895887`*^9}, {3.626535059747254*^9, 3.626535096118918*^9}, {
   3.6265351591666293`*^9, 3.6265352018835044`*^9}, {3.6265352450391808`*^9, 
   3.626535258207604*^9}, {3.626535289427259*^9, 3.6265354337787137`*^9}, 
   3.6265354828*^9, 
   3.626535515033657*^9},ExpressionUUID->"ea5e83f9-f7a2-434e-9285-\
b2f0b781bb48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.626076262571863*^9, 
  3.626076268047473*^9}},ExpressionUUID->"d6594887-35a6-48b1-aebf-\
3e58e801b5c3"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}], ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"cx", "[", "s", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "2"}], "}"}]}], "]"}], ",", " ", 
      RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5989446013283496`*^9, 3.5989446663580694`*^9}, 
   3.6136210267017107`*^9, {3.6172830626050825`*^9, 3.6172830651634874`*^9}, 
   3.618135583492111*^9, 3.6246084942260823`*^9, {3.624629400197584*^9, 
   3.624629455671282*^9}, {3.6260763368279934`*^9, 3.6260763401975994`*^9}, {
   3.699253376846661*^9, 
   3.699253450113714*^9}},ExpressionUUID->"e2d622ac-a0fd-45c8-8526-\
cc437711e6da"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v. 9.0.1.0 needed 2570.2 s \[TildeTilde] 43 min f0r this calculation.\n\
Using this simplification we define a formula to calculate the curvature \
vector as the second derivative of the curve cx[s], s its arc length:"
}], "Text",
 CellChangeTimes->{{3.59894497180654*^9, 3.598945037306286*^9}, {
   3.598945077202568*^9, 3.598945138706086*^9}, 3.6172010145564814`*^9, {
   3.617336690851932*^9, 3.6173367837032948`*^9}, {3.6173369022519894`*^9, 
   3.6173370104041758`*^9}, 3.617441792188218*^9, 3.6181355864405165`*^9, 
   3.618136128666269*^9, {3.6181361761059523`*^9, 3.618136187587572*^9}, 
   3.6246085348953533`*^9, {3.699256794717718*^9, 3.6992568310541897`*^9}, {
   3.699256880588894*^9, 3.699256925276761*^9}, {3.70816430258928*^9, 
   3.708164303253821*^9}, {3.7081643723006973`*^9, 
   3.708164401012685*^9}},ExpressionUUID->"d93861d5-3d76-4256-bb43-\
1bad13c62872"],

Cell[BoxData[
 RowBox[{
  RowBox[{"d2cx", "[", "s_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["hv", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hv", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["hu", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hu", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "1", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["hv", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hv", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["hu", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hu", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "2", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["hv", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hv", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["hu", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["hu", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox["hv", "\[Prime]",
        MultilineFunction->None], "[", "s", "]"}], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["hu", "\[Prime]",
         MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f", "[", "3", "]"}], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5989449039436584`*^9, 3.5989449378745995`*^9}, 
   3.6181355885621204`*^9},ExpressionUUID->"1af5b437-85b2-449f-954c-\
6f26113d945f"],

Cell["Its tangential projection is", "Text",
 CellChangeTimes->{{3.5989458073863325`*^9, 
  3.5989458423543324`*^9}},ExpressionUUID->"013871ee-a7b2-47cd-897f-\
b33f614a1e25"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}], ",", " ", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"pT", "[", "sf", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "s", "]"}], ",", 
         RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
       RowBox[{"d2cx", "[", "s", "]"}], "]"}], ",", " ", 
      RowBox[{"s", ">", "0"}], ",", " ", 
      RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}]}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.598945882152609*^9, 3.598945992372913*^9}, {
   3.5989466625182433`*^9, 3.5989466663334613`*^9}, {3.5989467172543736`*^9, 
   3.598946767455245*^9}, {3.598951350742051*^9, 3.5989513740263824`*^9}, 
   3.598957784087018*^9, 3.59895786157845*^9, 3.59895790475692*^9, 
   3.5990231499040775`*^9, {3.613443680308923*^9, 3.613443723037398*^9}, 
   3.613621042754139*^9, 3.618135592368527*^9, {3.626076655162153*^9, 
   3.626076666066572*^9}, {3.6261617859874597`*^9, 3.6261618344879446`*^9}, 
   3.62616193425012*^9, {3.699256994293151*^9, 
   3.6992570101089163`*^9}},ExpressionUUID->"3307041b-54b6-4615-9291-\
4ff02a4cf7bc"],

Cell["after more than90 min.", "Text",
 CellChangeTimes->{{3.699262952923052*^9, 
  3.699262993051035*^9}},ExpressionUUID->"bdc0e918-e6cf-4cae-9d4b-\
c8271b0ac676"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"pT", "[", "sf", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{"d2cx", "[", "s", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.598945882152609*^9, 3.598945992372913*^9}, {
   3.5989466625182433`*^9, 3.5989466663334613`*^9}, {3.5989467172543736`*^9, 
   3.598946767455245*^9}, {3.598951350742051*^9, 3.5989513740263824`*^9}, 
   3.598957784087018*^9, 3.59895786157845*^9, 3.59895790475692*^9, 
   3.5990231499040775`*^9, {3.613443680308923*^9, 3.613443723037398*^9}, 
   3.613621042754139*^9, 3.618135592368527*^9, {3.626076655162153*^9, 
   3.626076666066572*^9}, {3.6261617859874597`*^9, 3.6261618344879446`*^9}, 
   3.62616193425012*^9, {3.6265095320790744`*^9, 
   3.6265095549643145`*^9}},ExpressionUUID->"3d8415e1-a35c-44af-9c24-\
feeefc118288"],

Cell["", "Item",
 CellChangeTimes->{
  3.708172537997501*^9},ExpressionUUID->"8a0185f3-c0be-4420-bff8-\
d9676c4bd136"],

Cell["The  result has been entered into the following definition:", "Text",
 CellChangeTimes->{{3.599023115459217*^9, 3.599023135427252*^9}, 
   3.5990262044050426`*^9, {3.6262679305857706`*^9, 3.6262679869954696`*^9}, {
   3.6262680268691397`*^9, 3.6262681088628836`*^9}, 3.626509452066534*^9, {
   3.6265098531276383`*^9, 
   3.6265099014877234`*^9}},ExpressionUUID->"2aed746f-a564-478c-a708-\
7c423260638e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pTd2cx", "[", "s_", "]"}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "1", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "2", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"f", "[", "3", "]"}], 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           RowBox[{"hu", "[", "s", "]"}], ",", 
           RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"f", "[", "1", "]"}], 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "-", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "1", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "1", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "2", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "2", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"f", "[", "3", "]"}], 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{
                 RowBox[{"hu", "[", "s", "]"}], ",", 
                 RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"f", "[", "3", "]"}], 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{
                    RowBox[{"hu", "[", "s", "]"}], ",", 
                    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "1", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "2", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"f", "[", "3", "]"}], 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{
               RowBox[{"hu", "[", "s", "]"}], ",", 
               RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}], ")"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "1", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "2", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"f", "[", "3", "]"}], 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{
              RowBox[{"hu", "[", "s", "]"}], ",", 
              RowBox[{"hv", "[", "s", "]"}]}], "]"}], "2"]}], ")"}]}]}], 
       ")"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.599023047177897*^9, 3.5990230977843857`*^9, 
  3.61813559378813*^9},ExpressionUUID->"4fc59df0-3eeb-4ca4-b6cf-b1d87f36c4b6"],

Cell[TextData[{
 "This is a tangent vector of the surface in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]],ExpressionUUID->
  "7023b15c-fe6e-4981-9c53-e4ae874ce18a"],
 ", the tangential projection of the curvature vector of the curve cx[s]. By \
definition its norm is the ",
 StyleBox["geodesic curvature",
  FontColor->RGBColor[0, 0, 1]],
 " of the curve: the ",
 StyleBox["outer definition of the geodesic curvature",
  FontSlant->"Italic"],
 ". Now we show that it coincides with the ",
 StyleBox["inner definition of the geodesic curvature",
  FontSlant->"Italic"],
 ", contained in the\n\n",
 StyleBox["Proposition 5",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["The geodesic curvature is the norm of the absolute derivative of \
the tangent unit vector of the curve DD1[sf,\[Gamma],\[Gamma]\
\[CloseCurlyQuote]][s] with respect to the arc length s",
  FontSlant->"Italic"],
 ".  Thus a curve is a geodesic iff its geodesic curvature is zero.\n",
 StyleBox["Proof",
  FontColor->RGBColor[0, 0, 1]],
 "."
}], "Text",
 CellChangeTimes->{{3.59902627165676*^9, 3.599026696726307*^9}, {
   3.5990267275831614`*^9, 3.599026737676379*^9}, 3.5990267771600485`*^9, 
   3.6130242329889708`*^9, {3.6142281112104774`*^9, 3.6142281129576807`*^9}, {
   3.6173570308642416`*^9, 3.617357042295895*^9}, 3.6181355968925347`*^9, 
   3.626258361032352*^9, {3.699263403736918*^9, 3.699263405257016*^9}, {
   3.699263448192902*^9, 3.699263450104578*^9}, 
   3.699280247596465*^9},ExpressionUUID->"28ceaf1a-7dab-465a-acf0-\
72e960c031fa"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"pTd2cx", "[", "s", "]"}], ".", 
      RowBox[{"pTd2cx", "[", "s", "]"}]}], "-", 
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "sf", "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"DD1", "[", 
         RowBox[{"sf", ",", "\[Gamma]", ",", 
          RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"DD1", "[", 
         RowBox[{"sf", ",", "\[Gamma]", ",", 
          RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}]}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}], ",", " ", 
    RowBox[{"TimeConstraint", " ", "\[Rule]", " ", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.598957931526451*^9, 3.5989579547757807`*^9}, {
   3.5990234271945643`*^9, 3.599023494118682*^9}, {3.5990235576575937`*^9, 
   3.5990236292773194`*^9}, {3.599023667949787*^9, 3.5990237026754484`*^9}, 
   3.613445355876666*^9, {3.613445387497921*^9, 3.6134454029107485`*^9}, {
   3.6134463165107527`*^9, 3.6134463361355877`*^9}, 3.6136210445325418`*^9, {
   3.6181355982965374`*^9, 3.618135599372939*^9}, 3.626076522171919*^9, {
   3.626076618470888*^9, 3.626076619843691*^9}, {3.699280285755949*^9, 
   3.6992803000363894`*^9}},ExpressionUUID->"2bdfccdd-bef4-4663-8049-\
7b692ef549f0"],

Cell["Mathematica needed 0.876 s only to confirm the statement!  \
\[FilledSquare]", "Text",
 CellChangeTimes->{{3.6992803269760933`*^9, 
  3.699280418285839*^9}},ExpressionUUID->"bf339ef3-ced5-49b5-9939-\
8667de9e1932"],

Cell["\<\
The function pTd2cx[s] is used only once to prove the last proposition and to \
justify the following inner definition of  the geodesic curvature (up to \
sign) of the curve\
\>", "Text",
 CellChangeTimes->{{3.614146476570078*^9, 3.614146480048884*^9}, {
   3.614146537956186*^9, 3.614146561574627*^9}, 3.6141465923690815`*^9, {
   3.6142297053268776`*^9, 3.6142297166836977`*^9}, {3.626268201137046*^9, 
   3.6262682871555967`*^9}, {3.626268326717266*^9, 3.626268358837723*^9}, 
   3.6262684610491023`*^9, 
   3.626854496083068*^9},ExpressionUUID->"5787cb90-d77c-42a7-8785-\
464bb0760918"],

Cell[BoxData[
 RowBox[{"\[Gamma]", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6141466259559402`*^9, 
  3.6141466278123436`*^9}},ExpressionUUID->"038a3519-b718-469d-9ce0-\
18447cbc541b"],

Cell["\<\
on the surface ff[u,v], s an arbitrary parameter, by the Module (contained in \
eudiffgeov3.m):\
\>", "Text",
 CellChangeTimes->{{3.614146913948046*^9, 3.614146920047657*^9}, 
   3.6141480432028294`*^9, {3.626268401082597*^9, 3.626268447601879*^9}, 
   3.686289024940123*^9},ExpressionUUID->"a9ec03c0-80ac-4c8b-a721-\
7645bfc66ba1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"geodcurvature", "[", 
    RowBox[{"ff_", ",", "hu_", ",", "hv_"}], "]"}], "[", "s_", "]"}], ":=", 
  " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cuv", ",", "t", ",", "aa", ",", "bb", ",", "abc", ",", "vbc", ",", 
      "tt"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"cuv", "[", "t_", "]"}], "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"hu", "[", "t", "]"}], ",", 
        RowBox[{"hv", "[", "t", "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"abc", "[", "t_", "]"}], " ", "=", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"cuv", "[", "tt", "]"}], ",", "tt"}], "]"}], "/.", 
       RowBox[{"tt", "\[Rule]", "t"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"bb", "[", "t_", "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "ff", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "t", "]"}], ",", 
         RowBox[{"hv", "[", "t", "]"}]}], "]"}], "[", 
       RowBox[{
        RowBox[{"abc", "[", "t", "]"}], ",", 
        RowBox[{"abc", "[", "t", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vbc", "[", "t_", "]"}], " ", "=", 
      RowBox[{
       RowBox[{"abc", "[", "t", "]"}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"bb", "[", "t", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"aa", "[", "t_", "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"fund1", "[", "ff", "]"}], "[", 
        RowBox[{
         RowBox[{"hu", "[", "t", "]"}], ",", 
         RowBox[{"hv", "[", "t", "]"}]}], "]"}], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"DD1", "[", 
          RowBox[{"ff", ",", "cuv", ",", "vbc"}], "]"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"DD1", "[", 
          RowBox[{"ff", ",", "cuv", ",", "vbc"}], "]"}], "[", "t", "]"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"aa", "[", "s", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"bb", "[", "s", "]"}], ")"}]}], "]"}]}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.6141469785009594`*^9, 3.6141471594612775`*^9}, {
   3.614147207197361*^9, 3.614147215184575*^9}, 3.6141472683494687`*^9, {
   3.6141473036055307`*^9, 3.6141473691880455`*^9}, {3.6141474491693864`*^9, 
   3.6141474805566416`*^9}, {3.6141475110702953`*^9, 3.614147680611393*^9}, {
   3.61414772454107*^9, 3.614147742309501*^9}, {3.6141477802799683`*^9, 
   3.6141477893903837`*^9}, {3.614147823055243*^9, 3.61414788398895*^9}, {
   3.6141479364050417`*^9, 3.6141479817075214`*^9}, {3.614151658259579*^9, 
   3.614151816007056*^9}, {3.614235429132931*^9, 3.614235440661351*^9}, {
   3.6142355823876004`*^9, 3.6142355873484087`*^9}, {3.614236105440919*^9, 
   3.61423614015098*^9}, {3.6142572420372305`*^9, 3.614257250040045*^9}, {
   3.614397469072534*^9, 3.614397515295415*^9}, {3.614397546121069*^9, 
   3.6143976442608414`*^9}, {3.6143978611324224`*^9, 3.6143978685112357`*^9}, 
   3.6143981191256757`*^9, {3.6144010659989595`*^9, 3.614401078382668*^9}, 
   3.614401116990876*^9, {3.614401159157288*^9, 3.614401252086603*^9}, {
   3.614401300351364*^9, 3.614401303728557*^9}, {3.614401342224759*^9, 
   3.6144014189041443`*^9}, {3.6144014551352167`*^9, 
   3.6144015880558195`*^9}, {3.614401629657199*^9, 3.614401720151375*^9}, 
   3.614401760607689*^9, {3.614401801610034*^9, 3.614401837968114*^9}, 
   3.6144019127433906`*^9, 3.6144914658978214`*^9, {3.614861863091546*^9, 
   3.614861863107146*^9}, 3.6148631367089825`*^9, 3.6149177943229656`*^9, {
   3.626509981671864*^9, 3.626510000735098*^9}, {3.626510387022976*^9, 
   3.626510398535796*^9}},ExpressionUUID->"e416ad43-f119-4ad9-936f-\
2c7d6deef16f"],

Cell[BoxData[
 RowBox[{"?", "geodcurvature"}]], "Input",
 CellChangeTimes->{{3.62460558198038*^9, 3.6246057409134593`*^9}, {
  3.6246057820195312`*^9, 3.6246058622660723`*^9}, {3.6262687584324245`*^9, 
  3.6262687645632353`*^9}},ExpressionUUID->"5eba0f85-6495-426a-8af3-\
f44d0facc6d5"],

Cell[TextData[{
 "If t is the arc length of the curve,  then bb[t] == 1, and the definition \
corresponds to the result of the proposition.  For arbitrary parameters the \
norming defines the tangent unit vector vbc[t], and ensures that the \
expression is invariant under a parameter transformations. Obviously, by this \
definition the geodesic curvature is always non-negative. \n",
 StyleBox["Remark.",
  FontColor->RGBColor[0, 0, 1]],
 " With an adapted definition of the derivative DD1 the geodesic curvature \
may be easily generalized to curves in a Riemann manifold. We leave this to \
the user. "
}], "Text",
 CellChangeTimes->{{3.59902816170928*^9, 3.599028196403741*^9}, {
   3.6141482435071816`*^9, 3.614148310478099*^9}, {3.614430191294223*^9, 
   3.61443019195026*^9}, {3.614430470191175*^9, 3.614430667510461*^9}, {
   3.6144307257667933`*^9, 3.6144308274956117`*^9}, {3.6174418306204166`*^9, 
   3.6174418465883303`*^9}, 3.6188394259034586`*^9, 3.6252210520663753`*^9, {
   3.6262689136370974`*^9, 3.626269023820091*^9}, {3.626269059013753*^9, 
   3.626269065596964*^9}, 3.626269134265447*^9, {3.6262691845852957`*^9, 
   3.626269185646098*^9}, 3.626269238225794*^9, 3.626854508188689*^9, 
   3.699280681969205*^9},ExpressionUUID->"bb4db239-a730-4906-bec1-\
05e327915c86"],

Cell[TextData[{
 "We show\n",
 StyleBox["Lemma 7",
  FontColor->RGBColor[0, 0, 1]],
 ". ",
 StyleBox["The absolute derivative \
DD1[sf,\[Gamma],\[Gamma]\[CloseCurlyQuote]][s], s the arc length of the \
curve,  is orthogonal to the tangent vector \[Gamma]\[CloseCurlyQuote][s], s \
the arc length",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.599028227837796*^9, 3.599028350376012*^9}, {
   3.6144300781997547`*^9, 3.6144300966158075`*^9}, 3.617360986151471*^9, 
   3.617361063695906*^9, {3.6992806233290377`*^9, 
   3.699280624592758*^9}},ExpressionUUID->"bd92418f-9997-4b0d-af56-\
dee18262400f"],

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fund1", "[", "sf", "]"}], "[", 
       RowBox[{
        RowBox[{"hu", "[", "s", "]"}], ",", 
        RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"DD1", "[", 
         RowBox[{"sf", ",", "\[Gamma]", ",", 
          RowBox[{"\[Gamma]", "'"}]}], "]"}], "[", "s", "]"}], ",", 
       RowBox[{
        RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", 
     RowBox[{"s", ">", "0"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5990270185548725`*^9, 3.5990270848237886`*^9}, {
   3.59902713120267*^9, 3.599027132887473*^9}, {3.5990278914232054`*^9, 
   3.599027893310809*^9}, 3.613449468246689*^9, 3.6134495002267447`*^9, 
   3.6134495381348114`*^9, 3.6134495822360888`*^9, 3.613449621048957*^9, 
   3.613621310653409*^9, 3.6188396723842926`*^9, {3.626258652175663*^9, 
   3.626258723545789*^9}},ExpressionUUID->"112ea72e-f4f2-49ce-bf57-\
a9cc17f1a810"],

Cell[TextData[{
 "\[FilledRectangle]\nNow, as in case of the plane, we can provide the non \
zero geodesic curvature with a sign: If the orientation of the tangent planes \
defined by the pair {\[Gamma]\[CloseCurlyQuote][s], DD1[sf,\[Gamma],\[Gamma]\
\[CloseCurlyQuote]][s]}  coincides with the orientation defined by the \
parameters {tv[1][sf],tv[2][sf]} we take the curvature as positive, and as \
negative if this is not the case. In this sense the",
 StyleBox[" oriented geodesic curvature",
  FontColor->RGBColor[0, 0, 1]],
 " is defined."
}], "Text",
 CellChangeTimes->{{3.599028678070187*^9, 3.5990289698842993`*^9}, {
   3.5990290095707693`*^9, 3.599029014515978*^9}, {3.599029058773256*^9, 
   3.599029104512536*^9}, 3.617600026709092*^9, 3.617600085848796*^9, {
   3.6188408953452406`*^9, 3.618840921288086*^9}, {3.626259940472726*^9, 
   3.6262599431715307`*^9}},ExpressionUUID->"ce68cda9-e540-40b5-85b2-\
2f65a7959144"],

Cell["\<\
As a test for the correctness of the definitions of curvature, normal, and \
geodesic curvature we show by a lengthy symbolic calculation that the next \
expression equals zero:\
\>", "Text",
 CellChangeTimes->{{3.6136215027053466`*^9, 3.613621632201174*^9}, {
   3.61414866399032*^9, 3.614148664349121*^9}, 3.614313586866888*^9, 
   3.6262610545486827`*^9, {3.6262695467855377`*^9, 3.626269568221976*^9}, {
   3.626532300900201*^9, 3.6265324546228714`*^9}, {3.6265325839281893`*^9, 
   3.626532633659482*^9}},ExpressionUUID->"be21d4a5-1115-4811-8b5f-\
c614092165f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{"sf", ",", "hu", ",", "hv"}], "]"}], "[", "s", "]"}], "^", "2"}],
   "+", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{"sf", ",", "hu", ",", "hv"}], "]"}], "[", "s", "]"}], "^", "2"}],
   "-", 
  RowBox[{
   RowBox[{
    RowBox[{"curvature", "[", "cx", "]"}], "[", "s", "]"}], "^", 
   "2"}]}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.599040146992449*^9, {3.5990401854777164`*^9, 3.5990401961013346`*^9}, 
   3.613621085654214*^9, 3.613621484016514*^9, {3.6136232678952465`*^9, 
   3.6136232769900627`*^9}, {3.6136268909080105`*^9, 3.61362689666442*^9}, 
   3.614861863153946*^9, 3.6148631367089825`*^9, 3.626260981883755*^9, 
   3.6265224841950035`*^9, 3.626522529771884*^9, {3.6265226969417777`*^9, 
   3.62652278345953*^9}, {3.626522826281605*^9, 3.6265228681364784`*^9}, {
   3.626523443496689*^9, 
   3.6265234495807*^9}},ExpressionUUID->"9d9de78a-01e1-4ed8-97ca-\
b9234a11aa2d"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"scond2", "[", "sf", "]"}], "[", "s", "]"}], ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Together", "[", "%", "]"}], ",", 
      RowBox[{"TimeConstraint", "\[Rule]", "Infinity"}]}], "]"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.626523499890788*^9, 3.6265235053975973`*^9}, {
  3.6265236172341943`*^9, 3.626523629558216*^9}, {3.699280878311504*^9, 
  3.6992808830567417`*^9}, {3.699280932752225*^9, 
  3.699281009086245*^9}},ExpressionUUID->"4fd94716-b10e-4b91-991e-\
69922d7b4ee2"],

Cell["\<\
After 2601.152` s \[TildeTilde] 43 min the result was 0. With v. 9.0.1.0 : \
6270.284 \[TildeTilde] 104 min. !
OK.
In the next examples we consider some curves on specified surfaces, calculate \
their curvatures and  control this relation again.\
\>", "Text",
 CellChangeTimes->{{3.699283832130817*^9, 3.699283880101736*^9}, {
  3.6992839279208517`*^9, 3.69928398083154*^9}, {3.708188418199094*^9, 
  3.708188446325815*^9}, {3.70818847946262*^9, 3.70818851329661*^9}, {
  3.7081885648620977`*^9, 
  3.708188584566052*^9}},ExpressionUUID->"db11adaa-ede5-4622-bd3c-\
41a7db6acb21"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3.2. Circles on the Sphere", "Subsubsection",
 CellChangeTimes->{{3.6265356696031294`*^9, 3.626535718252015*^9}, 
   3.699284067328164*^9, 3.6993322244086447`*^9, 3.708188625462253*^9, 
   3.708222845179222*^9},ExpressionUUID->"55e8bfae-844c-4ca9-8462-\
51ea40bbf34c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "r", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6144904863257933`*^9, 3.6144904977664475`*^9}, 
   3.6265861898818274`*^9},ExpressionUUID->"6d094cf2-3492-473a-bc23-\
085829dd7370"],

Cell[" We consider the circles", "Text",
 CellChangeTimes->{{3.6141488938255234`*^9, 3.6141489033727407`*^9}, {
   3.6143272794730387`*^9, 3.6143272834572663`*^9}, 
   3.6144904761582117`*^9},ExpressionUUID->"3e7175ac-dc8f-4834-aea9-\
113387d1f9ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "t_", "]"}], " ", ":=", " ", "t"}], ";", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"h2", "[", "ca_", "]"}], "[", "t_", "]"}], " ", ":=", " ", "ca"}],
   ";"}]], "Input",
 CellChangeTimes->{{3.6141489619820433`*^9, 
  3.614149121149123*^9}},ExpressionUUID->"d2c8cd6a-0399-4d33-82cb-\
d220b8a19476"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphero", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"h1", "[", "t", "]"}], ",", 
     RowBox[{
      RowBox[{"h2", "[", 
       RowBox[{"Pi", "/", "4"}], "]"}], "[", "t", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", " ", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6141489619820433`*^9, 3.614149089215867*^9}, {
  3.6141491303999395`*^9, 
  3.614149285058611*^9}},ExpressionUUID->"ab9f588a-5d3b-4971-a0eb-\
c58988314af1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circ", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6141493241678796`*^9, 
  3.6141493321082935`*^9}},ExpressionUUID->"a632870e-a767-4274-b4a2-\
1583cf673468"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphero", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
   RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Opacity", "[", "0.7", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6141493439487143`*^9, 3.6141494448340917`*^9}, {
  3.614149700861741*^9, 3.6141497219685783`*^9}, {3.6142600151061015`*^9, 
  3.6142600366653395`*^9}},ExpressionUUID->"ee039290-2412-4302-b186-\
88ed78381426"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sph1", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6141497356654024`*^9, 
  3.61414974589902*^9}},ExpressionUUID->"d4583faa-20e9-4bb9-af52-\
263f2bce80a1"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"circ", ",", "sph1"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614149757833041*^9, 
  3.614149804227523*^9}},ExpressionUUID->"be1354bc-67c4-4e28-8b51-\
9e935936f7a9"],

Cell["The geodesic curvature of the circle with parameter ca is", "Text",
 CellChangeTimes->{{3.6142629124679904`*^9, 3.6142629310944233`*^9}, {
  3.6265865355316343`*^9, 
  3.626586553596466*^9}},ExpressionUUID->"6f9059e4-afa5-431b-9017-\
787482b50add"],

Cell[BoxData[
 RowBox[{
  RowBox[{"geodcurvature", "[", 
   RowBox[{
    RowBox[{"sphero", "[", "r", "]"}], ",", "h1", ",", 
    RowBox[{"h2", "[", "ca", "]"}]}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.614149876050049*^9, 3.614149963925003*^9}, {
   3.6141500332983255`*^9, 3.6141501013612447`*^9}, {3.6141501802973833`*^9, 
   3.6141502134162416`*^9}, 3.6141519955165715`*^9, {3.614236185172659*^9, 
   3.6142361856406603`*^9}, {3.6144907894011283`*^9, 3.6144908578020406`*^9}, 
   3.614861863216346*^9, 3.6148631367089825`*^9, 3.6188411396416693`*^9, 
   3.618841188157755*^9, {3.6188417041442614`*^9, 3.6188417117726746`*^9}, {
   3.618841825949275*^9, 3.618841866805747*^9}, 3.6265863265848675`*^9, {
   3.6265863956305885`*^9, 3.6265864207466326`*^9}, 3.6265866093665643`*^9, 
   3.6265871237462673`*^9},ExpressionUUID->"19fe8eb3-4c59-47a0-b1a5-\
546ceadf50af"],

Cell[BoxData[
 RowBox[{"kg", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r", ">", "0"}], ",", 
      RowBox[{"ca", ">", "0"}], ",", 
      RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6265105621332836`*^9, 3.6265105864225264`*^9}, {
   3.626586445535076*^9, 3.6265864880919514`*^9}, 3.6265866220493865`*^9, 
   3.6265871373962917`*^9},ExpressionUUID->"a077aef6-1c9d-4111-bb5f-\
98099a0c502b"],

Cell["Only the great circles (ca=0) are geodesics.", "Text",
 CellChangeTimes->{{3.6142629436212454`*^9, 3.6142629704532924`*^9}, {
  3.6265866708306723`*^9, 
  3.626586679285887*^9}},ExpressionUUID->"238b9d2a-c8f0-433c-84c8-\
42a0bf7601a2"],

Cell[BoxData[
 RowBox[{"kn", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"normalcurvature", "[", 
      RowBox[{
       RowBox[{"sphero", "[", "r", "]"}], ",", "h1", ",", 
       RowBox[{"h2", "[", "ca", "]"}]}], "]"}], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "ca", "]"}], ">", "0"}], ",", 
      RowBox[{"r", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6143273297369137`*^9, 3.614327353778289*^9}, {
   3.614327390450386*^9, 3.614327420572109*^9}, {3.6144908890498276`*^9, 
   3.6144909391846952`*^9}, 3.6144917093297453`*^9, 3.6144918945373383`*^9, 
   3.614861863263146*^9, 3.6148631367245827`*^9, {3.626523220275897*^9, 
   3.626523241710335*^9}, {3.626586790155282*^9, 
   3.6265867980176954`*^9}},ExpressionUUID->"39401fc0-f8d0-4085-8436-\
6474fc02e774"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sx", "[", "t_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"sphero", "[", "r", "]"}], "[", 
    RowBox[{
     RowBox[{"h1", "[", "t", "]"}], ",", 
     RowBox[{
      RowBox[{"h2", "[", "ca", "]"}], "[", "t", "]"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"curvature", "[", "sx", "]"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.61449096601723*^9, 3.614491046232818*^9}, {
   3.6144910803047667`*^9, 3.614491184156707*^9}, {3.614491760169653*^9, 
   3.614491772410353*^9}, 3.6148618632787457`*^9, 3.6148631367245827`*^9, {
   3.6265868432889752`*^9, 
   3.6265868849566483`*^9}},ExpressionUUID->"b686148d-a454-4e0c-a0df-\
971b89d42172"],

Cell[BoxData[
 RowBox[{"kk", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t", ">", "0"}], ",", 
      RowBox[{"r", ">", "0"}], ",", 
      RowBox[{"ca", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6144912102411985`*^9, 3.6144912524796147`*^9}, {
   3.6144918028020916`*^9, 3.614491847393642*^9}, 
   3.6265869062350855`*^9},ExpressionUUID->"95744320-45a2-43e8-ae84-\
6429d7c545ad"],

Cell["Test of the curvature relation:", "Text",
 CellChangeTimes->{{3.6144922778622637`*^9, 
  3.614492295334263*^9}},ExpressionUUID->"4e30ef92-8af7-4d57-b528-\
61ee7fdc8457"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kk", "^", "2"}], "-", 
  RowBox[{"kn", "^", "2"}], "-", 
  RowBox[{"kg", "^", "2"}]}]], "Input",
 CellChangeTimes->{{3.6144912677174864`*^9, 
  3.6144912827293453`*^9}},ExpressionUUID->"73d7ff15-8abb-4284-b06c-\
bbc2de4d3500"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", "%", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", 
     RowBox[{"ca", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614492018684439*^9, 3.614492069089322*^9}, {
  3.6265870882406054`*^9, 
  3.6265870939814157`*^9}},ExpressionUUID->"182f5fc0-5225-42ac-bafd-\
e05cb6db9e71"],

Cell["\<\
If the expression is not correctly evaluated with result zero,may be, since \
the case ca = Pi/2 +k*Pi is not excluded, try the following:\
\>", "Text",
 CellChangeTimes->{{3.699329664730146*^9, 3.699329752714149*^9}, {
  3.699329788090063*^9, 3.699329870009511*^9}, {3.699329915785178*^9, 
  3.699329966696782*^9}, {3.699330467236306*^9, 3.699330468964198*^9}, {
  3.6993310063439293`*^9, 3.699331097383472*^9}, {3.699331130175343*^9, 
  3.699331166751213*^9}, {3.6993312936781063`*^9, 3.699331301701886*^9}, {
  3.708222210610046*^9, 3.708222239696854*^9}, {3.7082222736248407`*^9, 
  3.708222291368783*^9}, {3.7082223286633463`*^9, 
  3.7082224590705147`*^9}},ExpressionUUID->"53f85302-68f5-4ee4-939f-\
3e09300ff4b9"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox[
       RowBox[{"Abs", "[", 
        RowBox[{"Sec", "[", "ca", "]"}], "]"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"Abs", "[", 
        RowBox[{"Tan", "[", "ca", "]"}], "]"}], "2"]}], 
     SuperscriptBox["r", "2"]], "\[Equal]", "0"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", 
     RowBox[{"ca", ">", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}]}], ",", 
     RowBox[{"ca", "<", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614492018684439*^9, 3.614492069089322*^9}, {
   3.6265870882406054`*^9, 3.6265870939814157`*^9}, {3.699329017241991*^9, 
   3.6993290427441072`*^9}, 3.6993295114015913`*^9, {3.699330876061511*^9, 
   3.699330886450745*^9}, 
   3.708222773670622*^9},ExpressionUUID->"55b7acc3-2bfc-4c2d-a997-\
8e61d0df4397"],

Cell["\<\
Plot evaluates the terms numerically and shows the numerical deviation:\
\>", "Text",
 CellChangeTimes->{{3.6993313131582413`*^9, 3.699331329456418*^9}, {
  3.69933136354135*^9, 
  3.69933144578906*^9}},ExpressionUUID->"76995b3f-af11-4c11-ad8c-\
ef0ed61345f9"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox[
        RowBox[{"Abs", "[", 
         RowBox[{"Sec", "[", "ca", "]"}], "]"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"Abs", "[", 
         RowBox[{"Tan", "[", "ca", "]"}], "]"}], "2"]}], 
      SuperscriptBox["r", "2"]], "/.", 
     RowBox[{"r", "\[Rule]", "3"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"ca", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.699330517187504*^9, 3.699330519044437*^9}, {
  3.699330550748179*^9, 3.699330708131792*^9}, {3.699330780428801*^9, 
  3.699330798259281*^9}},ExpressionUUID->"02453e7c-f2ed-426d-a4d4-\
b0eb586081f0"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox[
       RowBox[{"Abs", "[", 
        RowBox[{"Sec", "[", "ca", "]"}], "]"}], "2"], "-", 
      SuperscriptBox[
       RowBox[{"Abs", "[", 
        RowBox[{"Tan", "[", "ca", "]"}], "]"}], "2"]}], 
     SuperscriptBox["r", "2"]], "/.", 
    RowBox[{"r", "\[Rule]", "3"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", ">", "0"}], ",", 
     RowBox[{"ca", ">", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}]}], ",", 
     RowBox[{"ca", "<", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.708219907489203*^9, 
  3.7082199092012377`*^9}},ExpressionUUID->"5b8b959c-aff4-4006-b641-\
53c05ccd8de0"],

Cell["With this we finally get the correct picture :", "Text",
 CellChangeTimes->{{3.699332065926176*^9, 
  3.699332136536975*^9}},ExpressionUUID->"35e2dbb3-d560-4e77-ba22-\
2fb3d1909d7d"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox[
          RowBox[{"Sec", "[", "ca", "]"}], "2"], "-", 
         SuperscriptBox[
          RowBox[{"Tan", "[", "ca", "]"}], "2"]}], 
        SuperscriptBox["r", "2"]], "/.", 
       RowBox[{"r", "\[Rule]", "3"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r", ">", "0"}], ",", 
        RowBox[{"ca", ">", 
         RowBox[{
          RowBox[{"-", "Pi"}], "/", "2"}]}], ",", 
        RowBox[{"ca", "<", 
         RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"ca", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.699330517187504*^9, 3.699330519044437*^9}, {
  3.699330550748179*^9, 3.699330708131792*^9}, {3.699330780428801*^9, 
  3.699330798259281*^9}, {3.699331825454479*^9, 3.6993318370536737`*^9}, {
  3.699331879244357*^9, 3.699331880867833*^9}, {3.708222565695722*^9, 
  3.708222588814535*^9}, {3.708222663855661*^9, 
  3.708222665133101*^9}},ExpressionUUID->"540bad36-d1e7-416a-a8da-\
967f3dfbad77"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3.3. General Curves on the Unit Sphere", "Subsubsection",
 CellChangeTimes->{{3.626426940389179*^9, 3.626426942729183*^9}, {
   3.626439206942724*^9, 3.626439247705596*^9}, {3.626535746538865*^9, 
   3.6265357780861206`*^9}, 3.699332229225624*^9, 3.699332798484262*^9, 
   3.7082228530609617`*^9, 
   3.708223136675*^9},ExpressionUUID->"a1eb682c-08e4-4e9d-ac59-a19d3ece7b52"],

Cell["The unit sphere", "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
  3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
  3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
  3.613631784777006*^9, 3.6136317936534214`*^9}, {3.6265874323304095`*^9, 
  3.62658743254881*^9}},ExpressionUUID->"4a495e45-6895-4842-ba76-\
0c1cee23ca07"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.6144904863257933`*^9, 
  3.6144904977664475`*^9}},ExpressionUUID->"42f12777-bf55-48ef-b4ac-\
8f3906d01b9a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", " ", "[", 
   RowBox[{"hu", ",", "hv", ",", "kk", ",", "kn", ",", "kg"}], "]"}], ";", 
  RowBox[{
   RowBox[{"sphercx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"sphero", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6262696713989577`*^9, 3.626269769583931*^9}, {
   3.62627057233515*^9, 3.626270580473765*^9}, {3.6262715010427923`*^9, 
   3.6262715449472694`*^9}, {3.62627487396774*^9, 3.626274910835605*^9}, 
   3.6263327382028837`*^9, {3.626427055844982*^9, 3.626427070197007*^9}, {
   3.6265233742325673`*^9, 
   3.6265233838889847`*^9}},ExpressionUUID->"e893f4f2-16dd-46ae-96e4-\
e523b8dfa6ae"],

Cell[BoxData[
 RowBox[{"sphercx", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6262705892741804`*^9, 
  3.626270596951394*^9}},ExpressionUUID->"059f1574-bc1e-4bc4-af80-\
65bd115df8f2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kk", "[", "s_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"curvature", "[", "sphercx", "]"}], "[", "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6265874900817113`*^9, 
  3.626587502592933*^9}},ExpressionUUID->"e15c7ed2-d8ec-4c83-9e1b-\
f36a4c2f1b14"],

Cell[BoxData[
 RowBox[{"kk", "[", "s", "]"}]], "Input",ExpressionUUID->"4b25a954-a8fd-4071-834f-bb56afa7e5ae"],

Cell["kn= ?", "Text",
 CellChangeTimes->{{3.6264283126767893`*^9, 
  3.6264283200244026`*^9}},ExpressionUUID->"db94ca1b-13a5-4b85-aec1-\
9b0906545229"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kn", "[", "s_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"normalcurvature", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
   "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6262697808793507`*^9, 3.626269850185673*^9}, {
   3.6262706253152437`*^9, 3.6262706316176553`*^9}, {3.626271402313818*^9, 
   3.6262714245634575`*^9}, {3.62627146016672*^9, 3.626271463349126*^9}, 
   3.6262715810029325`*^9, 3.626271640242237*^9, 3.626333487987001*^9, 
   3.626428299026766*^9, {3.6264342729636583`*^9, 3.626434282604475*^9}, 
   3.6265876197023387`*^9},ExpressionUUID->"a36ca80e-e9ec-41e4-ba15-\
5e35eaf7b988"],

Cell[BoxData[
 RowBox[{"kn", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6265876294055557`*^9, 
  3.6265876457231846`*^9}},ExpressionUUID->"4e378ec7-b38a-405e-992b-\
5379620dbf5b"],

Cell["kg = ?", "Text",
 CellChangeTimes->{{3.6264283602256727`*^9, 
  3.626428363844879*^9}},ExpressionUUID->"97313dde-5931-44f9-80b1-\
0aba9af2384c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kg", "[", "s_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"geodcurvature", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
   "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6262723065954123`*^9, 3.626272358893704*^9}, 
   3.626333502151826*^9, 3.6264283515676575`*^9, {3.626434335550968*^9, 
   3.6264343443025837`*^9}, {3.62658778540583*^9, 
   3.6265877896802373`*^9}},ExpressionUUID->"b6b50768-8a88-47b7-b0cf-\
47eeea7b9c4a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kg", "[", "s", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.6264191133335824`*^9, 3.626419169852482*^9}, 
   3.626428376168901*^9, 3.626434711745629*^9, {3.62643603896716*^9, 
   3.6264360445363703`*^9}, {3.626587803096261*^9, 
   3.626587812253477*^9}},ExpressionUUID->"75ab6b28-b964-4694-a40d-\
66925441bf94"],

Cell[BoxData[
 RowBox[{"\[Sqrt]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}]}], "-", 
               RowBox[{"2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], " ", 
             RowBox[{
              SuperscriptBox["hv", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "4"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "4"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "4"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "4"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["hu", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "s", "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"]}]}], 
              ")"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["hu", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}], "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}]}]}], ")"}]}], 
            ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}]}], 
               ")"}], 
              RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["hu", "\[Prime]",
                MultilineFunction->None], "[", "s", "]"}], "2"]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "4"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "4"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "4"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "4"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"hv", "[", "s", "]"}], "]"}]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["hv", "\[Prime]",
                MultilineFunction->None], "[", "s", "]"}], "2"]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "4"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "4"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "4"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hu", "[", "s", "]"}], "]"}], "4"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", 
                    RowBox[{Cell["kn= ?", "Text",
                    
                    CellChangeTimes->{{3.6264283126767893`*^9, 
                    3.6264283200244026`*^9}},ExpressionUUID->
                    "28536e6a-92e2-4ca5-945d-5d1e48e30527"], "[", "s", 
                    "]"}]}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["hv", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "s", "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"h", Cell["kn= ?", "Text",
                    
                    CellChangeTimes->{{3.6264283126767893`*^9, 
                    3.6264283200244026`*^9}},ExpressionUUID->
                    "287800fa-d183-4ec9-ac3d-9544defedd0d"], 
                    RowBox[{"u", "[", "s", "]"}]}], "]"}], "2"]}]}], ")"}], 
                " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"]}]}], 
              ")"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["hv", "\[Prime]",
               MultilineFunction->None], "[", "s", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hu", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}], "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["hv", "\[Prime]",
                   MultilineFunction->None], "[", "s", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hu", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["hv", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "s", "]"}]}]}], ")"}]}], 
            ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hu", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["hv", "\[Prime]",
                    MultilineFunction->None], "[", "s", "]"}], "2"]}]}], 
               ")"}], 
              RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}], "2"]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"hu", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["hu", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"hv", "[", "s", "]"}], "]"}], "2"], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"hu", "[", "s", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"hv", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["hv", "\[Prime]",
          MultilineFunction->None], "[", "s", "]"}], "2"]}]}], ")"}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.699332399199551*^9, 
  3.699332399462373*^9}},ExpressionUUID->"f8aebddc-cef9-46f7-bf87-\
d67e46f5f05c"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Together", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"kk", "[", "s", "]"}], "^", "2"}], " ", "-", 
      RowBox[{
       RowBox[{"kn", "[", "s", "]"}], "^", "2"}], "-", 
      RowBox[{
       RowBox[{"kg", "[", "s", "]"}], "^", "2"}]}], "]"}], ",", 
    RowBox[{"s", ">", "0"}], ",", 
    RowBox[{"TimeConstraint", "\[Rule]", "Infinity"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6262723763989353`*^9, 3.6262724099117937`*^9}, {
  3.6262750511094522`*^9, 3.6262750574430637`*^9}, {3.6264192519866257`*^9, 
  3.6264192857918854`*^9}, {3.626436118028099*^9, 3.6264361445637455`*^9}, {
  3.6993324538013983`*^9, 
  3.699332498846676*^9}},ExpressionUUID->"d6d1e5dc-1956-40d0-a8ab-\
270f82f8bb18"],

Cell["\<\
Mathematica v. 9.0.1.0 needed 32.876 s  to get the result zero. OK.\
\>", "Text",
 CellChangeTimes->{{3.6264393374525537`*^9, 3.626439341508561*^9}, {
  3.699332684428637*^9, 3.699332769675745*^9}, {3.7082229805467997`*^9, 
  3.708223079250457*^9}},ExpressionUUID->"1cbe7edd-daee-40d8-9940-\
4f24a36e6486"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3.4. The Loxodromes", "Subsubsection",
 CellChangeTimes->{{3.6266047968208046`*^9, 3.6266047984900074`*^9}, 
   3.62677957012638*^9, {3.6267796293128843`*^9, 3.6267796330412908`*^9}, {
   3.626939234093667*^9, 3.626939236667671*^9}, 3.627111569371826*^9, 
   3.6993328088524847`*^9, 3.6994282487297583`*^9, 3.708223142986609*^9, 
   3.708233965354608*^9},ExpressionUUID->"728bbabc-be32-4589-adda-\
a2c789b5f29b"],

Cell["\<\
Loxodromes are curves on a sphere cutting the meridians under a constant \
angle. We considered them already in Example 3, Subsection 2.1.4:\
\>", "Text",
 CellChangeTimes->{{3.6266997272444143`*^9, 3.62669980431555*^9}, {
  3.6268546917543693`*^9, 3.626854707590397*^9}, {3.6993357376681633`*^9, 
  3.699335741483863*^9}, {3.6993358077074003`*^9, 
  3.699335888802785*^9}},ExpressionUUID->"1765dee9-9a47-4ea4-a6c7-\
a1b61d3965f5"],

Cell[BoxData[
 RowBox[{"?", "sphlox"}]], "Input",
 CellChangeTimes->{{3.699335893593198*^9, 
  3.699335893595688*^9}},ExpressionUUID->"e0127da4-1216-4f04-add0-\
ffbd14f7fe21"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphlox", "[", "a", "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.6993360241390867`*^9, 
  3.699336046425461*^9}},ExpressionUUID->"69fd7302-2c58-4b1d-9e03-\
a929ec0b1e67"],

Cell[BoxData[
 RowBox[{"lox1", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sphlox", "[", ".2", "]"}], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "70"}], ",", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7082237076992693`*^9, 3.7082237473857307`*^9}, 
   3.708223782232246*^9, {3.7082254638339*^9, 3.708225575725191*^9}, {
   3.708226034095333*^9, 
   3.708226038005004*^9}},ExpressionUUID->"6cdf1d4e-e295-456b-abe5-\
1f3801d4a11f"],

Cell["We plot a family of meridians", "Text",
 CellChangeTimes->{{3.708225862273411*^9, 
  3.708225921633095*^9}},ExpressionUUID->"3b523120-e1b7-4102-8664-\
54f75497e091"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"ParametricPlot3D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"sphero", "[", "1", "]"}], "[", 
       RowBox[{
        RowBox[{"2", "*", "Pi", "*", "n"}], ",", "u"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", 
        RowBox[{
         RowBox[{"-", "Pi"}], "/", "2"}], ",", 
        RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "1", ",", ".1"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.699415174130389*^9, 3.6994153227081127`*^9}, 
   3.69941536741171*^9, {3.699415411091386*^9, 3.699415426499425*^9}, {
   3.699415476155147*^9, 3.699415498066187*^9}, 3.6994155328696337`*^9, {
   3.699415564114382*^9, 3.699415588041707*^9}, {3.699415674991067*^9, 
   3.6994156874811277`*^9}, 
   3.708225676544571*^9},ExpressionUUID->"eb575821-e987-44c8-82b4-\
8676fa494f41"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
   RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.699415612396345*^9, 3.699415633824955*^9}, {
   3.699415735180443*^9, 3.699415755895637*^9}, {3.699420512830411*^9, 
   3.6994205356820374`*^9}, 
   3.69942057096675*^9},ExpressionUUID->"3713c19c-338c-490b-8d7b-\
b6134ebcda0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"meries", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.699420590867655*^9, 
  3.6994206001849747`*^9}},ExpressionUUID->"96cc8638-c1ce-4981-a006-\
edaef330b695"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", "meries", ",", "lox1"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
   RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.708225968843932*^9, 3.708225990394608*^9}, {
  3.7082260513158007`*^9, 
  3.708226085355254*^9}},ExpressionUUID->"55ac4805-6bd0-410f-a25a-\
007494fd99cc"],

Cell["\<\
We need another parameter representation of the loxodromes in the form\
\>", "Text",
 CellChangeTimes->{{3.6993366220684423`*^9, 3.699336680803823*^9}, 
   3.708226128895694*^9},ExpressionUUID->"df4cfd23-5db8-45d4-8c63-\
6e0ee5734541"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"\[Gamma]1", ",", "\[Gamma]2", ",", "hu", ",", "hv"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.699333516095112*^9, 3.699333519783043*^9}, {
  3.6993335586249027`*^9, 
  3.699333638606372*^9}},ExpressionUUID->"4d5be253-bc23-4fce-afc3-\
a7f359eaa7af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Gamma]", "[", "s_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hu", "[", "s", "]"}], ",", 
    RowBox[{"hv", "[", "s", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6993336613341503`*^9, 3.699333744405616*^9}, 
   3.699334299247128*^9},ExpressionUUID->"946ad788-ba33-487b-a339-\
ce6552627d9b"],

Cell["adapted to the parameter representation of the unit sphere", "Text",
 CellChangeTimes->{{3.69933669765182*^9, 
  3.69933674388338*^9}},ExpressionUUID->"7588c52a-fbc4-4bb8-ad76-\
9802c2185b57"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphero", "[", "1", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.699335980954763*^9, 
  3.6993360130416393`*^9}},ExpressionUUID->"4ae48c2f-381b-4f89-878e-\
52f64a7d2a24"],

Cell["The tangent unit vectors of the Meridians are ", "Text",
 CellChangeTimes->{{3.699415867685679*^9, 
  3.699415916533269*^9}},ExpressionUUID->"1282d9bf-d791-4bd3-9b06-\
854f7cc5a839"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tvm", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"amf", "[", "2", "]"}], "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", ">=", "0"}], ",", 
      RowBox[{"u", "<", 
       RowBox[{"2", "*", "Pi"}]}], ",", 
      RowBox[{"v", ">", 
       RowBox[{
        RowBox[{"-", "Pi"}], "/", "2"}]}], ",", 
      RowBox[{"v", "<", 
       RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6994159203129063`*^9, 3.699415924727631*^9}, {
  3.699416019325427*^9, 3.69941603562122*^9}, {3.699416083028693*^9, 
  3.6994160878365297`*^9}, {3.6994161893934097`*^9, 3.6994162063629827`*^9}, {
  3.6994162612109957`*^9, 3.6994162727788973`*^9}, {3.699416303371069*^9, 
  3.6994163829784517`*^9}},ExpressionUUID->"4d633deb-7134-4aa9-9e3f-\
84883cfa7e4c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tvm", "[", 
   RowBox[{"u", ",", "v"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.7082266803462048`*^9, 
  3.7082267385426903`*^9}},ExpressionUUID->"28e5f663-8f1e-437a-8e24-\
878f52df32d8"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"tvm", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ".", 
   RowBox[{"tvm", "[", 
    RowBox[{"u", ",", "v"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.699416423429072*^9, 
  3.699416515401327*^9}},ExpressionUUID->"3b581084-bc97-483c-8e0d-\
b19bf19fab92"],

Cell["Let", "Text",
 CellChangeTimes->{{3.699416540898963*^9, 
  3.699416553499112*^9}},ExpressionUUID->"1ab51a2d-79df-4232-8fde-\
4e08ba7be82c"],

Cell[BoxData[
 RowBox[{"\[Gamma]", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6995313984929256`*^9, 
  3.699531400820507*^9}},ExpressionUUID->"14922d87-99d3-42bb-b814-\
3c226dbb0866"],

Cell["\<\
be a curve in the parameter manifold such that s is the arc length of the \
curve\
\>", "Text",
 CellChangeTimes->{{3.699416687926239*^9, 
  3.699416766838882*^9}},ExpressionUUID->"aa61a681-3549-457a-a6b8-\
1e173ec703f7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphcu", "[", "s_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"sphero", "[", "1", "]"}], "[", 
   RowBox[{
    RowBox[{"hu", "[", "s", "]"}], ",", 
    RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6994167917115707`*^9, 
  3.699416843639201*^9}},ExpressionUUID->"8804eddc-b863-4b9a-9cce-\
4a8687e52917"],

Cell["on the unit sphere, that means", "Text",
 CellChangeTimes->{{3.6994168973977633`*^9, 3.699416902213726*^9}, {
  3.699417102860132*^9, 
  3.6994171215398493`*^9}},ExpressionUUID->"e4e98450-ebc0-4958-a05a-\
602e6ca29438"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "]"}], "\[Equal]", 
  " ", "1"}]], "Input",
 CellChangeTimes->{{3.6994169155229063`*^9, 3.6994169859663067`*^9}, {
  3.699417132255857*^9, 3.699417143572548*^9}, {3.699417176405025*^9, 
  3.699417215140048*^9}},ExpressionUUID->"ec0e414e-dda6-4e77-9b75-\
16f42eb986c7"],

Cell["\<\
The cosinus of the angle \[Alpha] between the tangent vectors of the curve \
and the meridian at their intersection point is\
\>", "Text",
 CellChangeTimes->{{3.699417272988062*^9, 3.699417323106166*^9}, {
  3.699417353474759*^9, 
  3.69941746350565*^9}},ExpressionUUID->"7183a71f-1295-4f94-98d0-\
3679f5ad1c87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c\[Alpha]", "[", "s_", "]"}], ":=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fund1", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.699417485201251*^9, 3.699417489737955*^9}, {
  3.699417529665695*^9, 3.6994176579127502`*^9}, {3.6994177030324917`*^9, 
  3.699417761913754*^9}},ExpressionUUID->"64012078-6edd-4f90-93d7-\
3becfd85c87e"],

Cell[BoxData[
 RowBox[{"c\[Alpha]", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.699417767826305*^9, 
  3.699417789138493*^9}},ExpressionUUID->"f221341f-c4e8-4ef5-a1a2-\
cd5fe99a9d7f"],

Cell["\<\
Thus the condition \[Alpha] = constant leads to \
c\[Alpha]\[CloseCurlyQuote][s] =h\[CloseCurlyQuote]\[CloseCurlyQuote][s]==0 \
with the solution \
\>", "Text",
 CellChangeTimes->{{3.699417898718494*^9, 3.6994180396940117`*^9}, 
   3.6994259487509212`*^9},ExpressionUUID->"29f1d9f4-733d-4427-854d-\
60b16a7c5594"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hv", "[", "s_", "]"}], "=", " ", 
  RowBox[{"a", "*", "s"}]}]], "Input",
 CellChangeTimes->{{3.69941612561195*^9, 3.69941617803585*^9}, {
  3.699418053335136*^9, 
  3.69941806519049*^9}},ExpressionUUID->"27a3970e-03da-4f19-ba0a-\
47332907678d"],

Cell["with", "Text",
 CellChangeTimes->{{3.699418119916782*^9, 
  3.69941812406884*^9}},ExpressionUUID->"4dc26fb6-5646-43f3-9592-\
4e0275ac0a21"],

Cell["a = Cos[\[Alpha]] = constant, -1<a<1.", "Text",
 CellChangeTimes->{{3.699418410395803*^9, 
  3.699418437866313*^9}},ExpressionUUID->"26b4accb-6f28-41b4-948d-\
8f23a940f344"],

Cell["\<\
The cases a =\[PlusMinus] 1 can be excluded, since the curve then coincides \
with the meridian. The arc length condition (*) gives the differential \
equation for hu[s]\
\>", "Text",
 CellChangeTimes->{{3.699418503249517*^9, 3.6994186017610826`*^9}, {
   3.699418781623502*^9, 3.6994188498548727`*^9}, 
   3.708224524404554*^9},ExpressionUUID->"742c41f9-42cf-45a3-ac30-\
1be66009e5ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "'"}], "[", "s", "]"}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"\[PlusMinus]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"1", "-", 
      RowBox[{"a", "^", "2"}]}], "]"}]}], "/", 
   RowBox[{"Cos", "[", 
    RowBox[{"a", "*", "s"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.699419078955933*^9, 3.6994190912609873`*^9}, {
   3.699419127173024*^9, 3.699419160756428*^9}, {3.699419223404067*^9, 
   3.699419298675387*^9}, 
   3.6994194775059958`*^9},ExpressionUUID->"aece0644-771d-4e59-91de-\
cbab9739a0df"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["hu", "\[Prime]",
    MultilineFunction->None], "[", "s", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"\[PlusMinus]", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["a", "2"]}]]}], " ", 
   RowBox[{"Sec", "[", 
    RowBox[{"a", " ", "s"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7083218538845167`*^9},ExpressionUUID->"94c01e25-f129-42f8-ab4e-\
057146611cb2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"h", "'"}], "[", "s", "]"}], "\[Equal]", " ", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{"a", "^", "2"}]}], "]"}], "/", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", "*", "s"}], "]"}]}]}], ",", 
   RowBox[{"h", "[", "s", "]"}], ",", "s"}], "]"}]], "Input",
 CellChangeTimes->{{3.6994193573140087`*^9, 3.6994194132344418`*^9}, 
   3.699419464759734*^9, {3.699531562915766*^9, 
   3.699531571419874*^9}},ExpressionUUID->"d248d931-4a4e-4197-ad9c-\
0d93fe767ddd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hu", "[", "s_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"h", "[", "s", "]"}], "/.", 
    RowBox[{"Flatten", "[", "%", "]"}]}], "/.", 
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "\[Rule]", " ", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.6994251230736313`*^9, 3.699425335000618*^9}, 
   3.699425439549827*^9, {3.699531595283712*^9, 
   3.699531604125063*^9}},ExpressionUUID->"5a210b5d-32c4-46a5-87e3-\
22e9639b5123"],

Cell["\<\
We choose the integration constant C[1] =0 such that the solution is \
\[PlusMinus]hu[s]. Since the arguments s with a*s = (2m+1)Pi/2 are \
singularities of this parameter representation:\
\>", "Text",
 CellChangeTimes->{{3.699419648791503*^9, 3.6994197930386963`*^9}, {
   3.6994198355181932`*^9, 3.69941984384603*^9}, 3.6994245124317923`*^9, {
   3.699424624452697*^9, 3.6994246490731153`*^9}, {3.6994256547355547`*^9, 
   3.699425675167594*^9}, 3.6995316710258493`*^9, {3.708232049457526*^9, 
   3.708232119777135*^9}, {3.708232371775094*^9, 3.7082324592210903`*^9}, 
   3.708232496421175*^9},ExpressionUUID->"3aa90077-a5a4-4db6-9a96-\
3545e6f0d038"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hu", "'"}], "[", 
  RowBox[{"Pi", "/", 
   RowBox[{"(", 
    RowBox[{"2", "*", "a"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7082325026070347`*^9, 
  3.708232530320223*^9}},ExpressionUUID->"874a9095-22ad-47c8-86ee-\
410f2b65068c"],

Cell["\<\
we restrict the parameter to the open interval {-Pi/(2*a),Pi/(2*a)}; this \
yields the whole curve:\
\>", "Text",
 CellChangeTimes->{{3.708232588180625*^9, 3.708232694084676*^9}, {
  3.7082328723953037`*^9, 
  3.708232889013091*^9}},ExpressionUUID->"574dfb19-346b-468e-bcc3-\
e0fb87483b65"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "/.", 
    RowBox[{"a", "\[Rule]", ".2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", 
      RowBox[{"(", 
       RowBox[{".2", "*", "2"}], ")"}]}], ",", 
     RowBox[{"Pi", "/", 
      RowBox[{"(", 
       RowBox[{".2", "*", "2"}], ")"}]}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.699420141508585*^9, 3.699420360875442*^9}, 
   3.699425699677376*^9, 3.6994259549402533`*^9, 3.69942630725428*^9, 
   3.699426346024317*^9, {3.699426392774208*^9, 3.6994264028935347`*^9}, {
   3.6994264628260403`*^9, 3.6994264739816103`*^9}, {3.6994265174016657`*^9, 
   3.699426590988991*^9}, {3.699531678147039*^9, 3.699531695419235*^9}, {
   3.708231703835012*^9, 
   3.708231804306959*^9}},ExpressionUUID->"3d4d2f77-1859-4874-aec3-\
55cf5117fb57"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lox", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.699420389127675*^9, 
  3.699420393930417*^9}},ExpressionUUID->"3ebb2b06-8562-4c0c-9635-\
7379dfe82e09"],

Cell["Thus the length of the loxodrome with parameter a is Pi/a.", "Text",
 CellChangeTimes->{{3.7082327551230593`*^9, 3.7082327831313553`*^9}, {
   3.708232823307785*^9, 3.708232828826612*^9}, 
   3.708232967778204*^9},ExpressionUUID->"3a3074dc-6249-4f8f-a579-\
196996ef6ec4"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", "lox", ",", "meries"}], "}"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", " ", 
   RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6994203980188417`*^9, 3.699420476778576*^9}, {
  3.699420614357456*^9, 
  3.699420617441121*^9}},ExpressionUUID->"8d2e4add-988b-4eb0-a16a-\
8c26d1d8d373"],

Cell["We control the angle", "Text",
 CellChangeTimes->{{3.708227168183728*^9, 
  3.708227179711481*^9}},ExpressionUUID->"a2547464-8808-4c15-b41b-\
b39c592e5557"],

Cell[BoxData[
 RowBox[{"\[Gamma]", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.699420685221629*^9, 3.699420785799844*^9}, 
   3.6994257662212963`*^9, {3.6995317446185007`*^9, 
   3.699531774217731*^9}},ExpressionUUID->"e7d9a880-7687-4220-bd1d-\
872d817a5748"],

Cell[BoxData[
 RowBox[{"??", "angle"}]], "Input",
 CellChangeTimes->{{3.6993383139415092`*^9, 
  3.699338317783091*^9}},ExpressionUUID->"77c3340a-63bf-43fd-bf93-\
ae16f74c26db"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"angle", "[", 
      RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
     RowBox[{
      RowBox[{"hu", "[", "s", "]"}], ",", 
      RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{
      RowBox[{"\[Gamma]", "'"}], "[", "s", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"a", "<", "1"}], ",", 
     RowBox[{
      RowBox[{"a", "*", "s"}], ">", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"a", "*", "s"}], "<", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6993383977548*^9, 3.6993385892690887`*^9}, 
   3.699338630684989*^9, {3.699420813543952*^9, 3.6994209093371277`*^9}, {
   3.6994209436392393`*^9, 3.699421026230297*^9}, {3.699425788874248*^9, 
   3.69942580406446*^9}, {3.699426781218137*^9, 3.699426799355541*^9}, {
   3.6995317998504467`*^9, 3.6995318609857683`*^9}, {3.708233012115038*^9, 
   3.708233062083*^9}, 
   3.70823312919306*^9},ExpressionUUID->"4e053b9e-dce3-43fe-8324-\
a958bc044ba7"],

Cell["\<\
Since a=Cos[\[Alpha]] the constant intersection angle of the loxodrome is \
\[Alpha]. We control yet the arc length condition:\
\>", "Text",
 CellChangeTimes->{{3.6994260427262707`*^9, 3.699426129085979*^9}, {
  3.699532008183082*^9, 
  3.699532031006777*^9}},ExpressionUUID->"a5e3e1db-2e20-493d-aa8e-\
56a655cacb3e"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fund1", "[", 
     RowBox[{"sphero", "[", "1", "]"}], "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"hu", "'"}], "[", "s", "]"}], ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"hu", "'"}], "[", "s", "]"}], ",", "a"}], "}"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6994232364523478`*^9, 3.699423237257142*^9}, {
   3.699423318282177*^9, 3.69942339222869*^9}, {3.6994234668369904`*^9, 
   3.6994234866242743`*^9}, {3.699423946658764*^9, 3.6994239964800367`*^9}, {
   3.699424042956728*^9, 3.699424062928636*^9}, {3.699425838973379*^9, 
   3.699425860303405*^9}, {3.69942597738342*^9, 3.6994259924955606`*^9}, 
   3.699531905497527*^9, {3.699531957370576*^9, 
   3.6995319835608063`*^9}},ExpressionUUID->"86ba55de-d725-408f-ab22-\
cacebf0b82f9"],

Cell["For a = 0, \[Alpha] = Pi/2, we have", "Text",
 CellChangeTimes->{{3.699427342694419*^9, 
  3.699427411920678*^9}},ExpressionUUID->"1410afea-38bb-41b1-865b-\
8530e7df2e65"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hu", "[", "s", "]"}], "/.", 
  RowBox[{"a", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.699427421218584*^9, 3.699427434703762*^9}, 
   3.6995320431036*^9},ExpressionUUID->"308cd7ad-b816-45e1-aac6-27525ee663b8"],

Cell["Consider", "Text",
 CellChangeTimes->{{3.699427447316733*^9, 
  3.699427469976281*^9}},ExpressionUUID->"f88eff6d-a8af-4955-9638-\
34ede4494f50"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"hu", "[", "s", "]"}], ",", 
   RowBox[{"a", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6994268887514668`*^9, 3.6994269074349318`*^9}, 
   3.699426939277761*^9, 
   3.6995320610154*^9},ExpressionUUID->"07c53f48-2d51-4664-9f71-292935a670b3"],

Cell["\<\
Thus choosing hv[s] = 0*s+c, c the integration constant, we obtain of course \
the circles of latitude, e.g.\
\>", "Text",
 CellChangeTimes->{{3.699427486538052*^9, 
  3.699427603005866*^9}},ExpressionUUID->"59839482-8a63-4c60-9ed0-\
525f750e4953"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sphero", "[", "1", "]"}], "[", 
    RowBox[{"s", ",", ".5"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", "*", 
      RowBox[{"Pi", "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"(", ".3", ")"}], "^", "2"}]}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6994269751571836`*^9, 3.69942722318501*^9}, 
   3.699427627520563*^9, {3.699427668854271*^9, 3.6994277010622997`*^9}, {
   3.6994278076107616`*^9, 3.699427847880772*^9}, 3.699427894682016*^9, 
   3.6994279350655622`*^9, 
   3.699428007338016*^9},ExpressionUUID->"062999d7-443a-461a-baf0-\
3a5e4e3b1c85"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lc", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6994277134291277`*^9, 
  3.6994277229982243`*^9}},ExpressionUUID->"cb9c406e-c512-4114-9922-\
1288b002515d"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sph1", ",", "lox", ",", "meries", ",", "lc"}], "}"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", " ", 
   RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6994203980188417`*^9, 3.699420476778576*^9}, {
  3.699420614357456*^9, 3.699420617441121*^9}, {3.699427763870892*^9, 
  3.699427767517063*^9}},ExpressionUUID->"ceb5cedc-7210-4cb4-a476-\
4fcfa792d8e2"],

Cell["\<\
Now we will calculate the curvatures of the loxodromes and control the \
curvature relation. We consider the parameter representation for \
-Pi/2a<s<Pi/2a\
\>", "Text",
 CellChangeTimes->{{3.699532309116661*^9, 3.699532316236129*^9}, {
  3.699532508730687*^9, 3.699532805384907*^9}, {3.7082316092373657`*^9, 
  3.708231628637541*^9}, {3.708233240417266*^9, 
  3.708233283848003*^9}},ExpressionUUID->"a3bed3af-d582-4de5-ac06-\
f6a3d64b8576"],

Cell[BoxData[
 RowBox[{"sphcu", "[", "s", "]"}]], "Input",
 CellChangeTimes->{
  3.6994357523118677`*^9},ExpressionUUID->"73b0874f-bd7d-470d-b013-\
acf61c665f67"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"sphcu", "[", "s", "]"}], ",", "s"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.699435811291584*^9, 3.699435837103486*^9}, 
   3.6995330977745647`*^9},ExpressionUUID->"dce4a478-a913-4ac2-9d90-\
69ccd68ed23e"],

Cell["Control of the arc length:", "Text",
 CellChangeTimes->{{3.699533318887073*^9, 
  3.6995333364150763`*^9}},ExpressionUUID->"8c60d680-3606-49a7-8d37-\
fe31b1c394e8"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ".", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.699435846206306*^9, 
  3.699435862031198*^9}},ExpressionUUID->"8c070495-d3c5-43ae-b394-\
86a89c115e04"],

Cell["The curvature vector is", "Text",
 CellChangeTimes->{{3.6995333531845493`*^9, 3.6995334031289988`*^9}, {
  3.699533435422276*^9, 
  3.699533446398106*^9}},ExpressionUUID->"a32b6660-52a3-4234-9335-\
a37af7c05982"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"sphcu", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.699533514790701*^9, 
  3.699533525718445*^9}},ExpressionUUID->"a77af5d3-9ae8-429f-bb79-\
c29d69625d9b"],

Cell["The curvature of this curve is", "Text",
 CellChangeTimes->{{3.699533580509111*^9, 
  3.6995336021890917`*^9}},ExpressionUUID->"b67b384c-530a-4e45-ba64-\
f1994d304a05"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"kk", "[", "s_", "]"}], "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"%", ".", "%"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.699435924234828*^9, 3.699435951006208*^9}, {
   3.6994366037315273`*^9, 3.6994367179611187`*^9}, 3.6994408043923683`*^9, {
   3.699440841048903*^9, 3.699440872947851*^9}, {3.6994409069880753`*^9, 
   3.699440909493045*^9}, {3.699443829546797*^9, 3.699443890391485*^9}, {
   3.699443941439701*^9, 3.699443956120407*^9}, {3.699444010231062*^9, 
   3.6994440497910357`*^9}, {3.6994441083636417`*^9, 3.699444142446604*^9}, 
   3.6994441892087097`*^9},ExpressionUUID->"a7d370ef-a692-47a8-84ee-\
f7ce97a42e59"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"kk", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"a", "<", "1"}], ",", 
     RowBox[{
      RowBox[{"a", "*", "s"}], ">", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"a", "*", "s"}], "<", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7082333369114733`*^9, 
  3.7082333747329483`*^9}},ExpressionUUID->"153e612c-d9fb-4301-aaa0-\
119288e4084d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "kk", "]"}], ";", 
  RowBox[{
   RowBox[{"kk", "[", "s_", "]"}], " ", "=", " ", "%"}]}]], "Input",
 CellChangeTimes->{{3.7082334020138474`*^9, 
  3.7082334303611593`*^9}},ExpressionUUID->"e90c86c2-63c9-44ac-af96-\
0102911ddbc2"],

Cell["Now we calculate the", "Text",
 CellChangeTimes->{{3.699533710508225*^9, 
  3.699533721587919*^9}},ExpressionUUID->"8221d06e-bf27-4d04-b190-\
807775585a40"],

Cell[BoxData[
 RowBox[{"?", "normalcurvature"}]], "Input",
 CellChangeTimes->{{3.6994445024547157`*^9, 3.699444503859881*^9}, {
  3.6994446170076723`*^9, 3.6994446638186502`*^9}, {3.699533729245278*^9, 
  3.6995337321569347`*^9}},ExpressionUUID->"4b601b56-4f79-4a58-a7a4-\
3e49e10c400e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kn", "[", "s_", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"normalcurvature", "[", 
      RowBox[{
       RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
     "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", ">", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"a", "<", "1"}], ",", 
      RowBox[{
       RowBox[{"a", "*", "s"}], ">", 
       RowBox[{
        RowBox[{"-", "Pi"}], "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{"a", "*", "s"}], "<", 
       RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6994442355193768`*^9, 3.699444262789493*^9}, {
   3.699444298049769*^9, 3.699444328596537*^9}, {3.699444373948823*^9, 
   3.699444410092123*^9}, 3.6994445325983267`*^9, {3.69944457821596*^9, 
   3.699444599611006*^9}, {3.699533781636395*^9, 3.699533789380598*^9}, {
   3.6995338761754*^9, 3.699533909979561*^9}, {3.699534121878138*^9, 
   3.699534142794394*^9}, 3.7082278351606607`*^9, {3.7082279529039*^9, 
   3.708228025589039*^9}, {3.708228269371873*^9, 3.708228282115625*^9}, {
   3.7082285814429207`*^9, 3.708228591209379*^9}, 3.708228698480917*^9, {
   3.7082334647922707`*^9, 
   3.7082334816200647`*^9}},ExpressionUUID->"570f3869-3a67-42bb-8134-\
f88db4f66efb"],

Cell["The normal curvature of this curve are the constant -1. ", "Text",
 CellChangeTimes->{{3.6995343572552013`*^9, 3.69953440077512*^9}, {
  3.708229835849547*^9, 3.708229835853238*^9}, {3.708229873746893*^9, 
  3.70822990605836*^9}, {3.708229966146864*^9, 3.7082299868584747`*^9}, {
  3.708230143768004*^9, 3.708230197055477*^9}, {3.708230710043558*^9, 
  3.708230719841303*^9}, {3.7082307616588287`*^9, 3.708230829211451*^9}, {
  3.7082335104871597`*^9, 
  3.708233536358305*^9}},ExpressionUUID->"18931b9d-f893-49ec-930c-\
0ab59fefd9f1"],

Cell[" We calculate now the geodesic curvature", "Text",
 CellChangeTimes->{{3.6995343572552013`*^9, 3.69953440077512*^9}, {
  3.708229835849547*^9, 3.708229835853238*^9}, {3.708229873746893*^9, 
  3.70822990605836*^9}, {3.708229966146864*^9, 3.7082299868584747`*^9}, {
  3.708230143768004*^9, 3.708230197055477*^9}, {3.708230710043558*^9, 
  3.708230719841303*^9}, {3.708230922691455*^9, 
  3.708230943978047*^9}},ExpressionUUID->"18931b9d-f893-49ec-930c-\
0ab59fefd9f1"],

Cell[BoxData[
 RowBox[{"?", "geodcurvature"}]], "Input",
 CellChangeTimes->{{3.699534407776637*^9, 
  3.699534416158915*^9}},ExpressionUUID->"2766ff10-d5be-4032-8847-\
a0dd70275fab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "kg", "]"}], ";", 
  RowBox[{
   RowBox[{"kg", "[", "s_", "]"}], ":=", 
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{
      RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
    "s", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6994442355193768`*^9, 3.699444262789493*^9}, {
   3.699444298049769*^9, 3.699444328596537*^9}, {3.699444373948823*^9, 
   3.699444410092123*^9}, 3.6994445325983267`*^9, {3.69944457821596*^9, 
   3.699444599611006*^9}, {3.699444723985051*^9, 3.6994447501927557`*^9}, {
   3.699534434247342*^9, 3.699534483039568*^9}, {3.699535876626109*^9, 
   3.699535887339664*^9}, {3.708230957438863*^9, 
   3.708231031013938*^9}},ExpressionUUID->"cc2d9a55-5ece-41d9-962e-\
af0196a41edd"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"kg", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"a", "<", "1"}], ",", 
     RowBox[{
      RowBox[{"a", "*", "s"}], ">", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"a", "*", "s"}], "<", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.708231076826033*^9, 3.708231163572486*^9}, 
   3.708233745659534*^9},ExpressionUUID->"f6b9edc5-d121-40ca-a53b-\
527ea79339d1"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "^", "2"}], "+", 
    RowBox[{
     RowBox[{"kn", "[", "s", "]"}], "^", "2"}], "-", 
    RowBox[{
     RowBox[{"kk", "[", "s", "]"}], "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "*", "s"}], ">", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"a", "*", "s"}], "<", 
      RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.708231076826033*^9, 3.708231163572486*^9}, {
  3.708231313182789*^9, 
  3.7082313822982597`*^9}},ExpressionUUID->"60df40d6-4943-4d22-93b5-\
b3018d977090"],

Cell["OK. This confirms the curvature relation.", "Text",
 CellChangeTimes->{{3.6267861581271515`*^9, 3.626786161387557*^9}, {
  3.6994261367339773`*^9, 3.699426137797881*^9}, {3.69953608423295*^9, 
  3.699536134616564*^9}},ExpressionUUID->"940b4526-1b5a-41e4-8934-\
e44b1ac46f1a"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "kk", ",", "kn", ",", "kg", ",", "hv", ",", "lox", ",", "lox1", ",", 
   "meries", ",", "lc", ",", "\[Gamma]"}], "]"}]], "Input",
 CellChangeTimes->{{3.699428088661838*^9, 3.699428185867304*^9}, {
  3.699536162705392*^9, 3.6995362074736137`*^9}, {3.7082339328792048`*^9, 
  3.70823393585249*^9}},ExpressionUUID->"ee6d3898-3d51-470e-8360-\
d321c8397cc7"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3.5. Another Curve on the Sphere", "Subsubsection",
 CellChangeTimes->{{3.626276300785455*^9, 3.6262763024390583`*^9}, {
   3.626437663195213*^9, 3.626437681915246*^9}, {3.6265357876021376`*^9, 
   3.626535792438146*^9}, 3.626780364932176*^9, {3.6271128923477497`*^9, 
   3.627112907978977*^9}, 3.699428254066945*^9, 3.699594065815956*^9, 
   3.708233973027063*^9, 
   3.708234356727427*^9},ExpressionUUID->"37128b40-c76e-4389-b169-\
e8469067489d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", " ", "[", 
   RowBox[{"hu", ",", "hv", ",", "kk", ",", "kg", ",", "kn"}], "]"}], ";", 
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], " ", "=", " ", "s"}], ";", " ", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], " ", "=", " ", 
   RowBox[{"Cos", "[", "s", "]"}]}], ";", 
  RowBox[{
   RowBox[{"sphercx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"sphero", "[", "1", "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6262696713989577`*^9, 3.626269769583931*^9}, {
   3.62627057233515*^9, 3.626270580473765*^9}, {3.6262715010427923`*^9, 
   3.6262715449472694`*^9}, {3.62627487396774*^9, 3.626274910835605*^9}, 
   3.6263327382028837`*^9, {3.626588250146246*^9, 
   3.6265882709254827`*^9}},ExpressionUUID->"73452e63-d97d-47db-bdd8-\
af5c372d5a79"],

Cell[BoxData[
 RowBox[{"sphercx", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6262705892741804`*^9, 
  3.626270596951394*^9}},ExpressionUUID->"96d11544-9bb2-40c0-b61c-\
bf852dc7bed3"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sphercx", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.626332700076417*^9, 3.6263327166904464`*^9}, {
  3.6263327568605165`*^9, 3.6263327771249523`*^9}, {3.6263332248613386`*^9, 
  3.6263332657178106`*^9}},ExpressionUUID->"3a1bbf19-b3ab-4f7d-b011-\
6e52186a150c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"curv", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.62633335644757*^9, 
  3.626333362547181*^9}},ExpressionUUID->"6f0785c0-e3d0-46bf-973d-\
9f48cc882139"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"curv", ",", "sph1"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.626333304639879*^9, 3.626333323281912*^9}, {
  3.626333369348793*^9, 
  3.626333387288824*^9}},ExpressionUUID->"9807d7b9-73aa-4449-b92b-\
b3da30c8c934"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kk", "[", "s_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"curvature", "[", "sphercx", "]"}], "[", "t", "]"}], "/.", 
   RowBox[{"t", "\[Rule]", " ", "s"}]}]}]], "Input",
 CellChangeTimes->{{3.6262697808793507`*^9, 3.626269850185673*^9}, {
  3.6262706253152437`*^9, 3.6262706316176553`*^9}, {3.6262715558516884`*^9, 
  3.6262715729357185`*^9}, {3.626439396046256*^9, 3.6264394321603203`*^9}, {
  3.6265883015171366`*^9, 3.626588320159169*^9}, {3.6265887890335927`*^9, 
  3.6265888381112785`*^9}},ExpressionUUID->"a8165989-ca40-4868-99a0-\
3477ebcdcf71"],

Cell[BoxData[
 RowBox[{"kk", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.626418694426047*^9, 3.626418752707749*^9}, {
  3.6264394420975375`*^9, 3.626439458461966*^9}, {3.6265883385516014`*^9, 
  3.6265883434812098`*^9}},ExpressionUUID->"484f65f1-b8db-4104-84d1-\
0ba3ff92356e"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"kk", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6263335604023285`*^9, 3.6263335987627954`*^9}, {
  3.626418774282587*^9, 
  3.6264187957482243`*^9}},ExpressionUUID->"a5d01589-715b-42ee-8451-\
802c3b80f043"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kn", "[", "s_", "]"}], ":=", 
  RowBox[{
   RowBox[{"normalcurvature", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
   "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6262697808793507`*^9, 3.626269850185673*^9}, {
   3.6262706253152437`*^9, 3.6262706316176553`*^9}, {3.626271402313818*^9, 
   3.6262714245634575`*^9}, {3.62627146016672*^9, 3.626271463349126*^9}, 
   3.6262715810029325`*^9, 3.626271640242237*^9, 3.626333487987001*^9, 
   3.626436637696212*^9, {3.6264394810664062`*^9, 3.6264394855280137`*^9}, {
   3.626588871854138*^9, 3.626588904270995*^9}, 3.6265889604466934`*^9, {
   3.6271116691964016`*^9, 
   3.627111682503225*^9}},ExpressionUUID->"2b90791f-9819-4445-867e-\
e3d8e5e56f8c"],

Cell[BoxData[
 RowBox[{"kn", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6264189328412657`*^9, 3.626418960000913*^9}, {
  3.626419062446293*^9, 3.626419083116329*^9}, {3.626436661860654*^9, 
  3.6264366832638917`*^9}, {3.6264394988972373`*^9, 3.6264395120792603`*^9}, {
  3.6265889178586187`*^9, 
  3.6265889221018267`*^9}},ExpressionUUID->"eaa32585-467e-449c-a673-\
b216b7201f1e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       RowBox[{"Cos", "[", "s", "]"}], "]"}]}], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "s", "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "s", "]"}], "2"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], "2"]}], 
           ")"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}], "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}], "3"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", "s", "]"}], "2"]}], "-", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "-", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}]}], ")"}]}]}], 
           ")"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"], " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", "s", "]"}], "2"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], "2"]}], 
            ")"}], 
           RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"Cos", "[", "s", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", "s", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "s", "]"}], " ", 
        RowBox[{"Sin", "[", "s", "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"], " ", 
           RowBox[{"Sin", "[", "s", "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"], " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", "s", "]"}], "2"]}], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], "2"]}], 
            ")"}]}], ")"}]}]}], "-", 
       RowBox[{
        RowBox[{"Sin", "[", "s", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              RowBox[{"Cos", "[", "s", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"], " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", "s", "]"}], "2"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], "2"]}], 
               ")"}]}], ")"}]}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", "s", "]"}], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], "3"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], "3"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"]}], "-", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "-", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}]}], 
                 ")"}]}]}], ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"], " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", "s", "]"}], "2"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], "2"]}], 
               ")"}], 
              RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "s", "]"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "s", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "s", "]"}], "2"]}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], "2"]}], 
           ")"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Sin", "[", "s", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
              RowBox[{"Sin", "[", "s", "]"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"Cos", "[", "s", "]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Sqrt]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"], " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", "s", "]"}], "2"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], "2"]}], 
               ")"}]}], ")"}]}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"], " ", 
                RowBox[{"Sin", "[", "s", "]"}]}], " ", "==="}], ">>>", 
              RowBox[{
               RowBox[{"4.3", 
                RowBox[{".5", "."}]}], " ", "Another", " ", "Curve", " ", 
               "on", " ", "the", " ", "Sphere", "\n", 
               RowBox[{"Clear", " ", "[", 
                RowBox[{"hu", ",", "hv", ",", "kk", ",", "kg", ",", "kn"}], 
                "]"}]}]}], ";", 
             RowBox[{
              RowBox[{"hu", "[", "s_", "]"}], " ", "=", " ", "s"}], ";", " ", 
             RowBox[{
              RowBox[{"hv", "[", "s_", "]"}], " ", "=", " ", 
              RowBox[{"Cos", "[", "s", "]"}]}], ";", 
             RowBox[{
              RowBox[{"sphercx", "[", "s_", "]"}], " ", ":=", " ", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"sphero", "[", "1", "]"}], "[", 
                 RowBox[{
                  RowBox[{"hu", "[", "s", "]"}], ",", 
                  RowBox[{"hv", "[", "s", "]"}]}], "]"}], "\n", 
                RowBox[{"sphercx", "[", "s", "]"}], "\n", 
                RowBox[{"ParametricPlot3D", "[", 
                 RowBox[{
                  RowBox[{"sphercx", "[", "s", "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"s", ",", "0", ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
                  RowBox[{"PlotStyle", " ", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}], "\n", 
                "curv"}], " ", "=", " ", "%"}]}], ";", "\n", 
             RowBox[{
              RowBox[{
               RowBox[{"Show", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"curv", ",", "sph1"}], "}"}], ",", 
                 RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}], 
               "\n", 
               RowBox[{"kk", "[", "s_", "]"}]}], ":=", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"curvature", "[", "sphercx", "]"}], "[", "t", "]"}], 
                "/.", 
                RowBox[{"t", "\[Rule]", " ", 
                 RowBox[{"s", "\n", 
                  RowBox[{"kk", "[", "s", "]"}], "\n", 
                  RowBox[{"Plot", "[", 
                   RowBox[{
                    RowBox[{"kk", "[", "s", "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"s", ",", "0", ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
                    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], 
                   "]"}], "\n", 
                  RowBox[{"kn", "[", "s_", "]"}]}]}]}], ":=", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"normalcurvature", "[", 
                   RowBox[{
                    RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}],
                    "]"}], "[", "s", "]"}], "\n", 
                 RowBox[{"kn", "[", "s", "]"}], "\n", 
                 RowBox[{"Plot", "[", 
                  RowBox[{
                   RowBox[{"kn", "[", "s", "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"s", ",", "0", ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
                   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
                   RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}], "\n", 
                 RowBox[{"kg", "[", "s_", "]"}]}], ":=", 
                RowBox[{
                 RowBox[{
                  RowBox[{"geodcurvature", "[", 
                   RowBox[{
                    RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}],
                    "]"}], "[", "s", "]"}], "\n", 
                 RowBox[{"kg", "[", "s", "]"}], "\n", 
                 RowBox[{"Plot", "[", 
                  RowBox[{
                   RowBox[{"kg", "[", "s", "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"s", ",", "0", ",", 
                    RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
                   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}],
                  "\n", 
                 RowBox[{"FullSimplify", "[", 
                  RowBox[{
                   RowBox[{"Together", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"kk", "[", "s", "]"}], "^", "2"}], " ", "-", 
                    RowBox[{
                    RowBox[{"kn", "[", "s", "]"}], "^", "2"}], "-", 
                    RowBox[{
                    RowBox[{"kg", "[", "s", "]"}], "^", "2"}]}], "]"}], ",", 
                   RowBox[{"s", ">", "0"}]}], "]"}], "\n", 
                 RowBox[{"OK", "!"}], 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "3"], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "-", 
                   RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}]}]}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"Cos", "[", "s", "]"}], "]"}], "4"], " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", "s", "]"}], "2"]}], "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"Cos", "[", "s", "]"}], "]"}]}]}], ")"}], "2"]}], 
               ")"}], 
              RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "s", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", "s", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Sin", "[", "s", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"Cos", "[", "s", "]"}], "]"}], "2"]}]}], ")"}]}]}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.708234313900997*^9, 
  3.7082343139221573`*^9}},ExpressionUUID->"18d47b08-6558-4de8-a2e3-\
27984588bf01"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"kn", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6263335604023285`*^9, 3.6263335987627954`*^9}, {
   3.626418774282587*^9, 3.6264187957482243`*^9}, 3.626419000919785*^9, {
   3.627112948882249*^9, 
   3.627112971595889*^9}},ExpressionUUID->"6017b57a-836c-41f0-b9b4-\
f87c6a6b9ebb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kg", "[", "s_", "]"}], ":=", 
  RowBox[{
   RowBox[{"geodcurvature", "[", 
    RowBox[{
     RowBox[{"sphero", "[", "1", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
   "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6262723065954123`*^9, 3.626272358893704*^9}, 
   3.626333502151826*^9, {3.626436708660736*^9, 3.6264367142455463`*^9}, {
   3.62658899833916*^9, 3.6265890019271665`*^9}, {3.626589037354829*^9, 
   3.626589062626873*^9}, {3.627112263136245*^9, 
   3.6271122711078587`*^9}},ExpressionUUID->"f02acd0e-d513-4302-85f4-\
d0302165b61d"],

Cell[BoxData[
 RowBox[{"kg", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6264191133335824`*^9, 3.626419169852482*^9}, {
  3.6264367308595753`*^9, 3.62643677326045*^9}, {3.6265890765576973`*^9, 
  3.626589082017707*^9}},ExpressionUUID->"2674b984-8698-4609-9b39-\
4935a5959de2"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"kg", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6263335604023285`*^9, 3.6263335987627954`*^9}, {
   3.626418774282587*^9, 3.6264187957482243`*^9}, 3.626419000919785*^9, 
   3.6264192312697897`*^9, 
   3.626596579512866*^9},ExpressionUUID->"2ea38812-26d8-4e77-b3e7-\
e6312de5bbae"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"kk", "[", "s", "]"}], "^", "2"}], " ", "-", 
     RowBox[{
      RowBox[{"kn", "[", "s", "]"}], "^", "2"}], "-", 
     RowBox[{
      RowBox[{"kg", "[", "s", "]"}], "^", "2"}]}], "]"}], ",", 
   RowBox[{"s", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6262723763989353`*^9, 3.6262724099117937`*^9}, {
  3.6262750511094522`*^9, 3.6262750574430637`*^9}, {3.6264192519866257`*^9, 
  3.6264192857918854`*^9}, {3.626436937965539*^9, 
  3.6264369527387652`*^9}},ExpressionUUID->"3d1c8d2d-a8fb-4901-834b-\
ee7bbf83d781"],

Cell["OK!", "Text",
 CellChangeTimes->{{3.6271128414760604`*^9, 
  3.627112843238864*^9}},ExpressionUUID->"44326dc3-fb25-4eb4-a3c4-\
16bfa874e9a3"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3.6. Further Examples", "Subsubsection",
 CellChangeTimes->{{3.626600317378045*^9, 3.626600325427659*^9}, {
   3.6266046150378838`*^9, 3.6266046193122916`*^9}, {3.626848682265691*^9, 
   3.626848696992117*^9}, 3.6268543822492666`*^9, 3.7082343632715387`*^9, 
   3.708235528420471*^9},ExpressionUUID->"c0c0cdde-3260-45ce-a768-\
ba9b42061f06"],

Cell[TextData[{
 StyleBox["Example 16",
  FontColor->RGBColor[0, 0, 1]],
 ". Graphs of Functions"
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
   3.613631784777006*^9, 3.6136317936534214`*^9}, 3.6136319442872863`*^9, {
   3.6142629800161095`*^9, 3.6142629821221128`*^9}, 3.6143299951743555`*^9, {
   3.699594402124679*^9, 
   3.699594404684533*^9}},ExpressionUUID->"a491f89c-2b52-4d93-a6a5-\
c2919c656aff"],

Cell["\<\
We consider the graph of an unspecified function f[u,v]. In this case we \
calculate  all kind of curvatures of the parameter lines and of a general \
curve on the surface. We control the curvature relation.\
\>", "Text",
 CellChangeTimes->{{3.613632210517354*^9, 3.6136322491742215`*^9}, {
  3.614329894398178*^9, 3.614329951790679*^9}, {3.699596562530903*^9, 
  3.699596585266473*^9}, {3.6995966253622217`*^9, 
  3.6995966792419157`*^9}},ExpressionUUID->"cf8b2651-f7f8-41ae-8806-\
0b377e85804f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a", ",", "hu", ",", "hv", ",", "sx"}], "]"}], ";", 
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], " ", "=", " ", "s"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"hv", "[", "a_", "]"}], "[", "s_", "]"}], ":=", " ", "a"}], ";", 
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"graph", "[", "f", "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{
      RowBox[{"hv", "[", "a", "]"}], "[", "s", "]"}]}], "]"}]}], ";", 
  RowBox[{"sx", "[", "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.6189120064650564`*^9, 3.6189120185394773`*^9}, {3.618912065011959*^9, 
   3.6189120878035994`*^9}, {3.618912435263009*^9, 3.6189124443734255`*^9}, {
   3.6189124810178895`*^9, 3.6189125661316395`*^9}, {3.699594544974588*^9, 
   3.699594572051298*^9}},ExpressionUUID->"0c0a8078-e8c9-4442-b391-\
59e6de9d812f"],

Cell[BoxData[
 RowBox[{"kk", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6189121673325386`*^9, 3.618912199640196*^9}, 
   3.618912235660659*^9, 3.6189122782331333`*^9, {3.61891238421972*^9, 
   3.618912384906121*^9}, {3.618912595880892*^9, 
   3.6189125967232933`*^9}},ExpressionUUID->"fd033b9a-037a-4e4d-ab08-\
4a242e50f181"],

Cell[BoxData[
 RowBox[{"kg", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{
      RowBox[{"graph", "[", "f", "]"}], ",", "hu", ",", 
      RowBox[{"hv", "[", "a", "]"}]}], "]"}], "[", "s", "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.618912026261491*^9, 
   3.618912029865097*^9}},ExpressionUUID->"a67aa883-c7b2-4e18-bace-\
0f92bb440341"],

Cell[BoxData[
 RowBox[{"kn", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"graph", "[", "f", "]"}], ",", "hu", ",", 
      RowBox[{"hv", "[", "a", "]"}]}], "]"}], "[", "s", "]"}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.61432944564779*^9, {
   3.614329681629404*^9, 3.6143297762279706`*^9}, {3.6145055851462154`*^9, 
   3.6145056105742607`*^9}, 3.6148618633255463`*^9, 3.6148631367245827`*^9, {
   3.6189121285040703`*^9, 
   3.618912134603681*^9}},ExpressionUUID->"6facef82-7e4f-418d-9d1f-\
5d7057d51ec2"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"kk", "^", "2"}], "-", 
    RowBox[{"kn", "^", "2"}], "-", 
    RowBox[{"kg", "^", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6145056477179255`*^9, 
  3.6145057008360186`*^9}},ExpressionUUID->"5ffa4b13-8aaa-49f5-937d-\
a4a0214bf3c7"],

Cell["A general curve on the surface:", "Text",
 CellChangeTimes->{{3.69959517058142*^9, 3.699595172837508*^9}, {
  3.699596728177182*^9, 
  3.699596755992682*^9}},ExpressionUUID->"321969ff-edea-476e-8de5-\
965b8cf8d597"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a", ",", "hu", ",", "hv", ",", "sx"}], "]"}], ";", 
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"graph", "[", "f", "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], ";", 
  RowBox[{"sx", "[", "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.6189120064650564`*^9, 3.6189120185394773`*^9}, {3.618912065011959*^9, 
   3.6189120878035994`*^9}, {3.618912435263009*^9, 3.6189124443734255`*^9}, {
   3.6189124810178895`*^9, 3.6189125661316395`*^9}, {3.699594544974588*^9, 
   3.699594572051298*^9}, {3.6995952680249*^9, 
   3.69959528281378*^9}},ExpressionUUID->"aa5fb0ca-fef5-4308-82b8-\
d64581ce6246"],

Cell[BoxData[
 RowBox[{"kk", " ", "=", 
  RowBox[{
   RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6189121673325386`*^9, 3.618912199640196*^9}, 
   3.618912235660659*^9, 3.6189122782331333`*^9, {3.61891238421972*^9, 
   3.618912384906121*^9}, {3.618912595880892*^9, 3.6189125967232933`*^9}, {
   3.699595998550727*^9, 
   3.699596008801169*^9}},ExpressionUUID->"7a94795c-1ebb-488a-af6c-\
8ee623c1f9b3"],

Cell[BoxData[
 RowBox[{"kg", "=", 
  RowBox[{
   RowBox[{"geodcurvature", "[", 
    RowBox[{
     RowBox[{"graph", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
   "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.618912026261491*^9, 3.618912029865097*^9}, 3.6995959143941097`*^9, {
   3.699596028025094*^9, 
   3.6995960414887543`*^9}},ExpressionUUID->"3aeaeca2-0f8c-4e8f-884a-\
dffc4b58eb22"],

Cell[BoxData[
 RowBox[{"kn", "=", 
  RowBox[{
   RowBox[{"normalcurvature", "[", 
    RowBox[{
     RowBox[{"graph", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
   "s", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.61432944564779*^9, {
   3.614329681629404*^9, 3.6143297762279706`*^9}, {3.6145055851462154`*^9, 
   3.6145056105742607`*^9}, 3.6148618633255463`*^9, 3.6148631367245827`*^9, {
   3.6189121285040703`*^9, 3.618912134603681*^9}, 3.6995959527378387`*^9, {
   3.699596076080674*^9, 
   3.699596079248155*^9}},ExpressionUUID->"9280e6f9-1d44-4e59-a3ac-\
daa089e54457"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"kk", "^", "2"}], "-", 
    RowBox[{"kn", "^", "2"}], "-", 
    RowBox[{"kg", "^", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6145056477179255`*^9, 
  3.6145057008360186`*^9}},ExpressionUUID->"91f894b0-934d-4755-9cfa-\
5d2c203d981a"],

Cell["The same for the specified function f3:", "Text",
 CellChangeTimes->{{3.6189278059856067`*^9, 3.6189278320064526`*^9}, 
   3.6189955701473665`*^9},ExpressionUUID->"0b3702ef-2c3b-411f-85a0-\
047ee2a39424"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f3", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"u", "^", "3"}], "+", 
   RowBox[{"v", "^", "3"}]}]}]], "Input",
 CellChangeTimes->{{3.618918953500458*^9, 
  3.6189189761204977`*^9}},ExpressionUUID->"451c89fd-ed04-42f5-ac64-\
9f45ab0e8a7d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"hu", ",", "hv", ",", "sx"}], "]"}], ";", 
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"graph", "[", "f3", "]"}], "[", 
    RowBox[{
     RowBox[{"hu", "[", "s", "]"}], ",", 
     RowBox[{"hv", "[", "s", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.6189120064650564`*^9, 3.6189120185394773`*^9}, {3.618912065011959*^9, 
   3.6189120878035994`*^9}, {3.618912435263009*^9, 3.6189124443734255`*^9}, {
   3.6189124810178895`*^9, 3.6189125661316395`*^9}, {3.6189131345654373`*^9, 
   3.6189131457974577`*^9}, 3.6189190083501544`*^9, {3.6189274238941355`*^9, 
   3.618927442770169*^9}, {3.6995961762752047`*^9, 3.699596214367593*^9}, 
   3.6996024127656097`*^9},ExpressionUUID->"3c4e158d-ba6f-4f98-94c1-\
010165f7fa66"],

Cell[BoxData[
 RowBox[{"sx", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.699596228855659*^9, 
  3.6995962334387503`*^9}},ExpressionUUID->"559244f9-5333-4f9f-a424-\
7341a7a8e3e8"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", "[", "f3", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6189190252917843`*^9, 
  3.618919153118409*^9}},ExpressionUUID->"09d83441-a927-4214-bd8a-\
cb77f0fe6984"],

Cell[BoxData[
 RowBox[{"kk", "=", 
  RowBox[{
   RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.618927532517126*^9, 3.6189275639511814`*^9}, {
  3.6995963109414263`*^9, 
  3.699596314181758*^9}},ExpressionUUID->"f7a84d57-c5de-430e-82c7-\
51e7f129a08c"],

Cell[BoxData[
 RowBox[{"kg", "=", 
  RowBox[{
   RowBox[{"geodcurvature", "[", 
    RowBox[{
     RowBox[{"graph", "[", "f3", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
   "s", "]"}]}]], "Input",
 CellChangeTimes->{{3.6143294721366367`*^9, 3.614329624065303*^9}, {
   3.614494308370402*^9, 3.6144943725460725`*^9}, {3.614505389490672*^9, 
   3.614505523245307*^9}, {3.6145055567073655`*^9, 3.614505570107789*^9}, 
   3.6148618633255463`*^9, 3.6148631367245827`*^9, 3.6189119646725826`*^9, {
   3.618912026261491*^9, 3.618912029865097*^9}, 3.618913684263603*^9, {
   3.618916542438223*^9, 3.6189165488186345`*^9}, {3.6189198543552403`*^9, 
   3.618919862155254*^9}, 3.6189275059502797`*^9, {3.6189276139960694`*^9, 
   3.6189276170536747`*^9}, {3.699596345201509*^9, 3.699596351517627*^9}, {
   3.6996009269071283`*^9, 
   3.699600946071691*^9}},ExpressionUUID->"bdb5845e-634a-41d7-8e95-\
a4e7797e1424"],

Cell[BoxData[
 RowBox[{"kn", "=", 
  RowBox[{
   RowBox[{"normalcurvature", "[", 
    RowBox[{
     RowBox[{"graph", "[", "f3", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
   "s", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.61432944564779*^9, {
   3.614329681629404*^9, 3.6143297762279706`*^9}, {3.6145055851462154`*^9, 
   3.6145056105742607`*^9}, 3.6148618633255463`*^9, 3.6148631367245827`*^9, {
   3.6189121285040703`*^9, 3.618912134603681*^9}, 3.6189276436205215`*^9, {
   3.699596382425582*^9, 3.699596385861792*^9}, {3.6996008925470667`*^9, 
   3.699600894303876*^9}},ExpressionUUID->"21793380-d3c3-4027-82f2-\
9135aed3483e"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"kk", "^", "2"}], "-", 
    RowBox[{"kn", "^", "2"}], "-", 
    RowBox[{"kg", "^", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6145056477179255`*^9, 
  3.6145057008360186`*^9}},ExpressionUUID->"c137f2d1-79c6-45d8-9229-\
4ed5a17d4f7d"],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6145057514113073`*^9, 
  3.6145057689301386`*^9}},ExpressionUUID->"25b7d99f-a8cb-4f59-ac2b-\
4af6fc76caaa"],

Cell[TextData[{
 "We consider a normal surface of the helix, see Subsection ",
 ButtonBox["3.8.2",
  BaseStyle->"Hyperlink",
  ButtonData->"helix"],
 "."
}], "Text",
 CellChangeTimes->{{3.614330152547432*^9, 3.614330182062683*^9}, {
  3.6143302386127825`*^9, 3.614330280420856*^9}, {3.699610794335291*^9, 
  3.699610796078755*^9}},ExpressionUUID->"78aa0109-2f90-4af6-b460-\
05cf4c6d6953"],

Cell[BoxData[
 RowBox[{"hel", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.6147509470177927`*^9, 
  3.614750947048992*^9}},ExpressionUUID->"a1178c97-677a-4090-85bf-\
73acab95b659"],

Cell["The surface generated by the binormals:", "Text",
 CellChangeTimes->{{3.618981650960631*^9, 
  3.6189816787130795`*^9}},ExpressionUUID->"0c8c45f8-e93a-4d24-a0ae-\
f15be38dfe3a"],

Cell[BoxData[
 RowBox[{"?", "helixnormalcongr"}]], "Input",
 CellChangeTimes->{
  3.699610931263504*^9},ExpressionUUID->"315817e1-6e96-45fd-997c-\
a2bb85667cbc"],

Cell[BoxData[
 RowBox[{"cb", "=", " ", 
  RowBox[{"Pi", "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.613977464712309*^9, 3.6139774850859447`*^9}, {
   3.613994501006675*^9, 3.613994505015882*^9}, 
   3.699610989648879*^9},ExpressionUUID->"b4b38cdc-6280-4b3d-9a5e-\
d7eed74f91db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hnsf", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"helixnormalcongr", "[", "cb", "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
    RowBox[{"v", "\[Element]", "Reals"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6139774919343567`*^9, 3.613977501715574*^9}, {
   3.61397753935844*^9, 3.613977571853297*^9}, {3.6139776021953506`*^9, 
   3.6139776329898043`*^9}, {3.61433035108898*^9, 3.614330391461851*^9}, 
   3.6290988682429657`*^9},ExpressionUUID->"b409b026-38c7-47a9-af4c-\
68dde17fc341"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"hnsf", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Opacity", "[", ".6", "]"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613977668760667*^9, 3.613977729663174*^9}, {
   3.614330411133486*^9, 3.6143304144874916`*^9}, {3.6143304498527536`*^9, 
   3.61433045337836*^9}, {3.6143307201856284`*^9, 3.614330757391694*^9}, {
   3.6996111801572523`*^9, 3.699611205067647*^9}, {3.699618422078577*^9, 
   3.6996184890839787`*^9}, 3.699618786778778*^9, {3.6996188397023287`*^9, 
   3.699618843033517*^9}, {3.699619956468214*^9, 
   3.699620038986362*^9}},ExpressionUUID->"abe34939-3d87-4174-96e5-\
ff422f182507"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hel1", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6143305134852657`*^9, 
  3.614330520380478*^9}},ExpressionUUID->"ce52c4ee-4e55-4aeb-a7e3-\
249b551bb708"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"hel", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", " ", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143305234224825`*^9, 3.6143305311132965`*^9}, {
   3.6143306628399277`*^9, 3.614330695381585*^9}, {3.6143307681869125`*^9, 
   3.6143307872501464`*^9}, {3.6143308932991323`*^9, 3.6143309148271704`*^9}, 
   3.6147509693882313`*^9, {3.699611261968192*^9, 3.699611265610937*^9}, {
   3.699611324783576*^9, 3.699611355145575*^9}, {3.699618921541872*^9, 
   3.699618933640862*^9}},ExpressionUUID->"3690ed52-3224-425d-a382-\
e6d3294637c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hel2", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.61433080043217*^9, 
  3.614330813395792*^9}},ExpressionUUID->"8afa14ed-0819-40a6-b8cd-\
9980eab18a27"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"hel1", ",", "hel2"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143308164845977`*^9, 
  3.614330844439847*^9}},ExpressionUUID->"3a63e82c-8fd0-41d3-9402-\
9cdd276ad8a0"],

Cell["\<\
We consider  hnsf. The helix itself is a curve on the surface.\
\>", "Text",
 CellChangeTimes->{{3.613632210517354*^9, 3.6136322491742215`*^9}, {
   3.613977780737664*^9, 3.613977788802878*^9}, {3.6143310270537677`*^9, 
   3.6143310468814025`*^9}, 
   3.6996118786200743`*^9},ExpressionUUID->"900289b0-d1d3-4f85-b79e-\
756e2e04474a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "sx", "]"}], ";", 
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{"hnsf", "[", 
    RowBox[{"s", ",", "0"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, {3.6139778317185535`*^9, 
   3.6139778583322*^9}, {3.6140535554544344`*^9, 3.614053565142051*^9}, 
   3.614057854151184*^9, {3.6140579446937437`*^9, 3.614057962664975*^9}, {
   3.6996122138613653`*^9, 
   3.699612231577367*^9}},ExpressionUUID->"18bbc1d1-ac09-4cde-9bf2-\
ce9e8c91a812"],

Cell[BoxData[
 RowBox[{"sx", "[", "t", "]"}]], "Input",
 CellChangeTimes->{
  3.6140536423777866`*^9, 3.6140578620915985`*^9, {3.6140579046484733`*^9, 
   3.614057915490492*^9}, {3.614057981244608*^9, 3.6140579829762106`*^9}, 
   3.61450612840157*^9, 3.6996117395020123`*^9, 
   3.699612909828664*^9},ExpressionUUID->"a07836ae-e627-45be-8e50-\
752c619c5040"],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{"hel", "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{{3.6996130408674192`*^9, 
  3.699613050233613*^9}},ExpressionUUID->"0a8ed1d4-6cad-48f4-a713-\
efd1e91518ba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], "=", "s"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], "=", "0"}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"curvature", "[", "sx", "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, {3.6139778317185535`*^9, 
   3.6139778583322*^9}, {3.613977953227167*^9, 3.613977974224804*^9}, 
   3.61399468710133*^9, {3.6140012428100443`*^9, 3.614001260500475*^9}, 
   3.614003200051882*^9, {3.614053692017074*^9, 3.6140537100195055`*^9}, 
   3.6143312564053707`*^9, 3.614506139196789*^9, 3.614861863387946*^9, 
   3.614863136740183*^9, {3.699612480913087*^9, 
   3.699612570101976*^9}},ExpressionUUID->"cb458bf9-4d65-4bf0-8b29-\
a9d164b907cd"],

Cell["It is a geodesic  on the surface:", "Text",
 CellChangeTimes->{{3.699613196543406*^9, 3.699613231878892*^9}, {
  3.699613264023094*^9, 
  3.699613265287889*^9}},ExpressionUUID->"7b062bfe-3b2e-492e-b200-\
783cb4e9cec8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"geodcurvature", "[", 
   RowBox[{"hnsf", ",", "hu", ",", "hv"}], "]"}], "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.699612366171029*^9, 3.699612425983306*^9}, {
  3.6996126712768784`*^9, 
  3.6996127073808517`*^9}},ExpressionUUID->"7af3e15a-dc73-440f-a327-\
206645185ac2"],

Cell["\<\
Its normal curvature coincides up to sign with its curvature:\
\>", "Text",
 CellChangeTimes->{{3.614331335575509*^9, 3.61433136426396*^9}, 
   3.6174418910598736`*^9, {3.69961333454218*^9, 
   3.699613350261948*^9}},ExpressionUUID->"bf29d98a-f41e-4201-85a8-\
59314c884f79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"normalcurvature", "[", 
   RowBox[{"hnsf", ",", "hu", ",", "hv"}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6136213128686132`*^9, {3.6136220816691637`*^9, 
   3.6136221609485025`*^9}, 3.6136226985098467`*^9, {3.6136230453764563`*^9, 
   3.613623055532074*^9}, {3.613632058448287*^9, 3.613632088088339*^9}, {
   3.613981056689015*^9, 3.6139810903850737`*^9}, {3.6140538078940773`*^9, 
   3.6140538380645304`*^9}, {3.614053909044655*^9, 3.6140539372963047`*^9}, {
   3.614057401001589*^9, 3.6140574170228167`*^9}, {3.6140574584564896`*^9, 
   3.614057531854618*^9}, {3.6140577454501934`*^9, 3.6140577665102305`*^9}, {
   3.614058011789461*^9, 3.6140580637219524`*^9}, {3.614331077410656*^9, 
   3.614331090155878*^9}, {3.6143311369871607`*^9, 3.614331232490528*^9}, 
   3.6148618634035463`*^9, 3.614863136740183*^9, {3.6189819294679203`*^9, 
   3.618981931745524*^9}, {3.618982920522061*^9, 3.618982951940516*^9}, 
   3.6996121573589153`*^9, 3.699612751248949*^9, {3.699612807148313*^9, 
   3.699612824715517*^9}},ExpressionUUID->"7f336d98-423d-40e5-9a5f-\
d950b129e2c1"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.699612835926696*^9, 
  3.699612849803496*^9}},ExpressionUUID->"61208584-6c85-45a7-95b6-\
5893ff79e6e1"],

Cell["Clearly, the generating lines are geodesics too:", "Text",
 CellChangeTimes->{{3.614331549857486*^9, 
  3.6143315806051397`*^9}},ExpressionUUID->"82d8260f-e618-4c71-b4f6-\
a529f9153829"],

Cell[BoxData[
 RowBox[{"hnsf", "[", 
  RowBox[{"so", ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.6143314959437914`*^9, 3.6143315099214153`*^9}, {
  3.6996192074983997`*^9, 
  3.699619230998444*^9}},ExpressionUUID->"88d64aca-b541-4cfb-865b-\
d9f7c670abf2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", " ", "uo"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], ":=", " ", 
   RowBox[{"vo", " ", "+", "s"}]}], ";", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{"hnsf", ",", "hu", ",", "hv"}], "]"}], "[", "t", "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6136213128686132`*^9, {3.6136220816691637`*^9, 
   3.6136221609485025`*^9}, 3.6136226985098467`*^9, {3.6136230453764563`*^9, 
   3.613623055532074*^9}, {3.613632058448287*^9, 3.613632088088339*^9}, {
   3.613981056689015*^9, 3.6139810903850737`*^9}, {3.6140538078940773`*^9, 
   3.6140538380645304`*^9}, {3.614053909044655*^9, 3.6140539372963047`*^9}, {
   3.614057401001589*^9, 3.6140574170228167`*^9}, {3.6140574584564896`*^9, 
   3.614057531854618*^9}, {3.6140577454501934`*^9, 3.6140577665102305`*^9}, {
   3.614058011789461*^9, 3.6140580637219524`*^9}, {3.614331077410656*^9, 
   3.614331090155878*^9}, {3.6143311369871607`*^9, 3.6143311824612403`*^9}, {
   3.6143314227796626`*^9, 3.614331442981698*^9}, 3.6148618634191465`*^9, 
   3.614863136740183*^9, {3.699619251729024*^9, 3.699619309053445*^9}, {
   3.699619435417507*^9, 
   3.6996194523884087`*^9}},ExpressionUUID->"167dcc8c-4c00-481b-854b-\
1a587553932d"],

Cell["For the parameter curves v = v0 we calculate", "Text",
 CellChangeTimes->{{3.618983158547279*^9, 3.618983177438912*^9}, {
  3.69961964165021*^9, 
  3.69961965014607*^9}},ExpressionUUID->"cfdc8903-3d02-4b6f-affa-\
f58d8629ca0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sx", "[", "s_", "]"}], ":=", 
  RowBox[{"hnsf", "[", 
   RowBox[{
    RowBox[{"uo", "+", "s"}], ",", "vo"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614331807290964*^9, 3.614331815195416*^9}, {
   3.6145062733882246`*^9, 3.614506286851048*^9}, {3.6145063753032036`*^9, 
   3.614506378017608*^9}, 3.614506412150468*^9, {3.6996194763803053`*^9, 
   3.6996194811642523`*^9}, {3.6996196681803493`*^9, 
   3.699619683650619*^9}},ExpressionUUID->"21e2ee3b-718e-4be7-a187-\
0974cf1d5616"],

Cell[BoxData[
 RowBox[{"sx", "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.6189830814987435`*^9, 3.618983098299973*^9}, 
   3.699619509600027*^9},ExpressionUUID->"bdafcf63-664a-42a3-af6e-\
abc3465214dd"],

Cell[BoxData[
 RowBox[{"kk", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], ",", 
    RowBox[{"s", "\[Element]", "Reals"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6145063038550777`*^9, 3.614506385412021*^9}, 
   3.614506423351288*^9, 3.6148618634347467`*^9, 
   3.614863136740183*^9},ExpressionUUID->"a25279fa-40bc-4b4e-924f-\
aaf46388fcfd"],

Cell[BoxData[
 RowBox[{"?", "torsion"}]], "Input",
 CellChangeTimes->{{3.6143322148102727`*^9, 
  3.614332225668894*^9}},ExpressionUUID->"30f2a3da-7f8e-4de3-b4ae-\
86d4e4976d4c"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"torsion", "[", "sx", "]"}], "[", "s", "]"}], ",", 
   RowBox[{"s", "\[Element]", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6145063038550777`*^9, 3.614506385412021*^9}, 
   3.614506423351288*^9, {3.614506500259423*^9, 
   3.614506531506278*^9}},ExpressionUUID->"91b5f31a-3fd9-4e3a-864a-\
5309d6991efd"],

Cell["\<\
It follows: The parameter curves v= const. are helices again, its curvature \
and torsion depend on vo.\
\>", "Text",
 CellChangeTimes->{{3.6143322874654284`*^9, 3.614332359217532*^9}, {
  3.614506634216858*^9, 3.6145066625777082`*^9}, {3.618983208092966*^9, 
  3.6189832084049664`*^9}, {3.699619765001006*^9, 
  3.699619787424897*^9}},ExpressionUUID->"f23c3d8a-81f7-451d-8e4d-\
b2f7817500ca"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"hnsf", "[", 
    RowBox[{"t", ",", "1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", " ", "Green"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143317451024065`*^9, 3.614331772987002*^9}, {
  3.6143318641392155`*^9, 3.614331897460121*^9}, {3.699619826657776*^9, 
  3.699619840993782*^9}},ExpressionUUID->"6bd226a3-93f1-4ba9-943e-\
025510a726af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"hel3", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.6143319076417036`*^9, 
  3.614331921147476*^9}},ExpressionUUID->"25f15049-3740-47ad-bfd2-\
890eaffbbad3"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"hel1", ",", "hel2", ",", "hel3"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143308164845977`*^9, 3.614330844439847*^9}, {
  3.614331956171479*^9, 
  3.6143319583726053`*^9}},ExpressionUUID->"66bd38f0-fd78-49a7-b780-\
7c03e094019b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", " ", "s"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], ":=", " ", "vo"}], ";", 
  RowBox[{"kg", " ", "=", 
   RowBox[{
    RowBox[{"geodcurvature", "[", 
     RowBox[{"hnsf", ",", "hu", ",", "hv"}], "]"}], "[", "s", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.599029134745389*^9, 3.599029405593065*^9}, 
   3.613476504428583*^9, 3.6136213128686132`*^9, {3.6136220816691637`*^9, 
   3.6136221609485025`*^9}, 3.6136226985098467`*^9, {3.6136230453764563`*^9, 
   3.613623055532074*^9}, {3.613632058448287*^9, 3.613632088088339*^9}, {
   3.613981056689015*^9, 3.6139810903850737`*^9}, {3.6140538078940773`*^9, 
   3.6140538380645304`*^9}, {3.614053909044655*^9, 3.6140539372963047`*^9}, {
   3.614057401001589*^9, 3.6140574170228167`*^9}, {3.6140574584564896`*^9, 
   3.614057531854618*^9}, {3.6140577454501934`*^9, 3.6140577665102305`*^9}, {
   3.614058011789461*^9, 3.6140580637219524`*^9}, {3.614331077410656*^9, 
   3.614331090155878*^9}, {3.6143311369871607`*^9, 3.6143311824612403`*^9}, {
   3.6143314227796626`*^9, 3.614331442981698*^9}, {3.6143316492429237`*^9, 
   3.6143316728042717`*^9}, 3.6143317151976967`*^9, 3.614506458201749*^9, 
   3.6145064916482077`*^9, {3.614506787409127*^9, 3.6145067899987316`*^9}, 
   3.6148618634815464`*^9, 3.614863136740183*^9, {3.699620237141529*^9, 
   3.6996202532856703`*^9}, 3.699620500712037*^9, {3.699621660685895*^9, 
   3.699621668985693*^9}},ExpressionUUID->"9303857b-3524-4feb-879f-\
b8f85b4f9fa4"],

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"kg", "/.", 
      RowBox[{"s", "\[Rule]", ".3"}]}], ")"}], "\[Equal]", "0"}], ",", " ", 
   "vo", ",", "Reals"}], "]"}]], "Input",
 CellChangeTimes->{{3.699621722818726*^9, 3.6996217918036423`*^9}, {
   3.699624553450729*^9, 3.69962459284594*^9}, {3.69962465334305*^9, 
   3.699624662293168*^9}, 
   3.699624743936489*^9},ExpressionUUID->"d1cfd486-a03f-47f4-9210-\
626afea3818d"],

Cell[BoxData[
 RowBox[{"kg", "/.", 
  RowBox[{"vo", "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.6996242640540113`*^9, 3.699624279671899*^9}, {
  3.6996247086377497`*^9, 
  3.699624710315661*^9}},ExpressionUUID->"d21fa9db-af3a-4deb-9c56-\
7adc902c6868"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"kg", "/.", 
    RowBox[{"s", "\[Rule]", ".2"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"vo", ",", 
     RowBox[{
      RowBox[{"-", "4"}], "*", "Pi"}], ",", 
     RowBox[{"4", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.699624299535685*^9, 3.6996245025347843`*^9}, {
  3.699624759424674*^9, 
  3.699624760092375*^9}},ExpressionUUID->"9032958c-b8ca-4b05-9e40-\
c74f9ac318a6"],

Cell["\<\
The only geodesic parameter curve v == vo is the generating helix obtained \
for vo = 0.\
\>", "Text",
 CellChangeTimes->{{3.6143326361293707`*^9, 3.6143326704333324`*^9}, 
   3.6145069125525475`*^9, 3.614751027217533*^9, {3.617429872653062*^9, 
   3.6174299091727257`*^9}, {3.618983277747088*^9, 3.6189833075431404`*^9}, {
   3.699620326451861*^9, 3.6996203296995897`*^9}, 3.6996203599075727`*^9, {
   3.708235035225957*^9, 
   3.708235036082706*^9}},ExpressionUUID->"ffae198d-b10a-4808-844e-\
c6d2f8c27170"],

Cell[BoxData[
 RowBox[{"kn", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"normalcurvature", "[", 
      RowBox[{"hnsf", ",", "hu", ",", "hv"}], "]"}], "[", "t", "]"}], ",", 
    RowBox[{"t", "\[Element]", "Reals"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614332709739581*^9, 3.6143327141728344`*^9}, {
   3.614506937574991*^9, 3.614506939836995*^9}, 3.6148618634971466`*^9, 
   3.614863136740183*^9},ExpressionUUID->"27454928-6115-433f-a4f7-\
dbc61613a8e5"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", 
    RowBox[{
     RowBox[{"kk", "^", "2"}], " ", "-", " ", 
     RowBox[{"kg", "^", "2"}], "-", 
     RowBox[{"kn", "^", "2"}]}], "]"}], ",", 
   RowBox[{"vo", "\[Element]", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6143327450406*^9, 3.614332813123494*^9}, {
   3.614332923036781*^9, 3.6143329233798003`*^9}, {3.6145069563262243`*^9, 
   3.614507048615986*^9}, 
   3.699624859587286*^9},ExpressionUUID->"6507299f-a404-43a2-bd11-\
33102d07d309"],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6145070851824503`*^9, 
  3.614507087226054*^9}},ExpressionUUID->"6ccac870-edda-492a-847b-\
fb797c49f510"],

Cell[TextData[{
 StyleBox["Example 18",
  FontColor->RGBColor[0, 0, 1]],
 ". Catenoid."
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
   3.613631784777006*^9, 3.6136317936534214`*^9}, 3.6136319442872863`*^9, {
   3.6136323634132223`*^9, 3.613632369544033*^9}, {3.6143337794257636`*^9, 
   3.6143337836740065`*^9}, {3.6996249628738956`*^9, 3.699624968417931*^9}, 
   3.6996780896229343`*^9, 
   3.699678571122665*^9},ExpressionUUID->"0ef79e79-de06-423d-9bd8-\
ad685224f2e3"],

Cell[BoxData[
 RowBox[{"?", "catenoid"}]], "Input",
 CellChangeTimes->{{3.699678589683023*^9, 
  3.699678599050755*^9}},ExpressionUUID->"9500e185-f5e1-42bb-a1fc-\
db86362f538c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"catenoid", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.61433378758123*^9, 
  3.6143337980828304`*^9}},ExpressionUUID->"e8fd0b2b-44b1-4a27-9688-\
b307a6c050f5"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"catenoid", "[", "1", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614333822495227*^9, 
  3.614333879636495*^9}},ExpressionUUID->"a4b22c85-956e-4e27-894e-\
7662b843b615"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"catenoid", "[", "ao", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", "Reals"}], ",", 
     RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614334848950937*^9, 3.6143348515860877`*^9}, {
  3.614334951923826*^9, 3.6143349775872946`*^9}, {3.6143361902226534`*^9, 
  3.6143362040454435`*^9}},ExpressionUUID->"f6d736b7-9ad1-4116-a665-\
fe92da5be9cd"],

Cell["\<\
Remember that this is the only minimal surface of revolution:\
\>", "Text",
 CellChangeTimes->{{3.617430756535014*^9, 
  3.61743078288346*^9}},ExpressionUUID->"3b482510-a982-4c34-bd56-\
06fc3984f514"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"meancurvature", "[", 
     RowBox[{"catenoid", "[", "ao", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Element]", "Reals"}], ",", 
     RowBox[{"v", "\[Element]", "Reals"}], ",", 
     RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614334848950937*^9, 3.6143348515860877`*^9}, {
   3.614334951923826*^9, 3.6143349775872946`*^9}, {3.6143361902226534`*^9, 
   3.6143362040454435`*^9}, 3.617430053285779*^9, {3.6174307303581676`*^9, 
   3.6174307367073793`*^9}},ExpressionUUID->"cc24ffdc-243a-4a41-9b9c-\
23189bca01a1"],

Cell["The geodesic curvature of a meridian is", "Text",
 CellChangeTimes->{{3.61433633999422*^9, 3.61433636132944*^9}, 
   3.6143959895035353`*^9},ExpressionUUID->"b64a256b-152f-4790-a59d-\
544aa010ab42"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "t_", "]"}], " ", ":=", "uo"}], ";", 
  RowBox[{
   RowBox[{"h2", "[", "t_", "]"}], ":=", " ", "t"}], ";", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"geodcurvature", "[", 
      RowBox[{
       RowBox[{"catenoid", "[", "ao", "]"}], ",", "h1", ",", "h2"}], "]"}], 
     "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"uo", "\[Element]", "Reals"}], ",", 
      RowBox[{"t", "\[Element]", "Reals"}], ",", 
      RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614335163132907*^9, 3.6143352204111834`*^9}, {
   3.614335253212059*^9, 3.614335367557599*^9}, 3.614335503949401*^9, 
   3.6145073265928745`*^9, 3.6148618635127463`*^9, 
   3.614863136755783*^9},ExpressionUUID->"726f1b77-5929-4857-9939-\
809623666c1c"],

Cell[" The meridians are geodesics.", "Text",
 CellChangeTimes->{{3.6145072358007145`*^9, 
  3.6145072494975386`*^9}},ExpressionUUID->"3df20ee9-149e-4576-b7e4-\
03231ded255b"],

Cell["Its normal curvature :", "Text",
 CellChangeTimes->{{3.6143363759432755`*^9, 3.6143363979705353`*^9}, {
  3.614507283645999*^9, 
  3.614507284753601*^9}},ExpressionUUID->"f977eb2b-aaf3-49ba-9760-\
43fd3bdd9630"],

Cell[BoxData[
 RowBox[{"kn", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"normalcurvature", "[", 
      RowBox[{
       RowBox[{"catenoid", "[", "ao", "]"}], ",", "h1", ",", "h2"}], "]"}], 
     "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"uo", "\[Element]", "Reals"}], ",", 
      RowBox[{"t", "\[Element]", "Reals"}], ",", 
      RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614335163132907*^9, 3.6143352204111834`*^9}, {
   3.614335253212059*^9, 3.614335367557599*^9}, 3.614335503949401*^9, {
   3.6143360854696617`*^9, 3.6143361025496387`*^9}, {3.614507348666913*^9, 
   3.614507356794527*^9}, 3.614861863528346*^9, 
   3.614863136755783*^9},ExpressionUUID->"459287d9-4426-485c-bef5-\
eeebdd373050"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sx", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"catenoid", "[", "ao", "]"}], "[", 
   RowBox[{"uo", ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6143966521458993`*^9, 3.6143966702887306`*^9}, {
  3.6143967042499905`*^9, 3.6143967161684113`*^9}, {3.6143967976629543`*^9, 
  3.6143968015005617`*^9}, {3.6145073821445723`*^9, 
  3.6145073949989944`*^9}},ExpressionUUID->"4b853b8b-55c7-41c8-8de4-\
67762e1842a1"],

Cell[BoxData[
 RowBox[{"sx", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.614396727759232*^9, 
  3.6143967316436386`*^9}},ExpressionUUID->"47c4d343-93e8-49ed-9901-\
22b45b63ff42"],

Cell[BoxData[
 RowBox[{"kk", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"curvature", "[", "sx", "]"}], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"uo", "\[Element]", "Reals"}], ",", 
      RowBox[{"t", "\[Element]", "Reals"}], ",", 
      RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614396815415786*^9, 3.6143968606402655`*^9}, {
   3.614507412595825*^9, 3.6145074240930457`*^9}, 3.6148618635439463`*^9, 
   3.614863136755783*^9},ExpressionUUID->"67b7ac97-57ba-4c98-95f3-\
facfb4531ffb"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"kk", "^", "2"}], "-", 
   RowBox[{"kn", "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614396897955531*^9, 3.614396932634392*^9}, 
   3.614397004098117*^9, 3.6143972530589542`*^9, {3.61450748368515*^9, 
   3.614507504776387*^9}},ExpressionUUID->"47d4e09e-40c0-406c-9f18-\
d83c3069b672"],

Cell["The geodesic curvature of the generating circles  v = vo is", "Text",
 CellChangeTimes->{{3.6143366537701664`*^9, 
  3.6143366972176514`*^9}},ExpressionUUID->"ce281940-477b-42f9-8ec6-\
bb4fd9951a85"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "t_", "]"}], " ", ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"h2", "[", "t_", "]"}], ":=", " ", "vo"}], ";", " ", 
  RowBox[{"kg1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"geodcurvature", "[", 
       RowBox[{
        RowBox[{"catenoid", "[", "ao", "]"}], ",", "h1", ",", "h2"}], "]"}], 
      "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", "\[Element]", "Reals"}], ",", 
       RowBox[{"vo", "\[Element]", "Reals"}], ",", 
       RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.614335163132907*^9, 3.6143352204111834`*^9}, {
   3.614335253212059*^9, 3.614335367557599*^9}, 3.614335503949401*^9, {
   3.6143365726285257`*^9, 3.6143365995500655`*^9}, {3.614507543948056*^9, 
   3.614507584570527*^9}, 3.6148618635595465`*^9, 
   3.614863136755783*^9},ExpressionUUID->"8c0a9494-402a-4adb-a7cd-\
68934503b2cc"],

Cell["It is a geodesic for vo = 0 only.", "Text",
 CellChangeTimes->{{3.6143367097293673`*^9, 
  3.614336749553645*^9}},ExpressionUUID->"d4c9e92c-9ac0-4bb3-9f6b-\
314310947faa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h1", "[", "t_", "]"}], " ", ":=", "t"}], ";", 
  RowBox[{
   RowBox[{"h2", "[", "t_", "]"}], ":=", " ", "vo"}], ";", " ", 
  RowBox[{"kn1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"normalcurvature", "[", 
       RowBox[{
        RowBox[{"catenoid", "[", "ao", "]"}], ",", "h1", ",", "h2"}], "]"}], 
      "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", "\[Element]", "Reals"}], ",", 
       RowBox[{"vo", "\[Element]", "Reals"}], ",", 
       RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.614335163132907*^9, 3.6143352204111834`*^9}, {
   3.614335253212059*^9, 3.614335367557599*^9}, 3.614335503949401*^9, {
   3.6143365726285257`*^9, 3.6143365995500655`*^9}, {3.614507543948056*^9, 
   3.614507584570527*^9}, {3.6145076250993986`*^9, 3.6145076497474422`*^9}, 
   3.6148618635751467`*^9, 
   3.614863136755783*^9},ExpressionUUID->"e9889ad6-33dd-48cb-9ed5-\
1f1e4034f039"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sx", "[", "t_", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"catenoid", "[", "ao", "]"}], "[", 
   RowBox[{"t", ",", "vo"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6145076705110784`*^9, 
  3.614507738542798*^9}},ExpressionUUID->"60e3b735-7996-4e8b-b982-\
9a078f8b923d"],

Cell[BoxData[
 RowBox[{"kk1", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"curvature", "[", "sx", "]"}], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"t", "\[Element]", "Reals"}], ",", 
      RowBox[{"vo", "\[Element]", "Reals"}], ",", 
      RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.614507752239622*^9, 3.614507799242504*^9}, 
   3.614861863590747*^9, 
   3.614863136755783*^9},ExpressionUUID->"5a4c921b-6053-4346-9281-\
d34d563a00d5"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", 
    RowBox[{
     RowBox[{"kk1", "^", "2"}], "-", 
     RowBox[{"kn1", "^", "2"}], "-", 
     RowBox[{"kg1", "^", "2"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vo", "\[Element]", "Reals"}], ",", 
     RowBox[{"ao", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6145078278997545`*^9, 
  3.61450790487029*^9}},ExpressionUUID->"ec38d85b-68fd-447c-afe2-\
394f023e3997"],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6145079169291115`*^9, 
  3.614507921234719*^9}},ExpressionUUID->"6c7543da-33f7-4d12-9d0b-\
bb09d6baaf07"],

Cell[TextData[{
 StyleBox["Example 19",
  FontColor->RGBColor[0, 0, 1]],
 ". Surfaces of revolution"
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
   3.613631784777006*^9, 3.6136317936534214`*^9}, 3.6136319442872863`*^9, {
   3.6136323634132223`*^9, 3.613632369544033*^9}, {3.614337018522029*^9, 
   3.614337032273816*^9}, {3.699624990721599*^9, 
   3.69962499369748*^9}},ExpressionUUID->"375fb261-0a77-44ed-b863-\
38f4e376f3da"],

Cell[TextData[{
 "We consider the special surfaces of revolution with  an unspecified \
function f[z], see Subsection ",
 ButtonBox["3.8.2",
  BaseStyle->"Hyperlink",
  ButtonData->"sfrev"],
 "."
}], "Text",
 CellChangeTimes->{{3.613632210517354*^9, 3.6136322491742215`*^9}, {
  3.614337045025545*^9, 3.614337100169699*^9}, {3.614337139193931*^9, 
  3.6143371486734734`*^9}, {3.6143371788692007`*^9, 3.614337178873201*^9}, {
  3.614337255633591*^9, 
  3.614337261929951*^9}},ExpressionUUID->"6d1242e5-5562-4ccd-99d7-\
8507fc6faa9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sfr", "[", "f", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6143369034754486`*^9},ExpressionUUID->"969f0546-2009-42db-aaed-\
28a108d5a8b6"],

Cell["The meridians of a surface of revolution are geodesics:", "Text",
 CellChangeTimes->{{3.6145105285608983`*^9, 3.6145105522417397`*^9}, 
   3.617441960564849*^9},ExpressionUUID->"d0c54d18-d6c3-4532-ac52-\
d090c75f5bcc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"sx", ",", "hu", ",", "hv"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.6143373012522*^9, 
   3.6143373205003014`*^9}, 3.614337396340639*^9, {3.6143374303895864`*^9, 
   3.614337446300497*^9}, {3.61451029605809*^9, 
   3.6145103278509455`*^9}},ExpressionUUID->"443d36e7-168b-4293-ba7a-\
e7e54f362a1a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", " ", "s"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], " ", ":=", " ", "vo"}], ";", 
  RowBox[{"kg", " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"geodcurvature", "[", 
      RowBox[{
       RowBox[{"sfr", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
     "s", "]"}], " ", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.61433920555312*^9, 3.6143392193249083`*^9}, {3.6145080441629343`*^9, 
   3.614508046003738*^9}, {3.6145097196370773`*^9, 3.6145097964828124`*^9}, 
   3.614861863606347*^9, 
   3.614863136755783*^9},ExpressionUUID->"9c924071-c4d2-402e-889e-\
d547b1061ef1"],

Cell[BoxData[
 RowBox[{"kn", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"sfr", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", "s",
     "]"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.6145080216832952`*^9, 3.6145080231028976`*^9}, 3.614861863621947*^9, 
   3.614863136771383*^9},ExpressionUUID->"f801c683-07a0-4381-9e9a-\
4f32b3178fee"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"sfr", "[", "f", "]"}], "[", 
    RowBox[{"s", ",", "vo"}], "]"}]}], ";", 
  RowBox[{"kk", " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], ",", 
     RowBox[{"s", "\[Element]", "Reals"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6143402822007008`*^9, 3.6143403642143917`*^9}, {
   3.614340406997839*^9, 3.6143404223017144`*^9}, {3.6145101194969797`*^9, 
   3.614510178839484*^9}, 3.6145103356353593`*^9, 3.6148618636375465`*^9, 
   3.614863136771383*^9},ExpressionUUID->"d2647a66-8b7b-4c78-b446-\
df0447098788"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"%", "^", "2"}], "-", 
   RowBox[{"%%", "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614510431934328*^9, 
  3.61451046704999*^9}},ExpressionUUID->"52e3d48d-afcd-483c-80fb-\
a07e91faa225"],

Cell["For the generating circles we obtain the following results:", "Text",
 CellChangeTimes->{{3.6145106139710484`*^9, 
  3.6145106484627085`*^9}},ExpressionUUID->"b69c14d5-151b-48d5-b1db-\
899e1cc9c930"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"sx", ",", "hu", ",", "hv"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.6143373012522*^9, 
   3.6143373205003014`*^9}, 3.614337396340639*^9, {3.6143374303895864`*^9, 
   3.614337446300497*^9}, {3.61451029605809*^9, 
   3.6145103278509455`*^9}},ExpressionUUID->"c6c96354-b36b-43a5-9fd6-\
67a5e29a0eff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", " ", "uo"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], " ", ":=", " ", "s"}], ";", 
  RowBox[{"kg1", " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"geodcurvature", "[", 
       RowBox[{
        RowBox[{"sfr", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", 
      "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Element]", "Reals"}], ",", 
       RowBox[{
        RowBox[{"f", "[", "uo", "]"}], ">", "0"}]}], "}"}]}], " ", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.61433920555312*^9, 3.6143392193249083`*^9}, {3.6145080441629343`*^9, 
   3.614508046003738*^9}, {3.6145097196370773`*^9, 3.6145097964828124`*^9}, {
   3.614510676839159*^9, 3.614510701627602*^9}, 3.614511028260976*^9, 
   3.6148618636531467`*^9, 
   3.614863136771383*^9},ExpressionUUID->"82aef66a-ffb1-4625-9c5a-\
0c60fb70d95c"],

Cell[BoxData[
 RowBox[{"kn1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"normalcurvature", "[", 
     RowBox[{
      RowBox[{"sfr", "[", "f", "]"}], ",", "hu", ",", "hv"}], "]"}], "[", "s",
     "]"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.6145080216832952`*^9, 3.6145080231028976`*^9}, 3.6145107301132526`*^9, 
   3.614861863668747*^9, 
   3.614863136771383*^9},ExpressionUUID->"e7966a5e-bee2-4ce6-b616-\
ba957f0f31f4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"sfr", "[", "f", "]"}], "[", 
    RowBox[{"uo", ",", "s"}], "]"}]}], ";", 
  RowBox[{"kk1", " ", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Element]", "Reals"}], ",", 
       RowBox[{
        RowBox[{"f", "[", "uo", "]"}], ">", "0"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6143402822007008`*^9, 3.6143403642143917`*^9}, {
   3.614340406997839*^9, 3.6143404223017144`*^9}, {3.6145101194969797`*^9, 
   3.614510178839484*^9}, 3.6145103356353593`*^9, {3.6145107478816833`*^9, 
   3.614510761375707*^9}, {3.614510957171651*^9, 3.614510976578085*^9}, 
   3.614861863684347*^9, 
   3.614863136771383*^9},ExpressionUUID->"fddb8e6f-118c-4258-9d28-\
69d499cee746"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"kk1", "^", "2"}], "-", 
    RowBox[{"kg1", "^", "2"}], " ", "-", 
    RowBox[{"kn1", "^", "2"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.614510431934328*^9, 3.61451046704999*^9}, {
  3.614510786335751*^9, 
  3.6145108526046677`*^9}},ExpressionUUID->"44141c61-5f54-446a-844a-\
56291d8e2889"],

Cell["OK.", "Text",
 CellChangeTimes->{{3.6145113332883115`*^9, 
  3.614511335768716*^9}},ExpressionUUID->"ac6e1023-d466-42d1-b3d0-\
74e140706606"],

Cell[TextData[{
 StyleBox["Example 20",
  FontColor->RGBColor[0, 0, 1]],
 ". Pseudo-sphere."
}], "Text",
 CellChangeTimes->{{3.6136216629488277`*^9, 3.6136217472669764`*^9}, {
   3.6136219986458178`*^9, 3.6136220101274376`*^9}, {3.6136316409915533`*^9, 
   3.6136316447511597`*^9}, {3.613631706792469*^9, 3.6136317217996955`*^9}, {
   3.613631784777006*^9, 3.6136317936534214`*^9}, 3.6136319442872863`*^9, {
   3.6136323634132223`*^9, 3.613632369544033*^9}, {3.614337018522029*^9, 
   3.614337032273816*^9}, {3.614520626709233*^9, 3.614520632524565*^9}, {
   3.699625009361433*^9, 3.699625012753525*^9}, {3.699679228053602*^9, 
   3.699679247973428*^9}},ExpressionUUID->"6f06c8f3-ef9d-49b7-a8d4-\
409f1506de85"],

Cell["We consider the  surface of revolution named", "Text",
 CellChangeTimes->{{3.613632210517354*^9, 3.6136322491742215`*^9}, {
  3.614337045025545*^9, 3.614337100169699*^9}, {3.614337139193931*^9, 
  3.6143371486734734`*^9}, {3.6143371788692007`*^9, 3.614337178873201*^9}, {
  3.614337255633591*^9, 3.614337261929951*^9}, {3.614520784941283*^9, 
  3.614520803445341*^9}},ExpressionUUID->"b4e918e0-5221-496b-8ba3-\
62d5512d8e31"],

Cell[BoxData[
 RowBox[{"?", "pseudosphere"}]], "Input",
 CellChangeTimes->{{3.6145206567479506`*^9, 
  3.614520666822527*^9}},ExpressionUUID->"ec47b269-ddcf-4e0c-8841-\
d0288f6660e0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6143369034754486`*^9, {3.6145206979213057`*^9, 3.6145207228067293`*^9}, 
   3.614861863699947*^9, 
   3.614862881648535*^9},ExpressionUUID->"f1277c26-6793-4cfc-8995-\
886794d81165"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "1", "]"}], "[", 
  StyleBox[
   RowBox[{"0", ",", " ", 
    RowBox[{"3", "*", 
     RowBox[{"Pi", "/", "2"}]}], ",", "0.001", ",", " ", 
    RowBox[{"Pi", "-", "0.001"}]}], "MSG"], 
  StyleBox["]", "MSG"]}]], "Input",
 CellChangeTimes->{{3.6145211179693313`*^9, 3.614521219566142*^9}, 
   3.6148618637155466`*^9, 
   3.614862882927737*^9},ExpressionUUID->"60c06642-fbb4-43a5-9251-\
40173b87b7a6"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"pseudosphere", "[", "5", "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     StyleBox["0", "MSG"], 
     StyleBox[",", "MSG"], 
     StyleBox[" ", "MSG"], 
     StyleBox[
      RowBox[{
       StyleBox[
        StyleBox["2", "MSG",
         FontWeight->"Plain"],
        FontWeight->"Plain"], 
       StyleBox[
        StyleBox["*", "MSG",
         FontWeight->"Plain"],
        FontWeight->"Plain"], "Pi"}], "MSG"]}], 
    StyleBox["}", "MSG"]}], 
   StyleBox[",", "MSG"], 
   RowBox[{"{", 
    RowBox[{"v", ",", ".05", 
     StyleBox[",", "MSG"], 
     StyleBox[" ", "MSG"], "3.07"}], 
    StyleBox["}", "MSG"]}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6145211179693313`*^9, 3.614521219566142*^9}, {
   3.61458697032903*^9, 3.61458724307563*^9}, {3.614587291074375*^9, 
   3.6145873808355093`*^9}, 3.6145874129723473`*^9, {3.6145875356043615`*^9, 
   3.6145876236113954`*^9}, {3.6145876565172777`*^9, 3.614587683412816*^9}, {
   3.6145877298114696`*^9, 3.6145877299794793`*^9}, {3.614587809876049*^9, 
   3.614587847756216*^9}, {3.6145878805000887`*^9, 3.614587970652245*^9}, {
   3.614588043044386*^9, 3.6145881118043184`*^9}, 3.614861863746747*^9, 
   3.6148628843317394`*^9, {3.626855000328114*^9, 
   3.626855037107379*^9}},ExpressionUUID->"375ae5ee-701e-4d1e-ba6d-\
cc02aa9c8776"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{
  3.6189942016752872`*^9},ExpressionUUID->"410f9bd3-6bae-442c-8be6-\
5de1c5439f55"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gauss", "[", 
     RowBox[{"pseudosphere", "[", "a", "]"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"u", ">", "0"}], ",", 
     RowBox[{"v", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614520815235016*^9, 3.6145208500470066`*^9}, 
   3.614521396431258*^9, {3.614521453503523*^9, 3.614521505631504*^9}, 
   3.614861863777947*^9, 
   3.614862885376941*^9},ExpressionUUID->"aca4aa83-4457-4713-a6f9-\
4939da1acd47"],

Cell["\<\
It is constant negative, as we know already, see  Subsection 3.9.5.\
\>", "Text",
 CellChangeTimes->{{3.614582936275565*^9, 3.614582960251937*^9}, {
   3.614583309187895*^9, 3.614583327723955*^9}, {3.6145833661561527`*^9, 
   3.6145833803799667`*^9}, {3.6145834365011764`*^9, 3.6145834365021763`*^9}, 
   3.6145881791771717`*^9, {3.699700701504105*^9, 
   3.699700720591668*^9}},ExpressionUUID->"deb83465-c89f-4944-8a82-\
0a63bfa2fc16"],

Cell[BoxData[
 RowBox[{"?", "prcurvatures"}]], "Input",
 CellChangeTimes->{
  3.699687266857081*^9},ExpressionUUID->"0360f823-e82d-421b-acf8-\
60038d2acd58"],

Cell[BoxData[
 RowBox[{
  RowBox[{"prcurvatures", "[", 
   RowBox[{"pseudosphere", "[", "a", "]"}], "]"}], "[", " ", 
  RowBox[{"u", ",", " ", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.592315825904586*^9, 3.592315836169404*^9}, 
   3.592315870785865*^9, 3.592741650505703*^9, 3.5988843282017965`*^9, {
   3.612074334747755*^9, 3.612074353998189*^9}, {3.614573304329767*^9, 
   3.614573332097816*^9}, {3.614573363750272*^9, 3.614573366168276*^9}, 
   3.6148618637935467`*^9, 3.6148628872021446`*^9, 3.69968723780744*^9, 
   3.6996872974894753`*^9},ExpressionUUID->"9d9c5d1d-d32e-4379-a569-\
172ad94cd99c"],

Cell["\<\
We obtain the Gaussian curvature as the product of the principal curvatures:\
\>", "Text",
 CellChangeTimes->{{3.6145828150596323`*^9, 3.614582894979203*^9}, {
  3.6145868363523664`*^9, 3.614586850311165*^9}, {3.6174318859931164`*^9, 
  3.617431890201357*^9}},ExpressionUUID->"6006e6ee-fd20-4e6a-9802-\
fb6a7a7c6c3b"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "*", 
    RowBox[{"%", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ",", 
   RowBox[{"v", "\[Element]", " ", "Reals"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.617431089080798*^9, 3.61743118701777*^9}, 
   3.617431225752638*^9},ExpressionUUID->"edf3bf77-f5b5-4eb5-be3f-\
9be68d65d6fb"],

Cell["\<\
As for all surfaces of revolution the meridians are geodesics. For the other \
parameter curves, the circles, we obtain\
\>", "Text",
 CellChangeTimes->{{3.6174320470253267`*^9, 3.6174320687845716`*^9}, {
  3.618994352449552*^9, 
  3.6189944130712585`*^9}},ExpressionUUID->"6898518c-393e-4aae-9be4-\
67a1db505513"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hu", "[", "s_", "]"}], ":=", "s"}], ";", 
  RowBox[{
   RowBox[{"hv", "[", "s_", "]"}], " ", ":=", " ", "uo"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"kg1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"geodcurvature", "[", 
      RowBox[{
       RowBox[{"pseudosphere", "[", "a", "]"}], ",", "hu", ",", "hv"}], "]"}],
      "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", ">", "0"}], ",", 
      RowBox[{"s", ">", "0"}]}], "}"}]}], " ", "]"}]}]}], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.6145080216832952`*^9, 3.6145080231028976`*^9}, 3.614521785152492*^9, {
   3.6145218322641864`*^9, 3.6145218887524176`*^9}, {3.614522956094466*^9, 
   3.614523048511752*^9}, {3.6145835550879593`*^9, 3.614583556488039*^9}, 
   3.6145835939061794`*^9, {3.6148618638559475`*^9, 3.6148618638559475`*^9}, 
   3.6148628927713547`*^9, 
   3.6148631367869825`*^9},ExpressionUUID->"6d176526-8e49-4aa5-9a5d-\
e88f80fab0ec"],

Cell[BoxData[
 RowBox[{"kn1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"normalcurvature", "[", 
      RowBox[{
       RowBox[{"pseudosphere", "[", "a", "]"}], ",", "hu", ",", "hv"}], "]"}],
      "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", ">", "0"}], ",", 
      RowBox[{"s", ">", "0"}]}], "}"}]}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.613621793911058*^9, 3.61362190860246*^9}, 
   3.6136224537922173`*^9, {3.6136225031195035`*^9, 3.613622523134339*^9}, {
   3.6136319875929623`*^9, 3.613631994222974*^9}, 3.6136324917858477`*^9, {
   3.6139708453034763`*^9, 3.6139709222428117`*^9}, 3.6139709681380925`*^9, 
   3.613972610035379*^9, 3.6139765411438866`*^9, {3.614337351228059*^9, 
   3.6143373738843546`*^9}, {3.614339108452566*^9, 3.6143391480198298`*^9}, {
   3.6145080216832952`*^9, 3.6145080231028976`*^9}, 3.614521785152492*^9, {
   3.6145218322641864`*^9, 3.6145218887524176`*^9}, {3.614522956094466*^9, 
   3.614523048511752*^9}, {3.6145835550879593`*^9, 3.614583556488039*^9}, 
   3.6145835939061794`*^9, {3.6148618638559475`*^9, 3.6148618638559475`*^9}, 
   3.6148628927713547`*^9, 3.6148631367869825`*^9, 3.617432148730144*^9, {
   3.6174321926216545`*^9, 
   3.617432218900158*^9}},ExpressionUUID->"c132b4d8-d6bd-4097-9675-\
18767b8d3e05"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sx", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"pseudosphere", "[", "a", "]"}], "[", 
    RowBox[{"s", ",", "uo"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"kk1", " ", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"curvature", "[", "sx", "]"}], "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", ">", "0"}], ",", 
      RowBox[{"s", ">", "0"}]}], "}"}]}], " ", "]"}]}]}], "Input",
 CellChangeTimes->{{3.6145864758237457`*^9, 3.614586558650483*^9}, {
   3.6145866388910723`*^9, 3.6145866895779715`*^9}, {3.614861863871547*^9, 
   3.614861863887147*^9}, 3.614862893816556*^9, 
   3.6148631367869825`*^9},ExpressionUUID->"f5d295d2-0c94-40f4-871c-\
54ca024367c5"],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"kn1", "^", "2"}], "+", 
    RowBox[{"kg1", "^", "2"}], "-", 
    RowBox[{"kk1", "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"uo", ">", "0"}]}], "}"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.6145863523506837`*^9, 3.614586387312683*^9}, {
  3.6145867153694468`*^9, 
  3.6145867620811186`*^9}},ExpressionUUID->"ba639552-d5d7-4216-aca8-\
91d68f292183"],

Cell["OK.", "Text",
 CellChangeTimes->{{3.614586770251586*^9, 
  3.614586793679926*^9}},ExpressionUUID->"54de9c56-f3dc-4bca-8309-\
8426697398cf"],

Cell[TextData[{
 "Using the local isometry of the pseudosphere with H. Poincar\[EAcute]\
\[CloseCurlyQuote]s model of the hyperbolic plane (see e.g. [",
 ButtonBox["OS3",
  BaseStyle->"Hyperlink",
  ButtonData->"OS3"],
 "],p. 255) one easily finds all geodesics of the pseudosphere. A good \
visualization  of the geodesics is the CDF-program ",
 ButtonBox["Pseudosphere Geodesics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/PseudosphereGeodesics/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/PseudosphereGeodesics/"],
 " in Wolfram ",
 ButtonBox["Demonstrations Project.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/index.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/index.html"]
}], "Text",
 CellChangeTimes->{{3.620533656797402*^9, 3.620533693067466*^9}, {
   3.620533723331519*^9, 3.6205338124076757`*^9}, {3.6205338774597893`*^9, 
   3.6205340125560265`*^9}, {3.6205345720787644`*^9, 3.620534626349869*^9}, {
   3.620534741843527*^9, 3.620534741843527*^9}, {3.620535057918519*^9, 
   3.620535074262454*^9}, {3.620535119074215*^9, 3.6205351472078247`*^9}, 
   3.620535178017508*^9, {3.6205352215883846`*^9, 
   3.6205352215883846`*^9}},ExpressionUUID->"616e33e6-ea8d-4853-ba60-\
c79e2aac6b56"],

Cell[TextData[{
 StyleBox["Exercise",
  FontColor->RGBColor[0, 0, 1]],
 ". Study this CDF program and calculate the geodesic curvature of the curves \
on the pseudosphere; it must be zero."
}], "Text",
 CellChangeTimes->{{3.620535308386937*^9, 
  3.6205354134687214`*^9}},ExpressionUUID->"b7b7252a-caf1-48ba-b43b-\
5bf794f8aa94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6178041659455204`*^9, 
  3.6178041730591326`*^9}},ExpressionUUID->"f88d29d3-485c-47b7-a204-\
f345ea0dbbd3"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
 CellChangeTimes->{{3.5881675431561174`*^9, 3.588167577236067*^9}, 
   3.5883163578378267`*^9, {3.591690059078165*^9, 3.591690069748584*^9}, {
   3.592463089910284*^9, 3.5924631116099224`*^9}, {3.5949735445390763`*^9, 
   3.594973561296035*^9}, {3.5980125441965847`*^9, 3.5980125441965847`*^9}, 
   3.598016745174763*^9, {3.614340028650199*^9, 
   3.61434006957854*^9}},ExpressionUUID->"1dfa043f-985f-4a7c-b0bd-\
c155d7a2464d"],

Cell["\<\
[B-R]  W. Blaschke, H. Reichardt. Einf\[UDoubleDot]hrung in die \
Differentialgeometrie.2. Aufl. Springer-Verlag. \
Berlin.G\[ODoubleDot]ttingen.Heidelberg. 1960.\
\>", "Text",
 CellChangeTimes->{{3.5866621958935566`*^9, 3.5866623742377577`*^9}, 
   3.5875491110897255`*^9, {3.588167593643005*^9, 3.5881676056026893`*^9}},
 CellTags->"B-R",ExpressionUUID->"65bf0289-6f9e-448e-839f-5f73100803ab"],

Cell[TextData[{
 "[G06] Alfred Gray, Simon Salamon, Elsa Abbena. Modern Differential Geometry \
of Curves and Surfaces with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ".\nThird ed. CRC Press. 2006. "
}], "Text",
 CellChangeTimes->{{3.4481738125625*^9, 3.448173840671875*^9}, {
   3.44817393246875*^9, 3.44817394509375*^9}, {3.448173979828125*^9, 
   3.448173980734375*^9}, {3.4481759745*^9, 3.448176007265625*^9}, 
   3.450237117953125*^9, {3.450237154*^9, 3.450237191546875*^9}, {
   3.450238953984375*^9, 3.450238956734375*^9}, 3.541836408394127*^9, 
   3.5418367181953497`*^9},
 CellTags->"Gray",ExpressionUUID->"6f602b7a-8edb-4aca-b794-b3546bcf47a4"],

Cell[TextData[{
 "[G06nb] Alfred Gray, Simon Salamon, Elsa Abbena. A series of 27 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebooks corresponding to the chapters of [G06], available from the \
website \n",
 ButtonBox["http://webmath2.unito.it/paginepersonali/abbena/gray/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://webmath2.unito.it/paginepersonali/abbena/gray/"], None},
  ButtonNote->"http://webmath2.unito.it/paginepersonali/abbena/gray/"]
}], "Text",
 CellChangeTimes->{{3.599201219155733*^9, 3.599201261780171*^9}, {
  3.5992013329092393`*^9, 3.599201340627681*^9}, {3.5992013935957108`*^9, 
  3.5992014308198395`*^9}, {3.599201571187868*^9, 3.599201593564148*^9}, {
  3.599201693291852*^9, 3.5992016987161627`*^9}, {3.599201729499923*^9, 
  3.599201765534984*^9}, {3.6997702034305763`*^9, 3.69977023389756*^9}},
 CellTags->"Gray2",ExpressionUUID->"908b18fe-110a-4406-a977-97e60173a74f"],

Cell["\<\
[G94] Alfred Gray. Differentialgeometrie. Klassische Theorie in moderner \
Darstellung. (\[CapitalUDoubleDot]bersetzung aus dem Amerikanischen H. Gollek).
Spektrum Akademischer Verlag, Heidelberg.Berlin.Oxford. 1994.\
\>", "Text",
 CellChangeTimes->{{3.450237198875*^9, 3.45023720096875*^9}, {
   3.450237249703125*^9, 3.450237440828125*^9}, {3.450238940359375*^9, 
   3.45023894278125*^9}, {3.454066758375*^9, 3.4540668540625*^9}, 
   3.45407173278125*^9, 3.541836408394155*^9, 3.5418367181953783`*^9},
 CellTags->"Gray3",ExpressionUUID->"049f0a6e-0111-4ebc-a240-f8c4afe3e8c2"],

Cell["\<\
[Kr] Erwin Kreyszig. Differentialgeometrie. Akademische Verlagsgesellschaft \
Geest & Portig K. G. Leipzig 1957.\
\>", "Text",
 CellChangeTimes->{{3.5906430418435745`*^9, 3.5906431143993025`*^9}, {
  3.5906432147074785`*^9, 3.590643286436404*^9}},
 CellTags->"Kr",ExpressionUUID->"dec11f5f-9442-4c48-a891-2fb4ba8aee05"],

Cell["\<\
{K-N1] S. Kobayashi, K. Nomizu. Foundations of Differential Geometry, Vol.  \
I. Interscience Publishers. New York - London. 1963.\
\>", "Text",
 CellChangeTimes->{{3.597388908321149*^9, 3.5973889165686207`*^9}, {
  3.5973889798572407`*^9, 3.597389168017003*^9}},
 CellTags->"K-N1",ExpressionUUID->"de314de3-1604-44a0-a4e1-8fbc5ee257be"],

Cell["\<\
[OS3] A. L. Onishchik, R. Sulanke. Projective and Cayley-Klein Geometries. \
Springer-Verlag. Berlin,Heidelberg. 2006.\
\>", "Text",
 CellChangeTimes->{{3.450266884375*^9, 3.45026689246875*^9}, {
   3.4502669551875*^9, 3.45026703496875*^9}, {3.450267067078125*^9, 
   3.450267115015625*^9}, 3.541836408394287*^9, 3.541836718195511*^9, {
   3.6205335043695345`*^9, 3.6205335122631483`*^9}},
 CellTags->"OS3",ExpressionUUID->"14dd576f-2729-4679-99e8-9735f1080024"],

Cell[CellGroupData[{

Cell["Homepage", "Subsubtitle",
 CellChangeTimes->{
  3.445933589770261*^9, {3.4459337168429823`*^9, 3.445933720398094*^9}, 
   3.541836408394314*^9, 
   3.541836718195538*^9},ExpressionUUID->"d1296356-b7f5-4e88-a6b7-\
4d9623b9db66"],

Cell[TextData[ButtonBox["http : // www - irm.mathematik.hu - \
berlin.de/~sulanke/",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["http://www-irm.mathematik.hu-berlin.de/~sulanke/"], None},
 ButtonNote->"http://www-irm.mathematik.hu-berlin.de/~sulanke/"]], "Text",
 CellChangeTimes->{{3.699706493381509*^9, 
  3.699706533827932*^9}},ExpressionUUID->"21937272-7853-4df9-9b41-\
b6bdf51bc994"],

Cell["e-mail: sulanke@mathematik.hu-berlin.de", "Text",
 CellChangeTimes->{{3.618995363041403*^9, 
  3.618995394834259*^9}},ExpressionUUID->"8dc6725b-d8d3-4bf4-b0ae-\
f32188d9b450"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{987, 651},
WindowMargins->{{4, Automatic}, {0, Automatic}},
ShowSelection->True,
ShowCellTags->True,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.1 for Linux x86 (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "barrel"->{
  Cell[1512206, 40450, 839, 12, 
  13698, "Text", "ExpressionUUID" -> "43216cae-9973-4c5f-8e44-7b29a277faa0",
   CellTags->"barrel"]},
 "bastr"->{
  Cell[694199, 18378, 441, 9, 
  48997, "Text", "ExpressionUUID" -> "36a7c052-766f-445a-9b18-ba1f42c2759f",
   CellTags->"bastr"]},
 "B-R"->{
  Cell[2974195, 79471, 405, 7, 
  105, "Text", "ExpressionUUID" -> "65bf0289-6f9e-448e-839f-5f73100803ab",
   CellTags->"B-R"]},
 "cij"->{
  Cell[1009898, 26800, 402, 9, 
  14310, "Text", "ExpressionUUID" -> "a2fd810c-c835-4380-ae90-2d98cf5c806f",
   CellTags->"cij"]},
 "cone"->{
  Cell[165980, 4237, 244, 6, 
  98113, "Text", "ExpressionUUID" -> "9eaeaff0-9343-4c42-accf-74fc5d252e11",
   CellTags->"cone"]},
 "dtt(1)"->{
  Cell[1758829, 47037, 508, 12, 
  70, "Text", "ExpressionUUID" -> "9f6db39f-e9cc-4637-990d-0526d5a66653",
   CellTags->"dtt(1)"]},
 "Ex1.1.3"->{
  Cell[151509, 3822, 192, 3, 
  98113, "Input", "ExpressionUUID" -> "ac5f48dd-ebe1-40d4-934c-4f1c34b77a5f",
   CellTags->"Ex1.1.3"]},
 "figsph3"->{
  Cell[177929, 4558, 405, 9, 
  98113, "Input", "ExpressionUUID" -> "4b6a0a77-3b13-42e9-9691-7fbbad5960bb",
   CellTags->"figsph3"]},
 "fund1"->{
  Cell[282489, 7459, 1269, 30, 
  165363, "Input", "ExpressionUUID" -> "6d0b18c6-1dcc-4a02-84e4-34ce8c69bcd7",
   CellTags->"fund1"],
  Cell[1710377, 45780, 341, 7, 
  1257, "Text", "ExpressionUUID" -> "72ae63ed-a570-42d3-b1c5-fb41d8c67501",
   CellTags->"fund1"]},
 "geodc"->{
  Cell[1143417, 30439, 1435, 31, 
  20547, "Text", "ExpressionUUID" -> "1c91ffc1-fe35-4dfb-9a57-8d400a598305",
   CellTags->"geodc"]},
 "Gray"->{
  Cell[2974603, 79480, 664, 13, 
  137, "Text", "ExpressionUUID" -> "6f602b7a-8edb-4aca-b794-b3546bcf47a4",
   CellTags->"Gray"]},
 "Gray2"->{
  Cell[2975270, 79495, 924, 17, 
  137, "Text", "ExpressionUUID" -> "908b18fe-110a-4406-a977-97e60173a74f",
   CellTags->"Gray2"]},
 "Gray3"->{
  Cell[2976197, 79514, 588, 9, 
  137, "Text", "ExpressionUUID" -> "049f0a6e-0111-4ebc-a240-f8c4afe3e8c2",
   CellTags->"Gray3"]},
 "Gsf"->{
  Cell[71804, 1696, 226, 3, 
  64, "Subsubsection", "ExpressionUUID" -> "ef0056b5-478d-4b80-8800-
   ceb18e11bfaf",
   CellTags->"Gsf"]},
 "g(i"->{
  Cell[297121, 7853, 1912, 35, 
  224916, "Text", "ExpressionUUID" -> "15b49bd8-af68-42dc-94ff-bbe33ba5bc59",
   CellTags->"g(i"],
  Cell[299036, 7890, 1809, 32, 
  234037, "Text", "ExpressionUUID" -> "7d57fac0-f7a8-4248-b16e-a41a8aca77a6",
   CellTags->"g(i"]},
 "helix"->{
  Cell[1286784, 34253, 761, 10, 
  75, "Subsubsection", "ExpressionUUID" -> "3abc168c-34a2-4447-
   ac4f-468453c34aa0",
   CellTags->"helix"],
  Cell[1328102, 35406, 800, 10, 
  64, "Subsubsection", "ExpressionUUID" -> "c46a0b57-65b8-4ab5-a5a6-
   aacc53df653a",
   CellTags->"helix"]},
 "Info363708329049-6824778"->{
  Cell[648928, 17161, 633, 11, 
  70, "Print", "ExpressionUUID" -> "04379eeb-ac44-4e25-a095-664f5f17361b",
   CellTags->"Info363708329049-6824778"]},
 "Info373708329049-6824778"->{
  Cell[727496, 19298, 461, 8, 
  70, "Print", "ExpressionUUID" -> "0506b40b-363b-4965-8d77-a32dc3d4feaa",
   CellTags->"Info373708329049-6824778"]},
 "Info873708329053-6824778"->{
  Cell[1830539, 48994, 493, 9, 
  70, "Print", "ExpressionUUID" -> "616128de-0eac-45b2-9bee-f48bf4d355da",
   CellTags->"Info873708329053-6824778"]},
 "Info883708329053-6824778"->{
  Cell[1832497, 49049, 405, 8, 
  70, "Print", "ExpressionUUID" -> "80527308-c6dd-4277-8ecb-d92bd0935294",
   CellTags->"Info883708329053-6824778"]},
 "Info893708329053-6824778"->{
  Cell[2379132, 64199, 465, 9, 
  70, "Print", "ExpressionUUID" -> "18686a5e-5560-4bb2-9b0d-5684365b14c0",
   CellTags->"Info893708329053-6824778"]},
 "intcond"->{
  Cell[738651, 19637, 280, 4, 
  75, "Subsubsection", "ExpressionUUID" -> "
   08bde261-96d9-4ec4-8aba-101d9a66df0b",
   CellTags->"intcond"]},
 "Kr"->{
  Cell[2976788, 79525, 329, 6, 
  105, "Text", "ExpressionUUID" -> "dec11f5f-9442-4c48-a891-2fb4ba8aee05",
   CellTags->"Kr"]},
 "K-N1"->{
  Cell[2977120, 79533, 347, 6, 
  105, "Text", "ExpressionUUID" -> "de314de3-1604-44a0-a4e1-8fbc5ee257be",
   CellTags->"K-N1"]},
 "lem2.1.1"->{
  Cell[770974, 20417, 681, 11, 
  68485, "Text", "ExpressionUUID" -> "52cd7c6c-5159-46e7-907b-111e15782e55",
   CellTags->"lem2.1.1"]},
 "nor"->{
  Cell[174990, 4471, 1172, 33, 
  230109, "Input", "ExpressionUUID" -> "645d395f-c346-4b65-b4c9-3797feb83265",
   InitializationCell->True,
   CellTags->"nor"]},
 "OS3"->{
  Cell[2977470, 79541, 472, 8, 
  105, "Text", "ExpressionUUID" -> "14dd576f-2729-4679-99e8-9735f1080024",
   CellTags->"OS3"]},
 "polco"->{
  Cell[834618, 22154, 299, 7, 
  19927, "Text", "ExpressionUUID" -> "dcc8e844-58e8-4107-a0ed-93d6e9e46201",
   CellTags->"polco"]},
 "ptr"->{
  Cell[345930, 9149, 1260, 36, 
  195462, "Text", "ExpressionUUID" -> "5f9e9458-8c19-42dc-a97b-adfdb87b7562",
   CellTags->"ptr"]},
 "rgT"->{
  Cell[285818, 7539, 2137, 56, 
  358438, "Input", "ExpressionUUID" -> "a2d8ecd2-fd87-4a23-ac18-e316cb4b914f",
   Evaluatable->False,
   CellTags->"rgT"]},
 "sfrev"->{
  Cell[1417219, 37807, 1315, 24, 
  13698, "Text", "ExpressionUUID" -> "a49f22f4-32d7-4119-aca4-5ccff7874c3c",
   CellTags->"sfrev"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"barrel", 2979198, 79592},
 {"bastr", 2979345, 79596},
 {"B-R", 2979487, 79600},
 {"cij", 2979626, 79604},
 {"cone", 2979768, 79608},
 {"dtt(1)", 2979911, 79612},
 {"Ex1.1.3", 2980057, 79616},
 {"figsph3", 2980205, 79620},
 {"fund1", 2980351, 79624},
 {"geodc", 2980629, 79631},
 {"Gray", 2980775, 79635},
 {"Gray2", 2980918, 79639},
 {"Gray3", 2981062, 79643},
 {"Gsf", 2981203, 79647},
 {"g(i", 2981351, 79652},
 {"helix", 2981626, 79659},
 {"Info363708329049-6824778", 2981944, 79668},
 {"Info373708329049-6824778", 2982125, 79672},
 {"Info873708329053-6824778", 2982305, 79676},
 {"Info883708329053-6824778", 2982486, 79680},
 {"Info893708329053-6824778", 2982667, 79684},
 {"intcond", 2982831, 79688},
 {"Kr", 2982984, 79693},
 {"K-N1", 2983123, 79697},
 {"lem2.1.1", 2983268, 79701},
 {"nor", 2983414, 79705},
 {"OS3", 2983586, 79710},
 {"polco", 2983727, 79714},
 {"ptr", 2983869, 79718},
 {"rgT", 2984011, 79722},
 {"sfrev", 2984179, 79727}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 229, 6, 224, "Title", "ExpressionUUID" -> \
"d91aa4b7-bcd9-45a5-9a98-c281548a33ed"],
Cell[812, 30, 361, 5, 77, "Subtitle", "ExpressionUUID" -> \
"2ee9d221-e9ec-4152-a9bb-44db9c445c55"],
Cell[1176, 37, 841, 15, 115, "Text", "ExpressionUUID" -> \
"9afc5a46-e66d-481f-987a-f5665aaca679"],
Cell[CellGroupData[{
Cell[2042, 56, 261, 5, 67, "Subsection", "ExpressionUUID" -> \
"11494bff-4cd3-44ec-8866-836e688f5af9"],
Cell[2306, 63, 11351, 191, 2033, "Text", "ExpressionUUID" -> \
"906fac9a-13bc-46f3-9a75-47ea3553ddfc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13694, 259, 206, 4, 67, "Subsection", "ExpressionUUID" -> \
"61d05635-94c6-4ba8-aadc-5296c2792d18"],
Cell[13903, 265, 3156, 45, 505, "Text", "ExpressionUUID" -> \
"17ae517b-45fd-4c8a-837e-cbad241090ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17096, 315, 252, 4, 67, "Subsection", "ExpressionUUID" -> \
"171f4455-19f7-404c-a837-1b71b1446006"],
Cell[17351, 321, 780, 13, 213, "Text", "ExpressionUUID" -> \
"acd044ff-55e4-469a-b6d2-253dacacc7df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18168, 339, 231, 4, 97, "Section", "ExpressionUUID" -> \
"b1beae35-4a24-416f-b170-8dda257d634e"],
Cell[CellGroupData[{
Cell[18424, 347, 159, 3, 67, "Subsection", "ExpressionUUID" -> \
"cfe94814-9eea-4f8b-9e30-778e1d47440b"],
Cell[18586, 352, 377, 8, 279, "Text", "ExpressionUUID" -> \
"438e5a64-e05b-4570-a20e-781382ad67c1"],
Cell[18966, 362, 589, 11, 163, "Input", "ExpressionUUID" -> \
"43e6512c-e599-454e-b411-0d66579e11ab",
 Evaluatable->False,
 InitializationCell->True],
Cell[19558, 375, 154, 3, 168, "Text", "ExpressionUUID" -> \
"223a2058-a892-4bc0-9aed-431f3201383e"],
Cell[CellGroupData[{
Cell[19737, 382, 681, 12, 244, "Input", "ExpressionUUID" -> \
"ae0b8abf-15ee-4571-bc52-9b831cde0262",
 InitializationCell->True],
Cell[20421, 396, 172, 3, 70, "Output", "ExpressionUUID" -> \
"257b5042-9650-448b-a51d-5cc99b637040"]
}, Open  ]],
Cell[20608, 402, 664, 11, 387, "Text", "ExpressionUUID" -> \
"f061795b-d55b-4245-93d0-c82799939a4d"],
Cell[21275, 415, 86, 0, 163, "Input", "ExpressionUUID" -> \
"546363b4-4279-4db8-b7d1-4df183c52794"],
Cell[21364, 417, 1052, 19, 607, "Text", "ExpressionUUID" -> \
"901b3b9e-c459-4e07-b960-307b9786fd81"],
Cell[22419, 438, 431, 8, 279, "Text", "ExpressionUUID" -> \
"8616df95-ef53-495d-b5a9-3b2185daf998"],
Cell[22853, 448, 210, 3, 168, "Text", "ExpressionUUID" -> \
"497810bd-1b48-449b-9cbf-5de8dcfd4333"]
}, Closed]],
Cell[CellGroupData[{
Cell[23100, 456, 221, 4, 53, "Subsection", "ExpressionUUID" -> \
"f39ee561-ff90-4f73-8cdb-8ce5ffc7f832"],
Cell[23324, 462, 309, 7, 162994, "Text", "ExpressionUUID" -> \
"02858510-ca01-4926-a195-93f6a46c3357"],
Cell[23636, 471, 633, 10, 98113, "Input", "ExpressionUUID" -> \
"f1f680a0-9ce0-4c12-8ed6-407e29326026",
 InitializationCell->True],
Cell[24272, 483, 333, 7, 162994, "Text", "ExpressionUUID" -> \
"99727518-a240-4c51-8c37-a63fb62c2c56"],
Cell[24608, 492, 226, 5, 98113, "Input", "ExpressionUUID" -> \
"82c185fa-c99b-4493-91c4-47a4be4aed36",
 InitializationCell->True],
Cell[24837, 499, 390, 7, 98113, "Text", "ExpressionUUID" -> \
"aa38288c-d6f8-41d6-b03d-4b235a7b6aa0"],
Cell[25230, 508, 276, 6, 98113, "Input", "ExpressionUUID" -> \
"a2449302-2161-465d-bef7-c7facdb28382",
 InitializationCell->True],
Cell[25509, 516, 729, 14, 230109, "Text", "ExpressionUUID" -> \
"3c8e655c-fe20-45cd-bb45-ff16d833f233"],
Cell[26241, 532, 498, 10, 98113, "Input", "ExpressionUUID" -> \
"07750388-505c-4aa2-b32b-6f7a39ca470e",
 InitializationCell->True],
Cell[26742, 544, 192, 4, 98113, "Input", "ExpressionUUID" -> \
"06305b5b-f269-4d80-8839-8adc0b78a7d5"]
}, Closed]],
Cell[CellGroupData[{
Cell[26971, 553, 231, 4, 53, "Subsection", "ExpressionUUID" -> \
"bc68fb4d-dce9-49d5-b942-8087a8549533"],
Cell[CellGroupData[{
Cell[27227, 561, 239, 4, 53, "Subsubsection", "ExpressionUUID" -> \
"235e96cf-caf5-4c0d-a00d-da3dfe77ee8a"],
Cell[27469, 567, 500, 9, 2147483647, "Text", "ExpressionUUID" -> \
"459029d8-635c-4cb5-8be9-a5a93b395af3"],
Cell[27972, 578, 176, 4, 2147483647, "Input", "ExpressionUUID" -> \
"95af507d-65e5-4e20-840b-49356011b620"],
Cell[28151, 584, 179, 3, 2147483647, "Text", "ExpressionUUID" -> \
"59b8ff17-d039-4b29-911f-ae1c1ec413fa"],
Cell[28333, 589, 173, 4, 2147483647, "Input", "ExpressionUUID" -> \
"26cce74a-aa65-485a-9a82-c23375e1ca37"],
Cell[28509, 595, 472, 9, 2147483647, "Text", "ExpressionUUID" -> \
"acc270a5-ba57-45e3-a325-1c99b89b7f92"],
Cell[28984, 606, 406, 10, 2147483647, "Text", "ExpressionUUID" -> \
"4ae7f3e0-bac0-4368-90ea-2a14bf662802"],
Cell[29393, 618, 168, 4, 2147483647, "Input", "ExpressionUUID" -> \
"73b2565a-a3e5-4a21-9fc4-a74d9e3a0851"],
Cell[29564, 624, 549, 15, 2147483647, "Text", "ExpressionUUID" -> \
"cb59419b-c0e6-44fb-a9e4-902da3397f44"],
Cell[30116, 641, 171, 4, 2147483647, "Input", "ExpressionUUID" -> \
"9b019aa0-4206-4876-ac06-56581494a0af"],
Cell[30290, 647, 487, 9, 2147483647, "Text", "ExpressionUUID" -> \
"1740bd6c-081e-4ba6-a537-9e1c4080bf23"]
}, Closed]],
Cell[CellGroupData[{
Cell[30814, 661, 342, 5, 42, "Subsubsection", "ExpressionUUID" -> \
"8861c3be-2a00-4aff-82e4-dc542f20f68c"],
Cell[CellGroupData[{
Cell[31181, 670, 406, 8, 2147483647, "Input", "ExpressionUUID" -> \
"1d863dec-c94b-49c5-b816-0d2997b2d588",
 InitializationCell->True],
Cell[31590, 680, 16760, 411, 70, "Print", "ExpressionUUID" -> \
"f0ad0d3d-1f94-40b9-8fb0-d6fb5aa8e639"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[48399, 1097, 237, 4, 42, "Subsubsection", "ExpressionUUID" -> \
"8162adf9-0d6a-4cd8-bea4-3e7999b325f4"],
Cell[CellGroupData[{
Cell[48661, 1105, 258, 6, 2147483647, "Input", "ExpressionUUID" -> \
"eb229808-b0a4-4656-9968-9091eeae0290",
 InitializationCell->True],
Cell[48922, 1113, 6782, 169, 70, "Print", "ExpressionUUID" -> \
"131a30a2-58cd-4949-956f-7df3efc53211"]
}, Open  ]],
Cell[55719, 1285, 258, 6, 2147483647, "Input", "ExpressionUUID" -> \
"2f75035e-6f87-403b-8e2f-c1ec9689aef9"]
}, Closed]],
Cell[CellGroupData[{
Cell[56014, 1296, 213, 4, 42, "Subsubsection", "ExpressionUUID" -> \
"5da4ef17-4e19-4c10-a4a3-f6ff952e2408"],
Cell[56230, 1302, 320, 5, 31151587, "Text", "ExpressionUUID" -> \
"91529811-9f00-4124-8ecb-e84eb41d3f13"],
Cell[CellGroupData[{
Cell[56575, 1311, 288, 6, 46505947, "Input", "ExpressionUUID" -> \
"4106378d-0f16-4428-8e4b-21faa606c071",
 InitializationCell->True],
Cell[56866, 1319, 13793, 340, 70, "Print", "ExpressionUUID" -> \
"90a98186-8c65-413e-b807-b1224f88b5ee"]
}, Open  ]],
Cell[70674, 1662, 273, 7, 31003965, "Input", "ExpressionUUID" -> \
"cfc8a4e9-ef4b-497b-8014-ecb042e15126"],
Cell[70950, 1671, 250, 5, 31003965, "Input", "ExpressionUUID" -> \
"d2e1e341-829d-46d9-aee1-834290d053ba"],
Cell[71203, 1678, 251, 5, 31003965, "Input", "ExpressionUUID" -> \
"45799b1b-ab81-4f65-aa22-7198b4183480"],
Cell[71457, 1685, 310, 6, 31003965, "Input", "ExpressionUUID" -> \
"6ebd0982-52fc-42fb-b850-ef398d04f73f"]
}, Closed]],
Cell[CellGroupData[{
Cell[71804, 1696, 226, 3, 64, "Subsubsection", "ExpressionUUID" -> \
"ef0056b5-478d-4b80-8800-ceb18e11bfaf",
 CellTags->"Gsf"],
Cell[72033, 1701, 288, 7, 105136605, "Text", "ExpressionUUID" -> \
"543d793c-d8bd-4193-a106-17cbc4560a07"],
Cell[72324, 1710, 178, 4, 104638380, "Input", "ExpressionUUID" -> \
"ce553396-f604-4b8a-9819-1bf99403a7f0"],
Cell[72505, 1716, 347, 7, 90811045, "Input", "ExpressionUUID" -> \
"c9bef079-e16a-4f7a-bbe8-5c28139e2e67"],
Cell[72855, 1725, 187, 4, 104638380, "Input", "ExpressionUUID" -> \
"3a50edde-7438-4353-8305-93f82ad770d7"],
Cell[73045, 1731, 302, 9, 104638380, "Input", "ExpressionUUID" -> \
"aa037684-a5af-4396-a684-4743fffcbea9"],
Cell[73350, 1742, 525, 10, 178414713, "Text", "ExpressionUUID" -> \
"d1e62a04-2520-4c00-9a8d-4ffe36eea828"],
Cell[73878, 1754, 174, 4, 104638380, "Input", "ExpressionUUID" -> \
"09f62588-625b-4e80-b074-54f198c34b6e"],
Cell[74055, 1760, 191, 4, 104638380, "Input", "ExpressionUUID" -> \
"062bf915-6863-4238-9d33-d636c4809162"],
Cell[74249, 1766, 448, 13, 104638380, "Input", "ExpressionUUID" -> \
"a5067f5b-f860-450b-a129-957fac4adea7"],
Cell[74700, 1781, 253, 4, 105136605, "Text", "ExpressionUUID" -> \
"3a77affe-98ae-4290-a1eb-c6d18c274dd0"],
Cell[74956, 1787, 177, 4, 104638380, "Input", "ExpressionUUID" -> \
"c1ccd43c-6e1f-46de-956b-5a1f066b982b"],
Cell[75136, 1793, 413, 12, 104638380, "Input", "ExpressionUUID" -> \
"834a8d8d-009b-4dd4-8ba1-e045ddf19d67"],
Cell[75552, 1807, 462, 13, 104638380, "Input", "ExpressionUUID" -> \
"b80fee63-ba7c-40d9-b570-1c30cda60d3a"],
Cell[76017, 1822, 249, 5, 104638380, "Input", "ExpressionUUID" -> \
"e8fc7502-b25b-4924-9216-a4dec290ece4"]
}, Closed]],
Cell[CellGroupData[{
Cell[76303, 1832, 262, 4, 42, "Subsubsection", "ExpressionUUID" -> \
"e7b51531-6e40-4b98-b7cb-b2ed776f1633"],
Cell[76568, 1838, 332, 7, 2147483647, "Text", "ExpressionUUID" -> \
"3526dda7-b8a3-4d6d-a857-89b592221634"],
Cell[76903, 1847, 176, 4, 2147483647, "Input", "ExpressionUUID" -> \
"5c0f7610-3570-4961-9b3b-46af35623202"],
Cell[77082, 1853, 352, 7, 2147483647, "Input", "ExpressionUUID" -> \
"e5610bbc-aa9c-4e60-8060-3fb5a1366f8d"],
Cell[77437, 1862, 187, 4, 2147483647, "Input", "ExpressionUUID" -> \
"8c31b61b-f3e9-4cc6-9638-8f64b38ed620"]
}, Closed]],
Cell[CellGroupData[{
Cell[77661, 1871, 311, 5, 42, "Subsubsection", "ExpressionUUID" -> \
"9618eda6-5c1b-4486-a845-31b760601338"],
Cell[77975, 1878, 225, 5, 2147483647, "Text", "ExpressionUUID" -> \
"e260c51f-0238-4afc-9b7e-8f7522b3d17e"],
Cell[78203, 1885, 181, 4, 2147483647, "Input", "ExpressionUUID" -> \
"ebc7a4da-e05b-41fc-8880-a45a1ff6b8c1"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78445, 1896, 715, 10, 97, "Section", "ExpressionUUID" -> \
"4b5771b4-d760-4c94-ae38-68743d778d19"],
Cell[CellGroupData[{
Cell[79185, 1910, 461, 7, 67, "Subsection", "ExpressionUUID" -> \
"47948dce-9f12-451b-9822-71f42458ee37"],
Cell[CellGroupData[{
Cell[79671, 1921, 336, 6, 53, "Subsubsection", "ExpressionUUID" -> \
"a84524ce-481d-434b-ac7e-d14f37ab32c4"],
Cell[80010, 1929, 670, 16, 98113, "Text", "ExpressionUUID" -> \
"9d552528-bb6d-434c-b324-4eb52e64b864"],
Cell[80683, 1947, 798, 19, 98113, "Input", "ExpressionUUID" -> \
"9a978b70-4ba5-4cf1-be61-65fd6e3ab4b4",
 InitializationCell->True],
Cell[81484, 1968, 332, 7, 98113, "Input", "ExpressionUUID" -> \
"ff2562bc-a4e7-46bd-b704-21cd54657606"],
Cell[81819, 1977, 405, 12, 100878, "Text", "ExpressionUUID" -> \
"e848169d-7ba1-4da0-83df-4a602e5a0671"],
Cell[82227, 1991, 179, 4, 98113, "Input", "ExpressionUUID" -> \
"1a0ba42f-6758-4764-95fe-e1f82fe6b6d0"],
Cell[82409, 1997, 355, 10, 97020, "Input", "ExpressionUUID" -> \
"f7ae1417-3d88-4a05-95a7-40bf2560b88d"],
Cell[82767, 2009, 240, 6, 98113, "Input", "ExpressionUUID" -> \
"9b6ae95d-ef51-4076-b295-fbcb06cf3959"],
Cell[83010, 2017, 490, 14, 98113, "Input", "ExpressionUUID" -> \
"cf8781fb-ee28-4f26-9dfa-1cb746513d48"],
Cell[83503, 2033, 325, 7, 165363, "Text", "ExpressionUUID" -> \
"b385c442-a6a8-485a-a55a-0a3ce5a4679a"],
Cell[83831, 2042, 3322, 63, 492832, "Text", "ExpressionUUID" -> \
"f0102807-c4d8-4b9d-bae1-64e7da8cc12b"],
Cell[87156, 2107, 171, 4, 98113, "Input", "ExpressionUUID" -> \
"a2031fe0-77b3-4928-9ca3-454d101a49f7"],
Cell[87330, 2113, 1792, 30, 297870, "Text", "ExpressionUUID" -> \
"47c20547-4b16-4702-a4e6-c4a0bed3abff"],
Cell[89125, 2145, 275, 6, 98113, "Input", "ExpressionUUID" -> \
"9fdcd6b8-7aeb-4568-b5e8-a717af86a0cf"],
Cell[89403, 2153, 2467, 52, 624316, "Text", "ExpressionUUID" -> \
"d7bcb71f-5501-4c46-b1c0-6e865045e92d"],
Cell[91873, 2207, 1231, 19, 289098, "Text", "ExpressionUUID" -> \
"67e23ab2-416d-46d6-8aa9-40e852b057eb"],
Cell[93107, 2228, 3992, 103, 807552, "Input", "ExpressionUUID" -> \
"cb85e98f-a844-4aed-8bec-f60f07a4e3fe",
 Evaluatable->False],
Cell[97102, 2333, 198, 4, 98113, "Text", "ExpressionUUID" -> \
"21e0c740-4ce4-4171-9aac-8db829d3c7af"],
Cell[97303, 2339, 118, 1, 98113, "Input", "ExpressionUUID" -> \
"8fab0c5b-43dd-4a52-91df-239d6fee8ee0"],
Cell[97424, 2342, 676, 14, 98113, "Input", "ExpressionUUID" -> \
"cae8795a-146c-409a-96a9-afc59a7b5052"],
Cell[98103, 2358, 487, 12, 98113, "Input", "ExpressionUUID" -> \
"182f7e0c-3723-4ca8-883c-cadc1ad6c298"],
Cell[98593, 2372, 513, 12, 98113, "Input", "ExpressionUUID" -> \
"140912d1-1218-4388-a7fe-667849cfb001"],
Cell[99109, 2386, 306, 6, 98113, "Input", "ExpressionUUID" -> \
"401caa83-da00-4561-ab8c-d8a191d62a1a"],
Cell[99418, 2394, 356, 8, 98113, "Input", "ExpressionUUID" -> \
"828e8299-294d-439c-95e6-fa4844cffaf9"],
Cell[99777, 2404, 402, 8, 168129, "Text", "ExpressionUUID" -> \
"1f717104-34fe-4481-ba1f-6db7172d9500"],
Cell[100182, 2414, 179, 4, 98113, "Input", "ExpressionUUID" -> \
"3424373b-ca40-4cae-8ae1-408471aeb5db"],
Cell[100364, 2420, 323, 9, 98113, "Input", "ExpressionUUID" -> \
"e5dd2f85-23f4-469e-aeaa-cb3f4825aa0a"],
Cell[100690, 2431, 165, 3, 98113, "Text", "ExpressionUUID" -> \
"5fdbf53a-3e35-4dd2-b723-bf5e8bdb5085"],
Cell[100858, 2436, 378, 8, 98113, "Input", "ExpressionUUID" -> \
"0551ebf6-c0ad-4c40-9d17-8854f091edd2"],
Cell[101239, 2446, 145, 3, 98113, "Text", "ExpressionUUID" -> \
"19ca7d63-f05b-4231-8799-2caa1ff4cb34"],
Cell[101387, 2451, 298, 8, 98113, "Input", "ExpressionUUID" -> \
"d401f6ec-f55f-4fe2-95d8-ad8888ceec79"],
Cell[101688, 2461, 343, 7, 224916, "Text", "ExpressionUUID" -> \
"fc5c2bc9-a4db-4311-9e9a-f72ec05daf9d"],
Cell[102034, 2470, 344, 9, 98113, "Input", "ExpressionUUID" -> \
"f04d00a7-425b-4208-82df-64150cf03b27"],
Cell[102381, 2481, 198, 3, 98113, "Text", "ExpressionUUID" -> \
"3d74cf57-cbac-4a0d-a752-bfddaaf0a424"],
Cell[102582, 2486, 282, 7, 98113, "Input", "ExpressionUUID" -> \
"222c3e1a-cbc0-481a-be2f-f8aa7fc24925"],
Cell[102867, 2495, 431, 9, 98113, "Input", "ExpressionUUID" -> \
"c270b07e-e4e0-4dbd-9c90-7e1bbf3f1650"],
Cell[103301, 2506, 254, 6, 98113, "Input", "ExpressionUUID" -> \
"82889054-bbd7-447f-b34b-90cbe890f155"],
Cell[103558, 2514, 306, 6, 98113, "Input", "ExpressionUUID" -> \
"4ca3642f-3ca6-4974-a554-096d1f45d5d7"],
Cell[103867, 2522, 203, 5, 98113, "Input", "ExpressionUUID" -> \
"7b953b66-7350-458d-9ce2-10be900ef5cd"],
Cell[104073, 2529, 364, 7, 98113, "Input", "ExpressionUUID" -> \
"e90ca77e-8422-4296-a742-0484d64aae05"],
Cell[104440, 2538, 588, 11, 98113, "Input", "ExpressionUUID" -> \
"09310338-bf5d-4a69-9108-b6dc79c698f9"],
Cell[105031, 2551, 467, 10, 165363, "Text", "ExpressionUUID" -> \
"d058c06d-cc60-4606-afc4-8da40dba81a5"],
Cell[105501, 2563, 173, 4, 98113, "Input", "ExpressionUUID" -> \
"2794cb73-5b99-45da-aad8-7ee657f3ad99"],
Cell[105677, 2569, 338, 9, 98113, "Input", "ExpressionUUID" -> \
"93b8db10-fb24-4fd3-859d-4633e49147c1"],
Cell[106018, 2580, 463, 8, 224916, "Text", "ExpressionUUID" -> \
"a3db7b04-ed72-43b9-b44b-65c7b19b0763"],
Cell[106484, 2590, 464, 11, 98113, "Input", "ExpressionUUID" -> \
"0d754463-aa87-4638-8e25-b22d3b205624"],
Cell[106951, 2603, 198, 3, 98113, "Text", "ExpressionUUID" -> \
"b204783c-6c14-4fcd-a09f-5573718134d9"],
Cell[107152, 2608, 331, 7, 98113, "Input", "ExpressionUUID" -> \
"c5098179-4d49-4201-ac19-f4e2d92d79bd"],
Cell[107486, 2617, 354, 10, 98113, "Input", "ExpressionUUID" -> \
"6d63dbd3-482c-4f34-b0a2-6d2715d316f1"],
Cell[107843, 2629, 283, 4, 98113, "Text", "ExpressionUUID" -> \
"7bed10d3-bf70-4338-8781-251311c9e5a7"],
Cell[108129, 2635, 237, 6, 98113, "Input", "ExpressionUUID" -> \
"b691c267-9d1d-426c-a775-5d7d3ae67480"],
Cell[108369, 2643, 167, 3, 98113, "Text", "ExpressionUUID" -> \
"fceeed76-0e6b-44e4-90ed-cbcf1c623a7a"],
Cell[108539, 2648, 472, 14, 98113, "Input", "ExpressionUUID" -> \
"5195b28d-f22e-4e0e-ab7d-94ad3faebfd9"],
Cell[109014, 2664, 182, 4, 98113, "Input", "ExpressionUUID" -> \
"6b6808c9-422b-4830-86eb-853434772257"],
Cell[109199, 2670, 144, 3, 98113, "Text", "ExpressionUUID" -> \
"ee7e09d5-85e4-427e-b12b-061fad7710c4"],
Cell[109346, 2675, 499, 13, 98113, "Input", "ExpressionUUID" -> \
"f2470a40-90a6-4a65-ab99-8ee390c001e9"],
Cell[109848, 2690, 208, 5, 98113, "Input", "ExpressionUUID" -> \
"ffcd753b-4462-40ea-8e87-6b2ef03d2a71"],
Cell[110059, 2697, 259, 4, 98113, "Text", "ExpressionUUID" -> \
"35d04a56-afd7-43a7-a351-28c35efa02f1"],
Cell[110321, 2703, 879, 23, 165363, "Input", "ExpressionUUID" -> \
"7db4a2fb-0679-469d-8164-33251c0dd42e"],
Cell[111203, 2728, 137, 3, 98113, "Input", "ExpressionUUID" -> \
"9ec28d41-7576-44ea-8ef0-1dca4a7e3097"],
Cell[111343, 2733, 263, 4, 98113, "Input", "ExpressionUUID" -> \
"cc2bde6d-57d6-4f42-bf48-35f5ad2836d1"],
Cell[111609, 2739, 186, 4, 98113, "Input", "ExpressionUUID" -> \
"c756307a-503e-4e43-9717-da671348fa88"],
Cell[111798, 2745, 238, 4, 98113, "Text", "ExpressionUUID" -> \
"1b3ecfa5-6699-41d1-957d-76515b6bf972"],
Cell[112039, 2751, 578, 14, 98113, "Input", "ExpressionUUID" -> \
"fc185909-38fb-4985-87d9-3e3164cade3c"],
Cell[112620, 2767, 284, 6, 98113, "Input", "ExpressionUUID" -> \
"cbc6815e-99a5-4285-be43-62fe625a254f"],
Cell[112907, 2775, 685, 13, 162994, "Text", "ExpressionUUID" -> \
"051c0686-e155-417d-8473-0a2528f75137"],
Cell[113595, 2790, 385, 8, 98113, "Input", "ExpressionUUID" -> \
"b39bfef9-1824-4756-9df9-3c47a7e17fa2"],
Cell[113983, 2800, 413, 8, 98113, "Input", "ExpressionUUID" -> \
"af8113bd-4f0f-49a0-be88-96821d238e6b"],
Cell[114399, 2810, 168, 3, 98113, "Text", "ExpressionUUID" -> \
"07cc3f35-7ba2-417f-9280-8b3552754989"],
Cell[114570, 2815, 465, 10, 98113, "Input", "ExpressionUUID" -> \
"cb7b850d-3409-461c-ab6b-568b38c4e2d1"],
Cell[115038, 2827, 497, 10, 98113, "Input", "ExpressionUUID" -> \
"4e54b34f-0118-418a-b070-7a4ad43c7a6c"],
Cell[115538, 2839, 232, 6, 98113, "Input", "ExpressionUUID" -> \
"695faf51-4771-4b4a-bee3-5d331a6b6e08"],
Cell[115773, 2847, 261, 5, 100878, "Text", "ExpressionUUID" -> \
"ce8ed0bc-bb41-40a6-9436-f0bce6dd11f6"],
Cell[116037, 2854, 273, 8, 98113, "Input", "ExpressionUUID" -> \
"9dc90e02-a140-4bff-8bd6-e6f327efc8d2"],
Cell[116313, 2864, 152, 3, 98113, "Text", "ExpressionUUID" -> \
"e894cc34-c25d-4dc2-b184-81dc03dbe0d6"],
Cell[116468, 2869, 281, 7, 98113, "Input", "ExpressionUUID" -> \
"57b92b7f-913a-4d42-8fec-9abf9e0e61c3"],
Cell[116752, 2878, 384, 8, 100878, "Text", "ExpressionUUID" -> \
"727c6215-7c8b-4671-a829-5c5cccfa27bf"],
Cell[117139, 2888, 238, 6, 98113, "Input", "ExpressionUUID" -> \
"ae6f1402-0e04-4475-863c-1d6ea851adae"],
Cell[117380, 2896, 312, 6, 98113, "Text", "ExpressionUUID" -> \
"ce7ce776-c810-4029-a2e7-04b8d8d89c65"],
Cell[117695, 2904, 342, 5, 100878, "Text", "ExpressionUUID" -> \
"f21020b1-ac33-46e6-9a85-0cdfd00fb957"],
Cell[118040, 2911, 196, 4, 98113, "Input", "ExpressionUUID" -> \
"b6138da3-c768-487e-abcd-bf05427dd489"],
Cell[118239, 2917, 654, 17, 165363, "Input", "ExpressionUUID" -> \
"9254e15e-86aa-4673-a7b6-93ac8941b93a",
 Evaluatable->False],
Cell[118896, 2936, 532, 12, 98113, "Input", "ExpressionUUID" -> \
"e9b42b4d-0fd2-407d-a9f1-c59965068046"],
Cell[119431, 2950, 334, 6, 98113, "Input", "ExpressionUUID" -> \
"dee2f2c3-f64e-415c-a223-e247490dbc6e"],
Cell[119768, 2958, 408, 9, 98113, "Input", "ExpressionUUID" -> \
"1a9d9d48-0ba1-434d-bb99-766ee156eab5"],
Cell[120179, 2969, 766, 18, 98113, "Input", "ExpressionUUID" -> \
"a7076517-bd00-4890-b679-f9803c15b807"],
Cell[120948, 2989, 1172, 25, 230109, "Text", "ExpressionUUID" -> \
"c0d72a51-9b96-4c6c-a3ca-86352d0ebc9c"],
Cell[122123, 3016, 617, 19, 98113, "Input", "ExpressionUUID" -> \
"e277336a-5d68-4010-8fcc-192ecd8015ec",
 Evaluatable->False],
Cell[122743, 3037, 267, 6, 98113, "Text", "ExpressionUUID" -> \
"1b5b73a7-3b16-4527-8438-4759f792a574"],
Cell[123013, 3045, 567, 17, 110242, "Input", "ExpressionUUID" -> \
"870304a1-fa45-4dd3-8569-53580664865f",
 Evaluatable->False],
Cell[123583, 3064, 997, 26, 110242, "Input", "ExpressionUUID" -> \
"0e1bfc5d-36e0-4763-8592-7daa45b3a511",
 Evaluatable->False],
Cell[124583, 3092, 886, 20, 100878, "Text", "ExpressionUUID" -> \
"a8e9048c-4915-4f3c-b458-995843528841"],
Cell[125472, 3114, 1228, 27, 100878, "Text", "ExpressionUUID" -> \
"9d01f955-fbe0-41a7-a5d2-3c46bd2630fa"],
Cell[126703, 3143, 732, 16, 98113, "Input", "ExpressionUUID" -> \
"6828496c-857b-416b-bfbd-d39181620ff9"],
Cell[127438, 3161, 179, 3, 98113, "Text", "ExpressionUUID" -> \
"1a85f12b-a520-4513-b899-813ef783e240"],
Cell[127620, 3166, 162, 4, 98113, "Input", "ExpressionUUID" -> \
"0c725e6b-2abb-44b5-906f-bdf9a58bf22d"],
Cell[127785, 3172, 898, 26, 98113, "Input", "ExpressionUUID" -> \
"62256401-9c1b-4d92-969f-ddb8ccba3c54"],
Cell[128686, 3200, 212, 3, 98113, "Text", "ExpressionUUID" -> \
"3f024191-8ec6-4c89-8178-0e3214909fde"],
Cell[128901, 3205, 1233, 30, 98113, "Input", "ExpressionUUID" -> \
"d80d5c82-c7ae-46cd-9aef-efe41e7ec577"],
Cell[130137, 3237, 185, 3, 98113, "Text", "ExpressionUUID" -> \
"d034656e-4ddb-49cc-989e-1ae041c18401"],
Cell[130325, 3242, 234, 5, 98113, "Input", "ExpressionUUID" -> \
"2593a261-fe05-43e0-9586-57dc4cd63c0b"],
Cell[130562, 3249, 959, 26, 98113, "Input", "ExpressionUUID" -> \
"ce138d6e-9d01-438c-8136-cc7b1b440206"],
Cell[131524, 3277, 1138, 32, 165363, "Input", "ExpressionUUID" -> \
"15f4cf7d-cf78-4ff0-9986-1ab8536e3d87"],
Cell[132665, 3311, 170, 3, 98113, "Text", "ExpressionUUID" -> \
"79ec762a-5abd-42e5-a3c2-8b08c1b553bb"],
Cell[132838, 3316, 1564, 39, 230109, "Input", "ExpressionUUID" -> \
"8f79e95b-fc34-4e95-bf30-1c425ab8a4eb"],
Cell[134405, 3357, 157, 3, 98113, "Text", "ExpressionUUID" -> \
"5b27ba6e-1cd7-49f3-9e63-225564a6b042"],
Cell[134565, 3362, 404, 8, 162994, "Text", "ExpressionUUID" -> \
"cdf6cc56-1efa-43e3-9a30-e2302a95fa94"],
Cell[134972, 3372, 322, 8, 98113, "Input", "ExpressionUUID" -> \
"6be695d0-03b2-4367-bd95-1dcd982e5808"],
Cell[135297, 3382, 336, 7, 162994, "Text", "ExpressionUUID" -> \
"aad9a9a8-92c2-4d2b-921a-16dcb16c45a9"],
Cell[135636, 3391, 171, 4, 98113, "Input", "ExpressionUUID" -> \
"fa8c310c-dc34-4217-bda2-fd82c6456eea"],
Cell[135810, 3397, 187, 4, 98113, "Input", "ExpressionUUID" -> \
"0b341673-aa29-4950-8647-3739ff53ad71"],
Cell[136000, 3403, 262, 7, 98113, "Input", "ExpressionUUID" -> \
"08c9287b-87e2-4bea-a9b7-7c5f9309ffc8"],
Cell[136265, 3412, 313, 8, 98113, "Input", "ExpressionUUID" -> \
"6bd4840f-2f65-4b39-8f32-b9ad5414ec3b"],
Cell[136581, 3422, 479, 13, 98113, "Input", "ExpressionUUID" -> \
"44ce372e-28a6-4285-a911-af76712aaaa8"],
Cell[137063, 3437, 663, 13, 98113, "Text", "ExpressionUUID" -> \
"fbdae33a-ef2e-4ce5-9b83-bb72710c1d73"],
Cell[137729, 3452, 476, 10, 98113, "Input", "ExpressionUUID" -> \
"7f28cbcf-be9b-42bd-9277-6d8bb60681d3"],
Cell[138208, 3464, 2815, 61, 688195, "Text", "ExpressionUUID" -> \
"f2b55ea3-3efe-4390-a26b-dd081a3fd6bc"],
Cell[141026, 3527, 416, 12, 98113, "Input", "ExpressionUUID" -> \
"c82d03ff-606c-4856-a592-86ab9e3ee112",
 Evaluatable->False],
Cell[141445, 3541, 1907, 43, 297870, "Text", "ExpressionUUID" -> \
"af24ab89-6c4e-4e4a-9349-6352b74ff525"],
Cell[143355, 3586, 350, 6, 98113, "Input", "ExpressionUUID" -> \
"73314e9e-9602-4fae-b887-2c572beacf54"],
Cell[143708, 3594, 960, 27, 230109, "Input", "ExpressionUUID" -> \
"47c617ed-785a-48d1-89ca-09810e573009",
 Evaluatable->False],
Cell[144671, 3623, 367, 9, 98113, "Input", "ExpressionUUID" -> \
"6a0f7563-b8fe-4458-88ae-3258be2a4da0"],
Cell[145041, 3634, 505, 11, 162994, "Text", "ExpressionUUID" -> \
"db4adc24-d131-4ffb-ac9f-e3f1893f73a4"],
Cell[145549, 3647, 307, 6, 98113, "Input", "ExpressionUUID" -> \
"eedb2772-25f9-4c65-b0d4-558283db31ea"],
Cell[145859, 3655, 1043, 28, 165363, "Input", "ExpressionUUID" -> \
"0fce594d-e55e-48a9-a6ef-3114edef370d",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[146927, 3687, 600, 13, 98113, "Input", "ExpressionUUID" -> \
"713a422e-d299-46fd-bb55-31c1f838286c",
 InitializationCell->True],
Cell[147530, 3702, 2192, 77, 70, "Output", "ExpressionUUID" -> \
"7fbb358f-3980-48b8-9554-0981a643d461"]
}, Open  ]],
Cell[149737, 3782, 448, 8, 168129, "Text", "ExpressionUUID" -> \
"cb6510f0-9b59-4fb3-8f62-a8efb14aa2a4"],
Cell[150188, 3792, 1083, 19, 98113, "Text", "ExpressionUUID" -> \
"eb32c254-c95c-4cc1-83fe-40836bb72a44"],
Cell[151274, 3813, 232, 7, 98113, "Text", "ExpressionUUID" -> \
"1afe63be-e426-4642-a83f-8d8a859cc1a0"],
Cell[151509, 3822, 192, 3, 98113, "Input", "ExpressionUUID" -> \
"ac5f48dd-ebe1-40d4-934c-4f1c34b77a5f",
 CellTags->"Ex1.1.3"],
Cell[151704, 3827, 398, 12, 97020, "Input", "ExpressionUUID" -> \
"fa7a7886-b6e8-4101-bc08-4a30f316759d"],
Cell[152105, 3841, 240, 6, 98113, "Input", "ExpressionUUID" -> \
"db1d3c8b-4bbe-4a6b-b42f-985cde7e87dd"],
Cell[152348, 3849, 625, 18, 165363, "Input", "ExpressionUUID" -> \
"ff2d3048-b5ac-4b5f-bd2f-2ca6ad11667a"],
Cell[152976, 3869, 861, 18, 224916, "Text", "ExpressionUUID" -> \
"36f4455f-071e-402d-934f-6f6cde756211"],
Cell[153840, 3889, 689, 17, 165363, "Input", "ExpressionUUID" -> \
"d4f12fdb-64c8-445a-9c73-161dda4f7f3b"],
Cell[154532, 3908, 410, 12, 98113, "Text", "ExpressionUUID" -> \
"26406ffa-6b50-47f4-bfd6-809cc26cb443"],
Cell[154945, 3922, 613, 17, 165363, "Input", "ExpressionUUID" -> \
"4ffb5466-ce99-4575-a10a-cae8788b510e"],
Cell[155561, 3941, 232, 4, 98113, "Text", "ExpressionUUID" -> \
"aa6f8dc1-a21d-474e-8fc4-857c9f0add25"],
Cell[155796, 3947, 245, 7, 98113, "Input", "ExpressionUUID" -> \
"85014c8c-c7c6-4cb8-8d58-d78b4f9e03ba"],
Cell[156044, 3956, 147, 3, 98113, "Text", "ExpressionUUID" -> \
"753f00b7-2801-43a2-b98d-6fc372ecb4a6"],
Cell[156194, 3961, 723, 19, 165363, "Input", "ExpressionUUID" -> \
"d49ebd2c-2e97-4ac8-abd0-491e41dbb893"],
Cell[156920, 3982, 241, 6, 162994, "Text", "ExpressionUUID" -> \
"097dd641-50fb-4f1e-be3e-ae9bc5876829"],
Cell[157164, 3990, 172, 4, 98113, "Input", "ExpressionUUID" -> \
"67c134b2-e7de-49d0-afe2-2416289782d9"],
Cell[157339, 3996, 151, 3, 98113, "Text", "ExpressionUUID" -> \
"88f33705-cc2b-4df0-a89b-b339e08bf340"],
Cell[157493, 4001, 769, 20, 98113, "Input", "ExpressionUUID" -> \
"1f82f053-9dfe-4410-a84b-d700066f1055"],
Cell[158265, 4023, 345, 8, 98113, "Input", "ExpressionUUID" -> \
"45895d7d-bea1-4f16-8470-0a6231341ad1"],
Cell[158613, 4033, 653, 14, 165363, "Input", "ExpressionUUID" -> \
"8ae54edd-b545-4e6f-a9b5-73e3de67744c"],
Cell[159269, 4049, 286, 7, 98113, "Text", "ExpressionUUID" -> \
"d681d2a0-eba2-44ac-ac57-229316557060"],
Cell[159558, 4058, 560, 11, 98113, "Input", "ExpressionUUID" -> \
"e0630b57-47b0-42e7-a51a-fa1b1581b736"],
Cell[160121, 4071, 182, 3, 98113, "Text", "ExpressionUUID" -> \
"1f0167b9-2ffb-47a9-8b65-620414137b10"],
Cell[160306, 4076, 341, 9, 98113, "Input", "ExpressionUUID" -> \
"cd6a5a84-1d54-4e1f-81c8-396b23d77664"],
Cell[160650, 4087, 216, 4, 98113, "Text", "ExpressionUUID" -> \
"08e18fa7-33bf-4b86-9c9d-55f5868f5380"],
Cell[160869, 4093, 311, 9, 98113, "Input", "ExpressionUUID" -> \
"8f25c07f-607a-4e94-95b7-0f2282ce74fd"],
Cell[161183, 4104, 167, 3, 98113, "Text", "ExpressionUUID" -> \
"b5c8bc6d-83b5-4b2e-9637-f1f17bc06ed1"],
Cell[161353, 4109, 636, 13, 98113, "Input", "ExpressionUUID" -> \
"5576eb07-9ea7-4102-aa8d-b2809b9d1f51"],
Cell[161992, 4124, 380, 10, 98113, "Input", "ExpressionUUID" -> \
"ec26a9a4-1897-4b1c-b205-84e61f56ed56"],
Cell[162375, 4136, 212, 5, 98113, "Text", "ExpressionUUID" -> \
"dfb7a188-4c19-43ab-ab1e-c2e4e8992871"],
Cell[162590, 4143, 261, 7, 98113, "Input", "ExpressionUUID" -> \
"26351bcd-da6d-401e-8476-fbdd3cdedbac"],
Cell[162854, 4152, 281, 8, 98113, "Input", "ExpressionUUID" -> \
"b9309a06-00ca-4da3-8909-98ebc6ab8d92"],
Cell[163138, 4162, 252, 4, 100878, "Text", "ExpressionUUID" -> \
"f54467d1-43b4-424c-976b-2a0b9464e735"],
Cell[163393, 4168, 374, 10, 98113, "Input", "ExpressionUUID" -> \
"deff1dca-ab43-44b4-a33f-4113a39514da"],
Cell[163770, 4180, 401, 10, 98113, "Input", "ExpressionUUID" -> \
"aaf0f880-93a1-4660-8d70-e5f2c0606eb7"],
Cell[164174, 4192, 272, 6, 162994, "Text", "ExpressionUUID" -> \
"f79eb88c-bf6e-458d-860a-571dbdc8e213"],
Cell[164449, 4200, 378, 10, 98113, "Input", "ExpressionUUID" -> \
"4586d611-fa39-41d9-90a3-c09a93da7e62"],
Cell[164830, 4212, 817, 14, 362740, "Text", "ExpressionUUID" -> \
"db0c14bd-983c-47f5-b7a0-89772c4e3955"],
Cell[165650, 4228, 327, 7, 162994, "Text", "ExpressionUUID" -> \
"12fa5307-ed55-43b9-9a96-3059825cc979"],
Cell[165980, 4237, 244, 6, 98113, "Text", "ExpressionUUID" -> \
"9eaeaff0-9343-4c42-accf-74fc5d252e11",
 CellTags->"cone"],
Cell[166227, 4245, 183, 4, 98113, "Input", "ExpressionUUID" -> \
"8eb2e4ef-0e3e-4855-98b7-a3c8958679b9"],
Cell[166413, 4251, 587, 13, 98113, "Input", "ExpressionUUID" -> \
"84efad01-6c57-4c15-ad2c-f93c4ce08f6b"],
Cell[167003, 4266, 244, 7, 98113, "Input", "ExpressionUUID" -> \
"8080314d-28c4-487d-828b-88f8dfc14f3c"],
Cell[167250, 4275, 804, 20, 165363, "Input", "ExpressionUUID" -> \
"682c9832-ec45-48cf-8e55-45d4b3ecad83"],
Cell[168057, 4297, 260, 6, 98113, "Input", "ExpressionUUID" -> \
"33912e44-34a9-4e5d-b7e5-dc2491acf719"],
Cell[168320, 4305, 900, 20, 165363, "Input", "ExpressionUUID" -> \
"66679ff0-d334-4d10-b3f8-ac267baedc4c"],
Cell[169223, 4327, 314, 8, 98113, "Input", "ExpressionUUID" -> \
"4c5327de-ebd7-4e8d-8060-faa4cfc5764b"],
Cell[169540, 4337, 157, 3, 98113, "Text", "ExpressionUUID" -> \
"e6324105-b528-4449-affa-24d163bc1216"],
Cell[169700, 4342, 542, 14, 224916, "Text", "ExpressionUUID" -> \
"14706ba4-2eb3-4628-9f79-1fde47180f34"],
Cell[170245, 4358, 405, 10, 98113, "Input", "ExpressionUUID" -> \
"632b0d2e-5578-4f89-bd07-6e17a8a863d9"],
Cell[170653, 4370, 1488, 34, 230109, "Input", "ExpressionUUID" -> \
"31ee244d-162f-4875-8e10-4fad536a04ca"],
Cell[172144, 4406, 888, 19, 98113, "Input", "ExpressionUUID" -> \
"58f59c31-02c4-4556-9b1a-aebd3e561391"],
Cell[173035, 4427, 749, 15, 230109, "Input", "ExpressionUUID" -> \
"a9c6bf2d-a2fa-41b4-86a1-0ff12401a010"],
Cell[173787, 4444, 237, 6, 100878, "Text", "ExpressionUUID" -> \
"d1d28da3-c19c-489f-a1cd-b027bec64185"],
Cell[174027, 4452, 960, 17, 224916, "Text", "ExpressionUUID" -> \
"82f2a50e-3931-433e-bcb9-5edf0ea60f16"],
Cell[174990, 4471, 1172, 33, 230109, "Input", "ExpressionUUID" -> \
"645d395f-c346-4b65-b4c9-3797feb83265",
 InitializationCell->True,
 CellTags->"nor"],
Cell[176165, 4506, 441, 11, 293193, "Input", "ExpressionUUID" -> \
"bf5ceb88-19ab-4b90-bd94-99e1a0d56c2c",
 InitializationCell->True],
Cell[176609, 4519, 222, 5, 98113, "Text", "ExpressionUUID" -> \
"bac139ba-94fc-4495-8c77-2e8084f09736"],
Cell[176834, 4526, 682, 17, 98113, "Input", "ExpressionUUID" -> \
"bca7af93-d4a6-4644-b4ab-951dc550c96f"],
Cell[177519, 4545, 407, 11, 98113, "Input", "ExpressionUUID" -> \
"80609658-e6e2-4388-967e-ed41aea01c74"],
Cell[177929, 4558, 405, 9, 98113, "Input", "ExpressionUUID" -> \
"4b6a0a77-3b13-42e9-9691-7fbbad5960bb",
 CellTags->"figsph3"]
}, Closed]],
Cell[CellGroupData[{
Cell[178371, 4572, 274, 4, 42, "Subsubsection", "ExpressionUUID" -> \
"1d7b7cd8-5526-4352-829f-dde7ad5faba9"],
Cell[178648, 4578, 1621, 38, 362740, "Text", "ExpressionUUID" -> \
"0a968b87-a2c6-4f6b-bd4b-377f684e97ab"],
Cell[180272, 4618, 206, 5, 98113, "Input", "ExpressionUUID" -> \
"6952ceca-c957-4178-be93-57887981f7bc"],
Cell[180481, 4625, 173, 4, 98113, "Input", "ExpressionUUID" -> \
"8399312b-89d6-46e9-8067-3912aaf654b6"],
Cell[180657, 4631, 176, 4, 98113, "Input", "ExpressionUUID" -> \
"06e9c5f2-73c5-4a76-b5fe-61f2de44ea70"],
Cell[180836, 4637, 148, 3, 98113, "Text", "ExpressionUUID" -> \
"acd6b22c-b1b1-4ac9-a2d8-79d579f2ce5c"],
Cell[180987, 4642, 357, 10, 98113, "Input", "ExpressionUUID" -> \
"36ab7914-bd85-4874-a4f7-351ca2f891e6"],
Cell[181347, 4654, 330, 9, 98113, "Input", "ExpressionUUID" -> \
"4c188a27-b7ef-41a4-b0db-5018a925dc64"],
Cell[181680, 4665, 405, 8, 162994, "Text", "ExpressionUUID" -> \
"89fe5a9a-c001-47be-8cbb-ba60e29af241"],
Cell[182088, 4675, 499, 12, 98113, "Input", "ExpressionUUID" -> \
"5cf49ce1-bdb5-4e5a-bcd4-9956f814f182"],
Cell[182590, 4689, 624, 15, 98113, "Input", "ExpressionUUID" -> \
"e54b425b-4ec1-4417-b254-45f5c467319c"],
Cell[183217, 4706, 779, 24, 162994, "Text", "ExpressionUUID" -> \
"6fd1af3c-2b2f-456c-a29f-bc9ecf607e39"],
Cell[183999, 4732, 994, 33, 98113, "Input", "ExpressionUUID" -> \
"6fd7362c-727c-4e07-a6c4-6458b59f587d",
 Evaluatable->False],
Cell[184996, 4767, 837, 26, 98113, "Input", "ExpressionUUID" -> \
"94d8d11b-85d6-44c9-9048-11106d55e31f",
 Evaluatable->False],
Cell[185836, 4795, 744, 22, 98113, "Input", "ExpressionUUID" -> \
"307fbd40-c8e3-4f4d-a9b7-dfdbc14ecacb",
 Evaluatable->False],
Cell[186583, 4819, 519, 9, 162994, "Text", "ExpressionUUID" -> \
"b6cc7d47-2569-4240-8c39-94c35ff03b59"],
Cell[187105, 4830, 684, 19, 98113, "Input", "ExpressionUUID" -> \
"9a28352e-babe-4e2f-bbad-c844778ff2fb",
 Evaluatable->False],
Cell[187792, 4851, 1632, 52, 168129, "Text", "ExpressionUUID" -> \
"df54eb15-562f-4d5b-a562-a7d60f03251e"],
Cell[189427, 4905, 431, 12, 98113, "Input", "ExpressionUUID" -> \
"f5a4b34e-6e82-41d6-a6bb-e4439c91109e",
 Evaluatable->False],
Cell[189861, 4919, 791, 23, 100878, "Text", "ExpressionUUID" -> \
"f8ceefe4-8b78-455c-a346-f1a4576068b9"],
Cell[190655, 4944, 176, 3, 98113, "Text", "ExpressionUUID" -> \
"81d90a0f-64b6-40a3-b9b3-8aadb5f49e14"],
Cell[190834, 4949, 408, 11, 98113, "Input", "ExpressionUUID" -> \
"0e2b6dc2-9d48-455d-bcb1-73ff9527d242"],
Cell[191245, 4962, 259, 7, 98113, "Input", "ExpressionUUID" -> \
"1a7276ee-8b9a-4292-aad2-d9dfed584d95"],
Cell[191507, 4971, 201, 4, 98113, "Text", "ExpressionUUID" -> \
"2b17cd71-db2b-42f8-9cf7-6da157134db5"],
Cell[191711, 4977, 563, 16, 98113, "Input", "ExpressionUUID" -> \
"5ff2a88b-c8c5-40ec-a7c4-0e5d3f17da32"],
Cell[192277, 4995, 215, 3, 98113, "Text", "ExpressionUUID" -> \
"b33b2abf-3fc7-4760-976a-f258b67ba8f0"],
Cell[192495, 5000, 476, 14, 98113, "Input", "ExpressionUUID" -> \
"20f8eb44-1225-45fd-a9c6-aceebeb8beae"],
Cell[192974, 5016, 298, 6, 98113, "Text", "ExpressionUUID" -> \
"b9a5221d-ac67-4a12-84d7-5d1820e76de5"],
Cell[193275, 5024, 720, 18, 98113, "Input", "ExpressionUUID" -> \
"3a598e19-5a8e-44a1-9d1d-8f0806b169ba"],
Cell[193998, 5044, 697, 22, 100878, "Text", "ExpressionUUID" -> \
"5decfc68-821f-4f97-b170-c33ca6581629"],
Cell[194698, 5068, 231, 6, 98113, "Input", "ExpressionUUID" -> \
"5723225a-ebfc-4199-a677-991b06b7f90a"],
Cell[194932, 5076, 413, 8, 162994, "Text", "ExpressionUUID" -> \
"ee5524aa-eadc-4a06-8828-f4b9c7b60de5"],
Cell[195348, 5086, 755, 20, 165363, "Input", "ExpressionUUID" -> \
"c5f2c5cb-c45f-4ee5-978b-9768f0a64942"],
Cell[196106, 5108, 295, 7, 162994, "Text", "ExpressionUUID" -> \
"0a71e0ac-98a5-4e1b-8a3c-eb9c37ef0d17"],
Cell[196404, 5117, 670, 20, 98113, "Input", "ExpressionUUID" -> \
"2af0dde4-0667-4105-9a50-10acef04358f"],
Cell[197077, 5139, 179, 3, 98113, "Text", "ExpressionUUID" -> \
"5aca6386-45ff-4d7e-abb2-fd3bd80470d0"],
Cell[197259, 5144, 182, 4, 98113, "Input", "ExpressionUUID" -> \
"9dd67403-ddf8-46b8-84dc-5803d57a812f"],
Cell[197444, 5150, 443, 12, 98113, "Input", "ExpressionUUID" -> \
"892c1b98-4db9-44ec-8ad0-1b05b81022da"],
Cell[197890, 5164, 222, 5, 98113, "Text", "ExpressionUUID" -> \
"4893bb2b-9758-448c-9274-0520bb282e71"],
Cell[198115, 5171, 608, 16, 98113, "Input", "ExpressionUUID" -> \
"82d53515-091c-4b01-b3c7-76bc63918406"],
Cell[198726, 5189, 606, 17, 171753, "Text", "ExpressionUUID" -> \
"b70bea43-7dba-4e80-9886-f16829a3afc3"],
Cell[199335, 5208, 338, 7, 98113, "Input", "ExpressionUUID" -> \
"aa2750dc-70aa-44fb-b49e-38205f217a74"],
Cell[199676, 5217, 156, 3, 98113, "Text", "ExpressionUUID" -> \
"a7910323-3383-4b0a-95b3-fb5d4ac16bd7"],
Cell[199835, 5222, 511, 14, 98113, "Input", "ExpressionUUID" -> \
"11f89357-e5dd-4efc-bb20-59a9a305a2a6"],
Cell[200349, 5238, 214, 5, 98113, "Text", "ExpressionUUID" -> \
"d07f930f-4420-45fb-83f5-fa71fcc4d752"],
Cell[200566, 5245, 891, 28, 230109, "Input", "ExpressionUUID" -> \
"d94e82ac-e93d-4bd4-9a7d-c067c94419cd"],
Cell[201460, 5275, 312, 7, 165363, "Text", "ExpressionUUID" -> \
"37222f77-5dd6-4874-85c1-8096757b2e4d"]
}, Closed]],
Cell[CellGroupData[{
Cell[201809, 5287, 292, 5, 42, "Subsubsection", "ExpressionUUID" -> \
"39a20d0d-7ca8-4f65-895f-4fd453392a4e"],
Cell[202104, 5294, 861, 17, 236337, "Text", "ExpressionUUID" -> \
"bde77ce1-607e-413b-975a-f257e2479315"],
Cell[202968, 5313, 712, 21, 165363, "Input", "ExpressionUUID" -> \
"9fc436a4-02b8-481a-b96d-637d49881ef9"],
Cell[203683, 5336, 204, 5, 98113, "Input", "ExpressionUUID" -> \
"36125031-f88f-4e22-b953-12c3e56ddf83"],
Cell[203890, 5343, 163, 3, 98113, "Text", "ExpressionUUID" -> \
"64000853-c721-46d9-8363-ada4837cb322"],
Cell[204056, 5348, 234, 6, 98113, "Input", "ExpressionUUID" -> \
"ea428f5b-53f8-467d-8887-dea60abe2f16"],
Cell[204293, 5356, 234, 5, 98113, "Input", "ExpressionUUID" -> \
"45f9d972-b97c-4e39-b734-5a061bc205e6"],
Cell[204530, 5363, 504, 15, 98113, "Input", "ExpressionUUID" -> \
"54b61e5d-0c0a-4f8f-b36d-05cb985d8a2e"],
Cell[205037, 5380, 282, 6, 162994, "Text", "ExpressionUUID" -> \
"fbe32433-9fe3-4d96-8e66-f9c98da32878"],
Cell[205322, 5388, 405, 11, 98113, "Input", "ExpressionUUID" -> \
"2effea26-7927-406c-b932-8586ce6764b9"],
Cell[205730, 5401, 382, 11, 98113, "Input", "ExpressionUUID" -> \
"b677012a-2856-4c09-bc4f-54b68c043ccc"],
Cell[206115, 5414, 221, 4, 98113, "Text", "ExpressionUUID" -> \
"295a4e9d-a65d-42b2-8971-9406d6e05d22"],
Cell[206339, 5420, 751, 22, 169218, "Input", "ExpressionUUID" -> \
"51d628f9-503e-4d7b-9d88-f6e2827c4e89",
 Evaluatable->False],
Cell[207093, 5444, 195, 3, 98113, "Text", "ExpressionUUID" -> \
"cd1d0af0-e142-43dc-95a4-564fb09a2c45"],
Cell[207291, 5449, 1330, 41, 248044, "Input", "ExpressionUUID" -> \
"b4c81148-b518-405c-a087-c0c51ebe29d6",
 Evaluatable->False],
Cell[208624, 5492, 268, 8, 98113, "Text", "ExpressionUUID" -> \
"7e0cda0c-be11-4bb7-97db-5b874f9b335c"],
Cell[208895, 5502, 295, 7, 100878, "Text", "ExpressionUUID" -> \
"6e97c0a5-ace4-46f4-bcf8-800cad554386"],
Cell[209193, 5511, 856, 23, 165363, "Input", "ExpressionUUID" -> \
"9757458e-280f-4911-9c70-17d3d4b313e4"],
Cell[210052, 5536, 1068, 23, 165363, "Input", "ExpressionUUID" -> \
"28490e39-8d73-4449-9b2e-6c1193b59cc6"],
Cell[211123, 5561, 417, 8, 162994, "Text", "ExpressionUUID" -> \
"bf2eeb76-d5d3-4863-a43e-48b4a4aab8df"],
Cell[211543, 5571, 1124, 25, 165363, "Input", "ExpressionUUID" -> \
"d9fd257b-b5c3-4d56-a8e9-ed996a045547"],
Cell[212670, 5598, 188, 3, 98113, "Text", "ExpressionUUID" -> \
"1c740801-9c18-4c7c-976c-cf1e4461fea2"],
Cell[212861, 5603, 350, 8, 98113, "Input", "ExpressionUUID" -> \
"4eb8bbbe-a5f6-4768-873a-3b2a15ae7248"],
Cell[213214, 5613, 255, 5, 162994, "Text", "ExpressionUUID" -> \
"ce2104ff-2304-4858-b58e-d8922275e534"],
Cell[213472, 5620, 259, 7, 98113, "Input", "ExpressionUUID" -> \
"a046ebeb-d1db-4f5c-95a9-4d49812a0bdf"],
Cell[213734, 5629, 228, 4, 98113, "Text", "ExpressionUUID" -> \
"e55d5301-2854-4bad-9a53-d740513101e2"],
Cell[213965, 5635, 784, 22, 165363, "Input", "ExpressionUUID" -> \
"7e4fcf6b-eaee-447e-a74b-85f46fa182df"],
Cell[214752, 5659, 693, 19, 98113, "Input", "ExpressionUUID" -> \
"08862e24-43e0-44d5-bcec-21a0aa11b243"],
Cell[215448, 5680, 212, 6, 98113, "Input", "ExpressionUUID" -> \
"e07fe16c-9616-47f3-884c-aeed7417757f"],
Cell[215663, 5688, 239, 6, 98113, "Input", "ExpressionUUID" -> \
"d1bc13b8-6595-4130-84a0-aaf33a9ab19a"],
Cell[215905, 5696, 194, 3, 98113, "Text", "ExpressionUUID" -> \
"c11fbedb-0109-496f-abae-08ddc32fab54"],
Cell[216102, 5701, 483, 14, 98113, "Input", "ExpressionUUID" -> \
"fa14edf7-e4f3-4f3e-8ca0-f7759fd09deb"],
Cell[216588, 5717, 528, 10, 98113, "Input", "ExpressionUUID" -> \
"fdb6f663-beeb-4f25-8b6e-e11626447252"],
Cell[217119, 5729, 652, 18, 165363, "Input", "ExpressionUUID" -> \
"552fb4fe-546b-4e29-9956-9a7b02dcee56"],
Cell[217774, 5749, 624, 19, 165363, "Input", "ExpressionUUID" -> \
"b582ef46-ce05-4276-9f60-b65037699d8a"],
Cell[218401, 5770, 376, 8, 98113, "Input", "ExpressionUUID" -> \
"29365930-46af-4026-b07b-65f79a0918f3"],
Cell[218780, 5780, 236, 5, 98113, "Text", "ExpressionUUID" -> \
"41acc83f-b6d1-492b-8ceb-d7446298c2a1"],
Cell[219019, 5787, 708, 15, 98113, "Input", "ExpressionUUID" -> \
"7a825d9f-e258-416d-8331-b68aa09f48d4"],
Cell[219730, 5804, 726, 16, 98113, "Input", "ExpressionUUID" -> \
"7760d3a7-f9e8-40d1-9de6-60f8308ec9d5"],
Cell[220459, 5822, 263, 6, 162994, "Text", "ExpressionUUID" -> \
"e38ee91f-3bb8-4755-82d5-4320b16abf32"],
Cell[220725, 5830, 287, 8, 98113, "Input", "ExpressionUUID" -> \
"73ab0545-fa03-46d0-ba54-9e0969c6dc16"],
Cell[221015, 5840, 286, 8, 98113, "Input", "ExpressionUUID" -> \
"14d5d8f7-5832-4821-ac83-77171a1ac4cf"],
Cell[221304, 5850, 493, 14, 98113, "Input", "ExpressionUUID" -> \
"dee60999-fe80-4b1e-90c4-e27c22f68ed7"],
Cell[221800, 5866, 622, 16, 98113, "Input", "ExpressionUUID" -> \
"33e0b238-4446-4fb7-9617-e7b90e685502"],
Cell[222425, 5884, 647, 16, 98113, "Input", "ExpressionUUID" -> \
"c494bda5-f79f-4ff5-963e-3207972d92a9"],
Cell[223075, 5902, 244, 6, 162994, "Text", "ExpressionUUID" -> \
"04f1a0ef-f256-45dd-897f-e4d6d676ad04"],
Cell[223322, 5910, 676, 18, 98113, "Input", "ExpressionUUID" -> \
"6f8ec002-c735-4822-afab-9e2b28cf9553"],
Cell[224001, 5930, 670, 12, 297870, "Text", "ExpressionUUID" -> \
"82dbc4bd-224b-435d-8fb5-6cb3ee17bbee"],
Cell[224674, 5944, 544, 14, 98113, "Input", "ExpressionUUID" -> \
"5f1a1082-e401-436c-a107-847de20fd54c"],
Cell[225221, 5960, 361, 10, 98113, "Input", "ExpressionUUID" -> \
"ec83907f-8858-44b5-aa06-ea71ecb0fce4"],
Cell[225585, 5972, 161, 3, 98113, "Text", "ExpressionUUID" -> \
"5fe84235-0f53-49ee-9253-5b8e399c03c6"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[225795, 5981, 884, 13, 67, "Subsection", "ExpressionUUID" -> \
"852bfb36-1014-4746-a224-dcd2f28ab08f"],
Cell[CellGroupData[{
Cell[226704, 5998, 418, 6, 53, "Subsubsection", "ExpressionUUID" -> \
"af836172-602d-4649-a1fd-058b6609624d"],
Cell[227125, 6006, 391, 8, 98113, "Input", "ExpressionUUID" -> \
"90963356-3cd9-4624-9bd1-c1bc12c828d1"],
Cell[227519, 6016, 204, 5, 98113, "Input", "ExpressionUUID" -> \
"a4a8e712-eba4-4b63-86a8-f53b0475a0fc"],
Cell[227726, 6023, 373, 7, 98113, "Text", "ExpressionUUID" -> \
"a09f9f17-0e98-4de9-b52f-86570526b5ca"],
Cell[228102, 6032, 407, 7, 98113, "Input", "ExpressionUUID" -> \
"180ddc97-3bac-43c2-bbce-010fad49dd70"],
Cell[228512, 6041, 271, 6, 162994, "Text", "ExpressionUUID" -> \
"ec189f8d-c543-45c7-b6f8-4fc06f4b6971"],
Cell[228786, 6049, 1293, 34, 230109, "Input", "ExpressionUUID" -> \
"25a7f2d7-da1f-47d2-92ad-b4ac33f2c8e2",
 Evaluatable->False],
Cell[230082, 6085, 177, 4, 98113, "Input", "ExpressionUUID" -> \
"882ed020-630b-48f9-89ff-1f15da48a753"],
Cell[230262, 6091, 496, 10, 98113, "Input", "ExpressionUUID" -> \
"3a984cc5-1df7-49b0-99f6-a0270d02ae81"],
Cell[230761, 6103, 1440, 38, 230109, "Input", "ExpressionUUID" -> \
"1cc0227d-b75b-4255-9558-37cdb023a45f",
 Evaluatable->False],
Cell[232204, 6143, 882, 16, 98113, "Input", "ExpressionUUID" -> \
"e75fac03-6c60-4e9a-a67e-9aeb180790cc"],
Cell[233089, 6161, 444, 10, 98113, "Text", "ExpressionUUID" -> \
"8d98f70b-d6c1-426a-aadc-7fb11fab132c"],
Cell[233536, 6173, 1308, 37, 230109, "Input", "ExpressionUUID" -> \
"b6610a0a-03d2-4983-a73a-839d473a7943",
 Evaluatable->False],
Cell[234847, 6212, 377, 10, 98113, "Text", "ExpressionUUID" -> \
"86d63b3f-7760-4088-8040-18b09d655534"],
Cell[235227, 6224, 747, 16, 98113, "Input", "ExpressionUUID" -> \
"6e5b3162-7c93-4680-bb61-d3e9daa57765"],
Cell[235977, 6242, 578, 12, 98113, "Input", "ExpressionUUID" -> \
"fd6fd187-c1e4-4468-b145-300d4176ff55"],
Cell[236558, 6256, 208, 3, 98113, "Text", "ExpressionUUID" -> \
"f835890b-d8f3-4da7-86d6-c20152b4cdd6"],
Cell[236769, 6261, 1013, 24, 165363, "Input", "ExpressionUUID" -> \
"a182b713-1080-4862-8b16-38a2842f4acc"],
Cell[237785, 6287, 182, 3, 98113, "Text", "ExpressionUUID" -> \
"d208e7dd-9bbc-4277-b831-199d96fa3ec0"],
Cell[237970, 6292, 583, 15, 98113, "Input", "ExpressionUUID" -> \
"47a11afe-1300-4bd7-b32b-31216a8a0539"],
Cell[238556, 6309, 744, 16, 224916, "Text", "ExpressionUUID" -> \
"c7580c31-6e47-43ab-bd2a-3ea3cb31d1b7"],
Cell[239303, 6327, 352, 9, 98113, "Text", "ExpressionUUID" -> \
"2bf8a3d5-4b75-4002-8e07-9582b94e630d"],
Cell[239658, 6338, 1745, 45, 230109, "Input", "ExpressionUUID" -> \
"c4d6d234-d687-4e04-8ef3-93c28ce918bf",
 InitializationCell->True],
Cell[241406, 6385, 724, 13, 421957, "Input", "ExpressionUUID" -> \
"641ed957-a675-49ee-bcd5-6d050ce5e74c",
 InitializationCell->True],
Cell[242133, 6400, 445, 8, 98113, "Text", "ExpressionUUID" -> \
"e7da7b6c-80d3-435b-892d-f4e94f99968c"],
Cell[242581, 6410, 1226, 28, 98113, "Input", "ExpressionUUID" -> \
"e88342be-ee86-4c5d-bfe8-111d530c760d"],
Cell[243810, 6440, 322, 10, 98113, "Text", "ExpressionUUID" -> \
"fb498a18-167a-4ab8-b353-57f0306ecd42"],
Cell[244135, 6452, 352, 10, 98113, "Text", "ExpressionUUID" -> \
"6eeea42c-385e-4ef5-88be-bf7e28995b4e"],
Cell[244490, 6464, 238, 5, 98113, "Input", "ExpressionUUID" -> \
"0b9ebfb5-4c9a-420a-b308-f2e9562ffd4f"],
Cell[244731, 6471, 270, 7, 98113, "Input", "ExpressionUUID" -> \
"32a76f9d-ecb0-4ef0-8d42-8f1203022d52"],
Cell[245004, 6480, 168, 3, 98113, "Text", "ExpressionUUID" -> \
"ef1c970d-bf66-4ce1-b93d-5633ddec66dc"],
Cell[245175, 6485, 183, 3, 98113, "Input", "ExpressionUUID" -> \
"7559e5f5-0919-43f0-aa94-ceab02183b27"],
Cell[245361, 6490, 958, 20, 165363, "Input", "ExpressionUUID" -> \
"cef81ba0-f07f-40a8-80c6-6d4b66605664"],
Cell[246322, 6512, 622, 9, 98113, "Text", "ExpressionUUID" -> \
"0a380c3b-b085-487b-9d55-70d6b18382ff"],
Cell[246947, 6523, 578, 13, 98113, "Input", "ExpressionUUID" -> \
"a7484fa3-121c-4c2c-98cb-e7da5b10c726"],
Cell[247528, 6538, 362, 7, 168129, "Text", "ExpressionUUID" -> \
"b0fdd680-39fd-4622-b6a1-60075dfdf137"],
Cell[247893, 6547, 1577, 34, 230109, "Input", "ExpressionUUID" -> \
"bc52cc27-17ad-4949-93b1-196da26fecc2"],
Cell[249473, 6583, 302, 8, 98113, "Input", "ExpressionUUID" -> \
"4055c74b-5ad4-4d96-93e9-a7e5dbc1cc52"],
Cell[249778, 6593, 605, 17, 165363, "Input", "ExpressionUUID" -> \
"fc109346-6629-4367-bd5c-50ff93df5d48"],
Cell[250386, 6612, 805, 21, 165363, "Input", "ExpressionUUID" -> \
"91a63e3c-4b57-4272-83d4-d8bc8ea5d585"],
Cell[251194, 6635, 372, 9, 98113, "Input", "ExpressionUUID" -> \
"3797a332-957e-4485-be3b-bc4639b3d3b6"],
Cell[251569, 6646, 159, 3, 98113, "Text", "ExpressionUUID" -> \
"626b85cf-5ae1-4777-82cf-455e3dca410d"],
Cell[251731, 6651, 493, 11, 98113, "Text", "ExpressionUUID" -> \
"316c137e-e381-4fba-a271-ac94c32c3c41"],
Cell[252227, 6664, 444, 11, 98113, "Input", "ExpressionUUID" -> \
"9b9cfae2-4a61-4719-ae7d-d38ce9e407fb"],
Cell[252674, 6677, 298, 6, 98113, "Text", "ExpressionUUID" -> \
"12bde49e-5fe9-4e50-a980-fc3011486af6"],
Cell[252975, 6685, 390, 9, 98113, "Input", "ExpressionUUID" -> \
"e404c699-de30-4192-92b9-5ce66b89dd35"],
Cell[253368, 6696, 337, 8, 98113, "Input", "ExpressionUUID" -> \
"0fd3b9e3-a0b1-40e7-98d5-9ab2b9389934"],
Cell[253708, 6706, 356, 8, 98113, "Input", "ExpressionUUID" -> \
"04aa2b10-cebc-4ae8-aae7-9acf59254559"],
Cell[254067, 6716, 1153, 26, 165363, "Input", "ExpressionUUID" -> \
"d2f306e6-c044-4a39-9c82-f5a9691b93e5"],
Cell[255223, 6744, 252, 4, 98113, "Text", "ExpressionUUID" -> \
"d4038b37-7f83-416b-8f0e-dd9919297e9b"],
Cell[255478, 6750, 588, 14, 98113, "Input", "ExpressionUUID" -> \
"0b338dec-aec2-425f-9577-2ad3d4b48da7"],
Cell[256069, 6766, 159, 3, 98113, "Text", "ExpressionUUID" -> \
"d0dc9e32-5f90-4056-a145-987c9215dc73"],
Cell[256231, 6771, 1250, 22, 492832, "Text", "ExpressionUUID" -> \
"988ae949-adf5-4a17-ac52-95a4ebf1e6d8"],
Cell[257484, 6795, 174, 4, 98113, "Input", "ExpressionUUID" -> \
"1ed95d27-f706-409f-8c00-ab67651bcd8a"],
Cell[257661, 6801, 224, 5, 98113, "Input", "ExpressionUUID" -> \
"4a34dd24-99f4-4e8b-b715-877b378250c4"],
Cell[257888, 6808, 191, 4, 98113, "Input", "ExpressionUUID" -> \
"1ad7dae9-a892-4ee5-bef9-66f61d5e2935"],
Cell[258082, 6814, 170, 3, 98113, "Input", "ExpressionUUID" -> \
"de03e2b1-af0c-4ee6-aedc-1d5dbedae514"],
Cell[258255, 6819, 412, 10, 162994, "Text", "ExpressionUUID" -> \
"e33c9d5c-3cd1-4fc3-9591-d35c4113d257"],
Cell[258670, 6831, 213, 4, 98113, "Text", "ExpressionUUID" -> \
"a2f57f94-ca63-4797-806f-3a38618001c0"],
Cell[258886, 6837, 678, 16, 98113, "Input", "ExpressionUUID" -> \
"f3814e36-fdd2-49a7-b9bc-966c8ad36ca2",
 Evaluatable->False],
Cell[259567, 6855, 339, 8, 98113, "Input", "ExpressionUUID" -> \
"d04be8bd-aafd-46ae-ae25-2ff836dc37b6"],
Cell[259909, 6865, 918, 24, 165363, "Input", "ExpressionUUID" -> \
"7e8c18cf-e699-494c-a2b4-7bc7de96246f",
 Evaluatable->False],
Cell[260830, 6891, 450, 8, 98113, "Input", "ExpressionUUID" -> \
"1b81bac7-6f07-4cf3-96b8-c1744fe102d5"],
Cell[261283, 6901, 187, 4, 98113, "Input", "ExpressionUUID" -> \
"f33263d7-cd30-445b-bf91-ebaf4e42c666"],
Cell[261473, 6907, 439, 9, 98113, "Input", "ExpressionUUID" -> \
"50062220-221a-4520-8751-a56d2486307a"],
Cell[261915, 6918, 949, 22, 98113, "Input", "ExpressionUUID" -> \
"bd05643f-9183-41ec-babb-f25987828308",
 Evaluatable->False],
Cell[262867, 6942, 355, 6, 98113, "Input", "ExpressionUUID" -> \
"a93d0c55-e17f-47ab-859c-2df8383aedc8"],
Cell[263225, 6950, 189, 4, 98113, "Input", "ExpressionUUID" -> \
"06548a82-be90-43b4-bce3-ac54a711512a"],
Cell[263417, 6956, 464, 10, 98113, "Input", "ExpressionUUID" -> \
"4b3f8593-fcb8-4a70-85b0-1f733e9b54a6"],
Cell[263884, 6968, 219, 5, 98113, "Input", "ExpressionUUID" -> \
"afcbb548-348f-4cc7-bade-832e4799b3b6"],
Cell[264106, 6975, 546, 12, 98113, "Input", "ExpressionUUID" -> \
"8454d938-5a3c-4d06-bdab-4cedc261aec7"],
Cell[264655, 6989, 208, 4, 98113, "Input", "ExpressionUUID" -> \
"afef3cfa-914f-4957-932a-aa1605f34f28"],
Cell[264866, 6995, 316, 8, 98113, "Input", "ExpressionUUID" -> \
"da3719c0-c308-4397-b8fd-19e833e2f46f"]
}, Closed]],
Cell[CellGroupData[{
Cell[265219, 7008, 591, 8, 42, "Subsubsection", "ExpressionUUID" -> \
"b76b761a-1280-4ac5-a383-7ed591d40012"],
Cell[265813, 7018, 244, 6, 98113, "Input", "ExpressionUUID" -> \
"0201dcb4-7ee3-4fb9-b529-f8369358e10b"],
Cell[266060, 7026, 197, 3, 98113, "Text", "ExpressionUUID" -> \
"82ea5204-9524-4a64-8eef-525fcde7b165"],
Cell[266260, 7031, 720, 16, 98113, "Input", "ExpressionUUID" -> \
"45ca94d3-9cc5-4fdf-9770-74118431c9b3",
 InitializationCell->True],
Cell[266983, 7049, 235, 4, 98113, "Text", "ExpressionUUID" -> \
"2c77312b-877c-43c6-9fc6-2cb4dfa1f580"],
Cell[267221, 7055, 647, 14, 98113, "Input", "ExpressionUUID" -> \
"cf13afab-7d91-4b2a-81bd-61ef29c7563f",
 InitializationCell->True],
Cell[267871, 7071, 257, 4, 98113, "Text", "ExpressionUUID" -> \
"8e3bc724-282e-4d1c-9e4a-9546a5ce88cb"],
Cell[268131, 7077, 302, 6, 98113, "Input", "ExpressionUUID" -> \
"b6a7b5be-f65e-4f39-80d6-638fb6e0ec0d"],
Cell[268436, 7085, 201, 3, 98113, "Text", "ExpressionUUID" -> \
"a79592de-d389-4759-bb67-03c012e3fc48"],
Cell[268640, 7090, 803, 18, 98113, "Input", "ExpressionUUID" -> \
"092571b5-c2f0-4983-9039-2db12188b1bd"],
Cell[269446, 7110, 144, 3, 98113, "Text", "ExpressionUUID" -> \
"07119f27-fff5-4f11-b9ca-c35f18485b92"],
Cell[269593, 7115, 847, 19, 98113, "Input", "ExpressionUUID" -> \
"3c958c1a-4c7a-4d15-bc28-8617f23448cc"],
Cell[270443, 7136, 1021, 29, 236337, "Text", "ExpressionUUID" -> \
"91250002-2ffb-40fa-b157-57d8bef13b6b"],
Cell[271467, 7167, 275, 6, 98113, "Text", "ExpressionUUID" -> \
"58443493-e153-4b1a-b3e9-1ef526ec513b"],
Cell[271745, 7175, 1534, 35, 230109, "Input", "ExpressionUUID" -> \
"46c36673-1706-461a-93f1-70dcbd9ab116"],
Cell[273282, 7212, 146, 3, 98113, "Text", "ExpressionUUID" -> \
"33ff7074-c65f-47ef-aa65-d0bf45e18b5a"],
Cell[273431, 7217, 919, 22, 98113, "Input", "ExpressionUUID" -> \
"ca2a3088-140e-49a2-85ae-4b79201896a9"],
Cell[274353, 7241, 177, 4, 98113, "Input", "ExpressionUUID" -> \
"876cb72f-5209-492d-b4d5-949df960bcca"],
Cell[274533, 7247, 709, 12, 224916, "Text", "ExpressionUUID" -> \
"50bf57ca-3035-45d5-91d3-9eeb9bf08f4a"],
Cell[275245, 7261, 598, 13, 98113, "Input", "ExpressionUUID" -> \
"aa396baa-fbef-40a5-9191-7bd3e2fd10ff"],
Cell[275846, 7276, 644, 22, 98113, "Input", "ExpressionUUID" -> \
"5faf315f-38a6-4c40-9e7e-860b54315821"],
Cell[276493, 7300, 220, 5, 98113, "Text", "ExpressionUUID" -> \
"e1911cb5-8c14-4d6e-9c27-d81967eed684"],
Cell[276716, 7307, 601, 16, 98113, "Input", "ExpressionUUID" -> \
"7ce095b5-d94d-4bc6-acf6-f7c837b71ae9"],
Cell[277320, 7325, 275, 6, 98113, "Text", "ExpressionUUID" -> \
"6ddfe3e4-d995-41f6-9bcd-b81d6afdbf53"],
Cell[277598, 7333, 832, 20, 98113, "Input", "ExpressionUUID" -> \
"009efc67-9322-4104-a73f-31c8e3357618"],
Cell[278433, 7355, 892, 18, 289098, "Text", "ExpressionUUID" -> \
"74377d56-b14c-4af1-91a3-abafc635b03a"],
Cell[279328, 7375, 176, 4, 98113, "Input", "ExpressionUUID" -> \
"6b0f5dbe-56b5-45de-8deb-cd099ce6ad22"],
Cell[279507, 7381, 152, 3, 98113, "Text", "ExpressionUUID" -> \
"ef51e68c-ef59-4eec-9305-456e6e266d2e"],
Cell[279662, 7386, 2288, 56, 358438, "Input", "ExpressionUUID" -> \
"1291b375-a591-4b65-8b87-b89a9d3c8ad3",
 Evaluatable->False],
Cell[281953, 7444, 189, 4, 98113, "Input", "ExpressionUUID" -> \
"7ab71b9b-a5fc-4e48-8001-9fb673b97a68"],
Cell[282145, 7450, 341, 7, 162994, "Text", "ExpressionUUID" -> \
"35412170-d5b0-4da6-962a-7cd0f97d085f"],
Cell[282489, 7459, 1269, 30, 165363, "Input", "ExpressionUUID" -> \
"6d0b18c6-1dcc-4a02-84e4-34ce8c69bcd7",
 CellTags->"fund1"],
Cell[283761, 7491, 216, 3, 98113, "Text", "ExpressionUUID" -> \
"5af2a714-0073-4dcd-8d26-e6ad0cf5a4fa"],
Cell[283980, 7496, 868, 15, 289098, "Text", "ExpressionUUID" -> \
"b36f9b4c-a357-4e74-b545-83e9e7d3a4aa"],
Cell[284851, 7513, 347, 9, 162994, "Text", "ExpressionUUID" -> \
"e033a15f-0e3e-49d6-be66-15f883a9e55a"],
Cell[285201, 7524, 424, 7, 98113, "Input", "ExpressionUUID" -> \
"5fceb009-99be-4791-999a-0f0437b70df3"],
Cell[285628, 7533, 187, 4, 98113, "Input", "ExpressionUUID" -> \
"895a5121-b708-44a4-b635-2bc6e5a9d51c"],
Cell[285818, 7539, 2137, 56, 358438, "Input", "ExpressionUUID" -> \
"a2d8ecd2-fd87-4a23-ac18-e316cb4b914f",
 Evaluatable->False,
 CellTags->"rgT"],
Cell[287958, 7597, 181, 3, 98113, "Text", "ExpressionUUID" -> \
"c853c20c-5897-4edf-9d22-228a14258d81"],
Cell[288142, 7602, 288, 9, 98113, "Input", "ExpressionUUID" -> \
"6f70ffe7-8edb-4044-86ad-10be4270b455"],
Cell[288433, 7613, 338, 10, 98113, "Input", "ExpressionUUID" -> \
"590f0c99-0132-4069-b2eb-b74193dec64f"],
Cell[288774, 7625, 390, 11, 98113, "Input", "ExpressionUUID" -> \
"8b352578-7755-49d0-a074-8dc47c217e3b"],
Cell[289167, 7638, 563, 12, 98113, "Input", "ExpressionUUID" -> \
"7b225e6b-5bd5-494e-a460-563a0f13cfe8"],
Cell[289733, 7652, 762, 15, 98113, "Input", "ExpressionUUID" -> \
"071003f6-42f2-4c58-a475-2cc0187f69bc"],
Cell[290498, 7669, 221, 5, 98113, "Text", "ExpressionUUID" -> \
"fc0fdbe2-7ffb-4624-8852-64ee2b99e6cf"],
Cell[290722, 7676, 621, 16, 98113, "Input", "ExpressionUUID" -> \
"25fb8b27-77de-46a4-867b-3853abc01936"],
Cell[291346, 7694, 1421, 41, 293193, "Input", "ExpressionUUID" -> \
"0f02c906-264e-4146-ae04-290762505a00"],
Cell[292770, 7737, 239, 6, 100878, "Text", "ExpressionUUID" -> \
"0c2487d5-5e47-45f8-9b9c-db0a4c10e9db"],
Cell[293012, 7745, 2121, 55, 234037, "Input", "ExpressionUUID" -> \
"c0cc65e1-ce30-4e63-8113-9ba63ed9a159"],
Cell[295136, 7802, 270, 6, 162994, "Text", "ExpressionUUID" -> \
"16b10e2d-bc4c-4598-8c64-c02dfea816e7"],
Cell[295409, 7810, 1051, 27, 165363, "Input", "ExpressionUUID" -> \
"98b683a1-dfff-472b-a793-d738952e8ec8"],
Cell[296463, 7839, 655, 12, 297870, "Text", "ExpressionUUID" -> \
"e9283cac-f694-4ecd-b97b-6e94f35a8903"],
Cell[297121, 7853, 1912, 35, 224916, "Text", "ExpressionUUID" -> \
"15b49bd8-af68-42dc-94ff-bbe33ba5bc59",
 CellTags->"g(i"],
Cell[299036, 7890, 1809, 32, 234037, "Text", "ExpressionUUID" -> \
"7d57fac0-f7a8-4248-b16e-a41a8aca77a6",
 CellTags->"g(i"],
Cell[300848, 7924, 464, 11, 98113, "Input", "ExpressionUUID" -> \
"6448d268-ab37-4667-ae04-455886e0e87d"],
Cell[301315, 7937, 343, 7, 162994, "Text", "ExpressionUUID" -> \
"b5350403-91f7-469f-b69d-e5242f113e1d"],
Cell[301661, 7946, 454, 11, 98113, "Input", "ExpressionUUID" -> \
"d0b8b223-663b-4185-8dbf-66069efbbf51"],
Cell[302118, 7959, 527, 12, 98113, "Input", "ExpressionUUID" -> \
"0eb1bba5-a302-4690-b03d-f07f39ee7fec"],
Cell[302648, 7973, 156, 3, 98113, "Text", "ExpressionUUID" -> \
"790cf409-4b01-4975-b17e-fd8a4ab274e4"],
Cell[302807, 7978, 903, 23, 98113, "Input", "ExpressionUUID" -> \
"14a76b67-5663-4b9b-99f4-7ee2b3a55306"],
Cell[303713, 8003, 380, 10, 102727, "Text", "ExpressionUUID" -> \
"d4936a14-5ec0-4519-b2e6-d8a21bfbf43b"],
Cell[304096, 8015, 392, 10, 98113, "Text", "ExpressionUUID" -> \
"47c2b9cb-76ec-48a8-8340-eb25639e0d8a"],
Cell[304491, 8027, 177, 4, 98113, "Input", "ExpressionUUID" -> \
"c11a4fe0-2d30-4a87-a692-e2b842d0e55d"],
Cell[304671, 8033, 766, 19, 98113, "Input", "ExpressionUUID" -> \
"c2cfb174-268c-4c08-a0a9-80b489ecf04d"],
Cell[305440, 8054, 208, 3, 98113, "Text", "ExpressionUUID" -> \
"2d12816f-2a91-4106-b11a-480abf8e730f"],
Cell[305651, 8059, 1091, 31, 165363, "Input", "ExpressionUUID" -> \
"d387df20-89b6-42ce-a1e1-530c06f46661"],
Cell[306745, 8092, 593, 18, 165363, "Input", "ExpressionUUID" -> \
"4046bba3-991d-4594-8251-cb8d5d30a819"],
Cell[307341, 8112, 458, 12, 162994, "Text", "ExpressionUUID" -> \
"cd02ca80-c591-4537-91bb-c3a014c130fa"],
Cell[307802, 8126, 719, 20, 165363, "Input", "ExpressionUUID" -> \
"a2169651-ea3e-4605-87ad-61fb48cfc89b",
 InitializationCell->True],
Cell[308524, 8148, 396, 9, 230109, "Input", "ExpressionUUID" -> \
"e4707856-fcda-463f-970d-92b95dc70d25",
 InitializationCell->True],
Cell[308923, 8159, 407, 8, 162994, "Text", "ExpressionUUID" -> \
"de180a98-c5fa-4406-9d34-967edb0d575b"],
Cell[309333, 8169, 732, 22, 165363, "Input", "ExpressionUUID" -> \
"2a1b0c58-a2cd-4097-b9e5-0f3bebc7cf34"],
Cell[310068, 8193, 402, 8, 162994, "Text", "ExpressionUUID" -> \
"7772f007-4e72-4ed2-b2df-8b7cb5eaaa4f"],
Cell[310473, 8203, 223, 6, 98113, "Input", "ExpressionUUID" -> \
"3f8c3be6-4bdf-457e-be9f-2d3f01a0a1df"],
Cell[310699, 8211, 807, 21, 230109, "Input", "ExpressionUUID" -> \
"c62f40b8-f447-40ea-9695-bf83eb4d743b"],
Cell[311509, 8234, 155, 3, 98113, "Input", "ExpressionUUID" -> \
"52ccda34-8a47-4eb3-8040-04c82eaa6a34"],
Cell[311667, 8239, 192, 3, 98113, "Text", "ExpressionUUID" -> \
"16dbceb0-7a41-4a2c-a78a-40e131688f20"],
Cell[311862, 8244, 1236, 32, 230109, "Input", "ExpressionUUID" -> \
"d3496e42-88cb-4af5-887a-f896fb6424a8"],
Cell[313101, 8278, 1362, 33, 165363, "Input", "ExpressionUUID" -> \
"b6f88685-bbc2-4321-831c-c5e75aa6f692"],
Cell[314466, 8313, 597, 16, 98113, "Text", "ExpressionUUID" -> \
"f78e2baf-2f9e-4750-a942-9bbd295e8481"],
Cell[315066, 8331, 308, 6, 98113, "Input", "ExpressionUUID" -> \
"3d30dcbe-d93e-4595-9011-4fd52afe0bfa"],
Cell[315377, 8339, 1306, 29, 165363, "Input", "ExpressionUUID" -> \
"e72e6916-087c-4522-84df-7f3b4c7f9f68",
 Evaluatable->False],
Cell[316686, 8370, 640, 12, 162994, "Text", "ExpressionUUID" -> \
"e23220c9-f219-45e9-99b0-3f74010d4a56"],
Cell[317329, 8384, 353, 8, 98113, "Text", "ExpressionUUID" -> \
"a2babf2d-6e03-4086-8fd4-977964b552e6"],
Cell[317685, 8394, 242, 7, 98113, "Input", "ExpressionUUID" -> \
"2c84e9f8-9b89-4125-bd53-f3e33c164852"],
Cell[317930, 8403, 443, 10, 98113, "Input", "ExpressionUUID" -> \
"8b83e8a0-eb67-46c0-a180-e5866bb5c78d"],
Cell[318376, 8415, 1149, 25, 165363, "Input", "ExpressionUUID" -> \
"6e15a345-b87e-44d2-84f9-3a719d4832e3"],
Cell[319528, 8442, 161, 3, 98113, "Text", "ExpressionUUID" -> \
"7ef300ac-562b-49dc-9e56-02778f08dfaf"],
Cell[319692, 8447, 862, 16, 289098, "Text", "ExpressionUUID" -> \
"756034e0-4f89-4cdb-a3b4-c93181d02281"],
Cell[320557, 8465, 277, 8, 98113, "Text", "ExpressionUUID" -> \
"f611733d-c667-4744-bab8-3cdee57dbb77"],
Cell[320837, 8475, 366, 10, 98113, "Input", "ExpressionUUID" -> \
"eebe1045-4d28-4380-be3c-5d3b65e6032d"],
Cell[321206, 8487, 311, 5, 98113, "Text", "ExpressionUUID" -> \
"3813f614-b444-4ffa-9222-48c6d1cb744f"],
Cell[321520, 8494, 416, 11, 98113, "Input", "ExpressionUUID" -> \
"2fcc5255-a6fb-4a41-a0ed-4a04768d1caf"],
Cell[321939, 8507, 247, 5, 98113, "Text", "ExpressionUUID" -> \
"0b2065d0-0231-402d-a1df-9ed727cdccbf"],
Cell[322189, 8514, 711, 19, 98113, "Input", "ExpressionUUID" -> \
"85e289e6-54d1-48c9-b891-035f6af7178f"],
Cell[322903, 8535, 689, 16, 165363, "Input", "ExpressionUUID" -> \
"e563fa4e-c61d-405c-aabe-93af47d172a3"],
Cell[323595, 8553, 161, 3, 98113, "Text", "ExpressionUUID" -> \
"bb416247-75c6-468c-bebb-8b38e3a46707"],
Cell[323759, 8558, 366, 10, 98113, "Input", "ExpressionUUID" -> \
"338140cd-631f-414f-8d88-ea022c652b1c"],
Cell[324128, 8570, 197, 3, 98113, "Text", "ExpressionUUID" -> \
"7067df43-f4ca-42a2-aedd-c9c1de10967f"],
Cell[324328, 8575, 750, 17, 98113, "Input", "ExpressionUUID" -> \
"70691998-fb92-4d10-9ec3-79166fc35360"],
Cell[325081, 8594, 677, 15, 231135, "Text", "ExpressionUUID" -> \
"7f49e6a2-399c-4473-9b22-5dbeebd1d035"],
Cell[325761, 8611, 596, 13, 230109, "Text", "ExpressionUUID" -> \
"ca61e132-2458-4333-bfdb-7b1e4a6ce415"],
Cell[326360, 8626, 544, 16, 165363, "Input", "ExpressionUUID" -> \
"e5cc2a44-75ef-4c39-9c96-d26aa6c90650"],
Cell[326907, 8644, 406, 11, 98113, "Text", "ExpressionUUID" -> \
"2db4ddab-cd18-4b7c-8b53-e061f6dcc005"],
Cell[327316, 8657, 1517, 46, 293193, "Input", "ExpressionUUID" -> \
"d9a33a25-09f2-4ce8-a1fd-6ceadff91c32"],
Cell[328836, 8705, 147, 3, 98113, "Text", "ExpressionUUID" -> \
"1a2b8852-b4b3-4017-9f38-3de3605c23e2"],
Cell[328986, 8710, 610, 17, 98113, "Input", "ExpressionUUID" -> \
"a6ca2df2-7e93-4d5a-8dd9-e0a409cf71b1"],
Cell[329599, 8729, 417, 8, 289098, "Text", "ExpressionUUID" -> \
"b4fd9c52-5d32-464c-8dd3-b2e77c4df993"],
Cell[330019, 8739, 2027, 59, 421957, "Input", "ExpressionUUID" -> \
"62e77eb5-f931-4a0c-98c5-4e69bcb1fc56"],
Cell[332049, 8800, 374, 8, 162994, "Text", "ExpressionUUID" -> \
"0d22035d-994d-4e04-a221-1f04b7c7a9ca"]
}, Closed]],
Cell[CellGroupData[{
Cell[332460, 8813, 932, 13, 42, "Subsubsection", "ExpressionUUID" -> \
"b2175e24-507e-43c3-b111-059b2379de01"],
Cell[333395, 8828, 241, 4, 98113, "Text", "ExpressionUUID" -> \
"e89db75f-40f8-45f4-8e78-79b8de3b2fe7"],
Cell[333639, 8834, 369, 8, 98113, "Input", "ExpressionUUID" -> \
"dcf5519b-713e-45c1-b6b3-ac9502b00169"],
Cell[334011, 8844, 208, 5, 98113, "Input", "ExpressionUUID" -> \
"44cd7295-a5cf-40bb-837b-89c9b5c6ff37"],
Cell[CellGroupData[{
Cell[334244, 8853, 702, 19, 98113, "Input", "ExpressionUUID" -> \
"25930684-f1fb-4e78-98d4-f7da6962e776",
 InitializationCell->True],
Cell[334949, 8874, 443, 14, 70, "Output", "ExpressionUUID" -> \
"da070c0a-974a-4fc6-9cc3-e580bb0576cf"]
}, Open  ]],
Cell[335407, 8891, 548, 12, 106204, "Text", "ExpressionUUID" -> \
"de3e93dc-8786-4303-970b-a5ae5df22da9"],
Cell[335958, 8905, 319, 8, 98113, "Input", "ExpressionUUID" -> \
"32d2d0f1-5239-4b7d-99c7-b6f4e8f6d896",
 Evaluatable->False],
Cell[336280, 8915, 348, 5, 98113, "Text", "ExpressionUUID" -> \
"564f165b-1620-4580-842a-588ea4eaffe7"],
Cell[336631, 8922, 886, 23, 98113, "Input", "ExpressionUUID" -> \
"a30c99a7-3722-45c0-919c-a7c075a8fb8a",
 Evaluatable->False],
Cell[337520, 8947, 577, 16, 98113, "Input", "ExpressionUUID" -> \
"96a5fa49-8bd9-40fd-9380-c3b5e84c0383"],
Cell[338100, 8965, 893, 20, 200821, "Input", "ExpressionUUID" -> \
"6490ae30-0a51-4c9f-81f6-ae9f8762d187",
 Evaluatable->False],
Cell[338996, 8987, 740, 12, 224916, "Text", "ExpressionUUID" -> \
"bbe2ada9-72b5-4cc0-8edc-2ae5b72468cc"],
Cell[339739, 9001, 677, 18, 102727, "Input", "ExpressionUUID" -> \
"0a979e5c-da2f-4298-abde-0da9d394f97a",
 Evaluatable->False],
Cell[340419, 9021, 1965, 32, 730521, "Text", "ExpressionUUID" -> \
"ddde1d89-7da1-42b0-b3a5-731a07823633"],
Cell[342387, 9055, 1159, 29, 165363, "Input", "ExpressionUUID" -> \
"b8fa3496-54da-4946-ab86-7218d3336830",
 InitializationCell->True],
Cell[343549, 9086, 256, 6, 98113, "Input", "ExpressionUUID" -> \
"44c63143-9da5-4530-9566-6042418278aa"],
Cell[343808, 9094, 949, 20, 293193, "Text", "ExpressionUUID" -> \
"715aac1e-4332-4f8e-be3c-411e1e67be46"],
Cell[344760, 9116, 469, 11, 162994, "Text", "ExpressionUUID" -> \
"d2941a41-c3cf-4e00-ad91-dcf4530001b2"],
Cell[345232, 9129, 390, 11, 98113, "Input", "ExpressionUUID" -> \
"8d529bd2-998b-4330-bbfe-9da8719c6140",
 Evaluatable->False],
Cell[345625, 9142, 302, 5, 98113, "Text", "ExpressionUUID" -> \
"93344a6d-6781-4811-9bc1-89a965ded4d2"],
Cell[345930, 9149, 1260, 36, 195462, "Text", "ExpressionUUID" -> \
"5f9e9458-8c19-42dc-a97b-adfdb87b7562",
 CellTags->"ptr"],
Cell[347193, 9187, 472, 11, 162994, "Text", "ExpressionUUID" -> \
"7e64db05-88b9-414a-8c84-71866e523e10"],
Cell[347668, 9200, 701, 17, 110242, "Input", "ExpressionUUID" -> \
"42e78552-7a3b-4f7e-b605-2361a14be1da",
 Evaluatable->False],
Cell[348372, 9219, 817, 19, 177513, "Text", "ExpressionUUID" -> \
"2cc35a51-6d30-4665-a4b4-858c923a01da"],
Cell[349192, 9240, 360, 9, 98113, "Input", "ExpressionUUID" -> \
"6ff57a55-dd94-4f34-b4d6-bb3faf272e14"],
Cell[349555, 9251, 300, 7, 162994, "Text", "ExpressionUUID" -> \
"647f8631-14fb-4d39-9fca-009ed911e5a0"],
Cell[349858, 9260, 673, 13, 168129, "Text", "ExpressionUUID" -> \
"c511aabe-04a0-4bf7-946e-1da200680eb2"],
Cell[350534, 9275, 799, 16, 231135, "Text", "ExpressionUUID" -> \
"c062ea32-d5f1-4cc4-9c71-612b1898c416"],
Cell[351336, 9293, 361, 7, 98113, "Input", "ExpressionUUID" -> \
"363a5d65-b0d2-49ce-b35e-38739b9f097a"],
Cell[351700, 9302, 344, 5, 98113, "Text", "ExpressionUUID" -> \
"47eaae74-86f3-4802-947b-8203f092f152"],
Cell[352047, 9309, 687, 13, 98113, "Input", "ExpressionUUID" -> \
"498273af-2371-4342-b1fd-c6943c5094a0"],
Cell[352737, 9324, 338, 5, 100878, "Text", "ExpressionUUID" -> \
"caba955a-ecd4-4dca-8d9b-44fee86d1d03"],
Cell[353078, 9331, 1369, 29, 563944, "Text", "ExpressionUUID" -> \
"fc49d812-24d9-47b8-ba11-30aca4080185"],
Cell[354450, 9362, 179, 4, 98113, "Input", "ExpressionUUID" -> \
"52b062dd-559d-4495-b2fc-b1f52476c26f"],
Cell[354632, 9368, 224, 5, 98113, "Input", "ExpressionUUID" -> \
"d1e24684-bdbf-44d5-91c5-1317964a0f23"],
Cell[354859, 9375, 1809, 39, 289098, "Text", "ExpressionUUID" -> \
"8a01e5e3-aa35-4fd7-99cc-921fbb4460ba"],
Cell[356671, 9416, 221, 4, 98113, "Input", "ExpressionUUID" -> \
"e00b0ad0-69a9-4634-8e9a-d530f30a6e22"],
Cell[356895, 9422, 519, 13, 98113, "Input", "ExpressionUUID" -> \
"4a6bcf54-12f5-46cb-b77d-7d0b35651909"],
Cell[357417, 9437, 503, 9, 224916, "Text", "ExpressionUUID" -> \
"3c5961e9-3e0a-4bc3-b6db-85ce65790d24"],
Cell[357923, 9448, 847, 15, 224916, "Text", "ExpressionUUID" -> \
"de92fb83-858e-41f8-bcef-209fbddd714d"],
Cell[358773, 9465, 1003, 25, 165363, "Input", "ExpressionUUID" -> \
"3f492188-353c-4039-b39e-52ce526005f4",
 InitializationCell->True],
Cell[359779, 9492, 258, 7, 98113, "Input", "ExpressionUUID" -> \
"a5be5376-187f-4bcf-8031-8f41a24531af"],
Cell[360040, 9501, 407, 11, 162994, "Text", "ExpressionUUID" -> \
"30ba7a60-128c-4c35-a80c-b786e3c0d834"],
Cell[360450, 9514, 588, 18, 98113, "Input", "ExpressionUUID" -> \
"d8393130-b9c3-42fd-9d2f-f54abb467ff0"],
Cell[361041, 9534, 367, 8, 98113, "Input", "ExpressionUUID" -> \
"a57c58a9-b244-4817-bf77-010bc1c2600a"],
Cell[361411, 9544, 1033, 22, 168129, "Text", "ExpressionUUID" -> \
"5e2ca991-057a-4556-b640-022b18433a86"],
Cell[362447, 9568, 344, 9, 98113, "Input", "ExpressionUUID" -> \
"b6d1fa77-573f-44e3-a88a-fd99035225c6"],
Cell[362794, 9579, 448, 13, 98113, "Input", "ExpressionUUID" -> \
"c63a0cb0-46f4-450e-a64b-7160b59c450e"],
Cell[363245, 9594, 174, 4, 98113, "Input", "ExpressionUUID" -> \
"ed812b89-c9d1-4a60-9576-e0afd5640b07"],
Cell[363422, 9600, 283, 7, 98113, "Text", "ExpressionUUID" -> \
"d68bb581-21b7-4cab-841a-bd1099903db8"],
Cell[363708, 9609, 445, 11, 98113, "Input", "ExpressionUUID" -> \
"67da134c-25e2-4365-9263-0731d94e2334"],
Cell[364156, 9622, 321, 8, 98113, "Input", "ExpressionUUID" -> \
"6d374882-d088-41f4-9056-81bd0f6d4b11"],
Cell[364480, 9632, 358, 7, 162994, "Text", "ExpressionUUID" -> \
"b46f75e6-4fe0-41bd-824e-4990e09469eb"],
Cell[364841, 9641, 327, 9, 98113, "Input", "ExpressionUUID" -> \
"6309df72-5691-421d-a68f-5b71aaf85b27"],
Cell[365171, 9652, 174, 4, 98113, "Input", "ExpressionUUID" -> \
"b35486ca-320e-4a49-9247-4b839f05de26"],
Cell[365348, 9658, 228, 5, 98113, "Input", "ExpressionUUID" -> \
"4396a36a-98f8-4d87-8f9f-7d1860696877"],
Cell[365579, 9665, 160, 3, 98113, "Text", "ExpressionUUID" -> \
"7bacae35-826c-4761-9c6c-37862c5d4486"],
Cell[365742, 9670, 398, 11, 98113, "Input", "ExpressionUUID" -> \
"63d5d134-114c-4131-b3f1-fda45f238f82"],
Cell[366143, 9683, 366, 9, 98113, "Input", "ExpressionUUID" -> \
"d33b4b6f-e017-4c17-94e4-7b933834ba0a"],
Cell[366512, 9694, 181, 3, 98113, "Text", "ExpressionUUID" -> \
"45d8248c-72e6-4bcb-8659-f1366f548eaa"],
Cell[366696, 9699, 219, 5, 98113, "Input", "ExpressionUUID" -> \
"ac9bf885-897c-42f4-bf87-c00b5d8961a8"],
Cell[366918, 9706, 397, 10, 98113, "Input", "ExpressionUUID" -> \
"b5fd850e-f6cb-4333-bf3a-3f2058ceff94"],
Cell[367318, 9718, 1540, 23, 416211, "Text", "ExpressionUUID" -> \
"ec708b96-9871-40fc-be84-a3e44ed36bd1"],
Cell[368861, 9743, 244, 5, 98113, "Input", "ExpressionUUID" -> \
"63c3831a-8dbb-439e-a079-f3942d384026"],
Cell[369108, 9750, 209, 4, 98113, "Text", "ExpressionUUID" -> \
"b073b776-31e5-4811-b20a-635634942684"],
Cell[369320, 9756, 309, 8, 98113, "Input", "ExpressionUUID" -> \
"a557014b-a7b2-4ec1-9a77-43d0d52fb399"],
Cell[369632, 9766, 171, 3, 98113, "Text", "ExpressionUUID" -> \
"5b330d4c-ee92-4d13-b28c-7ff33f92dd2f"],
Cell[369806, 9771, 291, 7, 98113, "Input", "ExpressionUUID" -> \
"453a076f-e898-4832-a9f3-499bcf70f47f"],
Cell[370100, 9780, 249, 4, 98113, "Text", "ExpressionUUID" -> \
"58c0b79e-052f-4b57-9b5d-f2d3ef7731c6"],
Cell[370352, 9786, 329, 8, 98113, "Input", "ExpressionUUID" -> \
"f2e8eb1a-f3d9-4034-9731-4f70c88c56f4"],
Cell[370684, 9796, 194, 3, 98113, "Text", "ExpressionUUID" -> \
"374e7e28-7530-49dd-a263-5814076b74cd"],
Cell[370881, 9801, 337, 8, 98113, "Input", "ExpressionUUID" -> \
"89572722-33e3-4b94-90b9-19a9e60269b5"],
Cell[371221, 9811, 378, 7, 98113, "Text", "ExpressionUUID" -> \
"7f405db4-c5af-401b-8e32-aa6155c75ae4"],
Cell[371602, 9820, 153, 3, 98113, "Input", "ExpressionUUID" -> \
"5e3683e7-137f-48f2-a7a6-57c2499b00d9"],
Cell[371758, 9825, 181, 4, 98113, "Input", "ExpressionUUID" -> \
"2726d666-ab84-4a36-8bff-a8201fc3d554"],
Cell[371942, 9831, 315, 8, 98113, "Input", "ExpressionUUID" -> \
"e8ec50a4-a598-4b96-945c-b914337f43a6"],
Cell[372260, 9841, 162, 3, 98113, "Text", "ExpressionUUID" -> \
"84927f7f-7835-4aba-9954-a592c37ca36a"],
Cell[372425, 9846, 655, 20, 98113, "Input", "ExpressionUUID" -> \
"e2c90dbf-892e-44af-b51a-8fbf81ef3afc",
 Evaluatable->False],
Cell[373083, 9868, 494, 9, 231135, "Text", "ExpressionUUID" -> \
"20aa9d42-0df8-4fcc-a460-e0382cfd0a22"],
Cell[373580, 9879, 918, 19, 362740, "Text", "ExpressionUUID" -> \
"e55dfd8d-1baa-466a-85b8-1afb1f228e12"]
}, Closed]],
Cell[CellGroupData[{
Cell[374535, 9903, 410, 6, 42, "Subsubsection", "ExpressionUUID" -> \
"3c41b8fd-833c-462d-8b54-7d335841ceb3"],
Cell[374948, 9911, 964, 16, 132387, "Text", "ExpressionUUID" -> \
"2fd01094-027d-4e72-8ba2-8e4b484a83a0"],
Cell[375915, 9929, 621, 15, 43606, "Input", "ExpressionUUID" -> \
"9fdb2383-8c96-4fc4-aa33-62051fe24650",
 Evaluatable->False],
Cell[376539, 9946, 166, 4, 43606, "Input", "ExpressionUUID" -> \
"692eec10-7916-49c0-a507-9cbf0eed1b9a"],
Cell[376708, 9952, 146, 3, 43606, "Text", "ExpressionUUID" -> \
"90b45682-8c4a-4603-8181-a18c9c1a70b4"],
Cell[376857, 9957, 385, 7, 43606, "Input", "ExpressionUUID" -> \
"65d5d34b-fdff-4185-b849-a952e7c5561b"],
Cell[377245, 9966, 1664, 42, 102271, "Input", "ExpressionUUID" -> \
"b18349f8-8aa4-4e4c-b235-8bcc049c1a29"],
Cell[378912, 10010, 842, 16, 131491, "Text", "ExpressionUUID" -> \
"4196591e-c9ab-45e2-8fca-83b9282c77fb"],
Cell[379757, 10028, 1973, 38, 100878, "Text", "ExpressionUUID" -> \
"1a61c890-2b01-4772-8f70-89babbc362eb"],
Cell[381733, 10068, 515, 16, 43606, "Input", "ExpressionUUID" -> \
"1f344dea-9282-4e31-a173-624d424798f9"],
Cell[382251, 10086, 492, 12, 43606, "Input", "ExpressionUUID" -> \
"e74c2cf4-5f51-4b65-92ce-07aed201fe81"],
Cell[382746, 10100, 312, 7, 43606, "Text", "ExpressionUUID" -> \
"f9336e3b-79bd-4e94-841e-d413214cbe8f"],
Cell[383061, 10109, 652, 16, 47202, "Input", "ExpressionUUID" -> \
"1db6763a-aedc-46f6-bfe9-37a76d2492e0",
 Evaluatable->False],
Cell[383716, 10127, 505, 10, 102727, "Text", "ExpressionUUID" -> \
"0853b47b-0bf4-4b66-8fbc-e70a113cdb52"],
Cell[384224, 10139, 416, 12, 43606, "Input", "ExpressionUUID" -> \
"db4e7881-5b42-4d67-a49f-363c1260f8b5",
 Evaluatable->False],
Cell[384643, 10153, 425, 10, 43606, "Text", "ExpressionUUID" -> \
"5b32d196-fea6-4d7a-8f73-f426bb7fa4e5"],
Cell[385071, 10165, 1062, 25, 73495, "Input", "ExpressionUUID" -> \
"47ba33d2-f97f-4e31-b507-d3faf7a9e898"],
Cell[386136, 10192, 161, 3, 43606, "Text", "ExpressionUUID" -> \
"2348e1c3-86ed-4113-9026-b35804152d2d"],
Cell[386300, 10197, 994, 21, 74724, "Text", "ExpressionUUID" -> \
"7cb662b2-ff8e-4170-b194-89ede5163b5e"],
Cell[387297, 10220, 863, 23, 48997, "Input", "ExpressionUUID" -> \
"844271ca-ac92-4eed-bf92-ce31bb37fb01",
 Evaluatable->False],
Cell[388163, 10245, 177, 4, 43606, "Input", "ExpressionUUID" -> \
"6703e91f-6b8a-4d2e-a715-17e1d8e8963c"],
Cell[388343, 10251, 173, 4, 43606, "Input", "ExpressionUUID" -> \
"7cce37f9-52ae-43aa-ba21-57e6a2ebc32c"],
Cell[388519, 10257, 744, 21, 73495, "Input", "ExpressionUUID" -> \
"ec89b802-f5ed-49a4-afa5-d3a3e7179f3f"],
Cell[389266, 10280, 2620, 53, 281305, "Text", "ExpressionUUID" -> \
"1b788730-99ef-4b16-a168-cdcb15df0cde"],
Cell[391889, 10335, 346, 10, 70803, "Input", "ExpressionUUID" -> \
"d7f5776d-0e01-4a99-a6b0-ea356a21ead4",
 Evaluatable->False],
Cell[392238, 10347, 1258, 22, 74724, "Text", "ExpressionUUID" -> \
"29d5b716-a82c-4e84-9118-70c2e17a56c0"],
Cell[393499, 10371, 1539, 35, 73495, "Input", "ExpressionUUID" -> \
"dae48903-8840-4856-8353-b682bd9db8f3",
 Evaluatable->False],
Cell[395041, 10408, 3777, 66, 102271, "Text", "ExpressionUUID" -> \
"b65527f9-20e6-4e1d-a063-f96f2093a94b"],
Cell[398821, 10476, 738, 18, 43606, "Input", "ExpressionUUID" -> \
"389c0dd9-778e-446f-a2e2-1d2c37fb269e",
 Evaluatable->False],
Cell[399562, 10496, 2807, 62, 110506, "Text", "ExpressionUUID" -> \
"7e3ee5ca-d782-4e67-8abe-80c4c9b83729"],
Cell[402372, 10560, 1620, 42, 102271, "Input", "ExpressionUUID" -> \
"d7c0a974-d8c4-4433-9701-d604ff74ee3f"],
Cell[403995, 10604, 390, 8, 72442, "Text", "ExpressionUUID" -> \
"3d2d2437-62ac-4d4b-be86-7a363b15362c"],
Cell[404388, 10614, 3636, 76, 226053, "Text", "ExpressionUUID" -> \
"272a1d1c-acb3-4c58-ac80-07f6cfd224e8"],
Cell[408027, 10692, 453, 12, 43606, "Input", "ExpressionUUID" -> \
"4314c209-0028-41ff-99b0-0e018636e0fe",
 Evaluatable->False],
Cell[408483, 10706, 896, 19, 132387, "Text", "ExpressionUUID" -> \
"204f8d96-1de8-4cc9-b2bf-a0db9f7b2c9f"],
Cell[409382, 10727, 570, 14, 43606, "Input", "ExpressionUUID" -> \
"87df5540-502d-4234-89fa-5dfc2b5be615",
 Evaluatable->False],
Cell[409955, 10743, 411, 8, 43606, "Text", "ExpressionUUID" -> \
"cc6a9380-a86c-4df9-8345-1b7650b587c7"],
Cell[410369, 10753, 308, 8, 43606, "Input", "ExpressionUUID" -> \
"3719605b-5cda-4b5c-8d77-6622b4e04feb",
 Evaluatable->False],
Cell[410680, 10763, 423, 9, 43606, "Text", "ExpressionUUID" -> \
"9ba080d5-1b1f-43a0-97cd-1f2e884ae6b7"],
Cell[411106, 10774, 323, 8, 43606, "Input", "ExpressionUUID" -> \
"ea65de98-31eb-423f-b8de-73644e9fb725"],
Cell[411432, 10784, 1130, 25, 78670, "Text", "ExpressionUUID" -> \
"32aaf051-360b-463b-bb9c-3b3d21539108"],
Cell[412565, 10811, 634, 12, 74724, "Text", "ExpressionUUID" -> \
"9b7869c6-f70a-4da4-a3fe-6c3a91361217"],
Cell[413202, 10825, 536, 16, 43606, "Input", "ExpressionUUID" -> \
"5765e49b-6939-4e40-830d-e20ec5a14f14",
 Evaluatable->False],
Cell[413741, 10843, 569, 13, 75208, "Text", "ExpressionUUID" -> \
"3406f4cd-59a0-4831-866f-8224d874191c"],
Cell[414313, 10858, 641, 18, 43606, "Input", "ExpressionUUID" -> \
"5805d173-a1c7-4fa1-b453-08df792e485d"],
Cell[414957, 10878, 757, 12, 102727, "Text", "ExpressionUUID" -> \
"d31b3a24-e906-4225-bcb0-4d943795f81a"],
Cell[415717, 10892, 815, 21, 43606, "Input", "ExpressionUUID" -> \
"c1211edf-f3aa-4310-910d-cea517056cb0",
 Evaluatable->False],
Cell[416535, 10915, 730, 18, 72442, "Text", "ExpressionUUID" -> \
"a8cf378f-666e-416b-a77f-0cb02ee0d9f9"],
Cell[417268, 10935, 629, 16, 43606, "Input", "ExpressionUUID" -> \
"73c7c4bb-4559-47c7-a1cb-ef0697fa9830"],
Cell[417900, 10953, 473, 14, 43606, "Input", "ExpressionUUID" -> \
"6752d97b-2bbd-4c90-8a37-644acf5babe4"],
Cell[418376, 10969, 766, 18, 43606, "Input", "ExpressionUUID" -> \
"4b212208-ba4d-4e98-a418-eb752042c685"],
Cell[419145, 10989, 282, 7, 43606, "Input", "ExpressionUUID" -> \
"38c205b0-8605-4a2d-b1bd-a1bab437842e"],
Cell[419430, 10998, 607, 18, 43606, "Input", "ExpressionUUID" -> \
"d1445ed3-a433-4f5e-bddd-7c40124f0e96"],
Cell[420040, 11018, 1050, 22, 131491, "Text", "ExpressionUUID" -> \
"a0edc508-e5d1-4f51-b8ce-1ef5ae77c4fd"],
Cell[421093, 11042, 582, 17, 43606, "Input", "ExpressionUUID" -> \
"01071464-0d88-4308-a7e8-47ad04892745"],
Cell[421678, 11061, 443, 13, 43606, "Input", "ExpressionUUID" -> \
"c866bb69-f3b0-4af7-8393-641c003dd566"],
Cell[422124, 11076, 238, 5, 43606, "Text", "ExpressionUUID" -> \
"8594be5c-e0c3-49f5-b6af-1e7795980b99"],
Cell[422365, 11083, 837, 17, 43606, "Input", "ExpressionUUID" -> \
"950130ec-b144-447b-8edb-643b52bd11de"],
Cell[423205, 11102, 201, 3, 43606, "Text", "ExpressionUUID" -> \
"e3cd5df2-df30-42a1-b94e-bcb579dcb11d"],
Cell[423409, 11107, 1623, 40, 102271, "Input", "ExpressionUUID" -> \
"b5bf5a70-ec3d-4387-981c-d0ecf7b3dd10"],
Cell[425035, 11149, 159, 3, 43606, "Text", "ExpressionUUID" -> \
"bf8634ac-9f9f-4738-8ba9-e2ba10b591fd"],
Cell[425197, 11154, 257, 5, 74724, "Text", "ExpressionUUID" -> \
"27044026-afa9-4488-86e7-fa67fc46ee97"],
Cell[425457, 11161, 806, 18, 123729, "Input", "ExpressionUUID" -> \
"9a71b3e8-f823-4cfb-b126-29040623b615",
 Evaluatable->False],
Cell[426266, 11181, 255, 6, 72442, "Text", "ExpressionUUID" -> \
"93d52932-64b6-4a5a-a73d-885ce94570af"],
Cell[426524, 11189, 1219, 27, 90324, "Input", "ExpressionUUID" -> \
"82cf669f-085e-4ca2-9928-98f94640bdf8",
 Evaluatable->False],
Cell[427746, 11218, 362, 8, 43606, "Text", "ExpressionUUID" -> \
"13d63717-5373-4225-af3a-74d38a084bcc"],
Cell[428111, 11228, 664, 20, 73495, "Input", "ExpressionUUID" -> \
"66d93224-5014-4109-8eb5-c9b415373d76"],
Cell[428778, 11250, 231, 6, 43606, "Text", "ExpressionUUID" -> \
"73029cfd-d266-483e-bfe6-e8f4e15e578e"],
Cell[429012, 11258, 575, 14, 43606, "Input", "ExpressionUUID" -> \
"b930615c-3a39-4d1d-bb4e-630bd97e2f21"],
Cell[429590, 11274, 203, 3, 43606, "Text", "ExpressionUUID" -> \
"ac2e95c0-7938-4a03-838c-3f6f5cdf2922"],
Cell[429796, 11279, 307, 7, 43606, "Input", "ExpressionUUID" -> \
"493b08db-cd5a-45f2-886e-067a219a411d"],
Cell[430106, 11288, 1194, 23, 102271, "Text", "ExpressionUUID" -> \
"b25a452a-73fc-4a43-a6eb-47d63db7cec2"],
Cell[431303, 11313, 1066, 19, 244491, "Input", "ExpressionUUID" -> \
"56d20ade-3c05-4c7e-a96d-76644ab5fc55",
 InitializationCell->True],
Cell[432372, 11334, 2992, 74, 187537, "Input", "ExpressionUUID" -> \
"5ef49606-5fc6-4144-a728-352998bd255e",
 InitializationCell->True],
Cell[435367, 11410, 198, 3, 43606, "Text", "ExpressionUUID" -> \
"ddab80ba-72da-470c-a862-6eedd88aed48"],
Cell[435568, 11415, 175, 4, 43606, "Input", "ExpressionUUID" -> \
"378b8d35-7cbf-46a1-9ad2-8e7f86e6b40b"],
Cell[435746, 11421, 442, 10, 72442, "Text", "ExpressionUUID" -> \
"d57ae63f-b88a-403f-90e7-49ea85b94303"],
Cell[436191, 11433, 704, 19, 73495, "Input", "ExpressionUUID" -> \
"7ff44af9-38ab-49f8-9d39-78c9c3cb99ed"],
Cell[436898, 11454, 233, 4, 43606, "Text", "ExpressionUUID" -> \
"b103261a-0488-4a73-ae86-de848da5266f"],
Cell[437134, 11460, 424, 13, 43606, "Input", "ExpressionUUID" -> \
"0c937568-e576-4358-8c1d-db73bd13a674"],
Cell[437561, 11475, 572, 15, 43606, "Input", "ExpressionUUID" -> \
"a7a1ec32-c512-4ddf-8503-f67d33d51b09"],
Cell[438136, 11492, 813, 17, 105039, "Text", "ExpressionUUID" -> \
"53f5890d-c159-44c4-8e81-4b6b383f95d8"],
Cell[438952, 11511, 180, 2, 43606, "Text", "ExpressionUUID" -> \
"b8196eef-b223-4550-8274-cf91e4a7b4ba"],
Cell[439135, 11515, 1964, 42, 102271, "Input", "ExpressionUUID" -> \
"d27e0d56-38f6-4d4e-b7a5-85096dc42b37"],
Cell[441102, 11559, 250, 6, 72442, "Text", "ExpressionUUID" -> \
"23e881e5-7f6d-4b91-981c-da4620574886"],
Cell[441355, 11567, 554, 15, 43606, "Input", "ExpressionUUID" -> \
"ae5c5dcf-2198-4fb9-85a0-2ab24d05c8fb"],
Cell[441912, 11584, 593, 17, 73495, "Input", "ExpressionUUID" -> \
"6c66cbbc-3ef3-4216-b45c-e12c0e3c638c"],
Cell[442508, 11603, 999, 18, 128488, "Text", "ExpressionUUID" -> \
"6ffc45e8-be15-4ad9-aadc-1859ace4b588"],
Cell[443510, 11623, 885, 21, 43606, "Input", "ExpressionUUID" -> \
"28c9d089-55b8-4f23-b2a8-7dd8705cfaa9",
 Evaluatable->False],
Cell[444398, 11646, 1091, 29, 73495, "Input", "ExpressionUUID" -> \
"9ae52333-6fe0-4210-821c-32a13cbf7300"],
Cell[445492, 11677, 1470, 27, 156025, "Text", "ExpressionUUID" -> \
"2196169a-21c3-4c92-8a3a-72e0ccb11665"],
Cell[446965, 11706, 2034, 33, 307549, "Text", "ExpressionUUID" -> \
"8e58ff47-e582-4634-a552-205af7562e59"],
Cell[449002, 11741, 1110, 32, 130308, "Input", "ExpressionUUID" -> \
"ea93bfcc-6d2f-451f-a521-5dc708989c19"],
Cell[450115, 11775, 410, 11, 45657, "Text", "ExpressionUUID" -> \
"27c46263-5548-4368-bf07-5583c354349e"],
Cell[450528, 11788, 584, 17, 43606, "Input", "ExpressionUUID" -> \
"fd05df74-ec97-4fcb-8cb7-2ba8f74994aa",
 Evaluatable->False],
Cell[451115, 11807, 159, 3, 43606, "Text", "ExpressionUUID" -> \
"8a42ec1c-dc0d-427a-b88e-4940a84dfda9"],
Cell[451277, 11812, 499, 13, 43606, "Input", "ExpressionUUID" -> \
"3e7c1fcf-ef53-4c1d-8dfe-58ccdc4327f4"],
Cell[451779, 11827, 479, 9, 74724, "Text", "ExpressionUUID" -> \
"71c54008-86a2-43a4-a529-5b64e0b0d96b"],
Cell[452261, 11838, 395, 9, 43606, "Input", "ExpressionUUID" -> \
"1c05afed-a9b7-4569-aa7f-7e3876952f59"],
Cell[452659, 11849, 159, 2, 43606, "Text", "ExpressionUUID" -> \
"9104ca34-3450-413b-9639-8e3495787fb6"],
Cell[452821, 11853, 984, 24, 73495, "Input", "ExpressionUUID" -> \
"939cab85-fc9f-467a-b10e-d50b3d5b710d"],
Cell[453808, 11879, 165, 3, 43606, "Text", "ExpressionUUID" -> \
"f56ffd7d-6fe5-4d06-b2bf-1c757abb3305"],
Cell[453976, 11884, 326, 7, 43606, "Input", "ExpressionUUID" -> \
"b1ac3afa-7c1b-4442-b4eb-72caf6c3a1f9",
 Evaluatable->False],
Cell[454305, 11893, 316, 7, 73495, "Text", "ExpressionUUID" -> \
"08aa03bd-b30c-4717-a156-eedda5f011b7"],
Cell[454624, 11902, 701, 21, 43606, "Input", "ExpressionUUID" -> \
"c3b043cb-e13a-4fdf-bdc9-3076295ef453",
 Evaluatable->False],
Cell[455328, 11925, 198, 3, 43606, "Text", "ExpressionUUID" -> \
"45cac05a-c115-4716-93a1-99d745f04e21"],
Cell[455529, 11930, 222, 5, 43606, "Input", "ExpressionUUID" -> \
"164f4e05-abf4-4b16-b9ba-c603063d9eb8"],
Cell[455754, 11937, 679, 18, 43606, "Input", "ExpressionUUID" -> \
"c950cd5c-399e-4b97-8011-40b15fa2a914",
 Evaluatable->False],
Cell[456436, 11957, 151, 3, 43606, "Text", "ExpressionUUID" -> \
"2f3deade-031d-4458-bcd7-f2fc15895484"],
Cell[456590, 11962, 356, 10, 43606, "Input", "ExpressionUUID" -> \
"a08b9f0c-ceaa-4768-96be-0fdfc9ed1a39",
 Evaluatable->False],
Cell[456949, 11974, 179, 3, 44835, "Text", "ExpressionUUID" -> \
"80803a17-a9d3-457c-82a2-1c11cdf72789"],
Cell[457131, 11979, 602, 13, 128488, "Text", "ExpressionUUID" -> \
"13115773-f716-44c3-a222-de275e556dec"],
Cell[457736, 11994, 667, 18, 43606, "Input", "ExpressionUUID" -> \
"b68f0473-ce4a-4511-8597-abc2b1f3252c",
 Evaluatable->False]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[458452, 12018, 416, 6, 67, "Subsection", "ExpressionUUID" -> \
"4d4535c2-ac88-42cd-820e-1a8e07592390"],
Cell[458871, 12026, 1495, 28, 213, "Text", "ExpressionUUID" -> \
"756af610-cd4c-408b-931f-6af47a75b4af"],
Cell[CellGroupData[{
Cell[460391, 12058, 714, 10, 53, "Subsubsection", "ExpressionUUID" -> \
"d54393ec-92b6-4a4d-b665-556e7b19c02a"],
Cell[461108, 12070, 676, 11, 289098, "Text", "ExpressionUUID" -> \
"67d9e2df-b0c3-499c-8a2d-789005f127ed"],
Cell[461787, 12083, 195, 5, 98113, "Input", "ExpressionUUID" -> \
"fd7fc8c1-62e2-45f6-9f63-f7fa4fef7515"],
Cell[461985, 12090, 311, 8, 98113, "Input", "ExpressionUUID" -> \
"c6a2fb78-07d8-42f3-b472-832dd693e430"],
Cell[462299, 12100, 434, 10, 98113, "Input", "ExpressionUUID" -> \
"807933f1-bde4-426f-a85d-0cfe4a4a4461"],
Cell[462736, 12112, 196, 3, 98113, "Text", "ExpressionUUID" -> \
"3ff5a9ad-f875-412a-905f-93bb61819ffe"],
Cell[462935, 12117, 628, 19, 98113, "Input", "ExpressionUUID" -> \
"19cb7579-59ad-473f-b46f-3e21e7e4bad0"],
Cell[463566, 12138, 173, 4, 98113, "Input", "ExpressionUUID" -> \
"77625ef2-bd71-4630-8b08-0ec29b1cccb3"],
Cell[463742, 12144, 444, 8, 165363, "Text", "ExpressionUUID" -> \
"0ad40cb4-3b24-461e-a40d-5d71de5a5490"],
Cell[464189, 12154, 211, 4, 98113, "Input", "ExpressionUUID" -> \
"301f23ba-8be1-4572-b12c-10a217af0f37"],
Cell[464403, 12160, 189, 4, 98113, "Input", "ExpressionUUID" -> \
"7a501258-e10b-40db-9044-2442cf613e5e"],
Cell[464595, 12166, 231, 5, 98113, "Input", "ExpressionUUID" -> \
"c7934590-baa9-4239-a0ee-5f9dfa3a454b"],
Cell[464829, 12173, 253, 4, 98113, "Text", "ExpressionUUID" -> \
"94a90e1b-f3eb-4b2c-9d3c-5b1db1b1ccd6"],
Cell[465085, 12179, 684, 20, 98113, "Input", "ExpressionUUID" -> \
"687866df-3742-422e-b348-21c40602e1aa"],
Cell[465772, 12201, 294, 7, 162994, "Text", "ExpressionUUID" -> \
"140eaf65-9197-4e73-a39d-619fe8f7a18d"],
Cell[466069, 12210, 479, 14, 98113, "Input", "ExpressionUUID" -> \
"f0f81e41-e2ec-4242-8550-031230790e1c"],
Cell[466551, 12226, 231, 4, 98113, "Text", "ExpressionUUID" -> \
"fe53e24c-f9ca-4ba1-9fcc-fb28c6ad10e8"],
Cell[CellGroupData[{
Cell[466807, 12234, 362, 10, 98113, "Input", "ExpressionUUID" -> \
"c7ddd504-dc0d-42c1-afda-872b4bb008d4",
 InitializationCell->True],
Cell[467172, 12246, 175, 5, 70, "Output", "ExpressionUUID" -> \
"f5b1b4b9-5a7e-4b49-896c-1728cd47ae72"]
}, Open  ]],
Cell[CellGroupData[{
Cell[467384, 12256, 309, 9, 98113, "Input", "ExpressionUUID" -> \
"cfaf23ee-c631-42f6-a400-232166e8206d",
 InitializationCell->True],
Cell[467696, 12267, 177, 5, 70, "Output", "ExpressionUUID" -> \
"45b21dd6-d271-431f-b3cc-5b7268a3b3c9"]
}, Open  ]],
Cell[467888, 12275, 264, 6, 98113, "Text", "ExpressionUUID" -> \
"d53b4dee-bd04-4bdf-8421-8429226ebdce"],
Cell[468155, 12283, 991, 23, 165363, "Input", "ExpressionUUID" -> \
"e43cb534-c730-46e5-8e55-a3d13a384d61",
 InitializationCell->True],
Cell[469149, 12308, 168, 3, 98113, "Text", "ExpressionUUID" -> \
"90986892-075e-4e43-b8f6-788fd22fcef4"],
Cell[469320, 12313, 110, 1, 98113, "Input", "ExpressionUUID" -> \
"e2fdb70e-3fcd-4509-8d9d-1f8a9fcca2bb"],
Cell[469433, 12316, 433, 10, 98113, "Input", "ExpressionUUID" -> \
"7f76d65f-f2d9-4855-9ba5-fee54270a9f9"],
Cell[469869, 12328, 246, 6, 98113, "Input", "ExpressionUUID" -> \
"e26a43a3-0a22-4f63-94e7-3408cb6459f1"],
Cell[470118, 12336, 197, 5, 98113, "Input", "ExpressionUUID" -> \
"8b9ae88d-403c-4f4b-a749-6d3416d2966e"],
Cell[470318, 12343, 487, 12, 98113, "Input", "ExpressionUUID" -> \
"3b43ef42-9e01-4fa1-8caa-dc753da90c18"],
Cell[470808, 12357, 388, 10, 98113, "Input", "ExpressionUUID" -> \
"95356add-e4dc-4121-9617-5ee94db748c8"],
Cell[471199, 12369, 157, 4, 98113, "Input", "ExpressionUUID" -> \
"7bbed2e1-0717-4546-bd5b-b4764ce80697"],
Cell[471359, 12375, 259, 6, 98113, "Input", "ExpressionUUID" -> \
"31f2bb3f-3447-4103-a643-8ef129c22fa5"],
Cell[471621, 12383, 335, 7, 98113, "Input", "ExpressionUUID" -> \
"6e08a3bb-615f-4e9c-9ed9-c482ba59003e"],
Cell[471959, 12392, 369, 8, 98113, "Text", "ExpressionUUID" -> \
"64bff028-3fba-462a-a382-568174705f12"],
Cell[472331, 12402, 208, 5, 98113, "Input", "ExpressionUUID" -> \
"860f5781-a67d-461c-9a54-bd9ed1122337"],
Cell[472542, 12409, 281, 7, 98113, "Input", "ExpressionUUID" -> \
"e9b51be6-f3a5-45c9-8f80-aa4ad8b9c971"],
Cell[472826, 12418, 308, 5, 98113, "Text", "ExpressionUUID" -> \
"91760962-7f25-40f0-a3a4-cf4195093f68"],
Cell[473137, 12425, 682, 15, 98113, "Input", "ExpressionUUID" -> \
"032332a8-eb0e-4cec-8ca1-d25a51e0d8b9"],
Cell[473822, 12442, 582, 19, 98113, "Input", "ExpressionUUID" -> \
"a0114adb-0b7a-47ae-ade7-cafeba37a919"],
Cell[474407, 12463, 1542, 37, 165363, "Input", "ExpressionUUID" -> \
"a56e506c-b3d8-4e24-af7d-108bb30f1019"],
Cell[475952, 12502, 553, 12, 98113, "Input", "ExpressionUUID" -> \
"0b61b578-41f1-409c-8302-b120837447bd"],
Cell[476508, 12516, 228, 4, 98113, "Text", "ExpressionUUID" -> \
"a22ec0e6-c33e-484b-9f59-e155027d357a"],
Cell[476739, 12522, 698, 19, 98113, "Input", "ExpressionUUID" -> \
"641f7efa-8ea0-484f-a04e-249dae3d7361"],
Cell[477440, 12543, 266, 7, 98113, "Input", "ExpressionUUID" -> \
"3ff3f038-0bee-4118-bd2d-1d9e397169f4"]
}, Closed]],
Cell[CellGroupData[{
Cell[477743, 12555, 483, 7, 42, "Subsubsection", "ExpressionUUID" -> \
"9cb85930-d995-42ff-8034-a40b701ae762"],
Cell[478229, 12564, 834, 22, 72442, "Text", "ExpressionUUID" -> \
"7c12ea26-d9af-49d4-9234-bad8a3afe486"],
Cell[479066, 12588, 346, 10, 70803, "Input", "ExpressionUUID" -> \
"8f9775af-e4c3-4fae-8782-e9d4c784a526",
 Evaluatable->False],
Cell[479415, 12600, 262, 8, 43606, "Text", "ExpressionUUID" -> \
"b0cb5030-342a-41bb-ae0f-7275e75125d4"],
Cell[479680, 12610, 724, 18, 43606, "Input", "ExpressionUUID" -> \
"59da13cd-e46e-4655-9fd5-c7516100884a",
 Evaluatable->False],
Cell[480407, 12630, 904, 14, 128488, "Text", "ExpressionUUID" -> \
"6ebcd6c5-5392-4958-94b6-9fe8d3ba776b"],
Cell[481314, 12646, 968, 30, 73495, "Input", "ExpressionUUID" -> \
"aed97f5a-47d8-4254-9278-1e8c1a05b72b"],
Cell[482285, 12678, 362, 7, 99963, "Text", "ExpressionUUID" -> \
"31e778f8-ac61-4b62-ad38-9333d6f660d4"],
Cell[482650, 12687, 867, 27, 73495, "Input", "ExpressionUUID" -> \
"23afcc0e-777f-42ac-8808-bceb11cfb915"],
Cell[483520, 12716, 919, 15, 72442, "Text", "ExpressionUUID" -> \
"684cff35-3bc3-4519-8eef-8205f22eac97"],
Cell[484442, 12733, 641, 15, 43606, "Input", "ExpressionUUID" -> \
"b2479cde-d66a-457e-8604-348b234ffc09"],
Cell[485086, 12750, 1106, 31, 105039, "Text", "ExpressionUUID" -> \
"c32c2a3e-79fa-4d06-8976-5e98ccc04b03"],
Cell[486195, 12783, 565, 16, 47202, "Input", "ExpressionUUID" -> \
"fdf6bdda-8786-4d0b-ba2c-deb138a6bcf7",
 Evaluatable->False],
Cell[486763, 12801, 657, 14, 99963, "Text", "ExpressionUUID" -> \
"48dec4a5-0917-4c1b-8446-6c81cd45bb04"],
Cell[487423, 12817, 332, 9, 43606, "Input", "ExpressionUUID" -> \
"7e848b8e-a9cf-4636-b180-12fcf97a46ea",
 Evaluatable->False],
Cell[487758, 12828, 907, 23, 73495, "Input", "ExpressionUUID" -> \
"19fb769d-aab8-4672-94a4-6b07808b4112",
 InitializationCell->True],
Cell[488668, 12853, 804, 15, 159306, "Input", "ExpressionUUID" -> \
"72f483e1-4df4-488e-bd18-3432688cecf8",
 InitializationCell->True],
Cell[489475, 12870, 381, 6, 43606, "Text", "ExpressionUUID" -> \
"d064fdb7-e548-4f64-a34b-1044e75cb2fe"],
Cell[489859, 12878, 250, 6, 43606, "Input", "ExpressionUUID" -> \
"7fe0af69-ada4-4bfe-8f83-86cd3710f3ec"],
Cell[490112, 12886, 390, 11, 43606, "Input", "ExpressionUUID" -> \
"19a4c6d9-e707-46c0-8feb-2dfefc20826a"],
Cell[490505, 12899, 189, 4, 43606, "Input", "ExpressionUUID" -> \
"2b05612a-56dd-46cd-8561-c1e2988c6e15"],
Cell[490697, 12905, 211, 3, 43606, "Text", "ExpressionUUID" -> \
"c374d821-30c6-4b74-8a5c-4c32817d7552"],
Cell[490911, 12910, 915, 27, 102271, "Input", "ExpressionUUID" -> \
"a551b11a-4c90-40f8-8464-26a9a6900d7f"],
Cell[491829, 12939, 411, 11, 43606, "Input", "ExpressionUUID" -> \
"f959657e-8b81-4614-bd77-32e73b422e06"],
Cell[492243, 12952, 236, 6, 43606, "Text", "ExpressionUUID" -> \
"0a99cdaf-958e-47e0-9bff-2adcd7b47583"],
Cell[492482, 12960, 6680, 151, 387720, "Input", "ExpressionUUID" -> \
"9b33321e-3ed0-4c9d-92a3-642b2bef97bb",
 InitializationGroup->True],
Cell[499165, 13113, 468, 11, 130308, "Input", "ExpressionUUID" -> \
"e0c4c360-b62c-4f1f-94e1-2d7024f6ecbb",
 InitializationCell->True],
Cell[499636, 13126, 154, 3, 43606, "Input", "ExpressionUUID" -> \
"d2d1f869-ad80-47bc-b994-41fc6db236db"],
Cell[499793, 13131, 454, 10, 72442, "Text", "ExpressionUUID" -> \
"c05043df-6709-415f-a8bf-6f8293ea7479"],
Cell[500250, 13143, 659, 15, 43606, "Input", "ExpressionUUID" -> \
"d76ee3de-0378-4840-9c69-1c02246c996b"],
Cell[500912, 13160, 611, 16, 43606, "Input", "ExpressionUUID" -> \
"6aa58c04-dabb-40fa-8e54-f3eca42ff24b"],
Cell[501526, 13178, 186, 3, 43606, "Text", "ExpressionUUID" -> \
"86c82e72-c360-46ec-99e5-36ae81178192"],
Cell[501715, 13183, 360, 9, 43606, "Input", "ExpressionUUID" -> \
"464e0b50-d762-48b3-85f4-26b8d27f72fe"],
Cell[502078, 13194, 691, 17, 43606, "Input", "ExpressionUUID" -> \
"9576f4d5-4db9-4de1-862b-94d547e63645"],
Cell[502772, 13213, 215, 5, 43606, "Text", "ExpressionUUID" -> \
"96a522c9-9894-4411-a667-b0fab7f99edf"],
Cell[502990, 13220, 914, 20, 43606, "Input", "ExpressionUUID" -> \
"f570f6e5-6ca1-4eae-9ef9-96cdbf16ef5f"],
Cell[503907, 13242, 1194, 33, 73495, "Input", "ExpressionUUID" -> \
"bd6cff70-cc84-4837-b705-190eee5b6bc9"],
Cell[505104, 13277, 157, 3, 43606, "Text", "ExpressionUUID" -> \
"51c53d3e-470f-4c86-8621-955e2bf6cdf4"],
Cell[505264, 13282, 483, 10, 43606, "Text", "ExpressionUUID" -> \
"2cdcf7b9-27ec-4db6-9d02-55fbf72fd5d3"],
Cell[505750, 13294, 473, 11, 43606, "Input", "ExpressionUUID" -> \
"19378761-7d2b-4092-91bf-44aa4cbd0269"],
Cell[506226, 13307, 429, 11, 43606, "Input", "ExpressionUUID" -> \
"bfc9c506-f959-49c5-952c-1ff224fa9b2a"],
Cell[506658, 13320, 309, 7, 43606, "Input", "ExpressionUUID" -> \
"dfa1cb9a-745c-4a8b-bcbe-b014db2ba81e"],
Cell[506970, 13329, 1006, 20, 74724, "Text", "ExpressionUUID" -> \
"5de08588-ee75-4258-ac28-f6474918cbcf"],
Cell[507979, 13351, 325, 8, 72442, "Text", "ExpressionUUID" -> \
"ce291a75-a595-4dc2-9f02-4a90f9f30a53"],
Cell[508307, 13361, 183, 4, 43606, "Input", "ExpressionUUID" -> \
"364519ec-ff18-42b5-bf64-49b380380d6f"],
Cell[508493, 13367, 525, 10, 72442, "Text", "ExpressionUUID" -> \
"b7395d7f-379c-4586-bda7-4a49036883bc"],
Cell[509021, 13379, 426, 8, 43606, "Text", "ExpressionUUID" -> \
"791ea374-a4ab-4c8f-91aa-f22333552187"],
Cell[509450, 13389, 327, 8, 72442, "Text", "ExpressionUUID" -> \
"423f591f-07c8-4988-9159-3651199765ef"],
Cell[509780, 13399, 271, 6, 43606, "Text", "ExpressionUUID" -> \
"2bac922b-50c0-4a3a-8e62-da1a8412f472"],
Cell[510054, 13407, 496, 13, 43606, "Input", "ExpressionUUID" -> \
"bc3ef6c7-42c1-4bbe-84f9-f7907b7da7ca"],
Cell[510553, 13422, 306, 7, 43606, "Input", "ExpressionUUID" -> \
"4c574c54-73a7-40d7-a684-5ac28fc6a39c"],
Cell[510862, 13431, 466, 12, 43606, "Input", "ExpressionUUID" -> \
"d49738fa-7eea-43cf-801a-87bf5d47fa00"],
Cell[511331, 13445, 699, 19, 102271, "Input", "ExpressionUUID" -> \
"461f2998-5296-4133-b256-4756a33f9f32"],
Cell[512033, 13466, 428, 8, 99963, "Text", "ExpressionUUID" -> \
"38bc6f76-017b-46c0-a007-f8a1d7dc3459"],
Cell[512464, 13476, 206, 4, 43606, "Input", "ExpressionUUID" -> \
"97eb703e-a8f9-4a6c-a4a1-55df773398c9"],
Cell[512673, 13482, 156, 3, 43606, "Text", "ExpressionUUID" -> \
"fa34d0a0-9ad0-48dc-b14a-8505d08cbf81"],
Cell[512832, 13487, 289, 7, 43606, "Input", "ExpressionUUID" -> \
"1ec5035e-90c4-4aea-a384-7aeec188f112"],
Cell[513124, 13496, 213, 5, 43606, "Input", "ExpressionUUID" -> \
"de5234e5-d4db-42dd-8a11-388f3a1015dd"],
Cell[513340, 13503, 440, 11, 73495, "Input", "ExpressionUUID" -> \
"0926f2f2-2ac6-48ed-b24c-db7620984b44"],
Cell[513783, 13516, 188, 3, 44835, "Text", "ExpressionUUID" -> \
"b8e929f9-7686-4b3f-a5cf-a4b80d20d1ce"],
Cell[513974, 13521, 564, 11, 72442, "Text", "ExpressionUUID" -> \
"17cac3c6-cc5e-4d8d-b090-70138d56c8d3"],
Cell[514541, 13534, 616, 16, 43606, "Input", "ExpressionUUID" -> \
"18b05be4-8a6b-4481-b768-2228932a38fb",
 Evaluatable->False],
Cell[515160, 13552, 274, 6, 44835, "Text", "ExpressionUUID" -> \
"b3d2ae08-0726-4254-b2b1-62153a03016f"],
Cell[515437, 13560, 442, 12, 43606, "Input", "ExpressionUUID" -> \
"95117a21-59a7-4272-bd29-a135f2bd1642",
 Evaluatable->False],
Cell[515882, 13574, 340, 7, 99963, "Text", "ExpressionUUID" -> \
"598447f4-5716-4376-911a-2428d012b1ea"],
Cell[516225, 13583, 825, 13, 92170, "Input", "ExpressionUUID" -> \
"b7064e36-266a-49bc-b5d1-1f0ab4c7a8b5",
 Evaluatable->False],
Cell[517053, 13598, 485, 9, 74724, "Text", "ExpressionUUID" -> \
"67b5a841-4bda-4d24-97ec-84c6037cf64d"],
Cell[517541, 13609, 274, 5, 43606, "Input", "ExpressionUUID" -> \
"6ea241ef-341b-492d-8aba-7e1e4de3754a"],
Cell[517818, 13616, 440, 9, 72442, "Text", "ExpressionUUID" -> \
"740cc6eb-21d1-4c65-899b-a8ebff9cfe85"],
Cell[518261, 13627, 262, 6, 43606, "Input", "ExpressionUUID" -> \
"d202c5fb-b5f5-44de-8993-0eec805008d8"],
Cell[518526, 13635, 168, 3, 43606, "Text", "ExpressionUUID" -> \
"4c52cfdc-9204-4e8f-bf18-8e7641908d00"],
Cell[518697, 13640, 614, 9, 92170, "Input", "ExpressionUUID" -> \
"fac5c1c2-23fc-47e4-8239-b3ad67ee3a04"],
Cell[519314, 13651, 735, 17, 160065, "Text", "ExpressionUUID" -> \
"272e62f5-2557-4a50-b695-46835202aad3"],
Cell[520052, 13670, 183, 4, 43606, "Input", "ExpressionUUID" -> \
"2837d704-f1bf-4346-b750-2ca2a0a3136e"],
Cell[520238, 13676, 587, 10, 99963, "Text", "ExpressionUUID" -> \
"87c6f407-3e86-4e5b-a2fb-523fcf7ebbed"],
Cell[520828, 13688, 199, 4, 43606, "Input", "ExpressionUUID" -> \
"82c212a4-de1d-4186-aa6c-36aac3bbb4b9"],
Cell[521030, 13694, 151, 3, 43606, "Text", "ExpressionUUID" -> \
"288797b3-8c5c-4b72-bf89-8bf70f2b8f36"],
Cell[521184, 13699, 382, 11, 43606, "Input", "ExpressionUUID" -> \
"09025624-a68d-491f-a680-3b2a827f3a98",
 InitializationCell->True],
Cell[521569, 13712, 359, 9, 73495, "Input", "ExpressionUUID" -> \
"6639871d-5bfd-4fc8-ac1e-7f459e7c48cb",
 InitializationCell->True],
Cell[521931, 13723, 255, 6, 43606, "Input", "ExpressionUUID" -> \
"db9ca36b-ae77-4d81-a80d-10de90c5ced1"],
Cell[522189, 13731, 186, 3, 43606, "Text", "ExpressionUUID" -> \
"fa31875c-03c2-427c-b1ae-6f5ccb23f36d"],
Cell[522378, 13736, 185, 4, 43606, "Input", "ExpressionUUID" -> \
"ab49536a-e43b-4a3d-96c7-d4edc4cff387"],
Cell[522566, 13742, 275, 6, 72442, "Text", "ExpressionUUID" -> \
"d8c56bed-981c-4531-a377-1525efe8f586"],
Cell[522844, 13750, 2496, 55, 244491, "Input", "ExpressionUUID" -> \
"3321563e-b1aa-4b87-85ca-0b6c1acce930",
 InitializationCell->True],
Cell[525343, 13807, 408, 9, 102271, "Input", "ExpressionUUID" -> \
"c20aa21a-22aa-406d-ab01-24aac1b65a7a"],
Cell[525754, 13818, 176, 4, 43606, "Input", "ExpressionUUID" -> \
"5c684fe4-1eca-4b42-ba9a-5ee904bc6aa2"],
Cell[525933, 13824, 194, 4, 43606, "Input", "ExpressionUUID" -> \
"86474d06-ee4e-4a29-a71c-ae4b8f86ea53"],
Cell[526130, 13830, 234, 6, 43606, "Text", "ExpressionUUID" -> \
"340e387b-ef5f-4559-8805-26064fb95e9e"],
Cell[526367, 13838, 321, 8, 43606, "Input", "ExpressionUUID" -> \
"eef55a3c-939e-4039-aeb1-f788f883834b"],
Cell[526691, 13848, 208, 4, 43606, "Input", "ExpressionUUID" -> \
"e8955ba3-c5a4-437c-aa10-c2893d3bf5c4"],
Cell[526902, 13854, 273, 7, 43606, "Input", "ExpressionUUID" -> \
"ea3bbb3f-0ed7-4520-b7ee-a4216d9949a9"],
Cell[527178, 13863, 322, 8, 43606, "Input", "ExpressionUUID" -> \
"42deb759-07e5-410e-a48d-d1240a991c9a"],
Cell[527503, 13873, 616, 17, 43606, "Text", "ExpressionUUID" -> \
"4d35908c-5029-4c5b-805d-d2de7b7e437b"],
Cell[528122, 13892, 451, 10, 43606, "Input", "ExpressionUUID" -> \
"3a363ea1-2591-4051-908b-89a99c73bf24"],
Cell[528576, 13904, 174, 4, 43606, "Input", "ExpressionUUID" -> \
"2283ff24-3e80-442b-8df8-f7a6f2103d3a"],
Cell[528753, 13910, 451, 12, 43606, "Input", "ExpressionUUID" -> \
"7fa6a3d7-ee00-42c5-87ba-c0a2d92a2e4b"],
Cell[529207, 13924, 672, 17, 43606, "Input", "ExpressionUUID" -> \
"52407b54-a617-4f6d-ba2f-53c7fafc5a76"],
Cell[529882, 13943, 647, 15, 102727, "Text", "ExpressionUUID" -> \
"dfaa8862-cc42-431a-8774-157f3b800438"],
Cell[530532, 13960, 831, 19, 99963, "Text", "ExpressionUUID" -> \
"bcde572a-1cc0-4af5-a03f-09da10ccd17c"],
Cell[531366, 13981, 329, 8, 43606, "Input", "ExpressionUUID" -> \
"254d3e18-669e-4e4d-8ba5-84d6a4148781"],
Cell[531698, 13991, 551, 12, 72442, "Text", "ExpressionUUID" -> \
"098c6194-800c-4ade-8801-0bf71d2b1757"],
Cell[532252, 14005, 589, 15, 43606, "Input", "ExpressionUUID" -> \
"0e31c670-0da7-4cad-878e-cb15a630416b"],
Cell[532844, 14022, 733, 17, 128488, "Text", "ExpressionUUID" -> \
"c2866379-38ae-4d7e-80eb-4051d677960f"],
Cell[533580, 14041, 604, 18, 43606, "Input", "ExpressionUUID" -> \
"ec86d0ae-f308-41ec-b36d-60032047767d"],
Cell[534187, 14061, 795, 13, 156025, "Text", "ExpressionUUID" -> \
"8cde407b-e664-42b8-ae40-1655b992fa57"],
Cell[534985, 14076, 457, 11, 43606, "Input", "ExpressionUUID" -> \
"9dc39d9c-b8b9-49a8-bfc9-7e534ca7f474",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[535479, 14092, 715, 10, 42, "Subsubsection", "ExpressionUUID" -> \
"82d751a9-1510-4af7-b728-850890746469"],
Cell[536197, 14104, 373, 10, 29071, "Text", "ExpressionUUID" -> \
"92145af7-cae6-40d3-aa83-d8b268ce0e74"],
Cell[536573, 14116, 533, 15, 49816, "Input", "ExpressionUUID" -> \
"7c2a9db5-f729-4c29-a14f-2362f2796780",
 Evaluatable->False],
Cell[537109, 14133, 2066, 53, 87661, "Text", "ExpressionUUID" -> \
"420a33ff-c578-4b8a-8b51-95f0a24b60b4"],
Cell[539178, 14188, 281, 5, 29071, "Input", "ExpressionUUID" -> \
"f3549d67-dcc9-4b12-a997-083997995aa9"],
Cell[539462, 14195, 275, 5, 29071, "Input", "ExpressionUUID" -> \
"ee087ae7-c4b7-4e5e-b76f-7eca2fa29e80"],
Cell[539740, 14202, 156, 3, 29071, "Text", "ExpressionUUID" -> \
"56fe933b-a22b-46e9-b4ea-710fb931f3d4"],
Cell[539899, 14207, 765, 17, 29071, "Input", "ExpressionUUID" -> \
"f2cc3409-c415-46e3-b3f2-dfd044ab0e0a"],
Cell[540667, 14226, 217, 5, 29071, "Text", "ExpressionUUID" -> \
"4d9bf912-9f04-48aa-a62f-c9ffe5fc2982"],
Cell[540887, 14233, 187, 4, 29071, "Input", "ExpressionUUID" -> \
"630298cc-5cbc-480d-b1c1-0a653c5e3855"],
Cell[541077, 14239, 177, 4, 29071, "Input", "ExpressionUUID" -> \
"d78fe741-24ce-4e04-8601-f29e5ab973f4"],
Cell[541257, 14245, 421, 9, 29071, "Text", "ExpressionUUID" -> \
"668dac78-46ef-48de-9436-16623f1701a0"],
Cell[541681, 14256, 607, 15, 29071, "Input", "ExpressionUUID" -> \
"0e282497-eac3-410a-ae18-e1242f2c2e77"],
Cell[542291, 14273, 268, 4, 29071, "Text", "ExpressionUUID" -> \
"76fb74f2-4ee7-401b-890c-78016c50efeb"],
Cell[542562, 14279, 576, 13, 48997, "Input", "ExpressionUUID" -> \
"86de071b-ee49-4987-b6b8-2a331582aee2",
 Evaluatable->False],
Cell[543141, 14294, 178, 4, 29071, "Input", "ExpressionUUID" -> \
"80d7c779-08a6-4c50-9e29-608f4ff81af6"],
Cell[543322, 14300, 955, 26, 48997, "Input", "ExpressionUUID" -> \
"fdbff668-273e-4ed0-80ff-22eafae7c55f"],
Cell[544280, 14328, 157, 4, 29071, "Input", "ExpressionUUID" -> \
"bbd862a7-9400-4e1b-b437-7304b293c9e3"],
Cell[544440, 14334, 474, 10, 48997, "Text", "ExpressionUUID" -> \
"bf96451f-7463-4366-b971-8fd7eaab5830"],
Cell[544917, 14346, 240, 6, 29071, "Input", "ExpressionUUID" -> \
"089e1d48-ea1c-41cc-a57b-8988e19d2fc6"],
Cell[545160, 14354, 354, 5, 29071, "Text", "ExpressionUUID" -> \
"98e025d2-6d7e-461c-8975-6e0b2df467b3"],
Cell[545517, 14361, 270, 7, 29071, "Input", "ExpressionUUID" -> \
"6b83112f-ba99-4fe2-a220-b6bcea6f6829"],
Cell[545790, 14370, 230, 4, 29071, "Text", "ExpressionUUID" -> \
"97528756-baa0-4cd5-8577-bfd2ad6c8e7a"],
Cell[546023, 14376, 341, 9, 43606, "Input", "ExpressionUUID" -> \
"7179baf0-eb69-4a6f-af7c-5a7519eab663"],
Cell[546367, 14387, 388, 9, 43606, "Input", "ExpressionUUID" -> \
"41bf3301-c762-4956-959f-1fc16fad0466"],
Cell[546758, 14398, 368, 5, 43606, "Text", "ExpressionUUID" -> \
"933ea6c7-24fe-4c09-8729-e96c5f503933"],
Cell[547129, 14405, 149, 3, 43606, "Text", "ExpressionUUID" -> \
"7bd6333c-f967-4bdf-a07d-dc7c2b52847c"],
Cell[547281, 14410, 446, 11, 43606, "Input", "ExpressionUUID" -> \
"cc2c6f9c-b819-4290-870b-a5f2f864eb60"],
Cell[547730, 14423, 304, 7, 44835, "Text", "ExpressionUUID" -> \
"e1813add-e660-40a7-bf3c-2878f733de0a"],
Cell[548037, 14432, 994, 24, 73495, "Input", "ExpressionUUID" -> \
"2035008e-19aa-4f4b-a0ea-71e70eb3bfc9"],
Cell[549034, 14458, 173, 3, 43606, "Text", "ExpressionUUID" -> \
"de0a64cf-32ad-4e1a-9d10-25a4b14f9cc2"],
Cell[549210, 14463, 180, 4, 43606, "Input", "ExpressionUUID" -> \
"8da51dad-8c8c-4834-b1cb-499ec02b6038"],
Cell[549393, 14469, 218, 4, 43606, "Text", "ExpressionUUID" -> \
"2b9f9676-2e46-4f60-841c-d92cc78f38d0"],
Cell[549614, 14475, 410, 12, 43606, "Input", "ExpressionUUID" -> \
"3b9e9c0b-b12b-44e2-b966-20dcf22e5ae7"],
Cell[550027, 14489, 211, 4, 44835, "Text", "ExpressionUUID" -> \
"c2fc159d-d336-4ff8-a399-bf0b292b8e9b"],
Cell[550241, 14495, 191, 4, 43606, "Input", "ExpressionUUID" -> \
"b6431340-2fab-445c-a327-39ddf7c193ef"],
Cell[550435, 14501, 208, 3, 43606, "Text", "ExpressionUUID" -> \
"c78b3aa7-6d83-4169-9cdc-788fe4892791"],
Cell[550646, 14506, 522, 12, 43606, "Input", "ExpressionUUID" -> \
"5e3c0f75-4cc9-4adc-bb7c-a59704af14b8"],
Cell[551171, 14520, 310, 6, 43606, "Text", "ExpressionUUID" -> \
"8d2b5312-7c95-4e92-a9b6-a7804eb08077"],
Cell[551484, 14528, 734, 20, 73495, "Input", "ExpressionUUID" -> \
"1dd18216-7242-4305-a0de-d81ecf4475aa"],
Cell[552221, 14550, 331, 8, 43606, "Text", "ExpressionUUID" -> \
"3ccde001-77bf-481a-a5f0-95f2e96d2930"],
Cell[552555, 14560, 830, 22, 73495, "Input", "ExpressionUUID" -> \
"fe27ff59-e1c1-46eb-8e07-dae6b83e942d"],
Cell[553388, 14584, 164, 3, 43606, "Text", "ExpressionUUID" -> \
"3a8132da-79eb-4802-bcd7-775902160537"],
Cell[553555, 14589, 830, 22, 73495, "Input", "ExpressionUUID" -> \
"be35319f-4bc6-4887-bd01-6f61295d2f51"],
Cell[554388, 14613, 401, 9, 72442, "Text", "ExpressionUUID" -> \
"5244bae9-f75b-4371-896f-1624c9e5eabe"],
Cell[554792, 14624, 328, 6, 43606, "Input", "ExpressionUUID" -> \
"e965bb57-6666-4563-90a8-9039e25a8378"],
Cell[555123, 14632, 189, 4, 43606, "Input", "ExpressionUUID" -> \
"44cc6501-48e3-472b-a3eb-fd0486d321e8"],
Cell[555315, 14638, 333, 6, 43606, "Text", "ExpressionUUID" -> \
"97af0d1b-0b72-4315-b2e1-b6a4ed1dd47f"],
Cell[555651, 14646, 209, 4, 43606, "Text", "ExpressionUUID" -> \
"a20fb6fe-e513-4538-9759-cbb49418ed01"],
Cell[555863, 14652, 620, 17, 43606, "Input", "ExpressionUUID" -> \
"c1db98d1-04c6-4ded-a6f8-e7d4ba529d1e"],
Cell[556486, 14671, 728, 18, 43606, "Input", "ExpressionUUID" -> \
"ab4c79d2-b6a5-4625-b65a-3b18edf8f942"],
Cell[557217, 14691, 750, 19, 43606, "Input", "ExpressionUUID" -> \
"3bc43774-6ddc-423d-8908-c24072a6d7e8"],
Cell[557970, 14712, 263, 6, 43606, "Text", "ExpressionUUID" -> \
"cfd7bb64-dacc-4b1b-b61c-30d57aaa17a4"],
Cell[558236, 14720, 241, 5, 43606, "Input", "ExpressionUUID" -> \
"49a76518-7d6f-4e51-87f0-419cb51490b8"],
Cell[558480, 14727, 298, 6, 43606, "Text", "ExpressionUUID" -> \
"8632cc52-96fd-4197-a430-e608b163dcd9"],
Cell[558781, 14735, 570, 15, 43606, "Input", "ExpressionUUID" -> \
"1ecb49d0-3a96-47eb-8c74-8e8537bf199a"],
Cell[559354, 14752, 181, 3, 43606, "Text", "ExpressionUUID" -> \
"6797d8fe-8a61-4b92-b386-ae4ebcef79dd"],
Cell[559538, 14757, 598, 14, 43606, "Input", "ExpressionUUID" -> \
"aa292b1e-75e3-4462-b9b8-28ca61fa750e"],
Cell[560139, 14773, 201, 3, 43606, "Text", "ExpressionUUID" -> \
"4a588bd9-17e9-47f2-9717-7961e91d4e8d"],
Cell[560343, 14778, 687, 19, 43606, "Input", "ExpressionUUID" -> \
"142b50f1-e7f7-46c2-80da-9c35d4a8293a"],
Cell[561033, 14799, 756, 20, 48997, "Input", "ExpressionUUID" -> \
"a78b4269-b1cf-4853-b2c8-c26fd370919f"],
Cell[561792, 14821, 702, 19, 48997, "Input", "ExpressionUUID" -> \
"0a624552-079a-438e-abd2-af903724500a"],
Cell[562497, 14842, 194, 3, 29071, "Text", "ExpressionUUID" -> \
"879be9f3-2fee-4e5c-bd3c-43f990f299ed"],
Cell[562694, 14847, 360, 6, 29071, "Input", "ExpressionUUID" -> \
"b08b0e6a-1220-4d9f-b111-62c92e98e791"],
Cell[563057, 14855, 279, 6, 48295, "Text", "ExpressionUUID" -> \
"0c4b2851-64fa-46dc-bea7-45f10b811276"],
Cell[563339, 14863, 869, 23, 48997, "Input", "ExpressionUUID" -> \
"c58026bf-7fa2-4ed6-a10c-9575dfa18b06"],
Cell[564211, 14888, 440, 12, 29071, "Text", "ExpressionUUID" -> \
"a9974bef-86a7-43bd-b290-fa053c06654e"],
Cell[564654, 14902, 278, 7, 29071, "Input", "ExpressionUUID" -> \
"0fe42e15-b64d-4712-aa22-69f3c8df0fa8"],
Cell[564935, 14911, 387, 8, 68181, "Text", "ExpressionUUID" -> \
"6c03d46a-5aea-459c-ba41-77947bffc1ee"],
Cell[565325, 14921, 520, 14, 29071, "Input", "ExpressionUUID" -> \
"51a098d8-1250-476f-a5fb-8231c06d7022"],
Cell[565848, 14937, 159, 3, 29071, "Text", "ExpressionUUID" -> \
"d699d0a0-f37e-4a1f-a6b2-4368cdf8d364"],
Cell[566010, 14942, 2064, 50, 107941, "Text", "ExpressionUUID" -> \
"e39ad930-e803-4a64-a169-c3035ba01ae4"],
Cell[568077, 14994, 540, 14, 29071, "Input", "ExpressionUUID" -> \
"275dbe25-181c-44b0-a312-27202e157a6c",
 Evaluatable->False],
Cell[568620, 15010, 151, 3, 29071, "Text", "ExpressionUUID" -> \
"fa79ef79-553d-44e5-a2d7-f63074f9990a"],
Cell[568774, 15015, 302, 8, 29071, "Text", "ExpressionUUID" -> \
"cc0464e4-146b-42a2-b648-4a3a832b363e"],
Cell[569079, 15025, 829, 23, 29071, "Input", "ExpressionUUID" -> \
"fb546825-5725-4834-b1de-692c335e9935",
 Evaluatable->False],
Cell[569911, 15050, 153, 3, 29071, "Text", "ExpressionUUID" -> \
"199e99fd-3617-4aad-9b19-bff0d632045f"],
Cell[570067, 15055, 1348, 39, 68181, "Input", "ExpressionUUID" -> \
"7b28a965-9b84-4aee-afe6-d9a13b0cd3f3"],
Cell[571418, 15096, 1598, 45, 68181, "Input", "ExpressionUUID" -> \
"760002d6-25b0-4407-943d-3d3354137be2"],
Cell[573019, 15143, 128, 1, 29071, "Input", "ExpressionUUID" -> \
"a1a42050-82eb-4a9b-888f-8df1a3b85716"],
Cell[573150, 15146, 290, 6, 29071, "Input", "ExpressionUUID" -> \
"4feca66c-2c4b-4741-b12a-da928d222a3b"],
Cell[573443, 15154, 488, 9, 66642, "Text", "ExpressionUUID" -> \
"828580cf-8701-4031-9a33-9e733be087c4"],
Cell[573934, 15165, 207, 5, 29071, "Input", "ExpressionUUID" -> \
"a82aae1c-8c10-416f-9fc2-57db1860c4ef"],
Cell[574144, 15172, 347, 7, 49816, "Text", "ExpressionUUID" -> \
"37ba48c0-bad9-4e9c-b8d5-a7c2f59ffc76"],
Cell[574494, 15181, 520, 12, 29071, "Input", "ExpressionUUID" -> \
"4b8c4185-42f6-44fb-9cbb-5652ceadce7b"],
Cell[575017, 15195, 202, 4, 29071, "Text", "ExpressionUUID" -> \
"a58f40dd-c815-40b7-88bf-6aa90a01e42b"],
Cell[575222, 15201, 573, 15, 29071, "Input", "ExpressionUUID" -> \
"a3625025-fa3a-4c7a-8fae-3dc20727bb09"],
Cell[575798, 15218, 175, 3, 29071, "Text", "ExpressionUUID" -> \
"912ff316-8448-4731-89ba-8b7eb1ac2c04"],
Cell[575976, 15223, 1090, 24, 48997, "Input", "ExpressionUUID" -> \
"e46eb69f-10a8-42bc-9b83-d348ac3a2a13"],
Cell[577069, 15249, 151, 3, 43606, "Text", "ExpressionUUID" -> \
"afbaa47e-62ed-4178-9bc6-81caaf739023"],
Cell[577223, 15254, 1206, 27, 73495, "Input", "ExpressionUUID" -> \
"18147cd8-837c-4358-aeda-e72cf0412fbe"],
Cell[578432, 15283, 150, 3, 43606, "Text", "ExpressionUUID" -> \
"dde6b9d9-ef7e-4296-9c01-0d04dec6954c"],
Cell[578585, 15288, 1242, 30, 73495, "Input", "ExpressionUUID" -> \
"869dc65f-5a10-42f0-9385-2d4846f924d5"],
Cell[579830, 15320, 173, 3, 43606, "Text", "ExpressionUUID" -> \
"82b4db9d-27ef-4764-8bf2-94cb7303bd6f"],
Cell[580006, 15325, 1421, 33, 73495, "Input", "ExpressionUUID" -> \
"a3aa3625-d6ba-4b4f-88f9-84277c06d671"],
Cell[581430, 15360, 192, 3, 44835, "Text", "ExpressionUUID" -> \
"de2b0ab1-de13-4dc3-a03e-24aa39028354"],
Cell[581625, 15365, 156, 3, 43606, "Text", "ExpressionUUID" -> \
"b7b552be-1a80-4404-b5bb-9db9c42ec57c"],
Cell[581784, 15370, 947, 23, 102271, "Input", "ExpressionUUID" -> \
"a7851dd9-ca0c-40b4-90a5-efc3474d392d"],
Cell[582734, 15395, 147, 3, 43606, "Text", "ExpressionUUID" -> \
"de808e4c-3d9e-40d0-8442-e30f88236036"],
Cell[582884, 15400, 624, 15, 73495, "Input", "ExpressionUUID" -> \
"b00a09fa-2f90-4c49-824c-2b2ee6c44e08"],
Cell[583511, 15417, 266, 6, 72442, "Text", "ExpressionUUID" -> \
"f3b19776-9526-4a18-90ca-b87db5d158dd"],
Cell[583780, 15425, 359, 7, 72442, "Text", "ExpressionUUID" -> \
"83ac46ec-9693-474a-8bee-003b5bb3c595"],
Cell[584142, 15434, 249, 6, 43606, "Input", "ExpressionUUID" -> \
"df9ca957-3682-47ca-9d1a-f0be9b1ddf86"],
Cell[584394, 15442, 172, 4, 43606, "Input", "ExpressionUUID" -> \
"5c37885c-77bc-4159-98d7-cbaa71fbfc33"],
Cell[584569, 15448, 281, 7, 43606, "Text", "ExpressionUUID" -> \
"933923fe-50b7-4b17-bdd8-77fb638eb644",
 Evaluatable->True],
Cell[584853, 15457, 1024, 21, 43606, "Input", "ExpressionUUID" -> \
"517842c3-ed22-4006-90d3-7e6b5020b6aa"],
Cell[585880, 15480, 246, 6, 43606, "Input", "ExpressionUUID" -> \
"6854fe47-4dfd-496f-836e-4cf60840185c"],
Cell[586129, 15488, 212, 5, 43606, "Text", "ExpressionUUID" -> \
"bf914d01-17c5-443e-828f-d13a38671a99"],
Cell[586344, 15495, 172, 4, 43606, "Input", "ExpressionUUID" -> \
"9d95e7a7-1b7f-4fcf-b132-d06a8cf6951a"],
Cell[586519, 15501, 773, 21, 43606, "Input", "ExpressionUUID" -> \
"7de76035-1502-4580-a1b7-5c9672503bb1"],
Cell[587295, 15524, 189, 3, 43606, "Text", "ExpressionUUID" -> \
"068f260a-e9d1-4c76-b96c-9711e951594b"],
Cell[587487, 15529, 332, 9, 43606, "Input", "ExpressionUUID" -> \
"f12bf3a5-3ed5-49a1-be4e-557d10775f59"],
Cell[587822, 15540, 174, 3, 43606, "Text", "ExpressionUUID" -> \
"a36078fe-93b4-4cbd-9070-d4abe8b73427"],
Cell[587999, 15545, 403, 12, 43606, "Input", "ExpressionUUID" -> \
"f95f814c-977c-480c-af06-1173664b36fc"],
Cell[588405, 15559, 155, 3, 43606, "Text", "ExpressionUUID" -> \
"8793b23b-40d8-4143-a719-7b215c388369"],
Cell[588563, 15564, 853, 25, 73495, "Input", "ExpressionUUID" -> \
"c1bde684-8e59-474d-9b02-7d8383236a4b"],
Cell[589419, 15591, 926, 22, 218295, "Text", "ExpressionUUID" -> \
"a72a7779-846f-40e0-8035-7a09bde82181"],
Cell[590348, 15615, 766, 19, 73495, "Input", "ExpressionUUID" -> \
"08c60183-a24e-4d79-94f3-22fa6e0bd132"],
Cell[591117, 15636, 238, 6, 43606, "Input", "ExpressionUUID" -> \
"bbaf4fc6-ffb0-4b63-aba4-491a96f9557d"],
Cell[591358, 15644, 145, 3, 43606, "Text", "ExpressionUUID" -> \
"bf5cf7ff-fb94-4af8-ba26-ae3c693e4ed7"],
Cell[591506, 15649, 630, 15, 43606, "Input", "ExpressionUUID" -> \
"b64cf499-cb50-47f7-8f92-b2d2ddeeae08"],
Cell[592139, 15666, 204, 4, 43606, "Input", "ExpressionUUID" -> \
"58cd1399-a150-42da-bc8c-31793bb114f1"],
Cell[592346, 15672, 242, 5, 43606, "Input", "ExpressionUUID" -> \
"a8e7d177-6020-489c-8139-e41c9f37fa51"],
Cell[592591, 15679, 370, 9, 72442, "Text", "ExpressionUUID" -> \
"feb8c45f-c658-4dea-92d6-ee7b02256cca"],
Cell[592964, 15690, 681, 19, 43606, "Input", "ExpressionUUID" -> \
"3e9cf613-de7c-4a3d-9694-60f73c0e62f7"],
Cell[593648, 15711, 398, 7, 43606, "Text", "ExpressionUUID" -> \
"c446922f-6be9-42ad-a889-ea7b4b3e991f"],
Cell[594049, 15720, 626, 16, 43606, "Input", "ExpressionUUID" -> \
"3ad16d0a-e865-4588-a4bd-50e241ac8e0e"],
Cell[594678, 15738, 1129, 31, 73495, "Input", "ExpressionUUID" -> \
"5d2d397b-9005-4d4a-b347-2b9c10af07a7"],
Cell[595810, 15771, 416, 8, 73495, "Text", "ExpressionUUID" -> \
"27f78f9f-fd25-45c5-8d15-8cee39d5b992"],
Cell[596229, 15781, 459, 10, 102271, "Text", "ExpressionUUID" -> \
"6a21450f-cba5-4a37-866f-d35e0bcd4609"],
Cell[596691, 15793, 391, 9, 102271, "Text", "ExpressionUUID" -> \
"130563b9-287c-4b94-a21c-08e44899a6cb"],
Cell[597085, 15804, 1284, 29, 102271, "Input", "ExpressionUUID" -> \
"2fb0bee4-5769-4b82-b67d-e2b5253758fb",
 Evaluatable->False],
Cell[598372, 15835, 425, 10, 99963, "Text", "ExpressionUUID" -> \
"1958fb81-c351-410d-90c6-692186102bd6"],
Cell[598800, 15847, 174, 4, 43606, "Input", "ExpressionUUID" -> \
"057abc3d-d4bb-4c8c-8cb3-2e4994b16361"],
Cell[598977, 15853, 839, 17, 43606, "Input", "ExpressionUUID" -> \
"90a32c1c-d827-4dbc-be1d-d06d7eaa2cd7"],
Cell[599819, 15872, 176, 3, 43606, "Text", "ExpressionUUID" -> \
"7e87f382-4a05-467a-aaa1-d96fd06a405c"],
Cell[599998, 15877, 177, 4, 43606, "Input", "ExpressionUUID" -> \
"8430f58e-1852-4a05-8557-c76234a0894f"],
Cell[600178, 15883, 832, 20, 73495, "Input", "ExpressionUUID" -> \
"22f2e206-eb42-4805-b4e3-366b808a6e7f"],
Cell[601013, 15905, 206, 4, 43606, "Text", "ExpressionUUID" -> \
"b6516a4d-8824-4b01-8cf1-f4f1b5a89dfb"],
Cell[601222, 15911, 1330, 27, 73495, "Input", "ExpressionUUID" -> \
"3958e97f-dd91-4ac0-91b4-72ffb0d5cc8d"],
Cell[602555, 15940, 837, 22, 73495, "Input", "ExpressionUUID" -> \
"333a96bd-fc0d-42c4-9bb2-bf083e587686"],
Cell[603395, 15964, 160, 3, 43606, "Text", "ExpressionUUID" -> \
"cd326062-33e5-410c-bf21-0d452af349a5"],
Cell[603558, 15969, 894, 24, 102271, "Input", "ExpressionUUID" -> \
"f20f3479-de35-44a2-91e1-481207445aae"],
Cell[604455, 15995, 154, 3, 43606, "Text", "ExpressionUUID" -> \
"3871ee85-dc9f-4a0c-b9f8-cb20cbfb0c52"],
Cell[604612, 16000, 1459, 30, 102271, "Input", "ExpressionUUID" -> \
"fad0e507-95ab-4197-bcaf-f0d4e2447461"],
Cell[606074, 16032, 1486, 34, 130308, "Input", "ExpressionUUID" -> \
"55acd8b2-43d2-4977-a1b3-69b7cdc15643"],
Cell[607563, 16068, 438, 10, 43606, "Text", "ExpressionUUID" -> \
"b915a774-7ae1-4669-bdb6-453489019934"],
Cell[608004, 16080, 1438, 33, 130308, "Input", "ExpressionUUID" -> \
"6e580730-244e-42a5-adc4-a780009409a4"],
Cell[609445, 16115, 293, 4, 43606, "Text", "ExpressionUUID" -> \
"2002d20b-b89e-4e28-af61-739a3aafd3d5"],
Cell[609741, 16121, 193, 3, 44835, "Text", "ExpressionUUID" -> \
"890791f7-1fc9-491b-b637-96b55fc363b7"],
Cell[609937, 16126, 644, 11, 74724, "Text", "ExpressionUUID" -> \
"d3aeb1d5-01d1-4a89-9865-ab275edf49be"],
Cell[610584, 16139, 570, 10, 44835, "Text", "ExpressionUUID" -> \
"9e3ba9d0-b04e-46dd-96ab-0a9abd27f0f4"],
Cell[611157, 16151, 530, 8, 44835, "Text", "ExpressionUUID" -> \
"b9cfa625-3af7-4c9d-b1af-2d7e07a3fa09"],
Cell[611690, 16161, 591, 15, 43606, "Input", "ExpressionUUID" -> \
"230cbd61-dc49-4e85-9907-c508ed6cfce8",
 Evaluatable->False],
Cell[612284, 16178, 400, 8, 74724, "Text", "ExpressionUUID" -> \
"d1624f3b-49f4-45c8-abcf-28da220a9e9b"],
Cell[612687, 16188, 254, 6, 43606, "Input", "ExpressionUUID" -> \
"add7bbc9-6f09-470e-a602-7d810661fd84"],
Cell[612944, 16196, 254, 6, 43606, "Input", "ExpressionUUID" -> \
"04e929be-0c2b-48d7-aba7-e494c3ad1453"],
Cell[613201, 16204, 347, 7, 72442, "Text", "ExpressionUUID" -> \
"7bd98796-8aaa-47f6-9405-e23ba635b388"],
Cell[613551, 16213, 927, 21, 66642, "Text", "ExpressionUUID" -> \
"94a0133f-be0b-4910-9554-e1ba7c9a898f"],
Cell[614481, 16236, 1083, 28, 131491, "Text", "ExpressionUUID" -> \
"0ecaec82-720f-493e-b3d7-12d96372ea84"],
Cell[615567, 16266, 826, 27, 74724, "Input", "ExpressionUUID" -> \
"22c4aa3d-4c8e-4fe1-88fd-caf83e30e309",
 Evaluatable->False],
Cell[616396, 16295, 219, 4, 44835, "Text", "ExpressionUUID" -> \
"04fccc5b-fdb4-4d0a-81db-a211af10adc8"],
Cell[616618, 16301, 282, 8, 43606, "Text", "ExpressionUUID" -> \
"fd113fcb-ccef-49e4-94dc-19b42c82aa21"],
Cell[616903, 16311, 308, 8, 43606, "Input", "ExpressionUUID" -> \
"1409f24e-29f1-46ce-bffb-826911a4f5a3"],
Cell[617214, 16321, 1488, 40, 130308, "Input", "ExpressionUUID" -> \
"49c73bd8-d483-41f0-8930-e720b9ff3090"],
Cell[618705, 16363, 210, 4, 43606, "Text", "ExpressionUUID" -> \
"48cb8d2f-58f1-4e32-9d84-c8048c737465"],
Cell[618918, 16369, 364, 9, 43606, "Input", "ExpressionUUID" -> \
"10638307-4848-4fc5-9cfa-da987f68dd16"],
Cell[619285, 16380, 1666, 49, 130308, "Input", "ExpressionUUID" -> \
"0671f6da-7cf9-43c3-9a1f-fc3acf5aa9fd"],
Cell[620954, 16431, 133, 3, 43606, "Text", "ExpressionUUID" -> \
"01e10df8-66c5-4dfc-913c-d14668656d6a"]
}, Closed]],
Cell[CellGroupData[{
Cell[621124, 16439, 785, 11, 42, "Subsubsection", "ExpressionUUID" -> \
"08623beb-3316-4144-b6db-a292a96c15d6"],
Cell[621912, 16452, 1071, 20, 29890, "Text", "ExpressionUUID" -> \
"cec2607e-a91b-4f62-a210-d1ead8918ed0"],
Cell[622986, 16474, 4103, 107, 243366, "Text", "ExpressionUUID" -> \
"c145ac93-fff6-44e8-925b-7720a664a600"],
Cell[627092, 16583, 570, 11, 66642, "Text", "ExpressionUUID" -> \
"4f178cdf-cd51-4b1c-93cc-0e4270289330"],
Cell[627665, 16596, 528, 14, 29071, "Input", "ExpressionUUID" -> \
"46c55cf2-fc10-4565-b9bf-c16969953d01",
 Evaluatable->False],
Cell[628196, 16612, 237, 6, 29890, "Text", "ExpressionUUID" -> \
"54b8323f-40a7-419c-8528-2e3562c799bf"],
Cell[628436, 16620, 826, 27, 49816, "Input", "ExpressionUUID" -> \
"80415a8f-a2a6-4c53-bcf0-4a756b2602f9",
 Evaluatable->False],
Cell[629265, 16649, 401, 8, 48295, "Text", "ExpressionUUID" -> \
"804d0cd1-ce3b-4dc7-a126-05100732c554"],
Cell[629669, 16659, 1008, 31, 50139, "Input", "ExpressionUUID" -> \
"7997c96a-3b41-4cbd-9c04-f7d72ed5058d",
 Evaluatable->False],
Cell[630680, 16692, 853, 13, 123322, "Text", "ExpressionUUID" -> \
"2f98f22e-f357-495b-b084-93f4a5b5956c"],
Cell[631536, 16707, 3062, 73, 162994, "Input", "ExpressionUUID" -> \
"93e82ab2-7290-4c43-b316-90afd7905fdf",
 InitializationCell->True],
Cell[634601, 16782, 553, 12, 86872, "Input", "ExpressionUUID" -> \
"96f10a4b-fcd6-4972-9e86-f68b5bd4f2d8",
 InitializationCell->True],
Cell[635157, 16796, 176, 4, 29071, "Input", "ExpressionUUID" -> \
"8d3e611f-2941-45d3-9034-83ddb78b4ee9"],
Cell[635336, 16802, 265, 7, 29071, "Input", "ExpressionUUID" -> \
"ba9d4203-2ae1-421b-ac9b-b677fa202ba3"],
Cell[635604, 16811, 475, 12, 29071, "Input", "ExpressionUUID" -> \
"87ad36e8-a1ca-4cb3-aeb7-1414d617ed64"],
Cell[636082, 16825, 585, 15, 29071, "Input", "ExpressionUUID" -> \
"25e0c5c5-0a2b-4aa0-ae78-50a5c1207b80"],
Cell[636670, 16842, 184, 3, 29071, "Text", "ExpressionUUID" -> \
"d127ba3f-4676-4c13-ae72-e13daac62e34"],
Cell[636857, 16847, 3166, 76, 145530, "Input", "ExpressionUUID" -> \
"08be5531-4a65-4baa-9f5a-7134b3db16e6",
 Evaluatable->False,
 InitializationCell->True],
Cell[640026, 16925, 328, 7, 48295, "Text", "ExpressionUUID" -> \
"014581d4-6094-43e6-8a68-57ab7b30712b"],
Cell[640357, 16934, 8069, 212, 696451, "Input", "ExpressionUUID" -> \
"87a9ff3e-9bda-41cb-b9e6-01ab27e37bad",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[648451, 17150, 474, 9, 29071, "Input", "ExpressionUUID" -> \
"d06cd785-2a5a-46b3-9388-0e5019c08f45",
 InitializationCell->True],
Cell[648928, 17161, 633, 11, 70, "Print", "ExpressionUUID" -> \
"04379eeb-ac44-4e25-a095-664f5f17361b",
 CellTags->"Info363708329049-6824778"]
}, Open  ]],
Cell[649576, 17175, 212, 5, 29071, "Text", "ExpressionUUID" -> \
"98a990ca-cc04-401a-bc2a-fa562fb1a1ca"],
Cell[649791, 17182, 245, 6, 29071, "Input", "ExpressionUUID" -> \
"eeb7e3ab-058c-4fd8-be69-720c3a2a3865"],
Cell[650039, 17190, 335, 9, 29071, "Input", "ExpressionUUID" -> \
"acac8dbb-872f-4726-8077-4119fc5dca7a"],
Cell[650377, 17201, 374, 7, 29071, "Input", "ExpressionUUID" -> \
"2a19d8a9-b5c5-423d-9c0f-38ba844cf5e3"],
Cell[650754, 17210, 191, 4, 29071, "Input", "ExpressionUUID" -> \
"a537d40f-00aa-4b9d-b3fb-732a1b02b87d"],
Cell[650948, 17216, 539, 10, 29071, "Input", "ExpressionUUID" -> \
"c8dc49c3-6457-46c2-a12d-11bb8e5da1fa"],
Cell[651490, 17228, 448, 9, 29071, "Input", "ExpressionUUID" -> \
"e80939f4-67c5-4700-9cb3-7c7284dfea47"],
Cell[651941, 17239, 252, 4, 29071, "Text", "ExpressionUUID" -> \
"1d0c046a-463d-4a26-987b-7faa4ca74c18"],
Cell[652196, 17245, 486, 12, 29071, "Input", "ExpressionUUID" -> \
"8be3fac8-b422-4a96-bbca-22692cea494f"],
Cell[652685, 17259, 301, 7, 29071, "Input", "ExpressionUUID" -> \
"03be3a8c-a06e-42fc-9d74-795560a0d1fe"],
Cell[652989, 17268, 188, 3, 29071, "Text", "ExpressionUUID" -> \
"d6726597-4e2d-44e4-9d90-5d1e97f0b126"],
Cell[653180, 17273, 189, 3, 29071, "Input", "ExpressionUUID" -> \
"58a8ca7b-0db1-4b7f-8348-704ca9bb4d85"],
Cell[653372, 17278, 450, 9, 29071, "Input", "ExpressionUUID" -> \
"ad02ddb4-5917-4a41-9a2d-8f11ce40c26e"],
Cell[653825, 17289, 160, 3, 29071, "Text", "ExpressionUUID" -> \
"047dfdb7-e75e-4396-b8dc-37aa0f80575c"],
Cell[653988, 17294, 484, 12, 29071, "Input", "ExpressionUUID" -> \
"946d1de3-b22f-4ad6-863f-eb48cfc7ffdb"],
Cell[654475, 17308, 160, 3, 29071, "Text", "ExpressionUUID" -> \
"f9d2a060-de02-4896-a6d0-80abea1d94ea"],
Cell[654638, 17313, 874, 20, 29071, "Input", "ExpressionUUID" -> \
"36c8d388-3b95-40d3-8ba8-e7982bee1d99"],
Cell[655515, 17335, 185, 3, 29071, "Text", "ExpressionUUID" -> \
"82feed7a-741c-4c27-bc63-fc19c5a235e8"],
Cell[655703, 17340, 1079, 26, 48997, "Input", "ExpressionUUID" -> \
"0b7b6001-c91c-43e4-b829-bc5c1bf4b4b3"],
Cell[656785, 17368, 227, 4, 29890, "Text", "ExpressionUUID" -> \
"bfaced54-ff07-4839-8d0a-e6ea73df2fad"],
Cell[657015, 17374, 628, 15, 29071, "Input", "ExpressionUUID" -> \
"ec35a373-f8ef-4fca-8dc5-1e729e4210ba"],
Cell[657646, 17391, 480, 9, 29071, "Input", "ExpressionUUID" -> \
"9acb7faa-dbe7-49bb-9f0f-054a29f2e054"],
Cell[658129, 17402, 184, 3, 29071, "Text", "ExpressionUUID" -> \
"a5a6799b-b1e3-4960-9720-18265ca10c58"],
Cell[658316, 17407, 191, 4, 29071, "Input", "ExpressionUUID" -> \
"26eb2844-a252-473b-b6b2-18ba8f46d3d0"],
Cell[658510, 17413, 1055, 26, 68181, "Input", "ExpressionUUID" -> \
"ef52553b-f629-4d74-b453-914343849a44"],
Cell[659568, 17441, 291, 7, 29071, "Text", "ExpressionUUID" -> \
"80a13a12-cd32-411b-a050-c142aeac14fd"],
Cell[659862, 17450, 514, 10, 29071, "Input", "ExpressionUUID" -> \
"c9fb8bff-0707-46c9-800e-ddb6ab84f0b1"],
Cell[660379, 17462, 195, 5, 29071, "Input", "ExpressionUUID" -> \
"e5978336-5ca3-4e66-8860-8ec5de8d16c5"],
Cell[660577, 17469, 754, 20, 29071, "Input", "ExpressionUUID" -> \
"8a20bf45-a28a-4f08-bded-a5f0b3f988ed"],
Cell[661334, 17491, 176, 4, 29071, "Input", "ExpressionUUID" -> \
"f626907f-fdde-47d3-aeaf-c57beaaf9dde"],
Cell[661513, 17497, 856, 23, 48997, "Input", "ExpressionUUID" -> \
"ec610560-4b93-49b6-9ea7-3fd32e079c93"],
Cell[662372, 17522, 276, 7, 29071, "Input", "ExpressionUUID" -> \
"1d91fc3d-f2f5-4f64-ad68-4c10ca4d4fff"],
Cell[662651, 17531, 842, 23, 48997, "Input", "ExpressionUUID" -> \
"473c44aa-f712-4ace-b1d0-ac17a7026db1"],
Cell[663496, 17556, 1076, 29, 48997, "Input", "ExpressionUUID" -> \
"5efbefce-24a9-40f4-a01e-11c3d8a8ef33"],
Cell[664575, 17587, 638, 15, 29071, "Input", "ExpressionUUID" -> \
"e69fab5d-318e-4bb9-a4ce-ac46067c73e4"],
Cell[665216, 17604, 1097, 28, 48997, "Input", "ExpressionUUID" -> \
"6ecd0ace-f6e8-4870-8769-f1346c1ab3dc"],
Cell[666316, 17634, 1862, 47, 86872, "Input", "ExpressionUUID" -> \
"08a080d3-379a-4280-87ce-6efce3ed1d60"],
Cell[668181, 17683, 902, 23, 48997, "Input", "ExpressionUUID" -> \
"df6deac3-9c11-4f0d-bfb9-7caf3bb174b8"],
Cell[669086, 17708, 1448, 33, 48997, "Input", "ExpressionUUID" -> \
"cda67598-9248-4446-ae41-dfe85a44cc4d"],
Cell[670537, 17743, 1901, 47, 106204, "Input", "ExpressionUUID" -> \
"3b3057ab-41ae-41de-9aec-22b840dfcb2d"],
Cell[672441, 17792, 506, 12, 29071, "Input", "ExpressionUUID" -> \
"4f299c4a-f0b6-4d2b-aca5-000a074b6723"],
Cell[672950, 17806, 276, 4, 29890, "Text", "ExpressionUUID" -> \
"b28d43ee-c69c-46b2-b1e8-4fb75381fe8f"],
Cell[673229, 17812, 280, 7, 29071, "Input", "ExpressionUUID" -> \
"21e79dff-2061-4bb4-b917-d18f9d2bb0fe"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[673558, 17825, 551, 8, 67, "Subsection", "ExpressionUUID" -> \
"58505d0f-92b2-4767-a144-c70a1b1e1843"],
Cell[CellGroupData[{
Cell[674134, 17837, 606, 9, 53, "Subsubsection", "ExpressionUUID" -> \
"aef1d765-6338-48da-aaae-6ec55bd20198"],
Cell[674743, 17848, 606, 11, 49816, "Text", "ExpressionUUID" -> \
"1175fb32-3026-41b2-8317-ef6112ba7bae"],
Cell[675352, 17861, 246, 6, 29071, "Input", "ExpressionUUID" -> \
"1f3bde43-652c-44d4-a5ab-227625ca97f6"],
Cell[675601, 17869, 2881, 60, 106204, "Input", "ExpressionUUID" -> \
"651902ca-1ae5-47c7-b41f-a39664d7c99a",
 Evaluatable->False],
Cell[678485, 17931, 179, 4, 29071, "Input", "ExpressionUUID" -> \
"76b5afbc-9773-40cf-94e6-f749f4e6b90e"],
Cell[678667, 17937, 193, 4, 29071, "Input", "ExpressionUUID" -> \
"47f11530-a369-4bc5-8674-7d3a93017019"],
Cell[678863, 17943, 557, 11, 29071, "Input", "ExpressionUUID" -> \
"59d1b9a3-7382-4d01-a0bd-94b551defa77"],
Cell[679423, 17956, 553, 14, 29071, "Input", "ExpressionUUID" -> \
"990138ec-3df1-4e4e-88f8-ba2be52fc377"],
Cell[679979, 17972, 553, 11, 29071, "Input", "ExpressionUUID" -> \
"f18a7a30-f18f-4c0c-8b80-894f391852b4"],
Cell[680535, 17985, 165, 3, 29071, "Text", "ExpressionUUID" -> \
"4c2b803c-fc34-48bb-9a8d-de21510c1a56"],
Cell[680703, 17990, 575, 15, 29071, "Input", "ExpressionUUID" -> \
"84ce839e-cd1c-43a5-afae-467c34f9097b"],
Cell[681281, 18007, 437, 10, 29071, "Input", "ExpressionUUID" -> \
"ebad0c6f-e252-4654-b06a-e39fbac067f0"],
Cell[681721, 18019, 485, 10, 29071, "Input", "ExpressionUUID" -> \
"6d4b9b7c-dcb4-4290-a587-f22da6db13f2"],
Cell[682209, 18031, 341, 10, 29071, "Input", "ExpressionUUID" -> \
"fa885d55-2eca-48fb-8a38-ab81ed934559"],
Cell[682553, 18043, 691, 13, 29071, "Input", "ExpressionUUID" -> \
"4987aefe-62eb-44b0-8e71-2db2e2cf11a0"],
Cell[683247, 18058, 356, 9, 29071, "Input", "ExpressionUUID" -> \
"a798006c-68eb-4e70-b6ea-f19c9ebab3b4"],
Cell[683606, 18069, 397, 11, 29071, "Input", "ExpressionUUID" -> \
"1a76d473-6ac8-4231-b96d-b89b102dc1d7"],
Cell[684006, 18082, 600, 16, 29071, "Input", "ExpressionUUID" -> \
"3e4251ca-f488-4513-95c3-380b3a228c91"],
Cell[684609, 18100, 323, 9, 48295, "Text", "ExpressionUUID" -> \
"16725ddf-dbb1-4b59-b3ed-534bc8492213"],
Cell[684935, 18111, 195, 5, 29071, "Input", "ExpressionUUID" -> \
"658bcc6a-b20b-45fb-bbfc-3a31a22d3c0e"],
Cell[685133, 18118, 1103, 30, 48997, "Input", "ExpressionUUID" -> \
"d3d8f982-6022-45da-8a14-a40e2516a5a2",
 Evaluatable->False],
Cell[686239, 18150, 1595, 43, 68181, "Input", "ExpressionUUID" -> \
"bcb9b2e2-4aaf-4756-9033-4d90dc22e369"],
Cell[687837, 18195, 179, 3, 29071, "Text", "ExpressionUUID" -> \
"16e13cbd-73c8-4d2b-ac58-c4509367f206"],
Cell[688019, 18200, 929, 28, 48997, "Input", "ExpressionUUID" -> \
"b211d8f8-3c6f-4362-85be-a0e7218f831f"],
Cell[688951, 18230, 699, 20, 29071, "Input", "ExpressionUUID" -> \
"ea6bb6d5-8b17-4e7b-ac9b-5c42d68c779d",
 Evaluatable->False],
Cell[689653, 18252, 198, 3, 29071, "Text", "ExpressionUUID" -> \
"d2264ea6-a231-42cb-9d79-39e9c4284647"],
Cell[689854, 18257, 1355, 36, 68181, "Input", "ExpressionUUID" -> \
"388c73b4-4b0b-421d-a0bd-9dc24c98e9a4"],
Cell[691212, 18295, 222, 6, 29890, "Text", "ExpressionUUID" -> \
"8a632e65-d621-4bd5-99d1-10a49fe661c1"],
Cell[691437, 18303, 840, 21, 29071, "Input", "ExpressionUUID" -> \
"69e12b5e-11dc-4fbb-abaa-863d7ad39f4e"],
Cell[692280, 18326, 600, 15, 29071, "Input", "ExpressionUUID" -> \
"35e86083-a52c-4d9c-aac5-c63e3fa1a32b"],
Cell[692883, 18343, 708, 20, 29071, "Input", "ExpressionUUID" -> \
"be1c7790-049e-4289-9b1b-c22546084688"],
Cell[693594, 18365, 602, 11, 88258, "Text", "ExpressionUUID" -> \
"b0d75645-185f-4cbe-8ac2-be269f9a265c"],
Cell[694199, 18378, 441, 9, 48997, "Text", "ExpressionUUID" -> \
"36a7c052-766f-445a-9b18-ba1f42c2759f",
 CellTags->"bastr"],
Cell[694643, 18389, 702, 20, 61965, "Input", "ExpressionUUID" -> \
"f4581b36-144f-4569-81c6-310f4abe9646",
 Evaluatable->False],
Cell[695348, 18411, 946, 26, 68485, "Input", "ExpressionUUID" -> \
"ba0a1b71-57e5-4eae-a972-eb52ca55cd07",
 Evaluatable->False],
Cell[696297, 18439, 214, 7, 29071, "Text", "ExpressionUUID" -> \
"3edc5f42-30ea-4027-b2a1-cadc97ec25bb"],
Cell[696514, 18448, 2086, 53, 86872, "Input", "ExpressionUUID" -> \
"9c6bccdc-0b5b-4d1b-bab2-700d93329a95"],
Cell[698603, 18503, 1745, 40, 68181, "Input", "ExpressionUUID" -> \
"54f6fafd-9e8f-46db-bd35-49e339b48040"],
Cell[700351, 18545, 155, 3, 29071, "Text", "ExpressionUUID" -> \
"635e3acb-8744-4d75-b083-75399c162f93"],
Cell[700509, 18550, 886, 24, 68181, "Input", "ExpressionUUID" -> \
"fb8a02e6-c739-4d25-a5f4-5510082c5d51"],
Cell[701398, 18576, 736, 20, 29071, "Input", "ExpressionUUID" -> \
"c8bed13a-0b97-4fd1-aa38-b57b4f16cdd1"],
Cell[702137, 18598, 401, 8, 48295, "Text", "ExpressionUUID" -> \
"d09f208e-16cb-4f84-a639-086fb5aa3bd6"],
Cell[702541, 18608, 287, 7, 29071, "Input", "ExpressionUUID" -> \
"dbda564a-e4ea-4f3d-acdc-a4f01dd4ea7c"],
Cell[702831, 18617, 287, 7, 29071, "Input", "ExpressionUUID" -> \
"77cf5b15-8ac4-42b5-b4e9-a9ca996eb9c3"],
Cell[703121, 18626, 846, 22, 48997, "Input", "ExpressionUUID" -> \
"fc771e94-b06c-466b-a06b-96a7acfa8885"],
Cell[703970, 18650, 1875, 50, 86872, "Input", "ExpressionUUID" -> \
"0a452160-534b-47de-a2e2-554c6135ef17"],
Cell[705848, 18702, 237, 6, 29071, "Text", "ExpressionUUID" -> \
"5b95221f-974f-4cab-bd13-655ad8d7f796"],
Cell[706088, 18710, 756, 21, 29071, "Input", "ExpressionUUID" -> \
"e738a781-5b66-4c0f-8691-2d5a90f203fb"],
Cell[706847, 18733, 1478, 39, 68181, "Input", "ExpressionUUID" -> \
"fa068db1-40ac-4aac-8180-db6dcd0bc36d"],
Cell[708328, 18774, 1385, 37, 68181, "Input", "ExpressionUUID" -> \
"479c1b70-cb3c-45f2-b884-822e6ba15377"],
Cell[709716, 18813, 653, 19, 29071, "Input", "ExpressionUUID" -> \
"0895ae30-4ad1-4f0f-9d0d-6ad120acc0c2"],
Cell[710372, 18834, 274, 6, 48295, "Text", "ExpressionUUID" -> \
"4805d512-51fa-4f46-91a4-334fd1be9fb5"],
Cell[710649, 18842, 880, 21, 48997, "Input", "ExpressionUUID" -> \
"40e2dcd0-5610-449b-a733-aedfa7e53acf",
 Evaluatable->False],
Cell[711532, 18865, 796, 21, 48997, "Input", "ExpressionUUID" -> \
"ff358a57-be26-41fb-b701-ea93eabe0774",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[712365, 18891, 531, 8, 42, "Subsubsection", "ExpressionUUID" -> \
"4a8faeb7-e75b-4a3f-a7b8-e632a7f9039a"],
Cell[712899, 18901, 305, 7, 48295, "Text", "ExpressionUUID" -> \
"aed6f4a2-4d37-4ee6-8435-5a58665fb192"],
Cell[713207, 18910, 1066, 26, 29071, "Input", "ExpressionUUID" -> \
"d566fc05-6b1c-4eed-bf5c-b4ac9511e661",
 Evaluatable->False],
Cell[714276, 18938, 459, 9, 48295, "Text", "ExpressionUUID" -> \
"cc63675b-b31d-4540-a0e5-14939440b033"],
Cell[714738, 18949, 638, 14, 29071, "Input", "ExpressionUUID" -> \
"55c2f275-814e-4c7c-8d02-8da0cf2bbdd7",
 Evaluatable->False],
Cell[715379, 18965, 222, 5, 29071, "Input", "ExpressionUUID" -> \
"5fe4f1b5-3454-4134-bf07-5543e0312c37"],
Cell[715604, 18972, 409, 10, 29071, "Text", "ExpressionUUID" -> \
"ce0e750b-cf28-4221-9478-95919b69fb2b"],
Cell[716016, 18984, 3503, 80, 144301, "Input", "ExpressionUUID" -> \
"d548d9c9-d5ad-4bf8-a8e0-ca49935b4d3f",
 Evaluatable->False],
Cell[719522, 19066, 396, 9, 29071, "Input", "ExpressionUUID" -> \
"c2af5c3a-d6cd-4cec-b6aa-edf6934997ba"],
Cell[719921, 19077, 445, 10, 29071, "Input", "ExpressionUUID" -> \
"406cb43f-49d5-45e6-b8ce-e992b6589ff3"],
Cell[720369, 19089, 536, 12, 29071, "Input", "ExpressionUUID" -> \
"01a4978d-aed3-4727-8d95-a545baa1e1ef"],
Cell[720908, 19103, 709, 18, 29071, "Input", "ExpressionUUID" -> \
"0e7a3180-d118-487f-ad30-5dbbaf879509"],
Cell[721620, 19123, 462, 11, 29071, "Input", "ExpressionUUID" -> \
"1aa3a8ac-2c3e-48de-9066-093acbe55231"],
Cell[722085, 19136, 340, 9, 29071, "Input", "ExpressionUUID" -> \
"5e836ee3-b982-4b9c-8bfe-608c76c58134"],
Cell[722428, 19147, 431, 10, 29071, "Input", "ExpressionUUID" -> \
"811fad58-e375-4bfe-ac9d-18cb124852c9"],
Cell[722862, 19159, 661, 17, 29071, "Input", "ExpressionUUID" -> \
"1c7bd226-6451-4ac0-baf3-6445e9d2e20d"],
Cell[723526, 19178, 433, 10, 29071, "Input", "ExpressionUUID" -> \
"29d796f9-a2a5-452e-aebd-acd3b10fcb09"],
Cell[723962, 19190, 568, 16, 29071, "Input", "ExpressionUUID" -> \
"1f19f0b6-ff7f-4fa8-a60e-4567bc1a892c"],
Cell[724533, 19208, 344, 9, 29071, "Input", "ExpressionUUID" -> \
"1a739352-63b7-4c28-9a3b-2c76ac93c5b1"],
Cell[724880, 19219, 313, 6, 29071, "Text", "ExpressionUUID" -> \
"41c7c55b-4906-4358-8ecc-9d530439b6e6"],
Cell[725196, 19227, 1822, 57, 68181, "Input", "ExpressionUUID" -> \
"30c05db7-1838-4ce3-8a9d-4ef81c409012",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[727043, 19288, 450, 8, 29071, "Input", "ExpressionUUID" -> \
"dcdb6cd5-0e93-4fba-8039-afd7fc37a83d",
 InitializationCell->True],
Cell[727496, 19298, 461, 8, 70, "Print", "ExpressionUUID" -> \
"0506b40b-363b-4965-8d77-a32dc3d4feaa",
 CellTags->"Info373708329049-6824778"]
}, Open  ]],
Cell[727972, 19309, 478, 10, 68181, "Text", "ExpressionUUID" -> \
"66d92b6a-d364-4bc1-836e-649c60ffec41"],
Cell[728453, 19321, 616, 18, 29071, "Input", "ExpressionUUID" -> \
"b68e93d5-a7a2-4aaa-a09d-2f845797d5c7"],
Cell[729072, 19341, 641, 18, 29071, "Input", "ExpressionUUID" -> \
"365b8827-c04a-47f0-9f8f-ab7aabfbffef"],
Cell[729716, 19361, 695, 19, 29071, "Input", "ExpressionUUID" -> \
"6b0a20ba-2271-4d6d-9124-888a2b0913d5"],
Cell[730414, 19382, 695, 19, 29071, "Input", "ExpressionUUID" -> \
"3e291cce-3d0e-45bc-b545-0816e2a660a8"],
Cell[731112, 19403, 157, 3, 29071, "Text", "ExpressionUUID" -> \
"1c14fd19-24fe-4cc5-be61-4de9275766d6"],
Cell[731272, 19408, 354, 8, 66642, "Text", "ExpressionUUID" -> \
"69a587f6-ac2f-481f-b047-c9620cc6b16c"],
Cell[731629, 19418, 673, 16, 29071, "Input", "ExpressionUUID" -> \
"34aff66f-0c27-4a8a-b04c-1674bfdc1dd6",
 Evaluatable->False],
Cell[732305, 19436, 649, 16, 29071, "Input", "ExpressionUUID" -> \
"be3a8357-ea9c-470c-a7bb-fdb4042515a0",
 Evaluatable->False],
Cell[732957, 19454, 670, 17, 29071, "Input", "ExpressionUUID" -> \
"da4dbc35-6d6e-4ddb-8553-6772c1541880",
 Evaluatable->False],
Cell[733630, 19473, 674, 16, 29071, "Input", "ExpressionUUID" -> \
"269adaa8-6ec6-4691-9550-3c1f80602206",
 Evaluatable->False],
Cell[734307, 19491, 247, 8, 29071, "Text", "ExpressionUUID" -> \
"c51429e0-79a4-4ee6-9180-c747a9a8bda0"],
Cell[734557, 19501, 1631, 51, 68181, "Input", "ExpressionUUID" -> \
"be76db0c-fffb-4e45-94d3-3adb56efec43"],
Cell[736191, 19554, 2053, 68, 68181, "Input", "ExpressionUUID" -> \
"0366fa3d-92a0-4a7b-872b-1a1d54de1a93"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[738293, 19628, 333, 5, 67, "Subsection", "ExpressionUUID" -> \
"ccb17bc2-bb90-4a7d-8c45-734698373130"],
Cell[CellGroupData[{
Cell[738651, 19637, 280, 4, 75, "Subsubsection", "ExpressionUUID" -> \
"08bde261-96d9-4ec4-8aba-101d9a66df0b",
 CellTags->"intcond"],
Cell[738934, 19643, 1516, 24, 204822, "Text", "ExpressionUUID" -> \
"3d42e2ba-10a5-4ea0-a05f-de970b28585b"],
Cell[740453, 19669, 170, 4, 29071, "Input", "ExpressionUUID" -> \
"37326151-9fb5-4852-b147-283da3c58914"],
Cell[740626, 19675, 425, 11, 29071, "Input", "ExpressionUUID" -> \
"309a24e1-3b9b-46be-8f20-bf9661d936e5",
 Evaluatable->False],
Cell[741054, 19688, 406, 10, 29071, "Input", "ExpressionUUID" -> \
"c205c8a8-8e7c-4cfe-bf6c-8b617842f021",
 Evaluatable->False],
Cell[741463, 19700, 478, 13, 29071, "Input", "ExpressionUUID" -> \
"da9c991c-9d77-4456-be6c-a3a22852a5ad",
 Evaluatable->False],
Cell[741944, 19715, 429, 11, 29071, "Input", "ExpressionUUID" -> \
"086af0da-2f84-473d-ae9c-e9c84c22b4ac",
 Evaluatable->False],
Cell[742376, 19728, 427, 11, 29071, "Input", "ExpressionUUID" -> \
"20b061fa-bd72-4536-9e3a-1175b35a914f",
 Evaluatable->False],
Cell[742806, 19741, 455, 12, 29071, "Input", "ExpressionUUID" -> \
"9e02d3d7-09d8-4370-b049-aab9c0049620",
 Evaluatable->False],
Cell[743264, 19755, 395, 8, 48295, "Text", "ExpressionUUID" -> \
"1d10034c-0a33-4f4f-b303-3cd3ca43fa9f"],
Cell[743662, 19765, 206, 5, 29071, "Input", "ExpressionUUID" -> \
"9ff7db2e-73c2-4735-b79f-52d8a1b9b809"]
}, Closed]],
Cell[CellGroupData[{
Cell[743905, 19775, 528, 8, 42, "Subsubsection", "ExpressionUUID" -> \
"403a1f6b-610d-451a-8913-1e699dd08de0"],
Cell[744436, 19785, 222, 5, 29071, "Input", "ExpressionUUID" -> \
"0ce1619e-398c-48a3-8320-c2361fe3406d"],
Cell[744661, 19792, 193, 4, 29071, "Input", "ExpressionUUID" -> \
"644274d5-74e5-48ad-b002-838a915258a6"],
Cell[744857, 19798, 463, 11, 29071, "Input", "ExpressionUUID" -> \
"57f39672-21ee-4c69-ac97-838b8d3c4bb2"],
Cell[745323, 19811, 889, 23, 48997, "Input", "ExpressionUUID" -> \
"47f5c457-2889-4b71-8294-2e829d86e30e"],
Cell[746215, 19836, 939, 23, 48997, "Input", "ExpressionUUID" -> \
"30af8779-c02b-4ba5-b3c3-0e1e9cdf72c4"],
Cell[747157, 19861, 1090, 28, 48997, "Input", "ExpressionUUID" -> \
"39a86b96-20db-4938-b314-268e488e873b"]
}, Closed]],
Cell[CellGroupData[{
Cell[748284, 19894, 510, 8, 42, "Subsubsection", "ExpressionUUID" -> \
"31449abb-39a5-4d33-9915-ebb8c9dc8bc2"],
Cell[748797, 19904, 1160, 27, 68181, "Input", "ExpressionUUID" -> \
"4ceeb843-4950-4e44-bc93-9d8ebca7c9db"],
Cell[749960, 19933, 461, 11, 29890, "Text", "ExpressionUUID" -> \
"37553efb-005b-45a6-ac69-bc117b649ae4"],
Cell[750424, 19946, 1135, 26, 68181, "Input", "ExpressionUUID" -> \
"c8e92b65-6ef7-4848-969b-21fbe27c9d84"],
Cell[751562, 19974, 341, 7, 29890, "Text", "ExpressionUUID" -> \
"c4ee5276-774e-43e5-8750-b6e56a4ca95c"],
Cell[751906, 19983, 1159, 27, 68181, "Input", "ExpressionUUID" -> \
"c77a6327-df41-4a34-ad33-269f06401fab"],
Cell[753068, 20012, 367, 7, 29890, "Text", "ExpressionUUID" -> \
"a01e9387-67d6-430a-9385-d7946087795b"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[753484, 20025, 378, 6, 67, "Subsection", "ExpressionUUID" -> \
"cd87d909-2f47-4b4e-8341-2bb7e038a732"],
Cell[753865, 20033, 280, 6, 83, "Text", "ExpressionUUID" -> \
"79147f62-6a87-4c94-85e6-2f2c1d97c6a8"],
Cell[754148, 20041, 1808, 31, 278, "Text", "ExpressionUUID" -> \
"69b666ff-7a4b-4bba-87f9-23b0b7a68b11"],
Cell[755959, 20074, 2453, 36, 223488, "Text", "ExpressionUUID" -> \
"1aea1f5c-4ed6-49d5-9b90-c9df754ca833"],
Cell[758415, 20112, 1030, 26, 29071, "Input", "ExpressionUUID" -> \
"0f1fc921-d268-44b5-9798-796641297c26",
 Evaluatable->False],
Cell[759448, 20140, 813, 22, 29071, "Input", "ExpressionUUID" -> \
"9667e09f-75bf-4fdb-b65c-4328a1d6b1a7",
 Evaluatable->False],
Cell[760264, 20164, 833, 23, 29071, "Input", "ExpressionUUID" -> \
"d6cde09b-7953-4639-973c-13dcbe98d9dd",
 Evaluatable->False],
Cell[761100, 20189, 887, 23, 29071, "Input", "ExpressionUUID" -> \
"02c61507-2cff-4117-bdab-d68886dd373e",
 Evaluatable->False],
Cell[761990, 20214, 969, 16, 107479, "Text", "ExpressionUUID" -> \
"2a5d71c6-f527-4c15-833a-fc615f0cf48f"],
Cell[762962, 20232, 236, 7, 29071, "Text", "ExpressionUUID" -> \
"e0cc2083-16b6-4516-88fe-577b2892a0d8"],
Cell[763201, 20241, 625, 12, 29071, "Input", "ExpressionUUID" -> \
"e13bf9be-977e-4aae-9139-11ef51611fd0"],
Cell[763829, 20255, 191, 4, 29071, "Input", "ExpressionUUID" -> \
"26331f13-95fa-4c8f-9439-9c171665f6be"],
Cell[764023, 20261, 262, 4, 29890, "Text", "ExpressionUUID" -> \
"ed0448e7-430f-4a1f-b32a-9c227dbaa160"],
Cell[764288, 20267, 692, 14, 29071, "Input", "ExpressionUUID" -> \
"de755044-b8b2-4fb7-b568-3c7d6a68674a"],
Cell[764983, 20283, 690, 15, 29071, "Input", "ExpressionUUID" -> \
"f06006ba-9b75-4e7a-85ad-9abf8368500a"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[765722, 20304, 455, 7, 97, "Section", "ExpressionUUID" -> \
"8165a65b-da93-4bd3-a36c-e8f3836dd76a"],
Cell[CellGroupData[{
Cell[766202, 20315, 220, 4, 67, "Subsection", "ExpressionUUID" -> \
"9920cbf1-e07b-43ad-8ac5-407583d118ee"],
Cell[CellGroupData[{
Cell[766447, 20323, 607, 9, 53, "Subsubsection", "ExpressionUUID" -> \
"e501a131-cafc-4ffe-a5aa-cc7e92b6dbec"],
Cell[767057, 20334, 2072, 37, 216451, "Text", "ExpressionUUID" -> \
"50ca4d36-385e-4665-8985-a4ecf0f5c519"],
Cell[769132, 20373, 833, 21, 29071, "Input", "ExpressionUUID" -> \
"ac978075-cdff-4e70-9b44-b2bbf9f124b0",
 Evaluatable->False],
Cell[769968, 20396, 1003, 19, 66642, "Text", "ExpressionUUID" -> \
"9e6f3136-5395-49a7-b2e2-e74f5643455c"],
Cell[770974, 20417, 681, 11, 68485, "Text", "ExpressionUUID" -> \
"52cd7c6c-5159-46e7-907b-111e15782e55",
 CellTags->"lem2.1.1"],
Cell[771658, 20430, 282, 7, 29071, "Text", "ExpressionUUID" -> \
"b009babb-6c75-4b38-ae02-35e471982e82"],
Cell[771943, 20439, 337, 5, 29071, "Text", "ExpressionUUID" -> \
"c53c0638-de34-4fd6-bc2e-62739b7d88c5"],
Cell[772283, 20446, 514, 9, 48295, "Text", "ExpressionUUID" -> \
"540d3ab2-5df7-4c76-a9a0-6cffe786799a"],
Cell[772800, 20457, 723, 18, 29071, "Input", "ExpressionUUID" -> \
"a555550b-64f2-40d4-a3fe-ea1f9f62cf6d",
 Evaluatable->False],
Cell[773526, 20477, 1421, 22, 127183, "Text", "ExpressionUUID" -> \
"2a1a64ec-0c01-4ace-802c-9e21b4fd3642"],
Cell[774950, 20501, 506, 12, 29071, "Input", "ExpressionUUID" -> \
"bceadbf0-8716-487c-9482-573c6eeb4142",
 Evaluatable->False],
Cell[775459, 20515, 206, 4, 29071, "Text", "ExpressionUUID" -> \
"64ce7a14-7b8b-44bd-9ab2-1fb3b84d751b"],
Cell[775668, 20521, 1908, 50, 68181, "Input", "ExpressionUUID" -> \
"127b1710-fa50-47cc-9752-7217b20a039c",
 Evaluatable->False],
Cell[777579, 20573, 485, 9, 49816, "Text", "ExpressionUUID" -> \
"608e76b0-5032-4a19-8973-6aca6f177f5d"]
}, Closed]],
Cell[CellGroupData[{
Cell[778101, 20587, 515, 8, 42, "Subsubsection", "ExpressionUUID" -> \
"ef16d79e-0471-4be3-8373-bb5cd1597da8"],
Cell[778619, 20597, 489, 11, 21465, "Text", "ExpressionUUID" -> \
"a73ae35a-e936-451d-bc33-3733b7e8157b"],
Cell[779111, 20610, 704, 20, 12921, "Input", "ExpressionUUID" -> \
"9fd727de-1c72-4bfe-b92c-64c3e54c4de6",
 InitializationCell->True],
Cell[779818, 20632, 261, 7, 12921, "Input", "ExpressionUUID" -> \
"8db182e1-0785-42a2-aa59-0e782a8b97bb"],
Cell[780082, 20641, 757, 18, 21465, "Text", "ExpressionUUID" -> \
"a907eb54-f30a-4ed7-a363-5aa4265cc075"],
Cell[780842, 20661, 397, 9, 13285, "Text", "ExpressionUUID" -> \
"124dc096-7994-4794-8e3e-a95803503bb2"],
Cell[781242, 20672, 784, 17, 22284, "Text", "ExpressionUUID" -> \
"6de376b9-7f68-44f7-8817-c2e49e9f743f"],
Cell[782029, 20691, 184, 4, 12921, "Input", "ExpressionUUID" -> \
"2ecfd4cd-af9a-414f-b0c0-8aac9fef2bc8"],
Cell[782216, 20697, 214, 4, 12921, "Input", "ExpressionUUID" -> \
"e2cc0750-eef0-4b93-b44f-05ecf6ca244f"],
Cell[782433, 20703, 231, 5, 12921, "Input", "ExpressionUUID" -> \
"efc89913-e6be-4288-a8d5-055c7f65fac0"],
Cell[782667, 20710, 614, 14, 12921, "Input", "ExpressionUUID" -> \
"4e56c838-71b2-4980-bced-b502b903ea19"],
Cell[783284, 20726, 208, 5, 12921, "Input", "ExpressionUUID" -> \
"25b83752-2ed7-44ac-96a8-34d48d4c64a6"],
Cell[783495, 20733, 270, 5, 13285, "Text", "ExpressionUUID" -> \
"4315f6f5-613b-43d7-8a1d-8687a6faca2e"],
Cell[783768, 20740, 177, 4, 19381, "Input", "ExpressionUUID" -> \
"5055769c-ed97-407b-b9f7-70b21a95e939"],
Cell[783948, 20746, 211, 5, 19381, "Input", "ExpressionUUID" -> \
"5322748e-15fa-4476-b37a-2fd1a1ee916d"],
Cell[784162, 20753, 288, 7, 19381, "Input", "ExpressionUUID" -> \
"77498715-2517-48fe-82b5-94d0489aeb9f"],
Cell[784453, 20762, 370, 8, 19381, "Input", "ExpressionUUID" -> \
"9aeb4ae5-470a-4fa8-ad8b-2dd0f8d21495"],
Cell[784826, 20772, 474, 13, 35065, "Text", "ExpressionUUID" -> \
"fb9d9643-a372-4ca1-b29e-712d12253d66"],
Cell[785303, 20787, 791, 21, 32665, "Input", "ExpressionUUID" -> \
"ba1e398f-bbad-4d1b-aed4-010ea2415f0e"],
Cell[786097, 20810, 582, 18, 19381, "Input", "ExpressionUUID" -> \
"aae0a66b-bff7-4dc9-8cd7-cce421f6a334"],
Cell[786682, 20830, 837, 24, 51880, "Input", "ExpressionUUID" -> \
"98eb5e1a-cde2-47ce-ba4a-9b09b970a92a"],
Cell[787522, 20856, 173, 3, 19381, "Text", "ExpressionUUID" -> \
"fac63950-f404-4a20-a154-1a81467d11d2"],
Cell[787698, 20861, 832, 23, 51880, "Input", "ExpressionUUID" -> \
"0cf8942e-f454-4fba-8064-a85b141351e5"],
Cell[788533, 20886, 297, 7, 32197, "Text", "ExpressionUUID" -> \
"351f6804-e668-4367-88a8-e34b19ea2ea5"],
Cell[788833, 20895, 477, 11, 19381, "Input", "ExpressionUUID" -> \
"0cbf4232-d93a-4276-94b4-ade51561f28b"],
Cell[789313, 20908, 256, 6, 19381, "Input", "ExpressionUUID" -> \
"77034e04-3247-4fa8-a9c2-3f2a98b841e7"],
Cell[789572, 20916, 219, 5, 19381, "Input", "ExpressionUUID" -> \
"fe9a18b9-ec06-48eb-9ef8-0d331575ce83"],
Cell[789794, 20923, 228, 4, 19927, "Text", "ExpressionUUID" -> \
"59d36a20-81bf-4b3f-8584-69e85c38a3b6"],
Cell[790025, 20929, 242, 6, 19381, "Input", "ExpressionUUID" -> \
"959b21c8-91d9-4e35-9082-ae6acfe1b5fe"],
Cell[790270, 20937, 193, 3, 19381, "Text", "ExpressionUUID" -> \
"791e842b-90b2-4618-bca3-669fc41e64cb"],
Cell[790466, 20942, 361, 9, 19381, "Input", "ExpressionUUID" -> \
"6832af88-e610-4c82-be0a-6c8ab039e3c4"],
Cell[790830, 20953, 182, 3, 19381, "Text", "ExpressionUUID" -> \
"8a4d1255-15e2-4e2d-a9b2-275643e4e872"],
Cell[791015, 20958, 363, 9, 19381, "Input", "ExpressionUUID" -> \
"4a9b8a44-3be0-49a4-8dd3-51f69806d594"],
Cell[791381, 20969, 308, 7, 19927, "Text", "ExpressionUUID" -> \
"b1b07da9-a72d-40c9-b475-e4e2c0c902c5"],
Cell[791692, 20978, 807, 22, 45454, "Input", "ExpressionUUID" -> \
"848a522b-df3d-4900-9ef5-3df6f87ac2df"],
Cell[792502, 21002, 510, 13, 27994, "Input", "ExpressionUUID" -> \
"ac464e83-a492-4415-9109-a8dbfaf05591"],
Cell[793015, 21017, 615, 14, 27994, "Input", "ExpressionUUID" -> \
"940d6d4e-bacb-48d4-b08d-8ca5d5fcd039"],
Cell[793633, 21033, 1066, 30, 32665, "Input", "ExpressionUUID" -> \
"7eab40ae-060f-4657-987b-4294cfc69b91"],
Cell[794702, 21065, 239, 4, 19381, "Text", "ExpressionUUID" -> \
"f1495331-84cb-4ac0-9989-6cc559ff9a0f"],
Cell[794944, 21071, 489, 13, 32665, "Input", "ExpressionUUID" -> \
"438f4680-8c82-422c-a299-f4cf94557597"],
Cell[795436, 21086, 209, 5, 19381, "Input", "ExpressionUUID" -> \
"3fd6fffb-dc81-49f0-9562-de025d549c7d"],
Cell[795648, 21093, 172, 3, 19381, "Text", "ExpressionUUID" -> \
"1cefde43-b3fa-4248-bf19-48e3e52ecbf2"],
Cell[795823, 21098, 755, 20, 45454, "Input", "ExpressionUUID" -> \
"f207c050-7af3-4c97-aa86-197a79fd0840"],
Cell[796581, 21120, 200, 5, 19381, "Input", "ExpressionUUID" -> \
"3670463b-2d09-45ca-b0d2-c67e1bbda455"],
Cell[796784, 21127, 322, 8, 19381, "Input", "ExpressionUUID" -> \
"318d551d-037b-48f8-848e-5141a2aa2295"],
Cell[797109, 21137, 294, 4, 19381, "Text", "ExpressionUUID" -> \
"17a5d85e-a917-49c6-b920-9795fc465724"],
Cell[797406, 21143, 464, 13, 19381, "Input", "ExpressionUUID" -> \
"9d2105a9-c287-4390-9de3-1d935b84a705"],
Cell[797873, 21158, 207, 3, 19381, "Text", "ExpressionUUID" -> \
"6a457e1e-180a-41b5-a23a-d11355eafd0e"],
Cell[798083, 21163, 1261, 39, 85950, "Input", "ExpressionUUID" -> \
"5a6d1307-dc02-4e83-b519-f91e929e044b"],
Cell[799347, 21204, 560, 15, 19381, "Input", "ExpressionUUID" -> \
"69f02040-2c0f-42b9-8cac-e51a65374b96"],
Cell[799910, 21221, 706, 16, 19381, "Input", "ExpressionUUID" -> \
"21f4e606-e4c8-4bc3-8af4-a9022152938c"],
Cell[800619, 21239, 201, 5, 19381, "Input", "ExpressionUUID" -> \
"35a1ba9e-c009-4ea5-83f0-d9967d2ec25d"],
Cell[800823, 21246, 833, 22, 32665, "Input", "ExpressionUUID" -> \
"17826ef9-9c02-495f-9abd-f0d49a113385"],
Cell[801659, 21270, 198, 5, 19381, "Input", "ExpressionUUID" -> \
"ce26fd3a-73d5-483c-881f-71b86ffacf26"],
Cell[801860, 21277, 241, 6, 19381, "Input", "ExpressionUUID" -> \
"10230c53-c416-47d8-8f78-a51531bd3430"],
Cell[802104, 21285, 280, 6, 19381, "Text", "ExpressionUUID" -> \
"07e52110-724f-4db5-b8eb-22a12fbf789c"],
Cell[802387, 21293, 250, 7, 19381, "Input", "ExpressionUUID" -> \
"ab4b4add-ea50-48d8-af9e-dd2890338673"],
Cell[802640, 21302, 236, 7, 19381, "Text", "ExpressionUUID" -> \
"7cb14625-7f9f-40c4-9e12-6bdb13efcfa7"],
Cell[802879, 21311, 527, 15, 19381, "Input", "ExpressionUUID" -> \
"f6f138e0-c45b-42a6-97e2-fc0adbf16b60"],
Cell[803409, 21328, 295, 4, 19381, "Text", "ExpressionUUID" -> \
"404aff16-3389-43a7-9ca7-02f93a8d1786"],
Cell[803707, 21334, 785, 21, 32665, "Input", "ExpressionUUID" -> \
"f269343e-0776-4c2d-81c4-40bc64d2d2ad"],
Cell[804495, 21357, 210, 5, 19381, "Text", "ExpressionUUID" -> \
"f4fc6843-09e3-4183-b4ed-517593ef4eae"],
Cell[804708, 21364, 327, 8, 19381, "Input", "ExpressionUUID" -> \
"13f5d1df-a27a-4f26-aab6-2f3e0c7f53bb"],
Cell[805038, 21374, 209, 3, 19381, "Text", "ExpressionUUID" -> \
"be0a9567-dc32-4c57-9106-33182b8af7dd"],
Cell[805250, 21379, 389, 10, 19381, "Input", "ExpressionUUID" -> \
"14239881-7611-43e5-b109-de5894fbc76e"],
Cell[805642, 21391, 223, 4, 19381, "Text", "ExpressionUUID" -> \
"9aa962f3-b73c-4b6a-b9da-d99f74116526"],
Cell[805868, 21397, 378, 11, 33927, "Input", "ExpressionUUID" -> \
"c897683e-3e50-4aab-a8be-31859d70b84e"],
Cell[806249, 21410, 476, 13, 33927, "Input", "ExpressionUUID" -> \
"0a3c553f-5bee-4d02-966d-0d1c7d1a2bdc"],
Cell[806728, 21425, 204, 3, 19381, "Text", "ExpressionUUID" -> \
"cfad1562-06fd-4874-bd3d-0d3aac4f43d0"],
Cell[806935, 21430, 161, 3, 19381, "Text", "ExpressionUUID" -> \
"609f2df2-e223-412c-b07c-b4795af95161"],
Cell[807099, 21435, 412, 8, 32197, "Text", "ExpressionUUID" -> \
"b62e058c-c45e-41b7-b00e-7116c6c8d98b"],
Cell[807514, 21445, 542, 14, 19381, "Input", "ExpressionUUID" -> \
"f2bcfb4c-bb40-498b-9fc3-1f78f107c425"],
Cell[808059, 21461, 274, 4, 19381, "Text", "ExpressionUUID" -> \
"525513bb-1008-429d-bfca-b7d9d3521f2c"],
Cell[808336, 21467, 997, 27, 32665, "Input", "ExpressionUUID" -> \
"6a8932c8-8074-4f1f-b520-006d9e2eab76"],
Cell[809336, 21496, 156, 3, 19381, "Text", "ExpressionUUID" -> \
"ef827b8e-314a-448c-9fa4-833e1d3dd4e6"],
Cell[809495, 21501, 872, 23, 32665, "Input", "ExpressionUUID" -> \
"647a099d-e30b-440f-aa52-7928ba872146"],
Cell[810370, 21526, 926, 24, 32665, "Input", "ExpressionUUID" -> \
"4d8c8a50-a8aa-4922-aede-537eaad4f08c"],
Cell[811299, 21552, 1488, 22, 73495, "Text", "ExpressionUUID" -> \
"fc3eaf83-00f5-4e24-8be5-fb9e18f4b5b7"],
Cell[812790, 21576, 2000, 59, 47202, "Input", "ExpressionUUID" -> \
"e2b23936-b97d-45cb-b111-eba1ef5f5b08",
 InitializationCell->True],
Cell[814793, 21637, 293, 6, 21465, "Text", "ExpressionUUID" -> \
"0c964480-9a46-4a5f-9d94-23f14208c4f0"],
Cell[815089, 21645, 620, 14, 12921, "Input", "ExpressionUUID" -> \
"4769b3c8-c77f-483b-a805-d35a10daa10e"],
Cell[815712, 21661, 624, 14, 12921, "Input", "ExpressionUUID" -> \
"e0e1432f-300e-41f5-a008-cf9b8de5a69e"],
Cell[816339, 21677, 649, 14, 12921, "Input", "ExpressionUUID" -> \
"a84c14a8-1678-494e-b7b5-83c37822d394"],
Cell[816991, 21693, 277, 6, 21465, "Text", "ExpressionUUID" -> \
"9070ac72-ce4c-4413-b8bb-80f8b4b1fa21"],
Cell[817271, 21701, 352, 8, 12921, "Input", "ExpressionUUID" -> \
"b1cef166-3877-4eeb-bef6-8facdb4be8eb"],
Cell[817626, 21711, 303, 7, 12921, "Input", "ExpressionUUID" -> \
"f3008c1c-8a72-4141-ad85-f693a8de2b8e"],
Cell[817932, 21720, 431, 11, 12921, "Input", "ExpressionUUID" -> \
"6f0cf977-2a44-41c5-8c9d-aae220820f85"],
Cell[818366, 21733, 339, 10, 12921, "Input", "ExpressionUUID" -> \
"d8e610f1-90dc-4a6d-b809-209bd821957b"],
Cell[818708, 21745, 502, 11, 29619, "Text", "ExpressionUUID" -> \
"663ce2e8-18e9-44da-b26f-2eadf05f4468"]
}, Closed]],
Cell[CellGroupData[{
Cell[819247, 21761, 588, 8, 42, "Subsubsection", "ExpressionUUID" -> \
"f1b9374a-a10e-4b93-999b-becd4d551031"],
Cell[819838, 21771, 394, 12, 19381, "Text", "ExpressionUUID" -> \
"8a2af423-f5b0-4b5b-94d4-3c91d00a2e66"],
Cell[820235, 21785, 185, 4, 19381, "Input", "ExpressionUUID" -> \
"a52ef0bb-e7d1-4a3b-b4ad-9715a8dbb931"],
Cell[820423, 21791, 197, 4, 19381, "Input", "ExpressionUUID" -> \
"d9adb974-c187-476e-9bb3-a2358e655997"],
Cell[820623, 21797, 369, 8, 19381, "Input", "ExpressionUUID" -> \
"e376a518-6e8f-436c-9029-91c5b748d84e"],
Cell[820995, 21807, 481, 11, 19381, "Input", "ExpressionUUID" -> \
"76ae3dfd-d4ca-466e-852a-9785857a34c0"],
Cell[821479, 21820, 356, 9, 32197, "Text", "ExpressionUUID" -> \
"f3b798c2-dc2d-45ff-aca6-5b6752ca4d9d"],
Cell[821838, 21831, 2275, 50, 60688, "Input", "ExpressionUUID" -> \
"cf5fff37-1356-4a23-99d2-005a410bedb5",
 InitializationCell->True],
Cell[824116, 21883, 171, 3, 19381, "Text", "ExpressionUUID" -> \
"c7e50f95-81b7-4d35-8d24-9824faa97a70"],
Cell[824290, 21888, 614, 16, 19381, "Input", "ExpressionUUID" -> \
"3a522405-864e-47ef-95a5-f2b88018642a"],
Cell[824907, 21906, 592, 13, 19381, "Input", "ExpressionUUID" -> \
"32963694-0b0f-48d5-bbd4-115160d3afad"],
Cell[825502, 21921, 282, 6, 19381, "Text", "ExpressionUUID" -> \
"ae71143a-806d-4a5d-b572-7308f691acca"],
Cell[825787, 21929, 1347, 36, 32665, "Input", "ExpressionUUID" -> \
"9dd95f57-de86-423d-9cbe-9f173c10a2f3"],
Cell[827137, 21967, 182, 3, 19381, "Text", "ExpressionUUID" -> \
"1ca85730-e25a-42f9-b10b-f6439b227803"],
Cell[827322, 21972, 1666, 31, 32665, "Input", "ExpressionUUID" -> \
"2da6e031-dd09-4041-b6df-5c254408eb14"],
Cell[828991, 22005, 1469, 27, 19381, "Input", "ExpressionUUID" -> \
"4068cc6f-c7f4-4af6-af64-7de534b27756"],
Cell[830463, 22034, 558, 13, 19381, "Input", "ExpressionUUID" -> \
"67226df2-fd76-42fd-9964-2fa4e151ea6a"],
Cell[831024, 22049, 209, 5, 19381, "Input", "ExpressionUUID" -> \
"5af9967e-2b34-4c37-b497-6fa4d24b7bf1"],
Cell[831236, 22056, 1006, 19, 57106, "Text", "ExpressionUUID" -> \
"fd6b6c70-6243-4314-836d-71dedcbf9531"],
Cell[832245, 22077, 227, 5, 19381, "Text", "ExpressionUUID" -> \
"9ca85e20-246d-4982-b5d1-9f2eefa645fb"],
Cell[832475, 22084, 610, 17, 19381, "Input", "ExpressionUUID" -> \
"3bea98f2-8355-41a3-a599-b0cc561e2889"],
Cell[833088, 22103, 191, 4, 19381, "Input", "ExpressionUUID" -> \
"ddd43119-2207-411d-8f6e-8206452e0c22"],
Cell[833282, 22109, 149, 3, 19381, "Text", "ExpressionUUID" -> \
"d2d0714a-cdf8-4736-9b23-f28cce9ce99a"],
Cell[833434, 22114, 425, 13, 19381, "Input", "ExpressionUUID" -> \
"629539e5-29a7-4fa5-888c-9383fb145a74"],
Cell[833862, 22129, 247, 6, 32197, "Text", "ExpressionUUID" -> \
"cb172e11-c07b-4696-a72c-d2c27c826f07"],
Cell[834112, 22137, 503, 15, 33426, "Input", "ExpressionUUID" -> \
"671c720d-7de2-499b-ac87-d0533700b830",
 Evaluatable->False],
Cell[834618, 22154, 299, 7, 19927, "Text", "ExpressionUUID" -> \
"dcc8e844-58e8-4107-a0ed-93d6e9e46201",
 CellTags->"polco"],
Cell[834920, 22163, 460, 12, 19381, "Input", "ExpressionUUID" -> \
"3ae43f23-b9bc-43f9-bed2-5e736565a627"],
Cell[835383, 22177, 217, 5, 19381, "Text", "ExpressionUUID" -> \
"f9aa49e7-acd0-44f1-8e09-6497a29b5f2c"],
Cell[835603, 22184, 550, 16, 19381, "Input", "ExpressionUUID" -> \
"49b63c91-7bfa-4f4c-9382-f2bf7f692b44"],
Cell[836156, 22202, 166, 3, 19381, "Text", "ExpressionUUID" -> \
"10e02b32-09f0-45c0-839c-cda648f8a993"],
Cell[836325, 22207, 379, 11, 22855, "Input", "ExpressionUUID" -> \
"60d88420-5de2-4c8b-95de-59e714e32c4f"],
Cell[836707, 22220, 184, 3, 19381, "Text", "ExpressionUUID" -> \
"936ee590-bc0d-4a7f-97df-92915c3b7813"],
Cell[836894, 22225, 428, 12, 19381, "Input", "ExpressionUUID" -> \
"13eaf523-b97d-4e37-ab6c-114f35b2cb64"],
Cell[837325, 22239, 504, 9, 32197, "Text", "ExpressionUUID" -> \
"100dd3dc-1ddf-4449-9695-ab8650f5080f"],
Cell[837832, 22250, 623, 16, 19381, "Input", "ExpressionUUID" -> \
"62418119-affb-42bd-a40c-99ce1d743473"],
Cell[838458, 22268, 743, 12, 58839, "Text", "ExpressionUUID" -> \
"2982f072-a8ed-449a-a479-9b1781ea8d36"],
Cell[839204, 22282, 314, 6, 19381, "Text", "ExpressionUUID" -> \
"2c173230-6bb9-4d8b-b3a7-afaaca6f34eb"],
Cell[839521, 22290, 177, 4, 19381, "Input", "ExpressionUUID" -> \
"35655846-6abc-4b25-996c-66c1c53b8ede"],
Cell[839701, 22296, 459, 13, 33927, "Input", "ExpressionUUID" -> \
"6e27d46d-d522-4a53-a237-5c5b0f9493aa"],
Cell[840163, 22311, 304, 7, 19381, "Input", "ExpressionUUID" -> \
"b9bedfbb-2549-42ae-ab22-6eb6516f568a"],
Cell[840470, 22320, 286, 4, 19381, "Text", "ExpressionUUID" -> \
"b75d32a4-7243-47e9-b8b4-0260a082fd9e"],
Cell[840759, 22326, 285, 7, 19381, "Input", "ExpressionUUID" -> \
"f7d26317-05e9-47b6-b8d3-8038363290d5"],
Cell[841047, 22335, 261, 7, 19381, "Input", "ExpressionUUID" -> \
"8cd3436a-e4ca-486f-8068-40e45b9a99b1"],
Cell[841311, 22344, 1139, 23, 32665, "Input", "ExpressionUUID" -> \
"45a32af9-c7d5-4dbf-8065-38de72b0f4ff"],
Cell[842453, 22369, 238, 6, 19381, "Input", "ExpressionUUID" -> \
"2c471db5-3181-4956-a9b1-6e1e863322df"]
}, Closed]],
Cell[CellGroupData[{
Cell[842728, 22380, 667, 10, 42, "Subsubsection", "ExpressionUUID" -> \
"de9c4c3b-3456-4790-928c-191283361a20"],
Cell[843398, 22392, 882, 16, 32197, "Text", "ExpressionUUID" -> \
"f0a70574-9de7-45e1-acb1-d23f4d41871e"],
Cell[844283, 22410, 455, 13, 19381, "Input", "ExpressionUUID" -> \
"36f3d535-012d-4fcf-b5b4-cc39f4704dee",
 Evaluatable->False],
Cell[844741, 22425, 400, 7, 19381, "Input", "ExpressionUUID" -> \
"a8a18882-6c03-41e4-919f-163ba1df89b0"],
Cell[845144, 22434, 193, 4, 19381, "Input", "ExpressionUUID" -> \
"5eb02480-3fe7-463b-80c4-8327fd4cbeee"],
Cell[845340, 22440, 236, 6, 19381, "Input", "ExpressionUUID" -> \
"50ab86f0-6a44-4550-80dd-ff5e51d6ec9b"],
Cell[845579, 22448, 514, 9, 32197, "Text", "ExpressionUUID" -> \
"78cbfab1-7d50-4307-b1a8-4bbf3cd561c6"],
Cell[846096, 22459, 164, 3, 19381, "Input", "ExpressionUUID" -> \
"faf8a161-d8e9-4d37-8a98-ba7bf7731469"],
Cell[846263, 22464, 193, 3, 19381, "Text", "ExpressionUUID" -> \
"963ec9eb-0abb-412c-b88d-15ca13c78df2"],
Cell[846459, 22469, 921, 20, 19381, "Input", "ExpressionUUID" -> \
"e84b9d06-942a-45d5-ae38-7f7717bb6d48"],
Cell[847383, 22491, 382, 10, 19381, "Input", "ExpressionUUID" -> \
"2f3d3706-e4e9-41de-bb13-bd0ed596a1b8"],
Cell[847768, 22503, 443, 8, 32197, "Text", "ExpressionUUID" -> \
"c7c9a2c7-266d-490a-a232-f4ea71446bec"],
Cell[848214, 22513, 457, 9, 19381, "Input", "ExpressionUUID" -> \
"34a2b3dc-0a71-4951-9e51-0af6ec5ac886"],
Cell[848674, 22524, 361, 5, 19927, "Text", "ExpressionUUID" -> \
"93a0af86-fee9-433a-9d8a-ed5a423eddc1"],
Cell[849038, 22531, 367, 7, 19927, "Text", "ExpressionUUID" -> \
"e73ab885-296f-4c56-8fb4-a3ecbaa79391"],
Cell[849408, 22540, 299, 5, 19927, "Text", "ExpressionUUID" -> \
"9faa0b9a-0265-40cc-8894-e4bb30b9583b"],
Cell[849710, 22547, 885, 20, 32665, "Input", "ExpressionUUID" -> \
"943fc235-65bb-4f94-a817-9fc27b9d2708"],
Cell[850598, 22569, 1286, 29, 45454, "Input", "ExpressionUUID" -> \
"91321051-74dc-4d6a-99f7-236a4e3422f6"],
Cell[851887, 22600, 1310, 32, 45454, "Input", "ExpressionUUID" -> \
"27bcf7c1-c820-4827-bce5-d0ff0631227e"],
Cell[853200, 22634, 1033, 27, 45454, "Input", "ExpressionUUID" -> \
"9132e47b-aae4-45c1-bb4a-b1c6363e13a9"],
Cell[854236, 22663, 284, 4, 19381, "Text", "ExpressionUUID" -> \
"8df13c7a-f87f-4b7e-ac11-04555ffe8a2a"],
Cell[854523, 22669, 868, 24, 32665, "Input", "ExpressionUUID" -> \
"de0644c2-c3f6-4075-96ce-2112c5954951"],
Cell[855394, 22695, 257, 4, 19381, "Text", "ExpressionUUID" -> \
"defdd300-632b-4375-8d23-57386fdec252"],
Cell[855654, 22701, 374, 12, 19381, "Input", "ExpressionUUID" -> \
"04648580-8862-4e6b-9a3d-8fb2b24b651c",
 Evaluatable->False],
Cell[856031, 22715, 818, 16, 45454, "Text", "ExpressionUUID" -> \
"cda56270-35b3-471a-8ed3-e5320ac9fbca"],
Cell[856852, 22733, 283, 8, 19381, "Text", "ExpressionUUID" -> \
"aa73ed87-5d9d-4aba-88b1-4fe438cec8f5"],
Cell[857138, 22743, 783, 18, 32197, "Text", "ExpressionUUID" -> \
"f7f0766c-a55e-48f5-b100-4592bac86652"],
Cell[857924, 22763, 1786, 53, 83350, "Input", "ExpressionUUID" -> \
"5510d66f-d56a-439f-b166-28f2c1cc852f",
 InitializationCell->True],
Cell[859713, 22818, 454, 10, 45454, "Input", "ExpressionUUID" -> \
"920230cc-59de-4ed7-b60e-87257dc2e4ec",
 InitializationCell->True],
Cell[860170, 22830, 438, 10, 19381, "Input", "ExpressionUUID" -> \
"70cea343-38d4-4df0-8d4e-76a8db611164"],
Cell[860611, 22842, 521, 14, 32665, "Input", "ExpressionUUID" -> \
"1003de18-6213-47fd-b45d-d7d984d7c2b6"],
Cell[861135, 22858, 197, 5, 19381, "Input", "ExpressionUUID" -> \
"516c9e31-a073-42df-a611-715c4cbb2e55"],
Cell[861335, 22865, 392, 10, 19381, "Input", "ExpressionUUID" -> \
"09d0400b-2166-4090-ac56-a527b866994a"],
Cell[861730, 22877, 217, 5, 19381, "Text", "ExpressionUUID" -> \
"597a7e10-8f2c-456b-8d0d-92f65a82cbc6"],
Cell[861950, 22884, 1166, 26, 45454, "Input", "ExpressionUUID" -> \
"ac7b810e-d9be-4e20-b049-9eebe588021d"],
Cell[863119, 22912, 209, 5, 19381, "Input", "ExpressionUUID" -> \
"fba6908a-a541-444a-b122-c9a554551aa1"],
Cell[863331, 22919, 513, 11, 32665, "Input", "ExpressionUUID" -> \
"31c9a411-dff6-4748-ab20-c18e70c2ee37"],
Cell[863847, 22932, 159, 3, 19381, "Text", "ExpressionUUID" -> \
"4e7fb75a-c701-4b45-8c46-234e6a925240"]
}, Closed]],
Cell[CellGroupData[{
Cell[864043, 22940, 693, 10, 42, "Subsubsection", "ExpressionUUID" -> \
"d69479b6-ac81-4139-9292-0fb5d2f63d56"],
Cell[864739, 22952, 1442, 26, 69345, "Text", "ExpressionUUID" -> \
"7a95758b-e875-43ae-a2d3-bfb54b902523"],
Cell[866184, 22980, 218, 5, 19381, "Input", "ExpressionUUID" -> \
"c878d43e-0905-4a07-b444-66ce1d66f0fa"],
Cell[866405, 22987, 626, 15, 19381, "Input", "ExpressionUUID" -> \
"706ab530-e772-48b9-b7e6-a9f76793dd72",
 Evaluatable->False],
Cell[867034, 23004, 256, 5, 19381, "Input", "ExpressionUUID" -> \
"68a751aa-bf97-4ac2-8800-8a9c3a0f0e6f"],
Cell[867293, 23011, 197, 4, 19381, "Input", "ExpressionUUID" -> \
"d40a1711-ad5e-41ce-82a5-4b67c08ebdee"],
Cell[867493, 23017, 161, 3, 19381, "Text", "ExpressionUUID" -> \
"cd07be60-2f2f-4665-8cb2-fa47f1a59bd5"],
Cell[867657, 23022, 187, 4, 19381, "Input", "ExpressionUUID" -> \
"f127f40c-6f99-44e9-b33e-bf18979492ff"],
Cell[867847, 23028, 268, 7, 19381, "Input", "ExpressionUUID" -> \
"5afd1408-bf77-4697-9cb3-b7ee2713fdec"],
Cell[868118, 23037, 840, 17, 19381, "Input", "ExpressionUUID" -> \
"c4fee53e-f5cd-4964-8e04-521ffb7c33c5",
 InitializationCell->True],
Cell[868961, 23056, 819, 19, 32665, "Input", "ExpressionUUID" -> \
"a3e2ddc8-882f-48eb-87ee-02b35076f101"],
Cell[869783, 23077, 192, 3, 19381, "Text", "ExpressionUUID" -> \
"988b2df5-c963-47b1-9766-9d7bd0e59b82"],
Cell[869978, 23082, 179, 4, 19381, "Input", "ExpressionUUID" -> \
"eeb73e3e-3e30-4df2-8a48-5791f55e3687"],
Cell[870160, 23088, 639, 17, 19381, "Input", "ExpressionUUID" -> \
"6d36d67f-615d-4054-9de1-3fa803a3b1ff"],
Cell[870802, 23107, 353, 9, 19381, "Input", "ExpressionUUID" -> \
"4437e643-4986-4186-8c2e-f6fbed3e485b"],
Cell[871158, 23118, 692, 16, 19381, "Input", "ExpressionUUID" -> \
"96f3b7d0-1d31-47d9-b6cc-79fce2ba3878"],
Cell[871853, 23136, 509, 9, 45657, "Text", "ExpressionUUID" -> \
"1cabd0b1-b348-4860-951f-e26bb5fab3b4"],
Cell[872365, 23147, 436, 11, 19381, "Input", "ExpressionUUID" -> \
"a39ecacf-3f08-4fcc-ac48-ff0807abacac"],
Cell[872804, 23160, 266, 6, 19381, "Text", "ExpressionUUID" -> \
"f3bbfdaf-11b1-4380-a9cb-91af7db1631c"],
Cell[873073, 23168, 1071, 32, 32665, "Input", "ExpressionUUID" -> \
"edd9fb6d-8051-4307-a8d6-121c83d6d4f3"],
Cell[874147, 23202, 588, 10, 44428, "Text", "ExpressionUUID" -> \
"1dbc5c11-ccb3-4441-94b8-cdfad0cd26b7"]
}, Closed]],
Cell[CellGroupData[{
Cell[874772, 23217, 814, 12, 42, "Subsubsection", "ExpressionUUID" -> \
"06267eac-aafb-442b-8c46-b806b748d659"],
Cell[875589, 23231, 598, 14, 32197, "Text", "ExpressionUUID" -> \
"30c63c8c-8974-4868-b0ca-6c4eee132dd7"],
Cell[876190, 23247, 654, 17, 19381, "Input", "ExpressionUUID" -> \
"5dc3f428-46e8-4726-9a25-cc467ce23162",
 Evaluatable->False],
Cell[876847, 23266, 374, 7, 19381, "Input", "ExpressionUUID" -> \
"109a05cc-3063-4164-9852-1c960dd1aaef"],
Cell[877224, 23275, 218, 4, 19381, "Input", "ExpressionUUID" -> \
"ffd6db8f-4598-4e2e-a199-fecb5524b33e"],
Cell[877445, 23281, 307, 7, 19381, "Text", "ExpressionUUID" -> \
"65affb4d-2f9b-4a24-96ba-2f3c72107212"],
Cell[CellGroupData[{
Cell[877777, 23292, 361, 7, 19381, "Input", "ExpressionUUID" -> \
"51c85c7d-4c8a-4696-a8ae-3dd458ebbaa8",
 InitializationCell->True],
Cell[878141, 23301, 365, 11, 70, "Output", "ExpressionUUID" -> \
"226f74ad-95e6-4f95-b7cb-65c22886d365"]
}, Open  ]],
Cell[878521, 23315, 198, 4, 19381, "Input", "ExpressionUUID" -> \
"1c69de2b-fdec-4443-8cbc-8f17cf69bdfb"],
Cell[878722, 23321, 378, 9, 19381, "Text", "ExpressionUUID" -> \
"a2083c47-efa5-47fb-a7b2-373e92a24815"],
Cell[879103, 23332, 740, 18, 32665, "Input", "ExpressionUUID" -> \
"8d616ffd-0a7c-4d02-a808-0150e9dfdda5"],
Cell[879846, 23352, 291, 6, 19381, "Input", "ExpressionUUID" -> \
"32d1a578-6ea2-4e1c-8725-5e7699b3c216"],
Cell[880140, 23360, 254, 4, 19381, "Text", "ExpressionUUID" -> \
"6f570d83-1e8d-4cfb-99eb-048e87f04a2f"],
Cell[CellGroupData[{
Cell[880419, 23368, 1476, 36, 45454, "Input", "ExpressionUUID" -> \
"9a2d8f3e-0380-418c-bc4b-92d0d0ea8690",
 InitializationCell->True],
Cell[881898, 23406, 1738, 55, 70, "Output", "ExpressionUUID" -> \
"6f09a1ac-5fb1-4431-9b6a-7d19a3fb54c8"]
}, Open  ]],
Cell[883651, 23464, 259, 6, 19381, "Text", "ExpressionUUID" -> \
"5d5ed5f2-e5cf-457f-93fe-f94ea8599a9b"],
Cell[883913, 23472, 473, 11, 19381, "Input", "ExpressionUUID" -> \
"c4ac8a1e-a2d4-4cb6-8d95-8e0179cb71db"],
Cell[884389, 23485, 794, 19, 19381, "Input", "ExpressionUUID" -> \
"d36401c7-f796-4f6b-9b7d-9eb5d8f2f1e6"],
Cell[885186, 23506, 809, 19, 19381, "Input", "ExpressionUUID" -> \
"d875256c-bee7-4d48-9360-4080aadbbad4"],
Cell[885998, 23527, 630, 11, 32197, "Text", "ExpressionUUID" -> \
"e2a49758-600c-4d8f-99d7-852c1f82b149"],
Cell[886631, 23540, 202, 4, 19381, "Input", "ExpressionUUID" -> \
"57314b49-8ae4-4dab-ad85-90ac7c427f61"],
Cell[886836, 23546, 469, 11, 19381, "Input", "ExpressionUUID" -> \
"cf5e24d0-ea24-4d8c-8ce0-e6e9668ea05d"],
Cell[887308, 23559, 325, 9, 19381, "Input", "ExpressionUUID" -> \
"96826c99-57fd-4e68-ac73-4c4d37e9b8d7"],
Cell[887636, 23570, 325, 9, 19381, "Input", "ExpressionUUID" -> \
"32b673a0-db72-434c-8d61-12354d50d84c"],
Cell[887964, 23581, 804, 19, 32665, "Input", "ExpressionUUID" -> \
"d5c34c5f-4c3f-4fed-a75c-1e90d9e109d9"],
Cell[888771, 23602, 616, 12, 45454, "Text", "ExpressionUUID" -> \
"7923199b-1eba-4177-bd36-3b8890a9075e"],
Cell[889390, 23616, 349, 7, 32197, "Text", "ExpressionUUID" -> \
"6160422f-95b2-48c4-874b-7fb394044116"],
Cell[889742, 23625, 824, 23, 45454, "Input", "ExpressionUUID" -> \
"9077b358-1142-4e41-84a0-e7f6700f52a5"],
Cell[890569, 23650, 544, 13, 20292, "Text", "ExpressionUUID" -> \
"653a0a30-47a6-4063-82b1-7254b428ab62"],
Cell[891116, 23665, 1185, 26, 32665, "Input", "ExpressionUUID" -> \
"ee278483-3e2b-4c5c-bb20-f5794a53693c"],
Cell[892304, 23693, 340, 7, 32197, "Text", "ExpressionUUID" -> \
"4c1260b3-2772-42a1-a175-dd194400ddec"],
Cell[892647, 23702, 739, 20, 24441, "Input", "ExpressionUUID" -> \
"7290befe-8565-4e0d-a81e-59f2946559b0"],
Cell[893389, 23724, 612, 12, 32197, "Text", "ExpressionUUID" -> \
"742e924c-79d3-4e5d-ba94-5ee757279163"],
Cell[894004, 23738, 1456, 26, 71961, "Text", "ExpressionUUID" -> \
"ebb84a0c-03ce-47bc-906d-261f8c7db466"],
Cell[895463, 23766, 763, 15, 45657, "Text", "ExpressionUUID" -> \
"9637fd22-e4d6-4f25-bcac-bc85297c51a8"],
Cell[896229, 23783, 201, 4, 19381, "Input", "ExpressionUUID" -> \
"de3b81a7-1dce-4a3c-9daf-f9506af67822"],
Cell[896433, 23789, 294, 7, 19381, "Input", "ExpressionUUID" -> \
"f524c8bb-5720-4fdc-bc7b-e4d751415f91"],
Cell[896730, 23798, 644, 16, 45454, "Input", "ExpressionUUID" -> \
"3ac259a9-f942-4b7a-adc1-90073ef1760e"],
Cell[897377, 23816, 226, 5, 19381, "Input", "ExpressionUUID" -> \
"8e942553-d97d-4e70-b2b8-95875eb69870"],
Cell[897606, 23823, 295, 8, 19381, "Input", "ExpressionUUID" -> \
"c13d7338-c815-4685-a5d7-ae7c63e6a8e7"],
Cell[897904, 23833, 1221, 29, 45454, "Input", "ExpressionUUID" -> \
"2c072070-c313-4b5f-aacc-45d5e9c0e323"],
Cell[899128, 23864, 341, 8, 19381, "Input", "ExpressionUUID" -> \
"ba5ead92-14af-46ec-8765-929961a16909"],
Cell[899472, 23874, 486, 10, 45657, "Text", "ExpressionUUID" -> \
"95f153aa-19b2-4fb9-9c0e-a73db804ea5c"]
}, Closed]],
Cell[CellGroupData[{
Cell[899995, 23889, 823, 12, 42, "Subsubsection", "ExpressionUUID" -> \
"e24ecd5a-e553-4a81-94fa-9a78657502e9"],
Cell[900821, 23903, 1283, 29, 62986, "Text", "ExpressionUUID" -> \
"373e8b78-bcfe-41d2-b200-f5f6fc689c34"],
Cell[902107, 23934, 429, 9, 21465, "Text", "ExpressionUUID" -> \
"f160d7f4-b602-4c67-8f57-b9a14436d273"],
Cell[902539, 23945, 440, 10, 21465, "Text", "ExpressionUUID" -> \
"52f28d38-12ff-41c1-9abe-67a37989f60f"],
Cell[902982, 23957, 195, 5, 12921, "Input", "ExpressionUUID" -> \
"6ea03828-01af-4c0a-9255-a906b56ba231"],
Cell[903180, 23964, 777, 18, 12921, "Input", "ExpressionUUID" -> \
"e4eb1902-f7a6-4fb4-b6ee-f6bed6856197",
 Evaluatable->False],
Cell[903960, 23984, 646, 15, 12921, "Input", "ExpressionUUID" -> \
"bc4abd46-9c9c-400f-b9b3-83e14de712ee",
 Evaluatable->False],
Cell[904609, 24001, 623, 10, 29619, "Text", "ExpressionUUID" -> \
"e9bc822a-0641-45ee-b9a2-090c18903365"],
Cell[905235, 24013, 469, 12, 12921, "Input", "ExpressionUUID" -> \
"69900bd0-3246-4d5a-a247-fe33a2070dee",
 Evaluatable->False],
Cell[905707, 24027, 273, 6, 21465, "Text", "ExpressionUUID" -> \
"3ea0a10c-ae75-459f-8176-f1b1c8a21ed7"],
Cell[905983, 24035, 698, 19, 12921, "Input", "ExpressionUUID" -> \
"3f4afe91-b076-4ff4-9cc5-0ff13d567172",
 Evaluatable->False],
Cell[906684, 24056, 297, 7, 13285, "Text", "ExpressionUUID" -> \
"15ee78f5-8540-4361-ac57-e4aff5a999bb"],
Cell[906984, 24065, 665, 17, 12921, "Input", "ExpressionUUID" -> \
"1f30f94a-fda4-4523-a90e-287572c62ac1",
 Evaluatable->False],
Cell[907652, 24084, 1139, 19, 64680, "Text", "ExpressionUUID" -> \
"6c461306-7524-48e6-b993-8d3a56bf4477"],
Cell[908794, 24105, 341, 9, 12921, "Input", "ExpressionUUID" -> \
"2c5f8f67-0edf-4ada-8941-d961efdbb786",
 Evaluatable->False],
Cell[909138, 24116, 519, 10, 29619, "Text", "ExpressionUUID" -> \
"e55d9215-cbca-43c0-b035-27da7f346270"],
Cell[909660, 24128, 443, 13, 12921, "Input", "ExpressionUUID" -> \
"f0f45a04-8571-445a-8c26-eac2ef6d1c6d",
 Evaluatable->False],
Cell[910106, 24143, 161, 3, 12921, "Text", "ExpressionUUID" -> \
"ef9fb1aa-4137-4b29-8dce-7c811c5b9a3a"],
Cell[910270, 24148, 402, 12, 12921, "Input", "ExpressionUUID" -> \
"9ac6a751-fd01-4c84-afbd-89787733315c",
 Evaluatable->False],
Cell[910675, 24162, 477, 15, 12921, "Input", "ExpressionUUID" -> \
"553da768-09af-436c-aa85-2123e33d2c05",
 Evaluatable->False],
Cell[911155, 24179, 559, 10, 38961, "Text", "ExpressionUUID" -> \
"7eb3f55a-00ab-4940-ab28-245c8ce78de3"],
Cell[911717, 24191, 287, 8, 12921, "Input", "ExpressionUUID" -> \
"4aba4406-30af-4030-b587-e1d05dd1b2e9",
 Evaluatable->False],
Cell[912007, 24201, 153, 3, 12921, "Text", "ExpressionUUID" -> \
"ab94206f-6cde-4319-b6ec-3419979ae13c"],
Cell[912163, 24206, 471, 15, 12921, "Input", "ExpressionUUID" -> \
"caba0849-7dc2-4672-b5ed-52016afa9001",
 Evaluatable->False],
Cell[912637, 24223, 518, 16, 12921, "Input", "ExpressionUUID" -> \
"9be19bfa-655d-4f09-885b-571b8f7fb2d2",
 Evaluatable->False],
Cell[913158, 24241, 151, 3, 12921, "Text", "ExpressionUUID" -> \
"a9a0f273-aab2-4030-860a-65ddc99c2044"],
Cell[913312, 24246, 690, 18, 12921, "Input", "ExpressionUUID" -> \
"10aa39cc-0134-49a7-8be1-08632fea304b",
 InitializationCell->True],
Cell[914005, 24266, 287, 7, 12921, "Text", "ExpressionUUID" -> \
"2557d460-e119-457f-b4e4-db71bd9c100d"],
Cell[914295, 24275, 702, 18, 12921, "Input", "ExpressionUUID" -> \
"0f17fe1b-f8f8-48a4-9525-1bd4d6a5d4c7",
 InitializationCell->True],
Cell[915000, 24295, 478, 9, 12921, "Input", "ExpressionUUID" -> \
"d17651a0-cc08-4b9e-9ff1-aee5ad935fc5"],
Cell[915481, 24306, 438, 8, 22141, "Text", "ExpressionUUID" -> \
"61da3f40-5e6d-4ec4-aaa3-366cecbb8597"],
Cell[915922, 24316, 918, 14, 47769, "Text", "ExpressionUUID" -> \
"c41209e0-95df-48f3-a1ab-d6f8677d74d0"],
Cell[916843, 24332, 717, 18, 12921, "Input", "ExpressionUUID" -> \
"ce8aed26-12bc-4e65-8a23-464c24c5a9eb",
 Evaluatable->False],
Cell[917563, 24352, 755, 12, 39226, "Text", "ExpressionUUID" -> \
"4a6a3499-5025-453b-acb2-fb38ca05139b"],
Cell[918321, 24366, 690, 21, 12921, "Input", "ExpressionUUID" -> \
"f3a84eed-6836-4cac-bdc5-ebe9bb12a5d8",
 Evaluatable->False],
Cell[919014, 24389, 381, 12, 12921, "Input", "ExpressionUUID" -> \
"b2636f6d-cfcc-4559-b598-97a0ca1b5e7d",
 Evaluatable->False],
Cell[919398, 24403, 198, 3, 12921, "Text", "ExpressionUUID" -> \
"c9a299f5-6916-4418-95b3-bb20cc8c6369"],
Cell[919599, 24408, 734, 21, 12921, "Input", "ExpressionUUID" -> \
"2858ed6b-2686-40b0-81dd-d0e57b372457",
 Evaluatable->False],
Cell[920336, 24431, 425, 13, 12921, "Input", "ExpressionUUID" -> \
"a50ebd78-c1a8-4f3d-aeed-d0bc209567e6",
 Evaluatable->False],
Cell[920764, 24446, 358, 7, 21777, "Text", "ExpressionUUID" -> \
"003ec908-8bf6-4ef6-b202-16d7444d5b0c"],
Cell[921125, 24455, 451, 13, 12921, "Input", "ExpressionUUID" -> \
"5ca9aa97-8528-4489-96d1-4f8f97d1fa1e",
 Evaluatable->False],
Cell[921579, 24470, 1480, 22, 64900, "Text", "ExpressionUUID" -> \
"3ee3da6e-1ec9-4f8f-b500-d5053cbab388"],
Cell[923062, 24494, 795, 22, 12921, "Input", "ExpressionUUID" -> \
"e1f4d4dc-10cf-4c33-86aa-a95440ba4648",
 Evaluatable->False],
Cell[923860, 24518, 381, 7, 22141, "Text", "ExpressionUUID" -> \
"427dc223-e0e9-43b1-b431-a793246256ab"],
Cell[924244, 24527, 694, 21, 12921, "Input", "ExpressionUUID" -> \
"946e745a-389f-4c10-a569-5af9566ae11e",
 Evaluatable->False],
Cell[924941, 24550, 276, 6, 12921, "Text", "ExpressionUUID" -> \
"b3a70a80-7146-4697-831b-fb112aecdc27"],
Cell[925220, 24558, 565, 14, 12921, "Input", "ExpressionUUID" -> \
"0ec418f0-aa1b-4a25-851b-2dcd627ecbe7",
 Evaluatable->False],
Cell[925788, 24574, 525, 8, 13285, "Text", "ExpressionUUID" -> \
"9852d936-5ff7-46cd-8807-0c7a38822219"],
Cell[926316, 24584, 417, 12, 12921, "Input", "ExpressionUUID" -> \
"a02eae72-70dc-4dd3-8220-8c94b1348bb0",
 Evaluatable->False],
Cell[926736, 24598, 564, 10, 13285, "Text", "ExpressionUUID" -> \
"49f62e1b-853e-44a9-be2a-2ae34bb4fc1e"],
Cell[927303, 24610, 905, 26, 21777, "Input", "ExpressionUUID" -> \
"fe741ef3-c313-4890-b5a4-765708a25b36",
 Evaluatable->False],
Cell[928211, 24638, 376, 8, 21465, "Text", "ExpressionUUID" -> \
"b4c32918-ea6d-4302-8bac-d8aef3c0cd22"],
Cell[928590, 24648, 717, 13, 29619, "Text", "ExpressionUUID" -> \
"20560a13-be1b-41f6-ba4f-bc60e48f307f"],
Cell[929310, 24663, 345, 10, 12921, "Input", "ExpressionUUID" -> \
"1242e88e-d0a8-4953-b3b2-eaf63eb42809",
 Evaluatable->False],
Cell[929658, 24675, 572, 10, 39226, "Text", "ExpressionUUID" -> \
"b075029b-fdf9-4a85-aec7-cb61d12e787c"],
Cell[930233, 24687, 289, 7, 21465, "Text", "ExpressionUUID" -> \
"6a25e849-6ef1-4e28-a778-e26b37281c95"]
}, Closed]],
Cell[CellGroupData[{
Cell[930559, 24699, 827, 12, 42, "Subsubsection", "ExpressionUUID" -> \
"c9ac43cd-9774-4091-8469-2a2ccb7832a9"],
Cell[931389, 24713, 913, 17, 29619, "Text", "ExpressionUUID" -> \
"303554f6-a4cb-4727-84ef-139e39feb8b9"],
Cell[932305, 24732, 184, 4, 12921, "Input", "ExpressionUUID" -> \
"ffa94cb6-e369-435e-a9f7-89d2d8683b28"],
Cell[932492, 24738, 307, 8, 12921, "Input", "ExpressionUUID" -> \
"72ecc2cd-6cc2-4e56-8511-0a531ac93c0e"],
Cell[932802, 24748, 290, 8, 12921, "Input", "ExpressionUUID" -> \
"c015320a-460c-43db-a7ec-2e13bb391076"],
Cell[933095, 24758, 389, 10, 12921, "Input", "ExpressionUUID" -> \
"0dcc9586-f1a0-48e6-a535-f4459c015d48"],
Cell[933487, 24770, 157, 3, 8614, "Text", "ExpressionUUID" -> \
"e6e11b81-5214-4531-b4cd-71cc087e2c7b"],
Cell[933647, 24775, 505, 13, 8614, "Input", "ExpressionUUID" -> \
"3a3486ef-072f-4750-8abb-b1048806f710",
 InitializationCell->True],
Cell[934155, 24790, 258, 6, 8614, "Input", "ExpressionUUID" -> \
"c95677cf-beba-42b8-9323-ac9119dc25f8"],
Cell[934416, 24798, 925, 22, 14518, "Input", "ExpressionUUID" -> \
"ab13559f-995b-4db8-a916-5c35b0c99488",
 InitializationCell->True],
Cell[935344, 24822, 185, 3, 12921, "Text", "ExpressionUUID" -> \
"c467a908-2d25-430a-ba40-a2ff4044d56f"],
Cell[935532, 24827, 853, 23, 21777, "Input", "ExpressionUUID" -> \
"59fd9cf1-417b-4899-a532-2a2027f2cf39"],
Cell[936388, 24852, 191, 4, 12921, "Input", "ExpressionUUID" -> \
"522b9bab-a81b-4de2-b345-95e6b4eb67ec"],
Cell[936582, 24858, 170, 3, 8614, "Text", "ExpressionUUID" -> \
"c32bf396-1759-4cfe-bcf1-98234cf9ec0d"],
Cell[CellGroupData[{
Cell[936777, 24865, 801, 20, 8614, "Input", "ExpressionUUID" -> \
"b6bb6dd6-d4f1-491c-919b-23c3cf084527",
 InitializationCell->True],
Cell[937581, 24887, 714, 24, 70, "Output", "ExpressionUUID" -> \
"bc910bcb-7ee2-4329-bd12-dd30a4cd9836"]
}, Open  ]],
Cell[938310, 24914, 287, 6, 21465, "Text", "ExpressionUUID" -> \
"fcd38a50-6006-421f-a838-e9b5daba8417"],
Cell[938600, 24922, 649, 17, 12921, "Input", "ExpressionUUID" -> \
"a47033ea-f16b-4c7f-a9e9-3cf33b63ccb1"],
Cell[939252, 24941, 343, 7, 21465, "Text", "ExpressionUUID" -> \
"0ffe573d-63c0-4249-9656-eaa0c34cbf36"],
Cell[939598, 24950, 848, 22, 21777, "Input", "ExpressionUUID" -> \
"f7b4917d-ea61-4f2f-b1b6-3276d9967fd1"],
Cell[940449, 24974, 281, 4, 12921, "Text", "ExpressionUUID" -> \
"631d0c09-e983-493e-b959-18fa6c00d932"],
Cell[940733, 24980, 231, 5, 12921, "Input", "ExpressionUUID" -> \
"f0d57486-9fe7-44a3-b79d-b7f30dbf580e"],
Cell[940967, 24987, 880, 26, 21777, "Input", "ExpressionUUID" -> \
"c94f567d-6296-46c2-b768-348818558270"],
Cell[941850, 25015, 945, 24, 21777, "Input", "ExpressionUUID" -> \
"efefff18-14ec-47f8-9f52-457b14c71ca6"],
Cell[942798, 25041, 669, 16, 12921, "Input", "ExpressionUUID" -> \
"a27163fe-216c-426b-966d-882fe2f08d41"],
Cell[943470, 25059, 305, 7, 21465, "Text", "ExpressionUUID" -> \
"5939c4af-ded6-4bb5-8802-e8891467e8d5"],
Cell[943778, 25068, 616, 12, 21777, "Input", "ExpressionUUID" -> \
"de68b114-34d5-4483-b5ca-801a03486d1e"],
Cell[944397, 25082, 277, 6, 12921, "Text", "ExpressionUUID" -> \
"f9aaf7ca-a0a1-42f1-8812-144d13c139fc"],
Cell[944677, 25090, 1159, 26, 12921, "Input", "ExpressionUUID" -> \
"4f776b99-5396-4322-a2e9-9ac68a4679de"],
Cell[945839, 25118, 319, 9, 12921, "Input", "ExpressionUUID" -> \
"ee9d6c95-916d-4084-8cb5-a999f0cae0fb"],
Cell[946161, 25129, 798, 18, 19746, "Text", "ExpressionUUID" -> \
"bb3bdf39-ca75-4c6d-be48-2105af3a8d47"],
Cell[946962, 25149, 238, 6, 8614, "Input", "ExpressionUUID" -> \
"23b6d536-1c3d-4e36-aad4-2bf88d262e1d"],
Cell[947203, 25157, 193, 4, 8614, "Input", "ExpressionUUID" -> \
"23e1d4c7-1587-40cf-9250-fee7f1c9f43a"],
Cell[947399, 25163, 382, 10, 8614, "Input", "ExpressionUUID" -> \
"f61c5b93-735a-4b3e-8941-5ed2c61554c9"],
Cell[947784, 25175, 193, 4, 8614, "Input", "ExpressionUUID" -> \
"5f975c97-ea54-491a-866d-45e105bea7fa"],
Cell[947980, 25181, 398, 7, 19746, "Text", "ExpressionUUID" -> \
"a36ef925-01d7-40c3-a3df-44592c430296"],
Cell[948381, 25190, 709, 17, 14518, "Input", "ExpressionUUID" -> \
"612d1605-8710-4ada-97c9-dbf4104e34e0"],
Cell[949093, 25209, 464, 12, 8614, "Input", "ExpressionUUID" -> \
"9592fd8d-de38-4234-8b8c-97fb55ee179f"],
Cell[949560, 25223, 180, 4, 8614, "Input", "ExpressionUUID" -> \
"88cc5db3-7cae-4d29-8edf-a6c870e0c99e"],
Cell[949743, 25229, 731, 20, 17434, "Text", "ExpressionUUID" -> \
"809633f8-138a-4c7d-8e9d-4029c7d455b5"],
Cell[950477, 25251, 616, 16, 8614, "Text", "ExpressionUUID" -> \
"97b66e1d-5fa9-409c-9486-f6c6daa09d1c"],
Cell[951096, 25269, 167, 4, 8614, "Input", "ExpressionUUID" -> \
"6ceac543-213f-4f42-8ac6-54eb9f4e5a81"],
Cell[951266, 25275, 224, 5, 8614, "Input", "ExpressionUUID" -> \
"fc31c219-5c00-4ff2-b67c-4220c0e492d9"],
Cell[951493, 25282, 211, 5, 8614, "Input", "ExpressionUUID" -> \
"92511048-92a8-4a23-b370-c30ad335a3bc"],
Cell[951707, 25289, 286, 6, 14310, "Text", "ExpressionUUID" -> \
"ea9fc978-83af-43f1-b945-9f8716122e2c"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[952042, 25301, 382, 6, 67, "Subsection", "ExpressionUUID" -> \
"175144be-5d87-4e95-bb00-fa6b50cbd9c6"],
Cell[CellGroupData[{
Cell[952449, 25311, 464, 8, 53, "Subsubsection", "ExpressionUUID" -> \
"6adce1bc-258c-40c5-8f0d-1325230a46a0"],
Cell[952916, 25321, 168, 3, 12921, "Text", "ExpressionUUID" -> \
"4f176d2f-1b06-4792-b3ec-a36fc9963639"],
Cell[953087, 25326, 939, 25, 30303, "Input", "ExpressionUUID" -> \
"87717148-1472-45f9-a007-59dbf7638214",
 InitializationCell->True],
Cell[954029, 25353, 201, 3, 12921, "Text", "ExpressionUUID" -> \
"fc30f74d-dfe6-4e62-beaa-5b2b4b9ef9ac"],
Cell[954233, 25358, 604, 15, 12921, "Input", "ExpressionUUID" -> \
"c9c6a163-159e-4b2c-88c5-3fd1f1588180"],
Cell[954840, 25375, 377, 9, 12921, "Input", "ExpressionUUID" -> \
"d24df62d-0fce-47cb-91db-3f483cfc85b8"],
Cell[955220, 25386, 622, 12, 38071, "Text", "ExpressionUUID" -> \
"a1c7a072-e955-4528-8b91-1e087f071e89"],
Cell[955845, 25400, 182, 4, 12921, "Input", "ExpressionUUID" -> \
"340d5efd-89fc-4ea5-acf8-7b44e37dd58e"],
Cell[956030, 25406, 344, 7, 21465, "Text", "ExpressionUUID" -> \
"959cc0fa-f032-4098-983a-320ff2d5abb0"],
Cell[956377, 25415, 653, 16, 12921, "Input", "ExpressionUUID" -> \
"4e17c684-cb00-4f1e-abf3-b3670d715e1a"],
Cell[957033, 25433, 182, 4, 12921, "Input", "ExpressionUUID" -> \
"579312d2-6546-46ad-a299-12a6349faaa5"],
Cell[957218, 25439, 203, 3, 12921, "Text", "ExpressionUUID" -> \
"1bad84ad-83a3-471e-9e14-fde4ab165ad5"],
Cell[957424, 25444, 732, 19, 21777, "Input", "ExpressionUUID" -> \
"572ea39a-1411-46ee-abea-35ded8aace74"],
Cell[958159, 25465, 182, 4, 12921, "Input", "ExpressionUUID" -> \
"0398027d-76ab-4e2f-90e1-09fb2a820ff2"],
Cell[958344, 25471, 289, 5, 13285, "Text", "ExpressionUUID" -> \
"6ed34ea4-dc80-49fd-9698-42a94d6e8b22"],
Cell[958636, 25478, 204, 5, 12921, "Input", "ExpressionUUID" -> \
"2e7619d0-054a-4b81-b826-00ba41729ff1"],
Cell[958843, 25485, 294, 7, 21465, "Text", "ExpressionUUID" -> \
"cb63d3b1-d743-4781-81d2-fe0d5c2d1667"],
Cell[959140, 25494, 335, 8, 12921, "Input", "ExpressionUUID" -> \
"3bfe53c3-1d98-433f-84bd-4cc059a5fee4"],
Cell[959478, 25504, 407, 10, 12921, "Input", "ExpressionUUID" -> \
"9ef5bfaa-7ee6-4941-978b-c748b13fbbf0"],
Cell[959888, 25516, 2197, 33, 116257, "Text", "ExpressionUUID" -> \
"79cbec79-6954-4c79-bbc2-a179c3525cb7"],
Cell[962088, 25551, 391, 7, 21465, "Text", "ExpressionUUID" -> \
"30126741-7e4e-4e0d-871d-27db30fe3d8a"],
Cell[962482, 25560, 513, 16, 12921, "Input", "ExpressionUUID" -> \
"a2b25571-189e-4dd0-b2ea-a6ecea005534"],
Cell[962998, 25578, 312, 7, 21465, "Text", "ExpressionUUID" -> \
"71922a85-c8dc-42b5-8a80-cc9a89604dfd"],
Cell[963313, 25587, 555, 14, 12921, "Input", "ExpressionUUID" -> \
"c0578f4a-f2e1-4746-b281-9d3153d89443"],
Cell[963871, 25603, 550, 14, 12921, "Input", "ExpressionUUID" -> \
"6d058f6d-600b-4522-b1d9-a04ad4bd41dd"],
Cell[964424, 25619, 570, 15, 12921, "Input", "ExpressionUUID" -> \
"54575c93-ceda-4201-9729-9df1a4215eea"],
Cell[964997, 25636, 571, 15, 12921, "Input", "ExpressionUUID" -> \
"6667d4c1-dd9f-4a7a-8add-0f377e35311b"],
Cell[965571, 25653, 384, 10, 12921, "Input", "ExpressionUUID" -> \
"4507cae9-c0cf-4d50-8187-ba652e4fe25c"],
Cell[965958, 25665, 197, 3, 12921, "Text", "ExpressionUUID" -> \
"ed423329-7cb1-4045-98c8-f01235c907ec"],
Cell[966158, 25670, 831, 20, 12921, "Input", "ExpressionUUID" -> \
"66e3108e-8bae-4439-a337-690e8cd659ca"],
Cell[966992, 25692, 833, 20, 12921, "Input", "ExpressionUUID" -> \
"30cddc7f-566d-403a-be1a-ae2b7e0fd2b5"],
Cell[967828, 25714, 914, 22, 12921, "Input", "ExpressionUUID" -> \
"7ab77189-ca5a-4bd3-b79c-3df0ae26b651"],
Cell[968745, 25738, 913, 22, 12921, "Input", "ExpressionUUID" -> \
"bd679612-3146-4bc4-8e49-e520372297e4"],
Cell[969661, 25762, 517, 11, 12921, "Input", "ExpressionUUID" -> \
"a8126e46-402e-4659-a02e-87b16beb1147"],
Cell[970181, 25775, 1241, 20, 64900, "Text", "ExpressionUUID" -> \
"49e2ff9f-2449-417a-ac68-1bb9157b445a"],
Cell[971425, 25797, 482, 14, 20292, "Input", "ExpressionUUID" -> \
"c0ee0eb9-a63d-42ab-b3e4-e6404a75ad2b",
 Evaluatable->False],
Cell[971910, 25813, 422, 9, 21465, "Text", "ExpressionUUID" -> \
"852e5f88-12cc-4e62-a514-8a8689282bb5"],
Cell[972335, 25824, 721, 19, 12921, "Input", "ExpressionUUID" -> \
"760e13e2-9ae1-4c6b-b317-ae2b7b192945",
 Evaluatable->False],
Cell[973059, 25845, 296, 6, 21777, "Text", "ExpressionUUID" -> \
"9e017ee6-0969-41cd-af60-c07285884639"],
Cell[973358, 25853, 1045, 30, 20547, "Input", "ExpressionUUID" -> \
"57339234-e4e2-4a95-a5f6-0a55ac694458",
 Evaluatable->False],
Cell[974406, 25885, 1123, 26, 30438, "Text", "ExpressionUUID" -> \
"66a28ffd-e72c-4413-a863-fe773f0cec0e"],
Cell[975532, 25913, 1134, 34, 30303, "Input", "ExpressionUUID" -> \
"11c6a640-57e6-401b-b151-0ab7bde8d29f",
 Evaluatable->False],
Cell[976669, 25949, 350, 6, 12921, "Input", "ExpressionUUID" -> \
"594a6f3d-8a01-4e7b-bae8-2b8545b09902"],
Cell[977022, 25957, 671, 13, 47769, "Text", "ExpressionUUID" -> \
"0ecdf3a7-eb19-4602-9ef0-23faef60d02a"],
Cell[977696, 25972, 282, 7, 12921, "Input", "ExpressionUUID" -> \
"397330b7-9dad-4e2e-806f-d83726f8a7c8"],
Cell[977981, 25981, 373, 7, 29619, "Text", "ExpressionUUID" -> \
"ee8a127a-c30a-4417-a453-da154b95d468"],
Cell[978357, 25990, 424, 12, 12921, "Input", "ExpressionUUID" -> \
"a2bf6ea5-5bb5-4d22-9313-925890c1356b"],
Cell[978784, 26004, 217, 5, 12921, "Text", "ExpressionUUID" -> \
"6f772419-77b8-4ee9-ae0b-91f872efa4fe"],
Cell[979004, 26011, 415, 11, 12921, "Input", "ExpressionUUID" -> \
"238142e1-2b03-42f1-ae40-5cf35cb1f95a"],
Cell[979422, 26024, 225, 5, 12921, "Text", "ExpressionUUID" -> \
"10cbc832-26ff-484e-a54d-12b265479a46"],
Cell[979650, 26031, 238, 6, 12921, "Input", "ExpressionUUID" -> \
"aa8386c1-0a9c-4418-bca9-796e97b7c1e9"],
Cell[979891, 26039, 560, 12, 12921, "Input", "ExpressionUUID" -> \
"1316e4ed-fe72-438a-99f9-2b47c8dea9c2"],
Cell[980454, 26053, 872, 16, 38961, "Text", "ExpressionUUID" -> \
"de053423-9387-40a5-b69d-f82e81d89935"],
Cell[981329, 26071, 582, 12, 30438, "Text", "ExpressionUUID" -> \
"8e6c2090-d64f-44d9-a8a8-83834674bcb2"],
Cell[981914, 26085, 245, 5, 12921, "Text", "ExpressionUUID" -> \
"7496c0f3-5fdd-426e-a485-3616fed64810"],
Cell[982162, 26092, 225, 5, 12921, "Input", "ExpressionUUID" -> \
"15617742-9832-4be5-ad88-dc52712a270b"],
Cell[982390, 26099, 547, 13, 12921, "Input", "ExpressionUUID" -> \
"14fda5fa-7b76-48ab-bdd1-1ce89cfdc271"],
Cell[982940, 26114, 236, 6, 12921, "Input", "ExpressionUUID" -> \
"ffb0d4a2-a4b9-4a91-93d0-111255cda229"],
Cell[983179, 26122, 414, 9, 12921, "Input", "ExpressionUUID" -> \
"b59acb2f-6bc7-4876-a158-792eba1cd584"],
Cell[983596, 26133, 440, 10, 12921, "Input", "ExpressionUUID" -> \
"dae82264-8b40-4350-b97a-89c3c729adb0"],
Cell[984039, 26145, 520, 11, 12921, "Input", "ExpressionUUID" -> \
"10cfb3e7-5779-4565-90a3-442a06f561ac"],
Cell[984562, 26158, 450, 12, 17631, "Text", "ExpressionUUID" -> \
"42fc14b8-5e56-4a69-b933-488bb5c2e663"],
Cell[985015, 26172, 544, 11, 12921, "Input", "ExpressionUUID" -> \
"8e01c861-0ce5-442e-b390-2dfd1464cfed"],
Cell[985562, 26185, 285, 6, 21465, "Text", "ExpressionUUID" -> \
"9b8b0813-77eb-43f0-9f1c-616f99630994"]
}, Closed]],
Cell[CellGroupData[{
Cell[985884, 26196, 522, 8, 42, "Subsubsection", "ExpressionUUID" -> \
"d71a64ac-9501-4a27-b7e4-52e433dcfdba"],
Cell[986409, 26206, 670, 12, 31846, "Text", "ExpressionUUID" -> \
"b0ac3a37-7b82-4fdf-bec9-5b3af4250075"],
Cell[987082, 26220, 379, 9, 14310, "Text", "ExpressionUUID" -> \
"ff7a5fe4-0194-4524-8aa0-cdadf754008c"],
Cell[987464, 26231, 522, 13, 8614, "Input", "ExpressionUUID" -> \
"03feef42-6651-46ff-811a-ffcbc0cd2456",
 Evaluatable->False],
Cell[987989, 26246, 991, 20, 26151, "Text", "ExpressionUUID" -> \
"572af91b-db96-4992-b0a9-ee51c422e60a"],
Cell[988983, 26268, 1715, 43, 31468, "Input", "ExpressionUUID" -> \
"a86625c1-a199-4210-999b-98921ac36032"],
Cell[990701, 26313, 439, 8, 20292, "Text", "ExpressionUUID" -> \
"7c97200b-3e49-4d73-864d-0b41680b9105"],
Cell[991143, 26323, 524, 14, 8614, "Input", "ExpressionUUID" -> \
"c625027e-e58a-43ba-9427-a326b2ce24ff",
 Evaluatable->False],
Cell[991670, 26339, 514, 11, 14310, "Text", "ExpressionUUID" -> \
"9fa9afc7-c442-4e66-b13e-778da8f60352"],
Cell[992187, 26352, 1309, 35, 20202, "Input", "ExpressionUUID" -> \
"b794af7e-82e8-4133-87fd-d3f9190e373c",
 Evaluatable->False],
Cell[993499, 26389, 1226, 34, 20202, "Input", "ExpressionUUID" -> \
"24c529e3-c341-422d-b66e-f38eed701c21",
 Evaluatable->False],
Cell[994728, 26425, 400, 7, 8614, "Input", "ExpressionUUID" -> \
"4cd9216e-68ad-405e-8f69-05195aa356ee"],
Cell[995131, 26434, 191, 4, 8614, "Input", "ExpressionUUID" -> \
"639698cb-63c6-442f-86b5-d4838f7b5b39"],
Cell[995325, 26440, 158, 3, 8614, "Text", "ExpressionUUID" -> \
"7bbd5a89-515a-4b27-91ee-2ba892b47478"],
Cell[995486, 26445, 1382, 36, 14518, "Input", "ExpressionUUID" -> \
"9f663417-1abd-4b9b-b28d-71b85ac6fbfe"],
Cell[996871, 26483, 1330, 39, 25740, "Input", "ExpressionUUID" -> \
"bd760cdf-38a5-42d2-94c8-e0d2b0696267"],
Cell[998204, 26524, 241, 4, 8857, "Text", "ExpressionUUID" -> \
"b47be714-9036-4f9b-b73f-3adfaf73d481"],
Cell[998448, 26530, 183, 5, 8614, "Input", "ExpressionUUID" -> \
"bda99c54-030c-41a6-9d2b-74a5dea2b5e4"],
Cell[998634, 26537, 157, 3, 8614, "Text", "ExpressionUUID" -> \
"f01ab482-916e-4401-9913-223d0cf4ebd6"],
Cell[998794, 26542, 424, 12, 8614, "Input", "ExpressionUUID" -> \
"da1c1f3b-f23f-4387-a355-7dae3f03928c"],
Cell[999221, 26556, 215, 5, 8614, "Text", "ExpressionUUID" -> \
"0028e747-9330-4741-ac17-eae7b8c23bd7"],
Cell[999439, 26563, 1470, 40, 25740, "Input", "ExpressionUUID" -> \
"20506d76-c93e-4725-a591-d6e564a35cae"],
Cell[1000912, 26605, 190, 3, 8614, "Text", "ExpressionUUID" -> \
"a83be79c-a562-4719-a46c-f11f31321e75"],
Cell[1001105, 26610, 569, 14, 15898, "Input", "ExpressionUUID" -> \
"87801be3-8e53-4009-bcd4-db7475e1d804",
 Evaluatable->False],
Cell[1001677, 26626, 286, 6, 8614, "Text", "ExpressionUUID" -> \
"b6147f70-24f6-4572-9a8c-b267d5d3c6ce"],
Cell[1001966, 26634, 737, 17, 15540, "Input", "ExpressionUUID" -> \
"1442864b-d2fd-49c5-bfe1-c94102a8865f",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[1002740, 26656, 571, 8, 42, "Subsubsection", "ExpressionUUID" -> \
"e848cc0d-d980-4daa-821f-7be6a39aa3ae"],
Cell[1003314, 26666, 655, 11, 19746, "Text", "ExpressionUUID" -> \
"1d1b83ee-da99-4bb4-a925-cb9afa616498"],
Cell[1003972, 26679, 1041, 18, 25381, "Text", "ExpressionUUID" -> \
"ef80dd7b-d40d-4759-a032-9549e4d2ecee"],
Cell[1005016, 26699, 3937, 69, 95481, "Text", "ExpressionUUID" -> \
"c110000f-ffd1-4450-8eb8-8341dfbc793a"],
Cell[1008956, 26770, 939, 28, 14518, "Input", "ExpressionUUID" -> \
"b2a024a6-7736-4623-a355-d785c7d7b569",
 Evaluatable->False],
Cell[1009898, 26800, 402, 9, 14310, "Text", "ExpressionUUID" -> \
"a2fd810c-c835-4380-ae90-2d98cf5c806f",
 CellTags->"cij"],
Cell[1010303, 26811, 171, 4, 8614, "Input", "ExpressionUUID" -> \
"968354ef-538a-476e-ae1b-3faf80a46995"],
Cell[1010477, 26817, 5061, 152, 87894, "Input", "ExpressionUUID" -> \
"726aba45-a446-4e9f-bcd4-010f255da41f",
 Evaluatable->False],
Cell[1015541, 26971, 174, 3, 8614, "Text", "ExpressionUUID" -> \
"8c0ca9db-b3e4-491f-a599-ab91c1aaf13b"],
Cell[1015718, 26976, 708, 18, 8614, "Input", "ExpressionUUID" -> \
"d286a6bb-4ccf-4d74-9ac7-ffe577475d75"],
Cell[1016429, 26996, 707, 12, 20202, "Text", "ExpressionUUID" -> \
"a27148b6-ccce-4028-a584-8e93d353d104"],
Cell[1017139, 27010, 1354, 35, 14518, "Input", "ExpressionUUID" -> \
"1a2dc900-efc2-4b74-b447-5dba66e573e9",
 Evaluatable->False],
Cell[1018496, 27047, 455, 9, 14761, "Text", "ExpressionUUID" -> \
"3e7b8d49-858a-4bed-9f23-bb908f2f6b08"],
Cell[1018954, 27058, 777, 22, 8614, "Input", "ExpressionUUID" -> \
"0e090342-b6a2-4509-bbb5-ed356c0aa98f",
 Evaluatable->False],
Cell[1019734, 27082, 318, 5, 8614, "Text", "ExpressionUUID" -> \
"007966ac-1f66-44db-8408-8f8afd39ebfc"],
Cell[1020055, 27089, 856, 24, 8614, "Input", "ExpressionUUID" -> \
"e1bd2ed4-b381-4516-bfcc-6b65e8f4a8fe",
 Evaluatable->False],
Cell[1020914, 27115, 301, 7, 8857, "Text", "ExpressionUUID" -> \
"08063ed8-afc5-49e9-94cb-a9d8d13e27ca"],
Cell[1021218, 27124, 849, 23, 8614, "Input", "ExpressionUUID" -> \
"4fbdfe5a-98bf-4710-ae5f-01403fc123e9",
 Evaluatable->False],
Cell[1022070, 27149, 194, 3, 8614, "Text", "ExpressionUUID" -> \
"0c14c6c2-7cae-455d-87d5-2ae1d98bc7de"],
Cell[1022267, 27154, 885, 23, 8614, "Input", "ExpressionUUID" -> \
"2a33ed0d-c691-40a6-a05f-8ec3770835b1",
 Evaluatable->False],
Cell[1023155, 27179, 356, 7, 8857, "Text", "ExpressionUUID" -> \
"1ca1a501-f2bb-4e86-8736-32c025db13af"],
Cell[1023514, 27188, 485, 13, 8614, "Input", "ExpressionUUID" -> \
"46ec8ea0-42fd-49fd-b5fd-ae1ea287d885",
 Evaluatable->False],
Cell[1024002, 27203, 551, 9, 20292, "Text", "ExpressionUUID" -> \
"d5aebf1d-e97b-4912-aff3-a12d321058b8"],
Cell[1024556, 27214, 958, 18, 36540, "Text", "ExpressionUUID" -> \
"451b1fe0-2519-4d4f-b784-6a911b427759"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1025575, 27239, 431, 6, 97, "Section", "ExpressionUUID" -> \
"9fed42b2-58ec-4f2a-877b-e970f669a20b"],
Cell[CellGroupData[{
Cell[1026031, 27249, 624, 9, 67, "Subsection", "ExpressionUUID" -> \
"c0982fd6-08da-40be-b6f7-3ea69d1025f0"],
Cell[1026658, 27260, 209, 5, 49, "Input", "ExpressionUUID" -> \
"90999149-5787-4f0d-8a76-9f111c99b7de"],
Cell[1026870, 27267, 449, 13, 50, "Text", "ExpressionUUID" -> \
"94bdbdea-4076-42b7-be29-64406ffea269"],
Cell[1027322, 27282, 1152, 28, 83, "Input", "ExpressionUUID" -> \
"760d19fc-2101-4d4f-8e96-83f4b6ca868f",
 Evaluatable->False],
Cell[1028477, 27312, 347, 6, 49, "Input", "ExpressionUUID" -> \
"a1e34954-9dfb-45c9-a189-2aa60cf9937c"],
Cell[1028827, 27320, 188, 4, 8614, "Input", "ExpressionUUID" -> \
"6551b6be-749c-4793-93d4-02ff395cacb1"],
Cell[1029018, 27326, 1289, 22, 43267, "Text", "ExpressionUUID" -> \
"d621d18d-5708-442d-8492-d0e068c5cb52"],
Cell[1030310, 27350, 2290, 56, 25740, "Input", "ExpressionUUID" -> \
"c98d2445-57e5-4646-b50d-7911f1aba5ff"],
Cell[1032603, 27408, 169, 3, 8614, "Input", "ExpressionUUID" -> \
"fbce4d84-290f-45e3-b434-35da5316d0ce"],
Cell[1032775, 27413, 301, 9, 8614, "Text", "ExpressionUUID" -> \
"f1ca0199-3e85-4629-aeee-fd6c6b255102"],
Cell[1033079, 27424, 789, 21, 14518, "Input", "ExpressionUUID" -> \
"6f07c39a-6018-492f-a334-463a9c045f54"],
Cell[1033871, 27447, 834, 22, 14518, "Input", "ExpressionUUID" -> \
"61b3fb9b-09e3-4c84-ba3f-2be23efefa45"],
Cell[1034708, 27471, 635, 16, 14310, "Text", "ExpressionUUID" -> \
"25078d7a-fb7c-437b-aaf6-606700e40b6e"]
}, Closed]],
Cell[CellGroupData[{
Cell[1035380, 27492, 518, 7, 53, "Subsection", "ExpressionUUID" -> \
"26107c3f-f1b2-4f63-8834-527a9bcf8704"],
Cell[1035901, 27501, 272, 6, 50, "Text", "ExpressionUUID" -> \
"9be3c6e7-e97c-492b-98b2-0649f4716b24"],
Cell[1036176, 27509, 1232, 31, 149, "Input", "ExpressionUUID" -> \
"ea6dfd5d-2b96-4939-85d2-ae1efaea4d4f"],
Cell[1037411, 27542, 972, 19, 31468, "Text", "ExpressionUUID" -> \
"0b0db3d5-1fe9-4122-87ff-c03ee2f709c3"],
Cell[1038386, 27563, 408, 12, 14310, "Text", "ExpressionUUID" -> \
"f17ef8ab-99c7-4843-8489-69098655f39a"],
Cell[1038797, 27577, 2142, 70, 25740, "Input", "ExpressionUUID" -> \
"fd7bdd75-0d0f-4d2f-a2f0-aaf28aff5a1f",
 Evaluatable->False],
Cell[1040942, 27649, 255, 5, 8614, "Input", "ExpressionUUID" -> \
"c838c03e-492b-448e-8bea-c070608e1261"],
Cell[1041200, 27656, 317, 6, 8614, "Text", "ExpressionUUID" -> \
"3a619a79-8460-429d-9c95-3bcb8838e240"],
Cell[1041520, 27664, 682, 19, 8614, "Input", "ExpressionUUID" -> \
"f0f843a3-9ba6-41d0-9c46-9dab3889b31d",
 Evaluatable->False],
Cell[1042205, 27685, 214, 7, 8614, "Text", "ExpressionUUID" -> \
"34b5a835-0b08-4cb4-b620-e59aaa9fcd4e"],
Cell[1042422, 27694, 1674, 46, 20202, "Input", "ExpressionUUID" -> \
"e6fb09ea-1b5b-4431-a3b2-48c8756185e0"],
Cell[1044099, 27742, 455, 8, 14310, "Text", "ExpressionUUID" -> \
"25e84c2e-9c7d-49ce-a2af-ba9a9e1a8979"],
Cell[1044557, 27752, 1308, 36, 20202, "Input", "ExpressionUUID" -> \
"000ea092-f0f0-4b67-9ae2-a540875c1955"],
Cell[1045868, 27790, 354, 10, 8614, "Text", "ExpressionUUID" -> \
"55593cff-0ae8-4ff4-9d0a-f849ecaafab0"],
Cell[1046225, 27802, 1953, 51, 25740, "Input", "ExpressionUUID" -> \
"61faa36c-12c3-41b6-9202-2f2706a19848"],
Cell[1048181, 27855, 966, 25, 14518, "Input", "ExpressionUUID" -> \
"f846740d-b0af-4707-b886-bd5a2b47e3ff"],
Cell[1049150, 27882, 853, 21, 14518, "Input", "ExpressionUUID" -> \
"48c07c99-ffaa-429f-928b-91a5f81c5c6f"],
Cell[1050006, 27905, 150, 3, 8614, "Text", "ExpressionUUID" -> \
"fae269db-2f9c-4126-91d8-b3d324dd3fc6"],
Cell[1050159, 27910, 1272, 32, 20202, "Input", "ExpressionUUID" -> \
"0bf8feb8-6f49-4578-96fe-ef3613ca83b1"],
Cell[1051434, 27944, 159, 3, 8614, "Text", "ExpressionUUID" -> \
"79950f28-be2d-43a4-904e-8e94d64e68e9"],
Cell[1051596, 27949, 520, 14, 14310, "Text", "ExpressionUUID" -> \
"82266dab-3401-4ef2-b29e-d8438bc90c53"],
Cell[1052119, 27965, 942, 25, 14518, "Input", "ExpressionUUID" -> \
"04d5b3e0-97d9-48f6-acf0-04e7ae061ae1"],
Cell[1053064, 27992, 166, 3, 8614, "Text", "ExpressionUUID" -> \
"d1f017d1-1906-4dd6-a9db-d755b449afbd"],
Cell[1053233, 27997, 533, 13, 8614, "Input", "ExpressionUUID" -> \
"2f831146-32e7-40b9-9367-56e8300e54df"],
Cell[1053769, 28012, 420, 12, 8614, "Input", "ExpressionUUID" -> \
"e886b2d3-2f4d-4bec-8230-85fbf9b6d66b"],
Cell[1054192, 28026, 177, 3, 8614, "Text", "ExpressionUUID" -> \
"48e8495c-9ccb-47a3-a41a-5f016386cb4b"],
Cell[1054372, 28031, 485, 13, 8614, "Input", "ExpressionUUID" -> \
"385577db-a1ad-4114-87dc-9b92cd02e423"],
Cell[1054860, 28046, 484, 14, 8614, "Input", "ExpressionUUID" -> \
"f9dcd69d-a1f9-4597-9dc3-1ea8bdb95ce7"],
Cell[1055347, 28062, 535, 10, 25974, "Text", "ExpressionUUID" -> \
"1391a0bf-92ae-498a-bc93-79c94e557e4e"]
}, Closed]],
Cell[CellGroupData[{
Cell[1055919, 28077, 526, 9, 53, "Subsection", "ExpressionUUID" -> \
"3f61b789-94cc-4600-872d-0cc816942bc2"],
Cell[1056448, 28088, 382, 8, 50, "Text", "ExpressionUUID" -> \
"0f72a80d-5d0e-4750-903e-64c082ab01cb"],
Cell[1056833, 28098, 1341, 41, 116, "Input", "ExpressionUUID" -> \
"82f2e695-a65f-46fe-b48c-694150f6da27"],
Cell[1058177, 28141, 219, 5, 8614, "Text", "ExpressionUUID" -> \
"1074fda9-ab75-404e-9234-0a257e541ce7"],
Cell[1058399, 28148, 1211, 30, 14518, "Input", "ExpressionUUID" -> \
"3b3c9b66-d277-4f98-8be0-d74c14c226c5"],
Cell[1059613, 28180, 192, 3, 8614, "Text", "ExpressionUUID" -> \
"74564876-5855-440d-b704-fd9d4f4c5252"],
Cell[1059808, 28185, 844, 24, 14518, "Input", "ExpressionUUID" -> \
"b9cc2952-15f7-41ff-bd96-d01012d56495"],
Cell[1060655, 28211, 849, 22, 14518, "Input", "ExpressionUUID" -> \
"de435c1e-a5ed-4541-bd8c-caaa393e5938"],
Cell[1061507, 28235, 847, 22, 14518, "Input", "ExpressionUUID" -> \
"2c9c490b-d7e3-4866-9d89-4a824f576077"],
Cell[1062357, 28259, 892, 24, 14518, "Input", "ExpressionUUID" -> \
"eefeaf51-870d-4d7d-a727-b9340dfc5435"],
Cell[1063252, 28285, 179, 3, 8614, "Text", "ExpressionUUID" -> \
"71a6953a-61b4-45c8-a029-745f9c5fdea6"],
Cell[1063434, 28290, 172, 4, 8614, "Input", "ExpressionUUID" -> \
"aeac584b-8eb2-4a60-a04f-4ce3864dbd0c"],
Cell[1063609, 28296, 154, 3, 8614, "Input", "ExpressionUUID" -> \
"b8bc20ee-c3fa-4d94-9d86-86a820f0fb2b"],
Cell[1063766, 28301, 2846, 77, 31468, "Input", "ExpressionUUID" -> \
"30586e71-5c42-4ad2-abab-b804b97155ff"],
Cell[1066615, 28380, 1118, 29, 14518, "Input", "ExpressionUUID" -> \
"fb8117dd-f974-44a2-9aaf-4d48f51af928"],
Cell[1067736, 28411, 186, 3, 8614, "Text", "ExpressionUUID" -> \
"e6330301-07ec-4cc0-b882-ce967fe12fa1"],
Cell[1067925, 28416, 1312, 36, 14518, "Input", "ExpressionUUID" -> \
"84314282-3cda-4ce2-8672-8645768fbe04",
 InitializationCell->True],
Cell[1069240, 28454, 197, 3, 8614, "Text", "ExpressionUUID" -> \
"249fb1e5-fb0f-4886-8dcc-47d015e3bdd6"],
Cell[1069440, 28459, 779, 18, 8614, "Input", "ExpressionUUID" -> \
"566c24cf-40b1-4984-a378-868111178e43"]
}, Closed]],
Cell[CellGroupData[{
Cell[1070256, 28482, 524, 8, 53, "Subsection", "ExpressionUUID" -> \
"59ab247d-c4d7-4e63-9cce-3edd86fce9ff"],
Cell[CellGroupData[{
Cell[1070805, 28494, 273, 4, 53, "Subsubsection", "ExpressionUUID" -> \
"9b385e5f-a03c-484a-995c-41aaaca403c4"],
Cell[1071081, 28500, 369, 8, 14310, "Text", "ExpressionUUID" -> \
"88dca62f-37f3-422e-b2ce-853eb0aeea38"],
Cell[1071453, 28510, 335, 9, 8614, "Input", "ExpressionUUID" -> \
"191093a0-066e-4765-93f7-34acd65b66b9"],
Cell[1071791, 28521, 207, 5, 8614, "Input", "ExpressionUUID" -> \
"c1762897-db47-4d41-a08f-7e1f0e6d29aa"],
Cell[1072001, 28528, 193, 3, 8614, "Text", "ExpressionUUID" -> \
"d68fa1bb-8a14-42b2-a7dd-fa2ed0440b15"],
Cell[1072197, 28533, 438, 12, 8614, "Input", "ExpressionUUID" -> \
"2a53cb12-056c-4858-b4b2-2a8405c170f2",
 InitializationCell->True],
Cell[1072638, 28547, 186, 3, 8614, "Text", "ExpressionUUID" -> \
"c854b9a1-45ed-4b68-bcb4-d656a3fffdfe"],
Cell[1072827, 28552, 434, 10, 8614, "Input", "ExpressionUUID" -> \
"55045566-5be6-42e5-92d3-f522ca076110",
 InitializationCell->True],
Cell[1073264, 28564, 185, 4, 8614, "Input", "ExpressionUUID" -> \
"9d7793a4-4665-4dd1-8f7d-ecf0d87cd48f"],
Cell[1073452, 28570, 256, 6, 8614, "Input", "ExpressionUUID" -> \
"f539bf3c-99cc-4392-82ab-e926ecb70e31"],
Cell[1073711, 28578, 911, 24, 8614, "Input", "ExpressionUUID" -> \
"7d066540-094c-4a9e-83e8-7de48e952971"],
Cell[1074625, 28604, 471, 9, 8614, "Text", "ExpressionUUID" -> \
"3a27f9d7-93bd-4dad-9b61-c8fc4b89b43e"],
Cell[1075099, 28615, 539, 17, 8614, "Input", "ExpressionUUID" -> \
"c6cf71f7-0222-43ad-9849-ec72a3a5d03c"],
Cell[1075641, 28634, 475, 9, 14310, "Text", "ExpressionUUID" -> \
"f8f4b736-9efb-4cbd-8006-154b8ab60b96"],
Cell[1076119, 28645, 177, 4, 8614, "Input", "ExpressionUUID" -> \
"3ed3c576-d9d8-46ba-a874-ece6b562e664"],
Cell[1076299, 28651, 239, 7, 8614, "Input", "ExpressionUUID" -> \
"35ee83e7-f362-496a-a3bc-07febfd931d5"],
Cell[1076541, 28660, 268, 7, 8614, "Input", "ExpressionUUID" -> \
"1004233b-eaa7-4501-a695-959a92a6c607"],
Cell[1076812, 28669, 364, 10, 8614, "Input", "ExpressionUUID" -> \
"d6e8055b-bf7f-4621-9e3b-786b315fcb53"],
Cell[1077179, 28681, 200, 5, 8614, "Input", "ExpressionUUID" -> \
"6ecef551-d8f2-49e0-8c37-e377ea9f4025"],
Cell[1077382, 28688, 1077, 26, 14518, "Input", "ExpressionUUID" -> \
"b0d2e69a-3eb1-42ed-bd44-646b7eb531f4"],
Cell[1078462, 28716, 528, 10, 19746, "Text", "ExpressionUUID" -> \
"d055f38d-37fd-40e2-a121-04013e04f25d"],
Cell[1078993, 28728, 777, 23, 14518, "Input", "ExpressionUUID" -> \
"0343cda6-0873-4fcc-8919-ccd206169dc3",
 InitializationCell->True],
Cell[1079773, 28753, 486, 10, 8614, "Input", "ExpressionUUID" -> \
"9a602179-89ea-4151-9c13-0049be835db7"],
Cell[1080262, 28765, 420, 8, 8614, "Text", "ExpressionUUID" -> \
"156fdcfe-40ef-4c06-8599-671d74513fb6"],
Cell[1080685, 28775, 569, 11, 8614, "Input", "ExpressionUUID" -> \
"caa79482-681e-49ec-89c5-d30b42cf9be8"],
Cell[1081257, 28788, 330, 9, 14310, "Text", "ExpressionUUID" -> \
"f3337602-c2fc-4d50-9d5d-7c17514eacde"],
Cell[1081590, 28799, 1050, 28, 14518, "Input", "ExpressionUUID" -> \
"c1056541-f443-4f2b-a99a-91ff23dad4f9"],
Cell[1082643, 28829, 1024, 25, 14518, "Input", "ExpressionUUID" -> \
"ded0067a-af4a-47ff-ae78-cd96098a59b0"],
Cell[1083670, 28856, 1195, 29, 14518, "Input", "ExpressionUUID" -> \
"04db162b-4d10-468c-ba3e-6ec443446eb8"],
Cell[1084868, 28887, 412, 8, 14310, "Text", "ExpressionUUID" -> \
"8fab39fd-c74c-4539-b401-3120ef120e38"],
Cell[1085283, 28897, 2201, 50, 31468, "Input", "ExpressionUUID" -> \
"f1c1168e-4f8c-48a0-b665-0f531794081b",
 InitializationCell->True],
Cell[1087487, 28949, 308, 5, 8614, "Text", "ExpressionUUID" -> \
"9a24ba3e-5d7f-45a1-9fb5-fd1561e62111"],
Cell[1087798, 28956, 995, 25, 14518, "Input", "ExpressionUUID" -> \
"01e4e01c-8bb5-4f95-b721-70005d11a403"],
Cell[1088796, 28983, 432, 10, 8614, "Text", "ExpressionUUID" -> \
"2765aba1-01c4-41df-ba14-807e36619e4d"],
Cell[1089231, 28995, 549, 16, 8614, "Input", "ExpressionUUID" -> \
"9cf36f17-cd83-4715-aad8-650ede844138"],
Cell[1089783, 29013, 203, 5, 8614, "Input", "ExpressionUUID" -> \
"3dc886df-d5d9-4a35-b2f7-28069dfdee9e"],
Cell[1089989, 29020, 1075, 28, 14518, "Input", "ExpressionUUID" -> \
"7004f4c7-93a0-43cd-9f72-0cf3f9154999"],
Cell[1091067, 29050, 430, 8, 14310, "Text", "ExpressionUUID" -> \
"ac48817d-caec-4d68-b77f-750e49fd6ef1"],
Cell[1091500, 29060, 429, 10, 8614, "Input", "ExpressionUUID" -> \
"b1987f18-94b8-43e1-bd11-0ea3e60f0f01"],
Cell[1091932, 29072, 175, 3, 8614, "Text", "ExpressionUUID" -> \
"7b4d172f-bff7-4112-9f57-3e7825d71e0a"],
Cell[1092110, 29077, 1095, 26, 20202, "Input", "ExpressionUUID" -> \
"ebf9e4f4-7a13-4696-bf72-05794e600a78"],
Cell[1093208, 29105, 155, 3, 8614, "Text", "ExpressionUUID" -> \
"0d82751a-e91f-459c-8739-dd4e341f4921"],
Cell[1093366, 29110, 282, 8, 8614, "Text", "ExpressionUUID" -> \
"945cfe3a-1350-40b3-b68a-33b880397e52"],
Cell[1093651, 29120, 219, 5, 8614, "Text", "ExpressionUUID" -> \
"e445c97f-1e2a-4446-aaa7-cf5c4edf2e99"],
Cell[1093873, 29127, 207, 5, 8614, "Input", "ExpressionUUID" -> \
"c641bb28-d7a2-4766-ae7d-bf42be76e068"],
Cell[1094083, 29134, 568, 18, 8614, "Input", "ExpressionUUID" -> \
"fcb5a6ca-8056-4016-9909-d3b4a38e66b0"],
Cell[1094654, 29154, 1312, 31, 14518, "Input", "ExpressionUUID" -> \
"01adaf9d-8ee8-4eb3-a7de-f575078dd526"],
Cell[1095969, 29187, 1083, 33, 14518, "Input", "ExpressionUUID" -> \
"35f46b79-ebaf-43fc-ad4e-a73b77d79bc4"],
Cell[1097055, 29222, 277, 6, 8614, "Text", "ExpressionUUID" -> \
"4b6ca26f-5786-487d-9de7-c93b7f31ac2e"],
Cell[1097335, 29230, 1305, 38, 20202, "Input", "ExpressionUUID" -> \
"cae14a07-1e19-428e-af3e-d0e00cc7d3cb"],
Cell[1098643, 29270, 271, 8, 19927, "Text", "ExpressionUUID" -> \
"0a09f08d-57dd-4eb0-8750-54788a1ab08e"],
Cell[1098917, 29280, 1097, 33, 14518, "Input", "ExpressionUUID" -> \
"49237436-328b-4312-ad4c-633d077a666f"]
}, Closed]],
Cell[CellGroupData[{
Cell[1100051, 29318, 260, 4, 42, "Subsubsection", "ExpressionUUID" -> \
"6b93a2cd-97cf-4e30-bd71-ad4a072f3978"],
Cell[1100314, 29324, 534, 12, 83, "Text", "ExpressionUUID" -> \
"33867a8e-77f8-416d-b6ab-3ef69a641dbd"],
Cell[1100851, 29338, 1002, 29, 140, "Input", "ExpressionUUID" -> \
"c335bed9-8602-4eb1-bafc-747d9d2a8a62",
 InitializationCell->True],
Cell[1101856, 29369, 429, 13, 49, "Input", "ExpressionUUID" -> \
"f93d9dab-62f2-45da-8602-4c1ecd37f6bb"],
Cell[1102288, 29384, 193, 4, 49, "Input", "ExpressionUUID" -> \
"dd445856-e708-401f-a663-110829c6d4ff"],
Cell[1102484, 29390, 816, 14, 115, "Text", "ExpressionUUID" -> \
"b9db2bb8-fbe4-4765-8c9c-410a62457a21",
 InitializationCell->True],
Cell[1103303, 29406, 2777, 67, 239, "Input", "ExpressionUUID" -> \
"68cd01a5-f007-4a24-b51e-fb12b506d140",
 InitializationCell->True],
Cell[1106083, 29475, 160, 3, 8614, "Text", "ExpressionUUID" -> \
"c6237e8d-10d5-4b2b-821a-8e7f763cae8d"],
Cell[1106246, 29480, 837, 15, 8614, "Input", "ExpressionUUID" -> \
"d2c16a62-94aa-47c4-8d08-876bbe70f3f6"],
Cell[1107086, 29497, 511, 11, 8614, "Input", "ExpressionUUID" -> \
"8d5a54b0-6118-4347-afbf-9447ed343075"],
Cell[1107600, 29510, 940, 22, 14518, "Input", "ExpressionUUID" -> \
"b22f2ed4-76a1-42c8-aad6-b4fd0ff27f22"],
Cell[1108543, 29534, 1280, 27, 8614, "Input", "ExpressionUUID" -> \
"b771107f-68bd-4561-a7f8-c53d6713fc96"],
Cell[1109826, 29563, 218, 5, 8614, "Input", "ExpressionUUID" -> \
"188c15ce-9af9-477b-b16e-fcb7836a45ce"],
Cell[1110047, 29570, 1106, 31, 20292, "Input", "ExpressionUUID" -> \
"b0923a05-a830-4ba1-99e0-9392828b0afd"],
Cell[1111156, 29603, 1088, 17, 8614, "Input", "ExpressionUUID" -> \
"93a78175-57c2-4926-b8d8-317764b053cf"],
Cell[1112247, 29622, 514, 8, 8614, "Text", "ExpressionUUID" -> \
"6b15e58e-7028-44b7-a1cc-d4a275128e45"]
}, Closed]],
Cell[CellGroupData[{
Cell[1112798, 29635, 441, 7, 42, "Subsubsection", "ExpressionUUID" -> \
"6040c043-8f26-493d-98d0-4f55b0f4fe0b"],
Cell[1113242, 29644, 522, 7, 50, "Text", "ExpressionUUID" -> \
"b08cdfb0-c15f-4639-9b4e-10103c89c165"],
Cell[1113767, 29653, 188, 4, 49, "Input", "ExpressionUUID" -> \
"889d06fd-f8c1-447a-8c75-1ad2da12e711"],
Cell[1113958, 29659, 496, 15, 83, "Input", "ExpressionUUID" -> \
"ef57b82a-190e-4c36-a2b0-927a151dfa0c",
 Evaluatable->False],
Cell[1114457, 29676, 180, 4, 49, "Input", "ExpressionUUID" -> \
"87da1504-b67c-4bf7-806f-8784ee0ebcb6"],
Cell[1114640, 29682, 230, 5, 50, "Text", "ExpressionUUID" -> \
"b06d7b60-b3cd-4880-a8a4-4d8e86c78497"],
Cell[1114873, 29689, 439, 11, 73, "Input", "ExpressionUUID" -> \
"3f568a4b-9212-4464-8f02-f8650e18f53d",
 InitializationCell->True],
Cell[1115315, 29702, 758, 13, 49, "Input", "ExpressionUUID" -> \
"f3fc4473-6238-46f9-a94a-2009a6bfd7be"],
Cell[1116076, 29717, 447, 9, 83, "Text", "ExpressionUUID" -> \
"1f779dbd-ec80-47bb-8422-bc9a79000ef8"],
Cell[1116526, 29728, 444, 10, 73, "Input", "ExpressionUUID" -> \
"ce9680d3-de75-4af5-b7df-cd301169a29e",
 InitializationCell->True],
Cell[1116973, 29740, 577, 12, 115, "Text", "ExpressionUUID" -> \
"3aca8ea8-0934-4976-b5d9-3c468574a320"],
Cell[1117553, 29754, 177, 4, 49, "Input", "ExpressionUUID" -> \
"56914e55-a614-4d03-820d-de3ffc00ae87"],
Cell[1117733, 29760, 189, 4, 8614, "Input", "ExpressionUUID" -> \
"bf89b53b-b36d-4dce-bdd5-43f99e607940"],
Cell[1117925, 29766, 223, 6, 8614, "Input", "ExpressionUUID" -> \
"081f35b6-a6ea-4b2b-90f6-c02fcb382cb4"],
Cell[1118151, 29774, 628, 18, 14518, "Input", "ExpressionUUID" -> \
"2e3ed331-7012-496b-81c4-9b74b166db07"],
Cell[1118782, 29794, 182, 3, 8614, "Text", "ExpressionUUID" -> \
"460f976d-f051-4a0d-b139-8de9e63e246e"],
Cell[1118967, 29799, 175, 4, 8614, "Input", "ExpressionUUID" -> \
"79ec81ca-2855-4a2d-a351-48555702b7d1"],
Cell[1119145, 29805, 193, 4, 8614, "Input", "ExpressionUUID" -> \
"d0be88e5-bacb-4285-81c7-1474ca7298d9"],
Cell[1119341, 29811, 803, 22, 20202, "Input", "ExpressionUUID" -> \
"abe6ab54-29ab-4ba2-b478-146f404838d6"],
Cell[1120147, 29835, 272, 7, 8857, "Text", "ExpressionUUID" -> \
"ef97f27d-ca95-4b47-a58b-33ecafa6c5ca"],
Cell[1120422, 29844, 1218, 29, 25740, "Input", "ExpressionUUID" -> \
"843161db-1d35-47cd-8e5b-c0f59adcbca7"],
Cell[1121643, 29875, 835, 16, 26151, "Text", "ExpressionUUID" -> \
"4873f77c-6f7a-4ecc-b64d-e624f55178e4"],
Cell[1122481, 29893, 246, 6, 8614, "Input", "ExpressionUUID" -> \
"c3403b72-ac52-4dec-8846-67f3cd2433b7"],
Cell[1122730, 29901, 255, 6, 8614, "Input", "ExpressionUUID" -> \
"8fc9b4d7-c222-4ab4-9a0a-40c2021d41f0"],
Cell[1122988, 29909, 553, 16, 8614, "Input", "ExpressionUUID" -> \
"0a75fb1b-68a4-4f80-9bf9-e7fcd1dc04ca"],
Cell[1123544, 29927, 606, 15, 8614, "Input", "ExpressionUUID" -> \
"00324bdc-4985-4837-8a7b-60e857694c2e"],
Cell[1124153, 29944, 320, 6, 8614, "Text", "ExpressionUUID" -> \
"802a5a64-61a1-4972-9433-a0b47277689e"],
Cell[1124476, 29952, 666, 15, 8614, "Input", "ExpressionUUID" -> \
"d7c101d4-d96a-4491-b0f4-9d5ffde41000"],
Cell[1125145, 29969, 149, 3, 8614, "Text", "ExpressionUUID" -> \
"bce152ba-84cf-40d6-ba57-05343926c697"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1125343, 29978, 483, 7, 67, "Subsection", "ExpressionUUID" -> \
"7bc79ead-3373-41d2-9b8e-7ff3403c767b"],
Cell[1125829, 29987, 176, 3, 50, "Text", "ExpressionUUID" -> \
"8003fa90-4f33-4d5c-9c81-d3fb4b63b3d2"],
Cell[1126008, 29992, 185, 4, 49, "Input", "ExpressionUUID" -> \
"dc889922-1127-4617-8862-f51e04707191"],
Cell[1126196, 29998, 136, 3, 49, "Input", "ExpressionUUID" -> \
"c719dd0e-c1e5-45ef-9ef3-ffef86bad2a7"],
Cell[1126335, 30003, 158, 3, 50, "Text", "ExpressionUUID" -> \
"76f8902b-c7ab-4b33-8331-4257a9dbe1fa"],
Cell[1126496, 30008, 206, 5, 49, "Input", "ExpressionUUID" -> \
"487337da-e9b9-4f88-8019-e2bd55937210"],
Cell[1126705, 30015, 721, 12, 148, "Text", "ExpressionUUID" -> \
"e9b97843-3103-40ca-93c6-1696c7438d30"],
Cell[1127429, 30029, 1399, 33, 14518, "Input", "ExpressionUUID" -> \
"cdb76891-8a24-44a2-bf8b-0b86efa3f5fa"],
Cell[1128831, 30064, 243, 4, 8614, "Text", "ExpressionUUID" -> \
"892bdf76-6c39-4a9e-a2dd-4523687927bb"],
Cell[1129077, 30070, 180, 4, 8614, "Input", "ExpressionUUID" -> \
"acdae391-0d95-4825-bc92-5b1e17f03f4f"],
Cell[1129260, 30076, 182, 4, 8614, "Input", "ExpressionUUID" -> \
"0392826c-2948-4b85-9783-60e825158521"],
Cell[1129445, 30082, 1889, 46, 20202, "Input", "ExpressionUUID" -> \
"48c3e669-b1a4-4cc2-8cd3-06cb2f73f86f"],
Cell[1131337, 30130, 1323, 31, 26151, "Text", "ExpressionUUID" -> \
"f4f2bd22-64eb-436d-aa14-0a532f5167d0"],
Cell[1132663, 30163, 538, 9, 14761, "Text", "ExpressionUUID" -> \
"f84f6e86-d5a3-4c23-9c38-2faddc07625e"],
Cell[1133204, 30174, 186, 4, 8614, "Input", "ExpressionUUID" -> \
"a1ef92d8-f86b-492b-b332-31a5431ca830"],
Cell[1133393, 30180, 2482, 61, 37045, "Input", "ExpressionUUID" -> \
"d7f01bd1-6917-4b28-ab40-949ea5e0ceef",
 Evaluatable->False],
Cell[1135878, 30243, 204, 4, 8614, "Input", "ExpressionUUID" -> \
"2415bad7-cfb5-4cee-a4fa-ef44d884cb78"],
Cell[1136085, 30249, 212, 4, 8614, "Text", "ExpressionUUID" -> \
"5237c9af-e899-4987-b6d5-2da857033ae6"],
Cell[1136300, 30255, 584, 17, 14518, "Input", "ExpressionUUID" -> \
"1c750e85-85cd-4fc9-88c1-d1ec50b197c4"],
Cell[1136887, 30274, 526, 10, 14310, "Text", "ExpressionUUID" -> \
"ec54893c-1e30-403f-aebf-8c8b9d706abb"],
Cell[1137416, 30286, 401, 9, 8614, "Text", "ExpressionUUID" -> \
"fdcb9ddc-49f7-47f4-8200-e55b17ffae82"],
Cell[1137820, 30297, 700, 18, 14518, "Input", "ExpressionUUID" -> \
"6bbc4cbc-7168-4935-ba1d-232f5a72209e"],
Cell[1138523, 30317, 607, 18, 8614, "Input", "ExpressionUUID" -> \
"5d5d9415-53ca-4191-a731-677959e8fc04"],
Cell[1139133, 30337, 780, 14, 20292, "Text", "ExpressionUUID" -> \
"ba47ce0c-12e7-4aee-81fd-4a23d3a21b7f"],
Cell[1139916, 30353, 403, 8, 14310, "Text", "ExpressionUUID" -> \
"e81c7b05-f87f-4219-aa1c-1da3b758a696"],
Cell[1140322, 30363, 423, 8, 14310, "Text", "ExpressionUUID" -> \
"65de680c-fd93-4e4c-b534-f571cf9db11e"],
Cell[1140748, 30373, 793, 19, 8614, "Input", "ExpressionUUID" -> \
"9c356f53-34df-4f38-8a53-b39f016dbdfc",
 Evaluatable->False],
Cell[1141544, 30394, 816, 14, 26151, "Text", "ExpressionUUID" -> \
"16ce51f8-2e49-4bbf-a37f-10bd56a434e6"],
Cell[1142363, 30410, 1051, 27, 9324, "Input", "ExpressionUUID" -> \
"2721bd9f-aadf-4adb-a597-f6772ce1b191",
 Evaluatable->False],
Cell[1143417, 30439, 1435, 31, 20547, "Text", "ExpressionUUID" -> \
"1c91ffc1-fe35-4dfb-9a57-8d400a598305",
 CellTags->"geodc"],
Cell[1144855, 30472, 517, 11, 8614, "Text", "ExpressionUUID" -> \
"11396394-b7a1-47f3-8314-654cfa6b8e77"],
Cell[1145375, 30485, 485, 16, 10158, "Input", "ExpressionUUID" -> \
"bdaa981d-35b1-4bf7-ad26-9f1fbd568436",
 Evaluatable->False],
Cell[1145863, 30503, 605, 19, 8614, "Text", "ExpressionUUID" -> \
"6f442ff2-a647-408f-bf4f-9e647f20a80a"],
Cell[1146471, 30524, 446, 12, 9324, "Input", "ExpressionUUID" -> \
"ee0d5d12-0ba1-4cca-9f14-791e91212550",
 Evaluatable->False],
Cell[1146920, 30538, 387, 8, 14518, "Text", "ExpressionUUID" -> \
"3b34c3bb-61e7-4eb8-bd35-dfc4cb56118d"],
Cell[1147310, 30548, 675, 12, 14761, "Text", "ExpressionUUID" -> \
"41aae714-89ab-49d1-9c41-8071420cca86"],
Cell[1147988, 30562, 670, 20, 16614, "Input", "ExpressionUUID" -> \
"a82dc26d-003a-49f0-8be3-822534e5ab83",
 Evaluatable->False],
Cell[1148661, 30584, 1952, 47, 43267, "Text", "ExpressionUUID" -> \
"3897dbdd-caf5-4f44-bdc2-ab15d2906e82"],
Cell[1150616, 30633, 563, 12, 19746, "Text", "ExpressionUUID" -> \
"05290ce3-edbc-4748-95b2-15a00041ec9d"],
Cell[1151182, 30647, 412, 6, 8857, "Text", "ExpressionUUID" -> \
"db715ab1-e16e-493a-9c8b-6311b7b778e4"],
Cell[1151597, 30655, 331, 5, 8614, "Text", "ExpressionUUID" -> \
"c10e5d36-078b-4a1a-b2b1-64b2fc448649"],
Cell[1151931, 30662, 616, 18, 10158, "Input", "ExpressionUUID" -> \
"4ca2bc6f-91d8-4782-bcca-c3f91ffb0585",
 Evaluatable->False],
Cell[1152550, 30682, 1104, 20, 43120, "Text", "ExpressionUUID" -> \
"9ce02a27-05a0-41ed-a50f-758f30cb2555"],
Cell[1153657, 30704, 594, 10, 19746, "Text", "ExpressionUUID" -> \
"5995f792-e5d5-4ea5-a8e1-f5b13e94be31"],
Cell[1154254, 30716, 435, 13, 8614, "Input", "ExpressionUUID" -> \
"02f9702f-4fc6-4913-a7c3-d25d85683fd5",
 Evaluatable->False],
Cell[1154692, 30731, 650, 13, 14761, "Text", "ExpressionUUID" -> \
"576a8221-365b-4209-a6df-11cb26aa6a1c"],
Cell[1155345, 30746, 1231, 29, 20202, "Input", "ExpressionUUID" -> \
"d89bd026-168b-4445-ae4a-3121e9749f21",
 Evaluatable->False],
Cell[1156579, 30777, 236, 5, 8614, "Input", "ExpressionUUID" -> \
"4a2c917c-612b-4959-8436-4802c28628e0"],
Cell[1156818, 30784, 252, 4, 8614, "Text", "ExpressionUUID" -> \
"4c557173-558b-43e1-bb68-07b6ef2b018f"],
Cell[1157073, 30790, 888, 24, 14518, "Input", "ExpressionUUID" -> \
"8af11eb3-a8ea-4628-b28e-beeeb5db711b"],
Cell[1157964, 30816, 681, 17, 8614, "Input", "ExpressionUUID" -> \
"ddf09840-5ecf-4bab-b28d-324480008a6f"],
Cell[1158648, 30835, 529, 10, 19746, "Text", "ExpressionUUID" -> \
"52ffc1e3-b448-45f4-af1e-8d9b72864a95"],
Cell[1159180, 30847, 509, 11, 8614, "Input", "ExpressionUUID" -> \
"f7a92ab0-a912-492e-85cd-f4aa4146d3b9"],
Cell[1159692, 30860, 1134, 21, 30820, "Text", "ExpressionUUID" -> \
"20122e30-7722-4088-b89b-c820849eafe7"],
Cell[1160829, 30883, 1378, 26, 52962, "Text", "ExpressionUUID" -> \
"5a4d1909-5844-42ce-950d-f00cffc43b1e"],
Cell[1162210, 30911, 768, 20, 20202, "Input", "ExpressionUUID" -> \
"52e1b976-74c5-4ecd-8ae8-863e20c2ee1e"],
Cell[1162981, 30933, 719, 19, 20202, "Input", "ExpressionUUID" -> \
"7598e849-4a02-4672-9e8c-cb9daaa357c9"],
Cell[1163703, 30954, 455, 8, 20202, "Text", "ExpressionUUID" -> \
"08f6ab03-84ed-48cb-9d20-3c5a935bb2e1"],
Cell[1164161, 30964, 577, 16, 8614, "Input", "ExpressionUUID" -> \
"6447fe08-5fb2-4a31-a0ae-fc5c71caa097"],
Cell[1164741, 30982, 625, 16, 8614, "Input", "ExpressionUUID" -> \
"6565f9fb-a299-4325-ba51-96242f84106d"],
Cell[1165369, 31000, 700, 16, 8614, "Input", "ExpressionUUID" -> \
"6df857a4-8b5c-4954-b905-c853a214ebd6"],
Cell[1166072, 31018, 702, 16, 8614, "Input", "ExpressionUUID" -> \
"441386f9-60bf-4d2e-bd88-687f99ee4064"],
Cell[1166777, 31036, 706, 15, 19746, "Text", "ExpressionUUID" -> \
"7b4a8747-b274-4cf3-8c2f-19b3b5cf2c63"],
Cell[1167486, 31053, 360, 9, 8614, "Input", "ExpressionUUID" -> \
"2ca7ee59-2827-4b63-a6c1-63545a9fa635"],
Cell[1167849, 31064, 367, 9, 8614, "Input", "ExpressionUUID" -> \
"55198388-2507-4dba-bbfd-de47e26a1a0a"],
Cell[1168219, 31075, 1211, 30, 25740, "Input", "ExpressionUUID" -> \
"9cbd8a3b-b4cb-43bc-8c55-5a3b98c3ae19"],
Cell[1169433, 31107, 892, 23, 20292, "Text", "ExpressionUUID" -> \
"2ea9f86a-eead-47fe-af39-90df5f324f7b"],
Cell[1170328, 31132, 773, 20, 17160, "Input", "ExpressionUUID" -> \
"59217326-9883-433b-8888-935dda0f9a5d",
 Evaluatable->False],
Cell[1171104, 31154, 428, 8, 14518, "Text", "ExpressionUUID" -> \
"b5a950ab-0366-4e9d-8ddc-1bed321c5312"],
Cell[1171535, 31164, 546, 11, 14310, "Text", "ExpressionUUID" -> \
"f59895a3-9f82-4ff5-a0ee-1e3cd01ffb61"],
Cell[1172084, 31177, 785, 23, 8614, "Input", "ExpressionUUID" -> \
"77e6c7c7-fa98-4a0a-9cad-4135f9a8baf3",
 Evaluatable->False],
Cell[1172872, 31202, 1049, 17, 31618, "Text", "ExpressionUUID" -> \
"2ae82fbc-a5d8-498e-b8a4-61cb87ebd316"],
Cell[1173924, 31221, 1422, 37, 20202, "Input", "ExpressionUUID" -> \
"258def1c-9fea-462c-b41a-ca1ab991f6c6"],
Cell[1175349, 31260, 528, 11, 14310, "Text", "ExpressionUUID" -> \
"65ad470d-7e72-436e-bd86-ba154b3199dd"],
Cell[1175880, 31273, 2153, 63, 31468, "Input", "ExpressionUUID" -> \
"bb1384a3-4f99-43f5-bad9-845804a7cb75",
 Evaluatable->False],
Cell[1178036, 31338, 230, 4, 8614, "Text", "ExpressionUUID" -> \
"c467c619-ed91-4db7-bd73-1e3af3836d25"],
Cell[1178269, 31344, 257, 5, 8614, "Input", "ExpressionUUID" -> \
"2ea55f6b-b427-46c6-b948-ed87cdc1655f"],
Cell[1178529, 31351, 324, 6, 8614, "Input", "ExpressionUUID" -> \
"689eae28-c15c-4948-8cb5-a03b9e4d92c6"],
Cell[1178856, 31359, 1355, 31, 14761, "Text", "ExpressionUUID" -> \
"c4ff1100-04e5-49f5-9c68-e712298b84da"],
Cell[1180214, 31392, 1186, 27, 14518, "Input", "ExpressionUUID" -> \
"2ae18368-4edb-4fbb-8116-f49c17615a89"],
Cell[1181403, 31421, 228, 5, 8614, "Input", "ExpressionUUID" -> \
"3e838ec4-09c5-4abd-95be-5ad16c35c830"],
Cell[1181634, 31428, 519, 11, 14310, "Text", "ExpressionUUID" -> \
"b9527c03-994c-4a38-a154-22a78a116ca3"],
Cell[1182156, 31441, 1114, 27, 14518, "Input", "ExpressionUUID" -> \
"8895a8e1-61eb-4045-a81c-ebf1ffc54274"],
Cell[1183273, 31470, 1303, 29, 20202, "Input", "ExpressionUUID" -> \
"cf59f3fe-5a30-4e3a-92a7-5779b6e3fbbb"],
Cell[1184579, 31501, 588, 13, 8614, "Input", "ExpressionUUID" -> \
"67e409a5-b1b3-4b8d-b340-abbe3e909a4d"],
Cell[1185170, 31516, 493, 10, 8614, "Input", "ExpressionUUID" -> \
"b844827a-3c68-46c0-be8c-dab6ec964d70"],
Cell[1185666, 31528, 345, 10, 8614, "Input", "ExpressionUUID" -> \
"4a5b974b-f059-40d2-ac6d-189287a82359"],
Cell[1186014, 31540, 245, 5, 8614, "Text", "ExpressionUUID" -> \
"2d657d41-db0e-4370-a5e2-614cc317c461"],
Cell[1186262, 31547, 546, 14, 8614, "Input", "ExpressionUUID" -> \
"13a66f39-ca05-4428-93c1-43a54af0942d"],
Cell[1186811, 31563, 407, 9, 8614, "Input", "ExpressionUUID" -> \
"e5802d6e-8f33-4df5-bc46-34746a7ec002"],
Cell[1187221, 31574, 320, 6, 8614, "Text", "ExpressionUUID" -> \
"d1981c60-6e0a-44cb-8cd4-aa4eb1fe0904"],
Cell[1187544, 31582, 1576, 40, 25740, "Input", "ExpressionUUID" -> \
"c4c007b8-d99e-4fd1-90fa-4fb7ce16d4aa"],
Cell[1189123, 31624, 540, 12, 14518, "Text", "ExpressionUUID" -> \
"34050b5e-b2f8-41bb-acef-88730b1ebc05"],
Cell[1189666, 31638, 281, 8, 8614, "Text", "ExpressionUUID" -> \
"6d079d3e-a2f5-4860-90ab-a5f91b0d38de"],
Cell[1189950, 31648, 981, 27, 14518, "Input", "ExpressionUUID" -> \
"ded4a181-f01f-435a-8e91-9db86b353557"],
Cell[1190934, 31677, 371, 10, 8614, "Input", "ExpressionUUID" -> \
"c51e036d-af99-46de-b576-6375f226919e"],
Cell[1191308, 31689, 437, 11, 8614, "Input", "ExpressionUUID" -> \
"6452f4aa-341e-4857-b824-43b0a1736936"],
Cell[1191748, 31702, 352, 7, 14310, "Text", "ExpressionUUID" -> \
"b35e8035-c0aa-4495-b177-60b3e3253fee"],
Cell[1192103, 31711, 459, 9, 8614, "Input", "ExpressionUUID" -> \
"4b877a18-df9a-415b-afaa-f8eb519de928"]
}, Closed]],
Cell[CellGroupData[{
Cell[1192599, 31725, 493, 7, 53, "Subsection", "ExpressionUUID" -> \
"aeac7398-b3de-4405-8e75-5edec592cb85"],
Cell[1193095, 31734, 434, 8, 115, "Text", "ExpressionUUID" -> \
"122b4519-9c32-47d2-82d9-e27f38f57fe4"],
Cell[1193532, 31744, 178, 4, 49, "Input", "ExpressionUUID" -> \
"c777c63a-6b3a-41d1-a26b-8da41187fc65"],
Cell[1193713, 31750, 262, 6, 49, "Input", "ExpressionUUID" -> \
"25caf269-b02f-45d5-a5af-8ef93e97a5b4"],
Cell[1193978, 31758, 240, 4, 50, "Text", "ExpressionUUID" -> \
"659a003c-b41d-4362-bcf8-ff1ee7db0b2f"],
Cell[1194221, 31764, 468, 10, 5743, "Input", "ExpressionUUID" -> \
"9e493249-3658-45cf-9f67-d984d9d3aa00"],
Cell[1194692, 31776, 466, 10, 5743, "Input", "ExpressionUUID" -> \
"99996f48-763b-4235-9446-8865c3e2fe59"],
Cell[1195161, 31788, 522, 11, 5743, "Input", "ExpressionUUID" -> \
"5b178c1f-2091-46fd-a07b-09dd3a6eef93"],
Cell[1195686, 31801, 875, 24, 9679, "Input", "ExpressionUUID" -> \
"cd57f2a2-b261-46c9-9599-6ac477f0672a"],
Cell[1196564, 31827, 394, 8, 13164, "Text", "ExpressionUUID" -> \
"f52464d1-de9b-425d-a3ca-ae2dc4e8e7ec"],
Cell[1196961, 31837, 1663, 52, 19381, "Input", "ExpressionUUID" -> \
"9d64924d-1f1c-4471-a87f-eebd7751560d"],
Cell[1198627, 31891, 186, 4, 5743, "Input", "ExpressionUUID" -> \
"42bee4d2-060d-496a-bd33-5f88060ec9cc"],
Cell[1198816, 31897, 514, 9, 16921, "Text", "ExpressionUUID" -> \
"30e0a42d-37a5-4c03-9446-aa7d22a86b9a"],
Cell[1199333, 31908, 1152, 31, 13468, "Input", "ExpressionUUID" -> \
"d4bbac51-0a08-4c87-a986-5273a0e0fd90"],
Cell[1200488, 31941, 272, 7, 5743, "Input", "ExpressionUUID" -> \
"c157f3bb-9f58-488b-aa26-abef244f99e8"],
Cell[1200763, 31950, 455, 11, 5743, "Input", "ExpressionUUID" -> \
"479582ec-a09c-4d54-8393-994056c132ae"],
Cell[1201221, 31963, 438, 12, 5743, "Input", "ExpressionUUID" -> \
"82b446fc-0a7e-4a8e-b1e6-ff878997632e"],
Cell[1201662, 31977, 477, 11, 5743, "Input", "ExpressionUUID" -> \
"e17a099e-1326-44a1-82fc-7c68cb562416"],
Cell[1202142, 31990, 438, 12, 5743, "Input", "ExpressionUUID" -> \
"a4148577-a2c8-419f-9cc5-2ec93c548d32"],
Cell[1202583, 32004, 308, 7, 9540, "Text", "ExpressionUUID" -> \
"38ca1005-9287-4baf-887b-1e89623f91c2"],
Cell[1202894, 32013, 179, 4, 5743, "Input", "ExpressionUUID" -> \
"b3d458f5-f751-4916-9458-5fd3e7f38b90"],
Cell[1203076, 32019, 200, 3, 5743, "Text", "ExpressionUUID" -> \
"0a52f071-8bff-4ea7-9ce4-c809a447786c"],
Cell[1203279, 32024, 454, 11, 5743, "Input", "ExpressionUUID" -> \
"90f5b357-1a67-4e33-bf7d-3cd5fa7a79f8"],
Cell[1203736, 32037, 841, 19, 5743, "Input", "ExpressionUUID" -> \
"74e6c3f5-e092-45dc-80a7-785b85710959"],
Cell[1204580, 32058, 417, 8, 9540, "Text", "ExpressionUUID" -> \
"fc8aeb7f-24b8-40fb-b553-aca9a1b84ef8"],
Cell[1205000, 32068, 584, 17, 5743, "Input", "ExpressionUUID" -> \
"bbedc7e2-b5ea-41e5-95ee-992c25487614"],
Cell[1205587, 32087, 244, 6, 5743, "Input", "ExpressionUUID" -> \
"11963e89-27ee-4692-8f80-deaa063acbf8"],
Cell[1205834, 32095, 759, 19, 9679, "Input", "ExpressionUUID" -> \
"93e037ff-24f2-41e3-b0b0-0934491c6e71"],
Cell[1206596, 32116, 806, 20, 9679, "Input", "ExpressionUUID" -> \
"f3c584b1-3517-4f48-b0d4-50472202a53b"],
Cell[1207405, 32138, 906, 21, 9679, "Input", "ExpressionUUID" -> \
"9b3f6f01-f5bc-45c7-b3f5-087a34d52058"],
Cell[1208314, 32161, 555, 16, 5743, "Input", "ExpressionUUID" -> \
"c2ba13e7-40e0-4051-af3b-57bf3a4516f8"],
Cell[1208872, 32179, 300, 8, 5743, "Text", "ExpressionUUID" -> \
"ce2aca4b-e2b2-4902-89cc-477e2532a69a"],
Cell[1209175, 32189, 567, 16, 9679, "Input", "ExpressionUUID" -> \
"31ca92df-e238-403c-8427-2c5368c1ca7a"],
Cell[1209745, 32207, 347, 7, 9540, "Text", "ExpressionUUID" -> \
"a0d03a3e-bdad-4834-aca0-c59a2c19b988"],
Cell[1210095, 32216, 639, 17, 9679, "Input", "ExpressionUUID" -> \
"f8dc5bdb-8837-403d-85d6-25496ad27db2"],
Cell[1210737, 32235, 279, 8, 5743, "Text", "ExpressionUUID" -> \
"838c3b50-dccd-40bb-8ba3-d07b34192d44"],
Cell[1211019, 32245, 662, 18, 9679, "Input", "ExpressionUUID" -> \
"5f558daf-b3ba-4817-9216-d2c7557dff17"],
Cell[1211684, 32265, 422, 11, 9540, "Text", "ExpressionUUID" -> \
"89b2100f-4e09-4389-9088-97312973fc51"],
Cell[1212109, 32278, 641, 17, 9679, "Input", "ExpressionUUID" -> \
"1d43cd84-7716-49db-b804-971d23e08807"],
Cell[1212753, 32297, 349, 7, 9540, "Text", "ExpressionUUID" -> \
"8523c61d-c0a6-4c95-829b-a31dd4178e25"],
Cell[1213105, 32306, 719, 18, 9679, "Input", "ExpressionUUID" -> \
"f96dbddb-468f-44b7-85f4-0cde8491d54e"],
Cell[1213827, 32326, 287, 6, 5743, "Input", "ExpressionUUID" -> \
"d18dd8df-0985-427e-bd68-7cfa214ba855"]
}, Closed]],
Cell[CellGroupData[{
Cell[1214151, 32337, 664, 9, 53, "Subsection", "ExpressionUUID" -> \
"6e036f36-2043-4f2f-8ea5-cd3da5d42425"],
Cell[1214818, 32348, 196, 3, 50, "Text", "ExpressionUUID" -> \
"f819541d-e3e9-4bf0-a971-ecd7f9ede225"],
Cell[1215017, 32353, 263, 7, 49, "Input", "ExpressionUUID" -> \
"b42f1235-ccab-4b4d-a7a1-73db839713df"],
Cell[1215283, 32362, 218, 5, 50, "Text", "ExpressionUUID" -> \
"249a9828-4742-4583-ab8b-5dc5c258c093"],
Cell[1215504, 32369, 627, 14, 73, "Input", "ExpressionUUID" -> \
"e605dd84-3bc2-4358-9a86-72538771d0d7",
 InitializationCell->True],
Cell[1216134, 32385, 283, 6, 3829, "Input", "ExpressionUUID" -> \
"63fa7479-50c2-4f23-aff9-6f8a472e5756"],
Cell[1216420, 32393, 210, 4, 3829, "Text", "ExpressionUUID" -> \
"b3bb31db-8e1d-4731-92c9-6be21f126ed3"],
Cell[1216633, 32399, 1103, 25, 6453, "Input", "ExpressionUUID" -> \
"180c8802-7a56-4803-b7df-713ded432850"],
Cell[1217739, 32426, 260, 6, 3829, "Text", "ExpressionUUID" -> \
"1696c0ac-8b43-4231-aeb0-5fa04967cd81"],
Cell[1218002, 32434, 326, 5, 3829, "Text", "ExpressionUUID" -> \
"33e13320-2f3b-4c6b-8ee9-1798e0b309a6"],
Cell[1218331, 32441, 393, 10, 3829, "Input", "ExpressionUUID" -> \
"137e5ed0-5c40-43aa-af6c-6d4d047b801d"],
Cell[1218727, 32453, 306, 4, 3829, "Text", "ExpressionUUID" -> \
"d9dafea3-91fd-4579-a191-afe02fc702c6"],
Cell[1219036, 32459, 325, 8, 3829, "Input", "ExpressionUUID" -> \
"c6d3f359-73ec-42f0-b3d3-67edb07cc161"],
Cell[1219364, 32469, 198, 3, 3829, "Text", "ExpressionUUID" -> \
"5dadb41c-dfd8-41ac-8a14-6858ce16d895"],
Cell[1219565, 32474, 347, 9, 3829, "Input", "ExpressionUUID" -> \
"97fa2253-4826-4340-9f16-daa53a0fd344"],
Cell[1219915, 32485, 533, 10, 8776, "Text", "ExpressionUUID" -> \
"fe3a3539-4922-4b04-9e23-fd56dd086d42"],
Cell[1220451, 32497, 1735, 52, 11440, "Input", "ExpressionUUID" -> \
"f19b588b-f4be-415d-be48-ec947651c567",
 InitializationCell->True],
Cell[1222189, 32551, 227, 5, 3829, "Input", "ExpressionUUID" -> \
"581b1a88-6515-4330-8e69-0251ccff7dc2"],
Cell[1222419, 32558, 425, 8, 6561, "Text", "ExpressionUUID" -> \
"7e2ff632-70a3-4f14-9007-78fa76c1c10c"],
Cell[1222847, 32568, 1794, 34, 6453, "Input", "ExpressionUUID" -> \
"c532b2f0-f4a2-4d8f-aec8-bbb0f53c604f"],
Cell[1224644, 32604, 215, 3, 3829, "Text", "ExpressionUUID" -> \
"c4d3620e-94ea-4919-9456-b1df4d882e1b"],
Cell[1224862, 32609, 1581, 30, 6453, "Input", "ExpressionUUID" -> \
"9a1ddc35-ff68-4d66-8481-12e564945470"],
Cell[1226446, 32641, 1519, 29, 6453, "Input", "ExpressionUUID" -> \
"04bf0e4b-4e00-4d4f-9911-2fa477049e2b"],
Cell[1227968, 32672, 176, 3, 3829, "Text", "ExpressionUUID" -> \
"f5ffaeb6-586d-41f0-820d-228e70b56e5f"],
Cell[1228147, 32677, 2086, 60, 11440, "Input", "ExpressionUUID" -> \
"f62fb5f9-7c0e-4353-8ed5-f0134f840aba"],
Cell[1230236, 32739, 154, 3, 3829, "Text", "ExpressionUUID" -> \
"6acd6922-94b1-465b-bcd1-91c35b8bdb80"],
Cell[1230393, 32744, 2062, 45, 11440, "Input", "ExpressionUUID" -> \
"cc045246-eaee-49dd-bf96-e3698ca80836"],
Cell[1232458, 32791, 272, 4, 3829, "Text", "ExpressionUUID" -> \
"012c7565-503f-43d2-b48a-89a5c478d7c6"],
Cell[1232733, 32797, 1112, 21, 6453, "Input", "ExpressionUUID" -> \
"090eb5fb-7866-435a-8353-2305f2f611ee"],
Cell[1233848, 32820, 568, 10, 3829, "Text", "ExpressionUUID" -> \
"b19ef9a2-2977-4266-b9d5-1de554cacae3"],
Cell[1234419, 32832, 4894, 142, 20440, "Input", "ExpressionUUID" -> \
"3f3d5774-ac9d-45d9-b57f-b48eda20606e"],
Cell[1239316, 32976, 568, 10, 9019, "Text", "ExpressionUUID" -> \
"00d4d11b-9e24-4a93-94a7-06eeead1525f"],
Cell[1239887, 32988, 922, 19, 6453, "Input", "ExpressionUUID" -> \
"1e61fb05-5377-45be-928d-6ae4d93e6dec"],
Cell[1240812, 33009, 412, 10, 3829, "Input", "ExpressionUUID" -> \
"63157f28-34c6-45ea-a2ae-42d239625133"],
Cell[1241227, 33021, 1045, 22, 6453, "Input", "ExpressionUUID" -> \
"692290b7-b679-4ecf-b467-c1f8bf2bf44a"],
Cell[1242275, 33045, 427, 6, 3829, "Text", "ExpressionUUID" -> \
"b1ceedcb-427d-4d22-a979-82797ad57530"],
Cell[1242705, 33053, 4975, 144, 20394, "Input", "ExpressionUUID" -> \
"5cdf5ff3-5e50-45cd-8349-2a81288f2871"],
Cell[1247683, 33199, 473, 13, 3829, "Input", "ExpressionUUID" -> \
"52a90903-10a1-49f4-a1b7-9113a01ee7e3"],
Cell[1248159, 33214, 1066, 22, 6453, "Input", "ExpressionUUID" -> \
"5aa51158-97ac-4bde-93f8-eaf13d6965ed"],
Cell[1249228, 33238, 340, 7, 6360, "Text", "ExpressionUUID" -> \
"0119b3be-c224-4615-93f4-a85a5f30221e"],
Cell[1249571, 33247, 12102, 350, 40690, "Input", "ExpressionUUID" -> \
"3d7ac983-5996-4834-aea0-ae2da64728a6"],
Cell[1261676, 33599, 288, 7, 3829, "Text", "ExpressionUUID" -> \
"3e22ef9d-d97e-401d-b36f-317214820c74"],
Cell[1261967, 33608, 429, 12, 3829, "Input", "ExpressionUUID" -> \
"0bfbc56d-d24d-4012-8c25-8449aaab9617"],
Cell[1262399, 33622, 500, 13, 6453, "Input", "ExpressionUUID" -> \
"3dd92597-b7ce-4a22-8081-a3532c606ae8"],
Cell[1262902, 33637, 638, 11, 6360, "Text", "ExpressionUUID" -> \
"2c3f709e-bbc1-4d3a-a712-c593511a87f5"],
Cell[1263543, 33650, 5110, 145, 24085, "Input", "ExpressionUUID" -> \
"310b1c95-3dfa-44b2-bd2b-be7289949438",
 InitializationCell->True],
Cell[1268656, 33797, 693, 14, 8776, "Text", "ExpressionUUID" -> \
"3be26655-ad43-4ed2-bb4f-49e6c82559e7"],
Cell[1269352, 33813, 696, 20, 3829, "Input", "ExpressionUUID" -> \
"c0b7be6a-0318-4a82-97b3-49c390bb00cd",
 Evaluatable->False],
Cell[1270051, 33835, 172, 3, 3829, "Text", "ExpressionUUID" -> \
"b017206b-f4c6-4658-97ea-9fdc2e559e3e"],
Cell[1270226, 33840, 1737, 50, 7836, "Input", "ExpressionUUID" -> \
"6c665418-4996-4588-bb5e-c568d427c186",
 Evaluatable->False],
Cell[1271966, 33892, 272, 4, 3829, "Text", "ExpressionUUID" -> \
"be0c7775-6726-40ca-95bc-127cd77fd09b"],
Cell[1272241, 33898, 1010, 28, 4515, "Input", "ExpressionUUID" -> \
"404aed06-b785-4883-8593-9e7982f49729",
 Evaluatable->False],
Cell[1273254, 33928, 951, 16, 3829, "Text", "ExpressionUUID" -> \
"c479a0de-1990-4e92-9201-a957eef82ee0"],
Cell[1274208, 33946, 1833, 51, 11440, "Input", "ExpressionUUID" -> \
"9c37259d-ac33-44e5-9a87-eee795318168"],
Cell[1276044, 33999, 718, 12, 9019, "Text", "ExpressionUUID" -> \
"23ffbc66-21f1-4eae-ba96-c483cb317f30"],
Cell[1276765, 34013, 334, 8, 3829, "Text", "ExpressionUUID" -> \
"d197ca8a-b52f-4a6b-8a49-35ecfbc1d27b"],
Cell[1277102, 34023, 1684, 44, 4164, "Text", "ExpressionUUID" -> \
"bf0544a4-d2a3-4890-8e1a-693f23234f85"],
Cell[1278789, 34069, 208, 4, 3829, "Text", "ExpressionUUID" -> \
"a6c2de0d-8c75-4ba5-b1ed-6921a87ebd61"],
Cell[1279000, 34075, 314, 8, 3829, "Input", "ExpressionUUID" -> \
"af5ccf33-b708-46e7-80fc-c06e5aec2e98"],
Cell[1279317, 34085, 2936, 61, 22005, "Text", "ExpressionUUID" -> \
"9c2b9634-f75e-4b44-a66d-c8cbada5f483"],
Cell[1282256, 34148, 300, 4, 3829, "Text", "ExpressionUUID" -> \
"37d23128-3a75-489c-89bd-7a3d4d61a8e1"],
Cell[1282559, 34154, 1164, 22, 6453, "Input", "ExpressionUUID" -> \
"1eb4aeda-5829-47ef-a996-5eeb210487f6"],
Cell[1283726, 34178, 272, 4, 3829, "Text", "ExpressionUUID" -> \
"6ae081c5-7204-46e3-9987-f1c99817fb08"],
Cell[1284001, 34184, 1537, 33, 8979, "Input", "ExpressionUUID" -> \
"077e624d-5f45-4aea-83a0-35bb86d5971f"],
Cell[1285541, 34219, 637, 14, 3829, "Input", "ExpressionUUID" -> \
"623f8eec-4d79-4422-b5d3-d59363c3a1c5"],
Cell[1286181, 34235, 145, 3, 3829, "Text", "ExpressionUUID" -> \
"e79b014f-e650-4984-9e29-7d90d04f8321"]
}, Closed]],
Cell[CellGroupData[{
Cell[1286363, 34243, 396, 6, 53, "Subsection", "ExpressionUUID" -> \
"8b22a6db-912d-4452-9cfb-d188d5ba53ce"],
Cell[CellGroupData[{
Cell[1286784, 34253, 761, 10, 75, "Subsubsection", "ExpressionUUID" -> \
"3abc168c-34a2-4447-ac4f-468453c34aa0",
 CellTags->"helix"],
Cell[1287548, 34265, 490, 12, 8776, "Text", "ExpressionUUID" -> \
"85ca6593-504e-4fae-8758-24f0511b04e5"],
Cell[1288041, 34279, 276, 7, 3829, "Input", "ExpressionUUID" -> \
"e6c511b1-7795-4518-bb5e-a6919415cd4e"],
Cell[1288320, 34288, 181, 4, 3829, "Input", "ExpressionUUID" -> \
"639f2f7b-c8f1-4915-a878-c8898cc13ca3"],
Cell[1288504, 34294, 366, 9, 3829, "Text", "ExpressionUUID" -> \
"659830d0-3630-4925-a8cf-41d566933c8c"],
Cell[1288873, 34305, 902, 26, 6453, "Input", "ExpressionUUID" -> \
"b5ea359d-4713-440f-9582-75f3911b757f",
 InitializationCell->True],
Cell[1289778, 34333, 597, 12, 13698, "Text", "ExpressionUUID" -> \
"54b38af0-060d-4a6a-a9a7-fa27513f49f0"],
Cell[1290378, 34347, 200, 4, 3829, "Input", "ExpressionUUID" -> \
"030eb3f9-ee16-49f6-ae8a-4e0e543c6ca5"],
Cell[1290581, 34353, 193, 4, 3829, "Input", "ExpressionUUID" -> \
"49490af0-31b8-4231-a8b0-810c0b8507cc"],
Cell[1290777, 34359, 183, 3, 3829, "Text", "ExpressionUUID" -> \
"b2c92de5-7fa4-492e-8c4c-dc36e57a5e9f"],
Cell[1290963, 34364, 563, 14, 3829, "Input", "ExpressionUUID" -> \
"1313255f-e6dd-4a67-afdf-5644f61aba12",
 InitializationCell->True],
Cell[1291529, 34380, 724, 19, 6453, "Input", "ExpressionUUID" -> \
"9761b552-9bf7-4c61-9d82-da738d80d0d3"],
Cell[1292256, 34401, 199, 3, 3829, "Text", "ExpressionUUID" -> \
"a4ff0bcb-7e7a-4f37-a130-47956801fe78"],
Cell[1292458, 34406, 364, 9, 3829, "Input", "ExpressionUUID" -> \
"9e3a19a1-1665-46dd-a7b4-c97959b5d28e"],
Cell[1292825, 34417, 1807, 41, 13627, "Text", "ExpressionUUID" -> \
"9fd54936-98f4-49a3-8ed3-79fad6ce856b"],
Cell[1294635, 34460, 409, 6, 3829, "Text", "ExpressionUUID" -> \
"a1287af2-aab1-460b-a4c6-d4c8decafc6a"],
Cell[1295047, 34468, 715, 21, 6453, "Input", "ExpressionUUID" -> \
"09137a31-fbb7-468a-a6c0-69295c21490c"],
Cell[1295765, 34491, 315, 6, 3829, "Text", "ExpressionUUID" -> \
"5490625b-4ede-4167-876d-0f35d065f3e4"],
Cell[1296083, 34499, 176, 4, 3829, "Input", "ExpressionUUID" -> \
"49763cd1-0c40-4379-90d4-09e266127f7e"],
Cell[1296262, 34505, 300, 4, 3829, "Text", "ExpressionUUID" -> \
"717849df-68c5-4abc-bb44-28a5c3eeec00"],
Cell[1296565, 34511, 683, 18, 6453, "Input", "ExpressionUUID" -> \
"78dfcf1c-c173-41f8-b589-576372c1b1d0",
 Evaluatable->False],
Cell[1297251, 34531, 184, 3, 3829, "Text", "ExpressionUUID" -> \
"485db3bb-bd41-4504-9600-3ed18b1daaf4"],
Cell[1297438, 34536, 1652, 44, 8979, "Input", "ExpressionUUID" -> \
"3327dc66-9dba-4257-872d-115b336f0ce4",
 Evaluatable->False],
Cell[1299093, 34582, 365, 8, 3829, "Text", "ExpressionUUID" -> \
"9312fd8e-e2cb-4c2e-a3e2-a19deeaaa225"],
Cell[1299461, 34592, 1123, 33, 8979, "Input", "ExpressionUUID" -> \
"e9d2d777-faa7-4bbf-bfda-55a3c0c46d2d"],
Cell[1300587, 34627, 177, 3, 3829, "Text", "ExpressionUUID" -> \
"0a90c6da-b76e-43ca-8700-83d69ac99524"],
Cell[1300767, 34632, 548, 15, 3829, "Input", "ExpressionUUID" -> \
"bede6ae6-2569-45df-92a5-1ab55fcf93b6"],
Cell[1301318, 34649, 194, 3, 3937, "Text", "ExpressionUUID" -> \
"a65e6822-85f9-4910-aebe-e522ab0802fd"],
Cell[1301515, 34654, 574, 18, 3829, "Input", "ExpressionUUID" -> \
"3a15e38d-fed4-414b-80b2-f0d653fb54d9",
 Evaluatable->False],
Cell[1302092, 34674, 569, 11, 11281, "Text", "ExpressionUUID" -> \
"a70eab01-dc33-43b8-a9c7-dc4217bd26fb"],
Cell[1302664, 34687, 403, 11, 3829, "Input", "ExpressionUUID" -> \
"5ab042f4-a545-4fe5-a88c-34f1c14c72ed",
 Evaluatable->False],
Cell[1303070, 34700, 157, 3, 3829, "Text", "ExpressionUUID" -> \
"9fa5c3ac-f367-45db-b42c-cf436416c59d"],
Cell[1303230, 34705, 317, 7, 3937, "Text", "ExpressionUUID" -> \
"0d87a6d6-799b-4168-9125-1a2a1f1581b9"],
Cell[1303550, 34714, 427, 10, 6360, "Text", "ExpressionUUID" -> \
"e4e6dfed-df77-4f89-92cd-32558f956714"],
Cell[1303980, 34726, 435, 12, 3829, "Input", "ExpressionUUID" -> \
"762992d7-6675-491d-a990-ae26661d47b6"],
Cell[1304418, 34740, 361, 8, 6561, "Text", "ExpressionUUID" -> \
"78d17517-bd46-41d1-9cf6-c0fa6bbc9f3c"],
Cell[1304782, 34750, 1522, 44, 7242, "Input", "ExpressionUUID" -> \
"7b0e0308-af5c-4cc9-9904-9636a1fdedc2"],
Cell[1306307, 34796, 1315, 40, 7242, "Input", "ExpressionUUID" -> \
"2194694e-b6e2-415c-97de-f4fe297b2554"],
Cell[1307625, 34838, 2798, 49, 39577, "Text", "ExpressionUUID" -> \
"ac8977ea-9533-467f-bfda-d47c28e2acc2"],
Cell[1310426, 34889, 1225, 37, 11440, "Input", "ExpressionUUID" -> \
"d90b29e9-ceae-432f-b92d-9ab654c3c761"],
Cell[1311654, 34928, 382, 10, 3829, "Input", "ExpressionUUID" -> \
"cbb6da1f-76bc-466a-b951-3c6264b2f1fa"],
Cell[1312039, 34940, 331, 9, 3829, "Input", "ExpressionUUID" -> \
"f1dbf0e9-959e-4381-a10f-239712029f19"],
Cell[1312373, 34951, 674, 20, 4302, "Input", "ExpressionUUID" -> \
"84f5468a-6f38-453e-8b0e-9a58e7b3d203"],
Cell[1313050, 34973, 206, 5, 3829, "Input", "ExpressionUUID" -> \
"a0a4fc28-1465-4fa6-88ea-b6b2883ab97f"],
Cell[1313259, 34980, 199, 3, 3829, "Text", "ExpressionUUID" -> \
"3f90d584-4c18-4b42-a080-62679ffe8eb7"],
Cell[1313461, 34985, 309, 8, 3829, "Input", "ExpressionUUID" -> \
"9645ad57-1475-4937-98e8-2b06cc59aaae"],
Cell[1313773, 34995, 206, 4, 3829, "Input", "ExpressionUUID" -> \
"94d5d51d-ba79-43c3-a559-440ea79f10a2"],
Cell[1313982, 35001, 388, 11, 3829, "Input", "ExpressionUUID" -> \
"f0a99ca4-e0b3-462f-8b5c-f4f3754a4cc2"],
Cell[1314373, 35014, 511, 11, 6453, "Text", "ExpressionUUID" -> \
"57f7cf37-3604-435f-bb60-e8611af9a66a"],
Cell[1314887, 35027, 349, 9, 3829, "Input", "ExpressionUUID" -> \
"97543a9c-2ed7-4165-9ad0-141631d1f17f"],
Cell[1315239, 35038, 567, 17, 4302, "Input", "ExpressionUUID" -> \
"fb535442-85aa-4e17-a715-dc1935a91af3"],
Cell[1315809, 35057, 1192, 36, 8092, "Input", "ExpressionUUID" -> \
"e8797b5a-dc4a-4958-86bf-f978aa677f8c"],
Cell[1317004, 35095, 233, 4, 3829, "Text", "ExpressionUUID" -> \
"1e6ce402-71c1-4d4c-a866-8fea282cfd2c"],
Cell[1317240, 35101, 539, 13, 3829, "Input", "ExpressionUUID" -> \
"f8716ab6-3e70-4746-bbb3-b7d2b90a9998"],
Cell[1317782, 35116, 849, 13, 14154, "Text", "ExpressionUUID" -> \
"4225a8a5-e059-4e8c-9edd-6c6ca9d3120c"],
Cell[1318634, 35131, 1001, 24, 6453, "Input", "ExpressionUUID" -> \
"1ae616ac-343c-432b-85fe-7a82fcfe6525"],
Cell[1319638, 35157, 273, 6, 3829, "Input", "ExpressionUUID" -> \
"c0508009-d498-4a37-8264-dd7aeb95ac44"],
Cell[1319914, 35165, 169, 3, 3829, "Text", "ExpressionUUID" -> \
"68f53635-4a53-44bb-be5e-d55341ff8568"],
Cell[1320086, 35170, 256, 6, 3829, "Input", "ExpressionUUID" -> \
"606f8ac9-76f1-45ad-a42d-dfdf3a8bb90b"],
Cell[1320345, 35178, 182, 3, 3829, "Text", "ExpressionUUID" -> \
"d6fb389b-f041-44d6-aedb-438f7f7807b5"],
Cell[1320530, 35183, 631, 17, 6453, "Input", "ExpressionUUID" -> \
"1f49d360-038e-482a-ba62-61d4af7274b7"],
Cell[1321164, 35202, 381, 7, 6453, "Text", "ExpressionUUID" -> \
"9953fa9d-da1e-46c3-850e-6174a8192779"],
Cell[1321548, 35211, 296, 8, 3829, "Text", "ExpressionUUID" -> \
"11ae6156-d1ce-4503-ba72-c53ff18f4b42"],
Cell[1321847, 35221, 211, 3, 3829, "Text", "ExpressionUUID" -> \
"3ec7a398-e104-4365-9652-758d7c0dea66"],
Cell[1322061, 35226, 722, 19, 6453, "Input", "ExpressionUUID" -> \
"649ee725-0864-4db0-8cf1-11321e3dc080"],
Cell[1322786, 35247, 215, 3, 3829, "Text", "ExpressionUUID" -> \
"90ea5e3f-e2e7-4807-9055-c11450854e4d"],
Cell[1323004, 35252, 866, 22, 6453, "Input", "ExpressionUUID" -> \
"1e99b8e8-d1df-43b8-af86-993f982ec6d1"],
Cell[1323873, 35276, 197, 5, 3829, "Input", "ExpressionUUID" -> \
"0cc9b891-9dbc-4165-b53d-244345369446"],
Cell[1324073, 35283, 181, 3, 3937, "Text", "ExpressionUUID" -> \
"13ef21ed-1f41-41e3-9074-dc02a8439b70"],
Cell[1324257, 35288, 611, 16, 6453, "Input", "ExpressionUUID" -> \
"eab1def3-e37d-4c32-baed-435db2af6abb"],
Cell[1324871, 35306, 195, 5, 3829, "Input", "ExpressionUUID" -> \
"4c38b351-1046-4c0f-a22d-4d136be9fa93"],
Cell[1325069, 35313, 350, 9, 3829, "Input", "ExpressionUUID" -> \
"481158ef-2f0c-42a5-89a7-b3add3edbf36"],
Cell[1325422, 35324, 183, 3, 3829, "Text", "ExpressionUUID" -> \
"65d9795f-0b3f-415e-8bbb-91bd8adb0520"],
Cell[1325608, 35329, 420, 11, 3829, "Input", "ExpressionUUID" -> \
"16872825-2bfa-4a1e-8d04-5d282e3ef69b"],
Cell[1326031, 35342, 291, 8, 3829, "Input", "ExpressionUUID" -> \
"ee52461a-dfd6-4dbe-92f9-c6750b922f04"],
Cell[1326325, 35352, 181, 3, 3829, "Text", "ExpressionUUID" -> \
"fe46952b-94ea-4a54-b4ff-51490c209ada"],
Cell[1326509, 35357, 346, 9, 3829, "Input", "ExpressionUUID" -> \
"b3663b11-f839-4df7-b74d-29626e57f1b6"],
Cell[1326858, 35368, 532, 13, 6453, "Input", "ExpressionUUID" -> \
"88bb3321-4454-439f-8eb4-ee5c114b34c9"],
Cell[1327393, 35383, 312, 8, 3829, "Input", "ExpressionUUID" -> \
"0df1b864-9298-408e-83ff-da1764a2e43b"],
Cell[1327708, 35393, 357, 8, 8857, "Text", "ExpressionUUID" -> \
"07fe3b26-1409-4827-b2e0-a0e62b05114b"]
}, Closed]],
Cell[CellGroupData[{
Cell[1328102, 35406, 800, 10, 64, "Subsubsection", "ExpressionUUID" -> \
"c46a0b57-65b8-4ab5-a5a6-aacc53df653a",
 CellTags->"helix"],
Cell[1328905, 35418, 402, 6, 3829, "Text", "ExpressionUUID" -> \
"58b81182-c165-4902-a59c-256627f06633"],
Cell[1329310, 35426, 683, 15, 3829, "Input", "ExpressionUUID" -> \
"9b76a9cc-5d76-42d0-a361-355cc7835bdf",
 InitializationCell->True],
Cell[1329996, 35443, 207, 4, 3829, "Input", "ExpressionUUID" -> \
"626c8f83-bd8f-45be-909f-293911148043"],
Cell[1330206, 35449, 315, 7, 6360, "Text", "ExpressionUUID" -> \
"2b0de31a-57e2-42d9-91d5-72cec5a7c772"],
Cell[1330524, 35458, 513, 12, 3829, "Input", "ExpressionUUID" -> \
"0ff3451e-f767-487e-b8e6-9fca0601398a"],
Cell[1331040, 35472, 489, 13, 3829, "Input", "ExpressionUUID" -> \
"f100ddf3-6560-4898-ad18-202a9806b1a0"],
Cell[1331532, 35487, 253, 6, 3829, "Input", "ExpressionUUID" -> \
"e8b42bfb-607e-4232-a077-39ca5f0b9d46"],
Cell[1331788, 35495, 821, 16, 3829, "Input", "ExpressionUUID" -> \
"6d3e120f-f86d-4f91-b3cb-9834a6d44331",
 InitializationCell->True],
Cell[1332612, 35513, 299, 7, 3829, "Input", "ExpressionUUID" -> \
"1fa465d0-ee6c-40e7-b995-6a61792ef7af"],
Cell[1332914, 35522, 179, 3, 3829, "Text", "ExpressionUUID" -> \
"d700cab9-b05e-41ba-b4bf-fc83261895ba"],
Cell[1333096, 35527, 751, 19, 6453, "Input", "ExpressionUUID" -> \
"47f764c2-889c-49f0-bb44-bf6beb9922f0"],
Cell[1333850, 35548, 199, 5, 3829, "Input", "ExpressionUUID" -> \
"c05daa15-2da9-4f22-ba69-c7df038dd540"],
Cell[1334052, 35555, 447, 10, 3829, "Input", "ExpressionUUID" -> \
"dbcea7ce-6d94-48c5-b7b8-03354c3d7657"],
Cell[1334502, 35567, 550, 10, 6360, "Text", "ExpressionUUID" -> \
"f744f1e3-d2b1-423b-aaab-be045f07b8f9"],
Cell[1335055, 35579, 833, 19, 6453, "Input", "ExpressionUUID" -> \
"79c6552b-3979-4dba-8872-ae9db911090d"],
Cell[1335891, 35600, 349, 9, 3829, "Input", "ExpressionUUID" -> \
"43612062-929c-4bc2-82e4-b68e82131787"],
Cell[1336243, 35611, 203, 5, 3829, "Input", "ExpressionUUID" -> \
"0f08379c-de22-4965-886a-5ba0805e4300"],
Cell[1336449, 35618, 448, 10, 3829, "Input", "ExpressionUUID" -> \
"2bd761fc-0370-452d-859d-210a97dc9894"],
Cell[1336900, 35630, 213, 3, 3829, "Text", "ExpressionUUID" -> \
"5dfebd71-1d24-4a1b-8ce1-d57f3f9e2f1f"],
Cell[1337116, 35635, 911, 21, 6453, "Input", "ExpressionUUID" -> \
"bf6c48f9-d0ff-43bd-b73d-817c1fbf2102"],
Cell[1338030, 35658, 349, 9, 3829, "Input", "ExpressionUUID" -> \
"498d0422-e8fd-488a-8cb3-a431bfbaa31c"],
Cell[1338382, 35669, 199, 5, 3829, "Input", "ExpressionUUID" -> \
"430596c7-e71f-4271-abdd-5c8f58b3c0c6"],
Cell[1338584, 35676, 241, 6, 3829, "Input", "ExpressionUUID" -> \
"60e08c10-e64c-4fc7-a2ef-9616453a06ef"],
Cell[1338828, 35684, 520, 11, 3829, "Input", "ExpressionUUID" -> \
"9f3ce5eb-aa95-4979-b860-225ef4991561"],
Cell[1339351, 35697, 502, 9, 6561, "Text", "ExpressionUUID" -> \
"df05e845-4e45-4597-9266-f0258f0db9d1"],
Cell[1339856, 35708, 301, 8, 3829, "Input", "ExpressionUUID" -> \
"6d810bb8-90c9-44a6-a820-ab728f96034c"],
Cell[1340160, 35718, 233, 6, 3829, "Text", "ExpressionUUID" -> \
"87260e89-7b9c-498f-af2d-47607e7036f3"],
Cell[1340396, 35726, 315, 9, 3829, "Input", "ExpressionUUID" -> \
"be9d086d-c2ca-46b3-a763-2b1998b99233"],
Cell[1340714, 35737, 277, 8, 3829, "Input", "ExpressionUUID" -> \
"53df1c57-8aae-445f-bc6c-89292d5fd329"],
Cell[1340994, 35747, 394, 10, 3829, "Input", "ExpressionUUID" -> \
"b2e15d87-7010-42ce-9e84-f43e996c1027"],
Cell[1341391, 35759, 1780, 59, 32847, "Input", "ExpressionUUID" -> \
"43e55912-7a44-45d4-b036-1000d17c8b3c"],
Cell[1343174, 35820, 175, 3, 3829, "Text", "ExpressionUUID" -> \
"87d8d09a-b442-40e7-8195-0662fcb172f7"],
Cell[1343352, 35825, 997, 21, 6453, "Input", "ExpressionUUID" -> \
"19ca7392-1b43-4ccf-be9f-80b7a6f5cb16"],
Cell[1344352, 35848, 270, 4, 3829, "Text", "ExpressionUUID" -> \
"ce7ae744-e7ef-4600-aa1f-bcc764551731"],
Cell[1344625, 35854, 1095, 24, 6453, "Input", "ExpressionUUID" -> \
"fd2683ed-3a5b-472c-b949-418799f007b5"],
Cell[1345723, 35880, 349, 9, 3829, "Input", "ExpressionUUID" -> \
"b854a0fd-d915-4214-9f99-b9559faaf8c7"],
Cell[1346075, 35891, 250, 6, 3829, "Input", "ExpressionUUID" -> \
"f117f890-36d0-470f-a655-b6d62c1fb8c7"],
Cell[1346328, 35899, 236, 6, 3829, "Text", "ExpressionUUID" -> \
"d022bdd9-4ece-4b4b-bb64-c1af5e660cd5"],
Cell[1346567, 35907, 671, 17, 6453, "Input", "ExpressionUUID" -> \
"4feb8e61-b798-4f93-82a9-1d43791058ad"],
Cell[1347241, 35926, 671, 17, 6453, "Input", "ExpressionUUID" -> \
"065fac43-ed50-4408-b243-15e49d507920"],
Cell[1347915, 35945, 576, 14, 3829, "Input", "ExpressionUUID" -> \
"acbc32e1-3c5e-4c7d-911b-de38d8370348"],
Cell[1348494, 35961, 182, 3, 3829, "Text", "ExpressionUUID" -> \
"1a83b050-06b9-4fe2-aaac-a38558780c9f"],
Cell[1348679, 35966, 305, 8, 3829, "Input", "ExpressionUUID" -> \
"74e2f9e5-05ba-45de-b5ba-e4dedb5069f9"],
Cell[1348987, 35976, 187, 3, 3829, "Text", "ExpressionUUID" -> \
"69d3369f-39a4-474f-b549-7ad668bc7c2f"],
Cell[1349177, 35981, 599, 18, 7627, "Input", "ExpressionUUID" -> \
"3ee93ead-526d-4c7d-ba8e-ad2d37ddc8e6"],
Cell[1349779, 36001, 222, 5, 3829, "Input", "ExpressionUUID" -> \
"a6138fa8-1a91-4a98-b74b-8231482455c7"],
Cell[1350004, 36008, 169, 3, 3829, "Text", "ExpressionUUID" -> \
"c3f7ec30-3989-468b-b9e6-69300843f8e6"],
Cell[1350176, 36013, 1015, 20, 6453, "Input", "ExpressionUUID" -> \
"ee91bdfe-1c40-4500-8555-a9393282ad20"],
Cell[1351194, 36035, 236, 6, 3829, "Input", "ExpressionUUID" -> \
"f8174e20-1bd4-4302-808f-834a1eafca47"],
Cell[1351433, 36043, 258, 6, 6360, "Text", "ExpressionUUID" -> \
"a255086c-b96b-4d4b-96bf-bfc0d34017f5"],
Cell[1351694, 36051, 707, 22, 3829, "Input", "ExpressionUUID" -> \
"3b4ed540-e89a-4cd5-9988-bf8bb98b55e9"],
Cell[1352404, 36075, 1156, 24, 6453, "Input", "ExpressionUUID" -> \
"18cad79c-e335-418b-8973-0384b4bae424"],
Cell[1353563, 36101, 314, 8, 3829, "Input", "ExpressionUUID" -> \
"3e1aed5e-5f96-4036-aa3e-013286714536"],
Cell[1353880, 36111, 306, 7, 6360, "Text", "ExpressionUUID" -> \
"8e1031a1-617f-4532-9f5c-93519902334b"],
Cell[1354189, 36120, 403, 10, 3829, "Input", "ExpressionUUID" -> \
"92df50b8-7d43-4aad-862a-06b58a963585"],
Cell[1354595, 36132, 906, 30, 18820, "Input", "ExpressionUUID" -> \
"c2e80687-2e5f-4506-93c2-1076c6dfe635"],
Cell[1355504, 36164, 348, 9, 3829, "Input", "ExpressionUUID" -> \
"233f2d5e-a4a8-4c49-b930-2f20794ebd9b"],
Cell[1355855, 36175, 455, 11, 3829, "Input", "ExpressionUUID" -> \
"772437cf-15a1-4d46-9b6c-4d31843fe2ff"],
Cell[1356313, 36188, 159, 3, 3829, "Input", "ExpressionUUID" -> \
"0f4a4f01-1b7f-4bb9-a2e7-6167d7bb932d"],
Cell[1356475, 36193, 657, 18, 10053, "Input", "ExpressionUUID" -> \
"ef6be350-e8b5-4382-aebf-ddc56da9758d"],
Cell[1357135, 36213, 345, 8, 6360, "Text", "ExpressionUUID" -> \
"3dfc5b2f-5e38-4047-9180-832a5cf7eebb"]
}, Closed]],
Cell[CellGroupData[{
Cell[1357517, 36226, 487, 7, 42, "Subsubsection", "ExpressionUUID" -> \
"36b19020-0264-4ce9-8515-7548bc556fce"],
Cell[1358007, 36235, 514, 11, 2827, "Text", "ExpressionUUID" -> \
"5a571e04-32ef-462a-935d-c1eb7230a920"],
Cell[1358524, 36248, 820, 21, 1702, "Input", "ExpressionUUID" -> \
"e1597b84-eb41-4c61-872d-1d3c9a101008",
 Evaluatable->False],
Cell[1359347, 36271, 277, 5, 1702, "Input", "ExpressionUUID" -> \
"7194ff86-43e6-4bf5-8789-4790b9879cac"],
Cell[1359627, 36278, 194, 4, 1702, "Input", "ExpressionUUID" -> \
"85bfce1c-9775-4639-920b-4e544ad4df32"],
Cell[1359824, 36284, 287, 7, 1702, "Text", "ExpressionUUID" -> \
"2d55fa0f-8765-46bc-a6b1-236ebff42e03"],
Cell[1360114, 36293, 358, 9, 1702, "Input", "ExpressionUUID" -> \
"fb3c5595-497b-4d1b-9dcc-127bc3b2fe87"],
Cell[1360475, 36304, 319, 6, 1702, "Text", "ExpressionUUID" -> \
"03ab4443-1d50-4e7c-a02e-3f488f8994ef"],
Cell[1360797, 36312, 335, 9, 1702, "Input", "ExpressionUUID" -> \
"553974a7-45e9-44bf-bff9-a73a7c8f670e"],
Cell[1361135, 36323, 276, 4, 1702, "Text", "ExpressionUUID" -> \
"0d589dc5-cb3a-4330-94e2-0407efd212f7"],
Cell[1361414, 36329, 469, 12, 1702, "Input", "ExpressionUUID" -> \
"9ef1fb61-3ff6-4884-80a0-47740dfb5558"],
Cell[1361886, 36343, 283, 6, 2827, "Text", "ExpressionUUID" -> \
"82964cd4-33f3-4938-be3c-1a8d45dbf961"],
Cell[1362172, 36351, 363, 10, 1702, "Input", "ExpressionUUID" -> \
"faf493df-bbfe-4c59-a8c2-3799f3f4f931"],
Cell[1362538, 36363, 348, 8, 1702, "Text", "ExpressionUUID" -> \
"40d48265-fa29-4211-835f-212ecfd305cb"],
Cell[1362889, 36373, 209, 5, 1702, "Input", "ExpressionUUID" -> \
"54f0deeb-e112-4e3a-b5b7-645c30755c60"],
Cell[1363101, 36380, 846, 16, 6088, "Text", "ExpressionUUID" -> \
"d073f027-9763-411e-b026-70e388d5125b"],
Cell[1363950, 36398, 626, 14, 1702, "Input", "ExpressionUUID" -> \
"03196883-6324-4b8a-b892-ddc52117aee5"],
Cell[1364579, 36414, 445, 9, 1702, "Text", "ExpressionUUID" -> \
"d2187819-78ac-45ae-9876-84c5564e35d0"],
Cell[1365027, 36425, 1402, 34, 1851, "Text", "ExpressionUUID" -> \
"49bb287e-ca04-4a3c-a7b5-87cc3c059670"],
Cell[1366432, 36461, 401, 8, 2916, "Text", "ExpressionUUID" -> \
"05bddabf-437f-4d2a-a429-775df1744de2"],
Cell[1366836, 36471, 542, 15, 1702, "Input", "ExpressionUUID" -> \
"a8a87f71-3fc5-4483-baa4-a8ca537d6ffa",
 Evaluatable->False],
Cell[1367381, 36488, 379, 7, 2827, "Text", "ExpressionUUID" -> \
"7bedcc40-fa4a-410a-ae85-5750cab11b07"],
Cell[1367763, 36497, 885, 23, 2007, "Input", "ExpressionUUID" -> \
"e8e0218c-834d-4ead-8b05-630ab03f998e",
 Evaluatable->False],
Cell[1368651, 36522, 351, 7, 2827, "Text", "ExpressionUUID" -> \
"a0d1fc13-d9da-4747-9c00-aa8508233ce6"],
Cell[1369005, 36531, 1430, 37, 2007, "Input", "ExpressionUUID" -> \
"7b3b4aba-c3b3-4020-ac34-fb7b51f62f44",
 Evaluatable->False],
Cell[1370438, 36570, 540, 12, 2916, "Text", "ExpressionUUID" -> \
"debdfb0b-db3a-4ae8-a235-87fb65b8fffd"],
Cell[1370981, 36584, 519, 13, 1702, "Input", "ExpressionUUID" -> \
"04883c07-1aef-40cb-9797-f69770bd213a",
 Evaluatable->False],
Cell[1371503, 36599, 251, 4, 1702, "Text", "ExpressionUUID" -> \
"78aa325b-3b83-4011-bb94-8d0975bb2731"],
Cell[1371757, 36605, 822, 26, 2868, "Input", "ExpressionUUID" -> \
"83d147fc-917d-49db-950f-386b2d604624",
 Evaluatable->False],
Cell[1372582, 36633, 378, 7, 2827, "Text", "ExpressionUUID" -> \
"bc2dcd13-f234-42bb-8028-a9cd0f2a9d31"],
Cell[1372963, 36642, 1006, 30, 3991, "Input", "ExpressionUUID" -> \
"16a0f3c2-286f-4d1a-ade7-00c2ecd623d4"],
Cell[1373972, 36674, 764, 18, 3991, "Text", "ExpressionUUID" -> \
"c78510d1-f278-4685-ba88-eb6e2dd318ac"],
Cell[1374739, 36694, 1371, 35, 2868, "Input", "ExpressionUUID" -> \
"5b714dda-e38d-45da-81e9-a2ad490c4550"],
Cell[1376113, 36731, 1105, 20, 8518, "Text", "ExpressionUUID" -> \
"1a71dea2-4570-4a26-83af-c93b10844400"],
Cell[1377221, 36753, 771, 20, 5166, "Text", "ExpressionUUID" -> \
"73f42006-6c68-49e7-9e52-ee86f830068b"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1378041, 36779, 324, 5, 67, "Subsection", "ExpressionUUID" -> \
"82743fe3-2c5e-4ece-be6c-970ece2598fd"],
Cell[1378368, 36786, 1446, 21, 310, "Text", "ExpressionUUID" -> \
"9a1e1fc7-a667-4031-9458-e768ab9f5c8c"],
Cell[CellGroupData[{
Cell[1379839, 36811, 487, 7, 53, "Subsubsection", "ExpressionUUID" -> \
"46a71205-93f6-4f60-b2cd-264cb7810502"],
Cell[1380329, 36820, 379, 8, 4240, "Text", "ExpressionUUID" -> \
"7da5e862-aa09-4973-ba3a-aa5ce34dbc09"],
Cell[1380711, 36830, 697, 19, 2553, "Input", "ExpressionUUID" -> \
"78acdcef-3d34-46be-841b-3a35d5c65943",
 InitializationCell->True],
Cell[1381411, 36851, 431, 9, 2553, "Input", "ExpressionUUID" -> \
"50b1290d-fe4b-4a75-8208-871b09816cb5"],
Cell[1381845, 36862, 319, 8, 2553, "Text", "ExpressionUUID" -> \
"834c3963-7b4c-4e2b-9bb2-d9bdf5719d59"],
Cell[1382167, 36872, 549, 12, 2553, "Input", "ExpressionUUID" -> \
"455fc558-bc48-4116-a63b-b482bd1ce61a"],
Cell[1382719, 36886, 186, 3, 2553, "Text", "ExpressionUUID" -> \
"3a774f71-bf64-4485-aa03-f678535677f1"],
Cell[1382908, 36891, 412, 9, 2553, "Input", "ExpressionUUID" -> \
"b50ca1f2-99e7-4d1f-a32a-fbb87d4ff44b"],
Cell[1383323, 36902, 238, 6, 2553, "Input", "ExpressionUUID" -> \
"1f8b9a2c-6031-492a-8f10-3560351d5a3a"],
Cell[1383564, 36910, 176, 4, 2553, "Input", "ExpressionUUID" -> \
"f28d7f15-c3f3-4f7d-ad29-bab56cc83e1f"],
Cell[1383743, 36916, 314, 8, 2553, "Input", "ExpressionUUID" -> \
"8825b89d-1b18-4918-9ce8-c6228cdce506"],
Cell[1384060, 36926, 473, 12, 2553, "Input", "ExpressionUUID" -> \
"88cd2e53-e643-4655-9ed9-6b75b3442164"],
Cell[1384536, 36940, 243, 7, 2553, "Input", "ExpressionUUID" -> \
"8d4f28f0-0be3-4eae-8b72-b02055e3276c"],
Cell[1384782, 36949, 300, 9, 2553, "Input", "ExpressionUUID" -> \
"1104f88a-f3d7-466d-bdc7-018085289cc0"],
Cell[1385085, 36960, 1281, 25, 2553, "Input", "ExpressionUUID" -> \
"558ae2d1-6e78-4b06-9ba6-614a8053d930"],
Cell[1386369, 36987, 1237, 25, 4302, "Input", "ExpressionUUID" -> \
"c5943a66-f6fd-415f-9259-1c5f3dfed6b5"],
Cell[1387609, 37014, 176, 3, 2553, "Text", "ExpressionUUID" -> \
"e64e42d7-4f79-4142-817c-ece6e3cbf455"],
Cell[1387788, 37019, 317, 8, 2553, "Input", "ExpressionUUID" -> \
"cc695911-80c7-40ef-a629-75b179f6456f",
 InitializationCell->True],
Cell[1388108, 37029, 193, 5, 2553, "Input", "ExpressionUUID" -> \
"96baec23-7170-4609-a879-fd99487e3511"],
Cell[1388304, 37036, 1633, 32, 4302, "Input", "ExpressionUUID" -> \
"380cbe50-4bd2-4936-92c3-b674a37844a4"],
Cell[1389940, 37070, 340, 9, 2553, "Input", "ExpressionUUID" -> \
"3acea782-5aae-494f-a7e8-68fa2ba1f59e"],
Cell[1390283, 37081, 1533, 29, 4302, "Input", "ExpressionUUID" -> \
"8f1eeb06-e894-4db9-a309-6c571788253c"],
Cell[1391819, 37112, 319, 7, 4240, "Text", "ExpressionUUID" -> \
"9535dee6-f819-4d53-838a-c182120ed2f3"],
Cell[1392141, 37121, 735, 20, 2553, "Input", "ExpressionUUID" -> \
"2fcc1cb2-7952-4282-b934-17af242e174d"],
Cell[1392879, 37143, 388, 7, 4374, "Text", "ExpressionUUID" -> \
"88ab18e7-d4c4-4d52-bb73-3f117a611170"],
Cell[1393270, 37152, 614, 16, 2553, "Input", "ExpressionUUID" -> \
"5f150cff-686f-42fa-a565-583ec7415a51"],
Cell[1393887, 37170, 230, 4, 2553, "Text", "ExpressionUUID" -> \
"d988db5e-e73b-4b7f-8dc8-339c6ac60cc1"],
Cell[1394120, 37176, 590, 19, 2553, "Input", "ExpressionUUID" -> \
"bc801e33-3641-4a97-82a0-e8f88eaced00"],
Cell[1394713, 37197, 430, 8, 5851, "Text", "ExpressionUUID" -> \
"956b113f-bfc4-4dba-af42-f2f49f0d3b18"],
Cell[1395146, 37207, 524, 15, 2553, "Input", "ExpressionUUID" -> \
"059bb68a-92d4-4a91-b466-bd9d10c16131"],
Cell[1395673, 37224, 1157, 32, 5986, "Input", "ExpressionUUID" -> \
"95373f55-845f-4a29-8a7c-f1ca5c2389c0"],
Cell[1396833, 37258, 522, 15, 2553, "Input", "ExpressionUUID" -> \
"f58a63a0-cf65-4224-9d06-13fba2821a53"],
Cell[1397358, 37275, 1348, 37, 5986, "Input", "ExpressionUUID" -> \
"acf4df47-4251-40b0-9d92-b9512bf6c4c8"],
Cell[1398709, 37314, 1316, 34, 7627, "Input", "ExpressionUUID" -> \
"73fb1aee-a8a3-496d-99b7-ce243006def1"],
Cell[1400028, 37350, 1154, 29, 11440, "Input", "ExpressionUUID" -> \
"a71207df-ada9-4a47-9001-36fbc1ef3b7e"],
Cell[1401185, 37381, 1355, 34, 11440, "Input", "ExpressionUUID" -> \
"592fe328-b4ae-4864-844b-d933175ef08b"],
Cell[1402543, 37417, 1254, 31, 8979, "Input", "ExpressionUUID" -> \
"cabc9971-df6b-4a9c-991e-600ef5cceb6f"],
Cell[1403800, 37450, 481, 11, 3829, "Input", "ExpressionUUID" -> \
"a37d95ef-dff8-4888-a712-8654cf437739"],
Cell[1404284, 37463, 1044, 28, 8979, "Input", "ExpressionUUID" -> \
"f2339c18-abdb-451a-8136-a1a45368538a"],
Cell[1405331, 37493, 729, 17, 6453, "Input", "ExpressionUUID" -> \
"4fd9207a-d933-4334-bcb6-63da0db01f1b"],
Cell[1406063, 37512, 445, 10, 6561, "Text", "ExpressionUUID" -> \
"2953cff4-9b5a-4fdd-94b4-38a7078e2119"],
Cell[1406511, 37524, 1135, 29, 8979, "Input", "ExpressionUUID" -> \
"67b51bb4-6ea3-45b4-ba43-8ebe4e277a5e"],
Cell[1407649, 37555, 790, 15, 13698, "Text", "ExpressionUUID" -> \
"dd6a4988-99f8-4e2b-9b13-ba8f11b1b28f"],
Cell[1408442, 37572, 1231, 31, 8979, "Input", "ExpressionUUID" -> \
"0012f8c0-66c0-4ba1-a574-7061cd785e0c"],
Cell[1409676, 37605, 250, 7, 3829, "Input", "ExpressionUUID" -> \
"5a5ea414-2a46-4fdf-98b0-c766fa22d3d8"],
Cell[1409929, 37614, 237, 5, 3829, "Text", "ExpressionUUID" -> \
"c3b947b7-cf23-4925-8255-f8519aac4b15"],
Cell[1410169, 37621, 371, 10, 3829, "Input", "ExpressionUUID" -> \
"6cf6aa32-4526-451f-a592-d6b4a9420613"],
Cell[1410543, 37633, 410, 8, 6360, "Text", "ExpressionUUID" -> \
"a4d4871e-7ee6-4548-bf64-1659f9319d55"],
Cell[1410956, 37643, 180, 4, 3829, "Input", "ExpressionUUID" -> \
"a908b819-1be4-4676-87a7-fae49e1bca88"],
Cell[1411139, 37649, 1061, 25, 11440, "Input", "ExpressionUUID" -> \
"8c76754a-4228-43e5-a499-77bbaccc992c"],
Cell[1412203, 37676, 696, 12, 6561, "Text", "ExpressionUUID" -> \
"222a565d-3d58-4faa-a594-4828d85f097f"],
Cell[1412902, 37690, 583, 14, 3829, "Input", "ExpressionUUID" -> \
"b4e3f01e-c3f7-4c56-9f24-c014ec0011cc"],
Cell[1413488, 37706, 734, 12, 11544, "Text", "ExpressionUUID" -> \
"0cf9aeba-45f6-4cd4-92ac-ac22696e6120"],
Cell[1414225, 37720, 318, 8, 3829, "Input", "ExpressionUUID" -> \
"90a6d5da-64bf-46c0-aaaf-c78d7294a2f6"],
Cell[1414546, 37730, 1034, 30, 7242, "Input", "ExpressionUUID" -> \
"1dfeee9f-3163-42ea-9e44-68653e5bc8af"],
Cell[1415583, 37762, 1141, 31, 7242, "Input", "ExpressionUUID" -> \
"623355ca-e2dc-42e9-87e8-39a4aa6ed584"]
}, Closed]],
Cell[CellGroupData[{
Cell[1416761, 37798, 455, 7, 42, "Subsubsection", "ExpressionUUID" -> \
"7ec45c47-32b7-44fe-9ee6-813303ee0015"],
Cell[1417219, 37807, 1315, 24, 13698, "Text", "ExpressionUUID" -> \
"a49f22f4-32d7-4119-aca4-5ccff7874c3c",
 CellTags->"sfrev"],
Cell[1418537, 37833, 174, 4, 3829, "Input", "ExpressionUUID" -> \
"04759584-fd9a-445a-a8e7-2461d39c7ac6"],
Cell[1418714, 37839, 407, 12, 3829, "Input", "ExpressionUUID" -> \
"daf9207c-7cf6-42cd-a5b4-8425d0499d48",
 InitializationCell->True],
Cell[1419124, 37853, 211, 6, 3829, "Input", "ExpressionUUID" -> \
"e53e3187-48aa-4b63-bbda-ab2e0bf31e21"],
Cell[1419338, 37861, 179, 3, 3829, "Text", "ExpressionUUID" -> \
"c68ad75d-8a2c-46ff-a82e-e12d6e54bb34"],
Cell[1419520, 37866, 329, 8, 3829, "Input", "ExpressionUUID" -> \
"80037f1d-0579-483f-8fe8-fec70328f2bf"],
Cell[1419852, 37876, 329, 8, 3829, "Input", "ExpressionUUID" -> \
"abede640-e9fb-4119-8679-fdd04fc10794"],
Cell[1420184, 37886, 259, 6, 6360, "Text", "ExpressionUUID" -> \
"46fabf91-b841-4ece-9c50-1f6f400e83c9"],
Cell[1420446, 37894, 236, 6, 3829, "Input", "ExpressionUUID" -> \
"045871d7-67be-41e4-af84-cf047c2a6ec9"],
Cell[1420685, 37902, 255, 6, 6360, "Text", "ExpressionUUID" -> \
"706583ef-5c8b-46e1-9194-5f5a8b523018"],
Cell[1420943, 37910, 1370, 33, 7242, "Input", "ExpressionUUID" -> \
"badb86e9-946c-448f-8240-1cf374db83b1"],
Cell[1422316, 37945, 153, 3, 3829, "Text", "ExpressionUUID" -> \
"28d3dc66-fd67-4b9c-8f88-cc928c0e24d7"],
Cell[1422472, 37950, 1207, 27, 4302, "Input", "ExpressionUUID" -> \
"380f8eb4-5f10-47d1-b06f-a0aa5fbe159c"],
Cell[1423682, 37979, 167, 3, 3829, "Text", "ExpressionUUID" -> \
"217622f5-5e06-447b-a481-fc8cd38a1d17"],
Cell[1423852, 37984, 1180, 33, 6702, "Input", "ExpressionUUID" -> \
"f3070a4a-1031-4f55-a9f6-28a7adb4e098"],
Cell[1425035, 38019, 180, 4, 3829, "Input", "ExpressionUUID" -> \
"5ab8af37-0a70-49dc-9ba6-83ee8396188c"],
Cell[1425218, 38025, 1153, 32, 6702, "Input", "ExpressionUUID" -> \
"eea564f0-45b5-4c0e-a5c5-f2e1660b1087"],
Cell[1426374, 38059, 185, 4, 3829, "Input", "ExpressionUUID" -> \
"4586537b-22a2-47c6-ba82-33173d1f0b4d"],
Cell[1426562, 38065, 217, 5, 3829, "Text", "ExpressionUUID" -> \
"2730b048-a929-4595-af91-a3eec1c818ce"],
Cell[1426782, 38072, 453, 12, 3829, "Input", "ExpressionUUID" -> \
"aa657e32-9d81-42fd-b3d6-9b7d79ae04f9"],
Cell[1427238, 38086, 453, 12, 3829, "Input", "ExpressionUUID" -> \
"a091fc16-2639-4a68-be93-477f681efad4"],
Cell[1427694, 38100, 263, 7, 3829, "Input", "ExpressionUUID" -> \
"1246cb2f-1003-4043-aa0f-1a14519895f0"],
Cell[1427960, 38109, 441, 12, 3829, "Input", "ExpressionUUID" -> \
"ffd371c7-3726-4fa2-a6b1-ff6811f8b304"],
Cell[1428404, 38123, 453, 12, 3829, "Input", "ExpressionUUID" -> \
"c883f8c4-3455-4c13-a495-87a6eb760873"],
Cell[1428860, 38137, 431, 12, 3829, "Input", "ExpressionUUID" -> \
"34016b21-70c2-47c8-9451-9b2919aa2708"],
Cell[1429294, 38151, 265, 6, 3829, "Input", "ExpressionUUID" -> \
"7c9e333e-0040-41e1-a7bc-0b5101fe85f5"],
Cell[1429562, 38159, 651, 18, 3829, "Input", "ExpressionUUID" -> \
"7a2d963e-9145-4608-a8c9-0a98ccbe70cf"],
Cell[1430216, 38179, 186, 3, 3829, "Text", "ExpressionUUID" -> \
"119bd3f9-9dfe-45ac-a4f5-777af257d5bd"],
Cell[1430405, 38184, 419, 11, 3829, "Input", "ExpressionUUID" -> \
"8dbc3b6e-54a5-4aea-95c1-89ddccdcb3a2"],
Cell[1430827, 38197, 540, 15, 3829, "Input", "ExpressionUUID" -> \
"4af4ce88-5894-442b-8437-e908c00f1802"],
Cell[1431370, 38214, 723, 17, 6360, "Text", "ExpressionUUID" -> \
"eea06f40-f17b-4f3b-b859-3395c562f24d"],
Cell[1432096, 38233, 178, 4, 3829, "Input", "ExpressionUUID" -> \
"f4b9bd1c-a381-4eaa-aa3f-bd6a9cefce05"],
Cell[1432277, 38239, 337, 9, 3829, "Input", "ExpressionUUID" -> \
"640cdd4b-2413-4bfa-a406-407f0e3d5e5d"],
Cell[1432617, 38250, 204, 3, 3829, "Text", "ExpressionUUID" -> \
"22390ffc-7e63-436a-8363-89276b29338c"],
Cell[1432824, 38255, 380, 11, 3829, "Input", "ExpressionUUID" -> \
"1f3bafeb-1e47-4728-9aeb-57fa2c41cfef"],
Cell[1433207, 38268, 1101, 32, 6453, "Input", "ExpressionUUID" -> \
"5dbdcba7-4c0b-4a9c-8547-ae7ee27f379d"],
Cell[1434311, 38302, 212, 5, 3829, "Text", "ExpressionUUID" -> \
"059d20ba-aacd-4b3a-9c29-93785e2dcbd8"],
Cell[1434526, 38309, 889, 20, 6453, "Input", "ExpressionUUID" -> \
"2cb0e4e1-2586-4143-87a9-74fa95fa9675"],
Cell[1435418, 38331, 165, 3, 3829, "Text", "ExpressionUUID" -> \
"686e66a8-0f44-41ae-8a59-688d36ad8a3e"],
Cell[1435586, 38336, 707, 18, 6453, "Input", "ExpressionUUID" -> \
"4eab9280-ab69-4964-b6a3-d8d004cfc233"],
Cell[1436296, 38356, 585, 15, 3829, "Input", "ExpressionUUID" -> \
"ca8d5ac4-5a7f-4a42-943f-3d493f74ac1a"],
Cell[1436884, 38373, 272, 6, 6360, "Text", "ExpressionUUID" -> \
"dfd3472d-02dc-4acc-bc82-70e9cbfda116"],
Cell[1437159, 38381, 610, 16, 3829, "Input", "ExpressionUUID" -> \
"b1613623-b41f-456e-a2ae-cf55a60a077f"],
Cell[1437772, 38399, 509, 9, 8776, "Text", "ExpressionUUID" -> \
"72324ff7-e34b-4f2f-88e8-f3815fe905e0"],
Cell[1438284, 38410, 970, 22, 6453, "Input", "ExpressionUUID" -> \
"2b21c969-0b44-45c7-a349-4761adf0ceaf"],
Cell[1439257, 38434, 232, 4, 3829, "Text", "ExpressionUUID" -> \
"daad77da-e099-46a9-9d2a-b5203875aa0c"],
Cell[1439492, 38440, 1238, 27, 9132, "Input", "ExpressionUUID" -> \
"3b76db5b-b6f6-4007-a197-c4f3ad494ce9"],
Cell[1440733, 38469, 281, 6, 3829, "Text", "ExpressionUUID" -> \
"6f367ae9-2f29-4c30-9aea-fd54b388e17c"],
Cell[1441017, 38477, 480, 14, 3829, "Input", "ExpressionUUID" -> \
"c4cd5ca4-cbe1-4011-bbbf-fa7349dff232"],
Cell[1441500, 38493, 658, 11, 11623, "Text", "ExpressionUUID" -> \
"300e313c-4ed8-4721-95b8-cbe55ea595c3"],
Cell[1442161, 38506, 448, 14, 3829, "Input", "ExpressionUUID" -> \
"13be0a38-3fb0-4967-b9e4-be221eede4b1"],
Cell[1442612, 38522, 652, 18, 3829, "Input", "ExpressionUUID" -> \
"96f3d648-dfe5-4b15-b640-0ed431e5af66"],
Cell[1443267, 38542, 445, 11, 3829, "Input", "ExpressionUUID" -> \
"9803b14c-8a63-4d47-8d47-8537c534c176"],
Cell[1443715, 38555, 1390, 37, 7242, "Input", "ExpressionUUID" -> \
"2469206e-c7da-4dfd-b309-9bc15b96cac5"],
Cell[1445108, 38594, 557, 9, 6360, "Text", "ExpressionUUID" -> \
"32db2611-fb33-4918-a199-b257ca455ab7"],
Cell[1445668, 38605, 1762, 50, 30438, "Input", "ExpressionUUID" -> \
"01c7aefd-6475-4aff-958f-e8573cea0a79"],
Cell[1447433, 38657, 151, 3, 3829, "Text", "ExpressionUUID" -> \
"02c1355e-834b-4a61-9b5b-74b7242b2f52"],
Cell[1447587, 38662, 1645, 53, 16465, "Input", "ExpressionUUID" -> \
"3ffac7e2-b013-4ca0-9c42-c75124146793"],
Cell[1449235, 38717, 149, 3, 3829, "Text", "ExpressionUUID" -> \
"51afe6e0-5060-4b5f-a6f9-c430fc911f9c"],
Cell[1449387, 38722, 500, 14, 4144, "Input", "ExpressionUUID" -> \
"465ea0f3-4bee-467e-9379-e732535b8541"],
Cell[1449890, 38738, 269, 6, 3829, "Text", "ExpressionUUID" -> \
"55484243-47fd-41ab-9c8f-76582dd7b877"],
Cell[1450162, 38746, 271, 6, 6360, "Text", "ExpressionUUID" -> \
"b99c6a3d-a759-48f5-883b-0e887c3898a7"],
Cell[1450436, 38754, 660, 17, 3829, "Input", "ExpressionUUID" -> \
"f8a56b79-2d22-4d2f-ac4e-dcc143f710b7"],
Cell[1451099, 38773, 524, 14, 4144, "Input", "ExpressionUUID" -> \
"33afef35-42ad-4620-a755-70c917df0e2b"],
Cell[1451626, 38789, 187, 3, 3829, "Text", "ExpressionUUID" -> \
"fe39b220-14bd-4150-a39d-dcb3ed77240e"],
Cell[1451816, 38794, 1528, 38, 9132, "Input", "ExpressionUUID" -> \
"5d4cda65-4188-4af3-8f28-f27f0e0b2cd6"],
Cell[1453347, 38834, 575, 13, 3829, "Input", "ExpressionUUID" -> \
"228b1f82-b776-4ee2-b0a7-9f77b0681d1a"],
Cell[1453925, 38849, 476, 11, 9019, "Text", "ExpressionUUID" -> \
"8ff612c6-38f6-41d7-81a5-46ffa525d9a4"]
}, Closed]],
Cell[CellGroupData[{
Cell[1454438, 38865, 586, 10, 42, "Subsubsection", "ExpressionUUID" -> \
"b7274637-00f4-4dec-a11b-2e15c97b76cb"],
Cell[1455027, 38877, 349, 7, 6453, "Text", "ExpressionUUID" -> \
"b7330a3e-9e78-40aa-9101-23956f3db247"],
Cell[1455379, 38886, 553, 15, 3829, "Input", "ExpressionUUID" -> \
"a8733d65-faeb-4ca3-9794-89cbfaa07a62",
 InitializationCell->True],
Cell[1455935, 38903, 261, 6, 3829, "Input", "ExpressionUUID" -> \
"e81dfac9-c3dc-4a35-95c9-d5724cfb64f7"],
Cell[1456199, 38911, 564, 10, 8776, "Text", "ExpressionUUID" -> \
"01642d42-6250-440f-8dd7-60ba76c98f48"],
Cell[1456766, 38923, 877, 23, 6453, "Input", "ExpressionUUID" -> \
"1e6addc5-781a-455f-b12b-f633cabafb8a"],
Cell[1457646, 38948, 364, 10, 3829, "Input", "ExpressionUUID" -> \
"35cd805a-a2e4-404d-acc3-449e0f7fb267"],
Cell[1458013, 38960, 252, 7, 3829, "Input", "ExpressionUUID" -> \
"9f2774cd-075c-498f-8435-cd81338244b0"],
Cell[1458268, 38969, 282, 4, 3829, "Text", "ExpressionUUID" -> \
"f2359f5a-1021-49ac-ab33-2937d3e59877"],
Cell[1458553, 38975, 359, 9, 3829, "Input", "ExpressionUUID" -> \
"80ff21ff-c6f5-4ae2-a9b4-99dd35563095"],
Cell[1458915, 38986, 431, 10, 3829, "Text", "ExpressionUUID" -> \
"fd6ac66e-80d3-45c5-ac90-c8b228713525"],
Cell[1459349, 38998, 887, 26, 8979, "Input", "ExpressionUUID" -> \
"f001eca6-b2e6-41af-8b09-b61c6da86717",
 InitializationCell->True],
Cell[1460239, 39026, 593, 10, 6360, "Text", "ExpressionUUID" -> \
"5a361653-ba47-4769-8470-6c330ac4ba71"],
Cell[1460835, 39038, 865, 18, 3829, "Input", "ExpressionUUID" -> \
"da822a64-ebb1-4f3e-9f0e-2c37ffb1c0fd"],
Cell[1461703, 39058, 274, 6, 3829, "Text", "ExpressionUUID" -> \
"417339fb-b21d-40d2-89bf-a22c797c3feb"],
Cell[1461980, 39066, 2537, 76, 56040, "Input", "ExpressionUUID" -> \
"05e6d9d6-a7e3-4063-abc1-6fb14d2645ec"],
Cell[1464520, 39144, 168, 3, 3829, "Text", "ExpressionUUID" -> \
"f9a6584e-ed98-4997-9c8f-275c3bdf9833"],
Cell[1464691, 39149, 1421, 50, 20292, "Input", "ExpressionUUID" -> \
"dee20251-9b03-436f-a385-e4b959b068d9"],
Cell[1466115, 39201, 186, 3, 3829, "Text", "ExpressionUUID" -> \
"f4881816-6a4f-4ddd-90a8-d8cabae8f9eb"],
Cell[1466304, 39206, 1856, 56, 20202, "Input", "ExpressionUUID" -> \
"7c758385-36f8-4a7d-bfd6-caf9fa41168d"],
Cell[1468163, 39264, 243, 4, 3829, "Text", "ExpressionUUID" -> \
"4a7ec058-f823-4970-af8d-3014f8202d5c"],
Cell[1468409, 39270, 1286, 34, 8979, "Input", "ExpressionUUID" -> \
"4f21f863-0405-4713-8bc2-51ebcd518060"],
Cell[1469698, 39306, 439, 8, 6453, "Text", "ExpressionUUID" -> \
"76fe34b1-c352-478e-8f63-02355febbc80"],
Cell[1470140, 39316, 342, 8, 3829, "Input", "ExpressionUUID" -> \
"7dc9ad39-27d6-4133-a127-7596bcc6d184"],
Cell[1470485, 39326, 187, 5, 3829, "Input", "ExpressionUUID" -> \
"caa00531-4eac-4b8e-89f1-561cfb1ec44b"],
Cell[1470675, 39333, 467, 13, 4144, "Text", "ExpressionUUID" -> \
"b810023d-8e3c-4181-89d8-96af9b820d1a"],
Cell[1471145, 39348, 1598, 44, 13627, "Input", "ExpressionUUID" -> \
"3dd1ca7a-3b18-431e-863e-302b0e96b374"],
Cell[1472746, 39394, 237, 4, 3829, "Text", "ExpressionUUID" -> \
"7fbffea0-1591-439a-b303-5eee40130d6c"],
Cell[1472986, 39400, 793, 26, 12466, "Input", "ExpressionUUID" -> \
"fcbc65aa-8a48-453b-b1e8-c689e3a591fc",
 InitializationCell->True],
Cell[1473782, 39428, 641, 12, 9019, "Text", "ExpressionUUID" -> \
"6c835e65-c6aa-4fef-a41c-2d7e7cd8745d"],
Cell[1474426, 39442, 423, 10, 6360, "Text", "ExpressionUUID" -> \
"e60aab5f-0066-4a26-81b6-d2b16edc6f0c"],
Cell[1474852, 39454, 448, 13, 3829, "Input", "ExpressionUUID" -> \
"1ede3b1b-eaf4-4a8f-a5a4-f01f52b9a6f6"],
Cell[1475303, 39469, 406, 12, 3829, "Input", "ExpressionUUID" -> \
"2013d3c5-6e1a-4ca9-b315-1b36faed3e38"],
Cell[1475712, 39483, 299, 8, 3829, "Input", "ExpressionUUID" -> \
"91d86e6e-96c3-4d6f-8237-b1abd046a595"],
Cell[1476014, 39493, 161, 3, 3829, "Text", "ExpressionUUID" -> \
"81ab5a0c-212d-40ec-82ab-a481cb660885"],
Cell[1476178, 39498, 532, 9, 6561, "Text", "ExpressionUUID" -> \
"b9e4562c-7b9f-4b13-ba63-3710e22113de"],
Cell[1476713, 39509, 343, 8, 3829, "Input", "ExpressionUUID" -> \
"903768fc-ad70-4221-8173-b7ac3a257485"],
Cell[1477059, 39519, 331, 5, 3829, "Text", "ExpressionUUID" -> \
"2c1670ff-5039-4a56-aa5e-8da69f0316e6"],
Cell[1477393, 39526, 711, 22, 7992, "Input", "ExpressionUUID" -> \
"0f817cbf-f0e0-4350-97df-e85f9c4f5ddf",
 Evaluatable->False],
Cell[1478107, 39550, 433, 6, 3937, "Text", "ExpressionUUID" -> \
"fb620cb5-57e5-46f7-88fa-7d415c0b9d7e"],
Cell[1478543, 39558, 338, 9, 3829, "Input", "ExpressionUUID" -> \
"3e609c69-ef04-4b0a-857f-e867a2fe098d"],
Cell[1478884, 39569, 191, 3, 3829, "Text", "ExpressionUUID" -> \
"f4df3a98-260a-4611-a7a6-634548af2ab0"],
Cell[1479078, 39574, 660, 17, 6453, "Input", "ExpressionUUID" -> \
"292ecb41-ce55-4a66-b581-4be57181ff7d"],
Cell[1479741, 39593, 383, 8, 3829, "Text", "ExpressionUUID" -> \
"14dd7cee-0c7d-41e3-af9d-4104bc732923"],
Cell[1480127, 39603, 341, 9, 3829, "Input", "ExpressionUUID" -> \
"2c7caa0e-6cb9-4508-bda4-06441629c15f"],
Cell[1480471, 39614, 324, 7, 3937, "Text", "ExpressionUUID" -> \
"b8787609-22a4-42ca-942e-685750b59d22"],
Cell[1480798, 39623, 263, 7, 3829, "Input", "ExpressionUUID" -> \
"9e59ed64-0a63-4c47-99a9-77bab61bb368"],
Cell[1481064, 39632, 222, 5, 3829, "Text", "ExpressionUUID" -> \
"f8833246-b84d-4ad5-bb1e-fb5425f51504"],
Cell[1481289, 39639, 770, 19, 6453, "Input", "ExpressionUUID" -> \
"b57d974f-e5ba-4862-9d45-4c4cd85db722"],
Cell[1482062, 39660, 209, 4, 3829, "Input", "ExpressionUUID" -> \
"818c95f8-c2b7-4196-90f7-0f0f89caf0fa"],
Cell[1482274, 39666, 1022, 16, 14053, "Text", "ExpressionUUID" -> \
"1f4811fd-e7e0-42b4-aa87-967459dbfc2a"],
Cell[1483299, 39684, 1271, 29, 6453, "Input", "ExpressionUUID" -> \
"79b348b9-6be3-4a20-ba10-c049c39516ac"],
Cell[1484573, 39715, 204, 5, 3829, "Input", "ExpressionUUID" -> \
"67a4359d-f89d-47d5-8938-a8040a0c32c6"],
Cell[1484780, 39722, 206, 5, 3829, "Input", "ExpressionUUID" -> \
"f825f188-530a-4f3f-b663-e0184e0b04dc"],
Cell[1484989, 39729, 258, 6, 6360, "Text", "ExpressionUUID" -> \
"cc9c661d-c37d-419a-932f-46a0a42535a0"],
Cell[1485250, 39737, 451, 13, 3829, "Input", "ExpressionUUID" -> \
"339e95b7-8842-4e3e-bc76-38514c94e01c"],
Cell[1485704, 39752, 236, 6, 3829, "Input", "ExpressionUUID" -> \
"06543ccf-3e85-4a72-8bd8-6c9b8ee65098"],
Cell[1485943, 39760, 312, 7, 6360, "Text", "ExpressionUUID" -> \
"c7ea2036-419b-4928-9863-862cb2beda7d"],
Cell[1486258, 39769, 826, 20, 6453, "Input", "ExpressionUUID" -> \
"40e862d4-80b4-49e8-a904-77adecfef3ab"],
Cell[1487087, 39791, 218, 5, 3829, "Input", "ExpressionUUID" -> \
"6eb0c197-7348-4488-856c-30c99be50ea1"],
Cell[1487308, 39798, 429, 8, 6561, "Text", "ExpressionUUID" -> \
"dafff44e-2321-4afa-b45e-04ca9695ec1b"],
Cell[1487740, 39808, 272, 7, 3829, "Input", "ExpressionUUID" -> \
"39ab8887-289a-4ee3-b734-e55dea544438"],
Cell[1488015, 39817, 319, 8, 3829, "Input", "ExpressionUUID" -> \
"579db135-f4ea-485f-9ddf-0ca00fddcb7d"],
Cell[1488337, 39827, 301, 7, 6360, "Text", "ExpressionUUID" -> \
"93411a0b-6af6-4986-a443-80af58bb9fff"],
Cell[1488641, 39836, 838, 22, 6453, "Input", "ExpressionUUID" -> \
"a79c465f-d0af-49fb-b03b-6a76735f5735"],
Cell[1489482, 39860, 189, 4, 3829, "Input", "ExpressionUUID" -> \
"dbf21f00-03e5-41f4-bf87-a6cce344cd90"],
Cell[1489674, 39866, 482, 10, 9019, "Text", "ExpressionUUID" -> \
"004cdc94-1038-4b1c-9183-d7cb93f6fb22"]
}, Closed]],
Cell[CellGroupData[{
Cell[1490193, 39881, 592, 9, 79, "Subsubsection", "ExpressionUUID" -> \
"630fa08f-6c46-4f58-a400-273a3d621721"],
Cell[1490788, 39892, 552, 9, 6360, "Text", "ExpressionUUID" -> \
"e776e4aa-c591-40f6-b0e0-84595ad4b513"],
Cell[1491343, 39903, 236, 6, 3829, "Input", "ExpressionUUID" -> \
"6029f882-87dc-46a5-88b5-c4f5f7687cc3"],
Cell[1491582, 39911, 144, 3, 3829, "Text", "ExpressionUUID" -> \
"34954e7e-559f-4fad-b0d0-2784f457496f"],
Cell[1491729, 39916, 376, 9, 3829, "Input", "ExpressionUUID" -> \
"bdac15ee-16e6-4623-b9b4-bc6e68080426"],
Cell[1492108, 39927, 234, 4, 3829, "Text", "ExpressionUUID" -> \
"24201ee6-2824-4a38-a8f6-e5e6c0a20351"],
Cell[1492345, 39933, 498, 12, 3829, "Input", "ExpressionUUID" -> \
"de9f4d2c-8958-4f0e-ae84-09a8f78c4f09"],
Cell[1492846, 39947, 691, 18, 6603, "Input", "ExpressionUUID" -> \
"5c4582f0-f367-4d79-98b0-e986dc699388"],
Cell[1493540, 39967, 166, 4, 3829, "Input", "ExpressionUUID" -> \
"abfdfba0-58f3-4f60-badd-ef77b1693866"],
Cell[1493709, 39973, 621, 11, 8776, "Text", "ExpressionUUID" -> \
"b5906faa-916b-41f8-a8b6-8afc0e519b62"],
Cell[1494333, 39986, 286, 7, 3829, "Input", "ExpressionUUID" -> \
"e331a07c-1329-4e7d-ac0d-cdb253ed6789"],
Cell[1494622, 39995, 1165, 23, 3829, "Input", "ExpressionUUID" -> \
"132cae92-b03b-4431-9efc-1a3468e4e82a"],
Cell[1495790, 40020, 214, 5, 3829, "Text", "ExpressionUUID" -> \
"dc1c74a7-19db-4d60-b76b-cb6dec84af4a"],
Cell[1496007, 40027, 1267, 25, 3829, "Input", "ExpressionUUID" -> \
"7886de8d-d06a-4c57-916d-f3ef29e48f85"],
Cell[1497277, 40054, 284, 4, 3829, "Text", "ExpressionUUID" -> \
"886acbd8-2e88-4479-ac78-4e27ace71cb8"],
Cell[1497564, 40060, 796, 17, 3829, "Input", "ExpressionUUID" -> \
"3f514405-7a9c-4c6f-a630-0ab093a7b12a"],
Cell[1498363, 40079, 175, 3, 3829, "Text", "ExpressionUUID" -> \
"ec9d8b3f-4002-46ce-a542-a577e422aa8e"],
Cell[1498541, 40084, 815, 20, 3829, "Input", "ExpressionUUID" -> \
"24e58d45-a53a-4547-a086-de48cb147cf3"],
Cell[1499359, 40106, 884, 21, 10053, "Text", "ExpressionUUID" -> \
"aaf024e1-55ee-4a52-9fdd-a95ada58e340"],
Cell[1500246, 40129, 443, 9, 3829, "Text", "ExpressionUUID" -> \
"dcbcef03-0665-4ee8-afeb-a93cc1850ea4"],
Cell[1500692, 40140, 1846, 42, 13986, "Input", "ExpressionUUID" -> \
"33098766-488e-43b2-802e-6b7929f232bc"],
Cell[1502541, 40184, 401, 9, 3937, "Text", "ExpressionUUID" -> \
"621ca10f-b762-4b7c-aa4a-dcdef3db7829"],
Cell[1502945, 40195, 267, 6, 3829, "Input", "ExpressionUUID" -> \
"bfdebfa5-9a13-4fff-8dbc-bd96a92dddaf"],
Cell[1503215, 40203, 533, 9, 8979, "Text", "ExpressionUUID" -> \
"8354ae3c-351a-4ec6-92d1-42ff7dee86d5"],
Cell[1503751, 40214, 288, 7, 3829, "Input", "ExpressionUUID" -> \
"7faa3f87-9879-4d98-9f4c-f33d41b62500"],
Cell[1504042, 40223, 171, 3, 3829, "Text", "ExpressionUUID" -> \
"ee686949-fa96-4dda-a4e1-1f7ee9769dc7"],
Cell[1504216, 40228, 474, 11, 3829, "Input", "ExpressionUUID" -> \
"9a36d863-6e8d-4780-addd-7a5e84598d67"],
Cell[1504693, 40241, 168, 3, 3829, "Text", "ExpressionUUID" -> \
"285bec7f-594d-40e9-8df9-13f5dede7866"],
Cell[1504864, 40246, 261, 7, 3829, "Input", "ExpressionUUID" -> \
"1be63382-f0d8-424e-8fdb-2ff4ec57fbee"],
Cell[1505128, 40255, 697, 19, 3829, "Input", "ExpressionUUID" -> \
"a168ec2c-313a-4de8-9e5a-6ea2643768cc"],
Cell[1505828, 40276, 205, 5, 3829, "Input", "ExpressionUUID" -> \
"4f8ee577-9fd9-4fb3-be7b-e4891f2fe4a0"],
Cell[1506036, 40283, 412, 9, 3829, "Input", "ExpressionUUID" -> \
"590f81ad-e907-49c0-b2d5-7a66b421bc5f"],
Cell[1506451, 40294, 405, 9, 3829, "Input", "ExpressionUUID" -> \
"fc30cd13-5d93-49b5-a57e-b321f34255bd"],
Cell[1506859, 40305, 437, 8, 6561, "Text", "ExpressionUUID" -> \
"9be20f71-e3bc-41a8-968a-899f843ed2fc"],
Cell[1507299, 40315, 655, 12, 6561, "Text", "ExpressionUUID" -> \
"cd2b06eb-a51e-4910-bf24-79651ab0cf64"],
Cell[1507957, 40329, 626, 19, 3829, "Input", "ExpressionUUID" -> \
"c3842b2c-ced3-4bae-be88-5a82ec9272b4"],
Cell[1508586, 40350, 454, 7, 3829, "Text", "ExpressionUUID" -> \
"e150e43d-d25a-4206-bda6-1284909dbed2"],
Cell[1509043, 40359, 531, 14, 3829, "Input", "ExpressionUUID" -> \
"cd47af73-aa98-4fc0-ada4-78c452fdc4f3"],
Cell[1509577, 40375, 182, 3, 3829, "Text", "ExpressionUUID" -> \
"6bce9d16-07b1-4af1-b8e4-38f826007e46"],
Cell[1509762, 40380, 342, 8, 3829, "Input", "ExpressionUUID" -> \
"d88a8457-00b3-4ebc-8d67-cced1c3cc792"],
Cell[1510107, 40390, 646, 17, 6453, "Input", "ExpressionUUID" -> \
"232fc6d3-6194-42b4-90b5-1b236f52a720"],
Cell[1510756, 40409, 442, 10, 3829, "Input", "ExpressionUUID" -> \
"273913eb-749a-471a-b92e-affe99f72559"],
Cell[1511201, 40421, 230, 4, 3829, "Text", "ExpressionUUID" -> \
"9d2aca61-578d-4ed5-8b9f-c5ccebe0b8f3"],
Cell[1511434, 40427, 373, 9, 3829, "Input", "ExpressionUUID" -> \
"ec2f653a-c9a8-4586-83e0-9900f1c42b0f"],
Cell[1511810, 40438, 393, 10, 3829, "Input", "ExpressionUUID" -> \
"0700c47f-404f-44a5-ad36-ffe96641cef3"],
Cell[1512206, 40450, 839, 12, 13698, "Text", "ExpressionUUID" -> \
"43216cae-9973-4c5f-8e44-7b29a277faa0",
 CellTags->"barrel"],
Cell[1513048, 40464, 260, 6, 3829, "Input", "ExpressionUUID" -> \
"2a69e8a7-1f58-4fe1-a9c7-4b3f131a983e"],
Cell[1513311, 40472, 1085, 26, 6453, "Input", "ExpressionUUID" -> \
"dc4d63f3-3551-452c-a724-f22d0a036927"],
Cell[1514399, 40500, 1052, 27, 11895, "Input", "ExpressionUUID" -> \
"f4dcf853-612e-4a8a-88b6-7bb1bae0369c"],
Cell[1515454, 40529, 551, 14, 3829, "Input", "ExpressionUUID" -> \
"aff8a5fb-4fa2-4188-b59f-ceb3b8ecd1bd"],
Cell[1516008, 40545, 209, 3, 3829, "Text", "ExpressionUUID" -> \
"596cdee9-c3fe-4f9b-9f8d-26724164ef46"],
Cell[1516220, 40550, 6772, 144, 41526, "Input", "ExpressionUUID" -> \
"9a94a225-8206-4518-bf57-3e0918c8a702",
 InitializationCell->True],
Cell[1522995, 40696, 785, 15, 13986, "Input", "ExpressionUUID" -> \
"99857775-5fe7-4ef3-b428-80ef48fde1a5",
 InitializationCell->True],
Cell[1523783, 40713, 300, 6, 6360, "Text", "ExpressionUUID" -> \
"9f22e0c3-0912-449b-b2e2-a3a11c87ec76"],
Cell[1524086, 40721, 393, 11, 3829, "Input", "ExpressionUUID" -> \
"c8cf8359-62b1-4a38-bf34-b563922e9550"],
Cell[1524482, 40734, 254, 6, 3829, "Input", "ExpressionUUID" -> \
"c6c7d059-22f1-4bfe-b1c5-06d5b6719922"],
Cell[1524739, 40742, 454, 11, 3829, "Input", "ExpressionUUID" -> \
"4cc1847f-1060-4635-858f-95a395d53001"],
Cell[1525196, 40755, 572, 16, 6453, "Input", "ExpressionUUID" -> \
"c7f83596-0453-4663-8831-e4bbdaa9f172"],
Cell[1525771, 40773, 226, 5, 3829, "Text", "ExpressionUUID" -> \
"10b4fa21-0deb-486a-9712-a32d8c033b23"],
Cell[1526000, 40780, 348, 8, 6360, "Text", "ExpressionUUID" -> \
"e4fea29d-4efe-4923-a4e7-11ae63c0c4ff"],
Cell[1526351, 40790, 614, 13, 3829, "Input", "ExpressionUUID" -> \
"f91672e0-806c-477b-8cbc-29cedd6a12d8"],
Cell[1526968, 40805, 168, 3, 3829, "Text", "ExpressionUUID" -> \
"72343e7e-94fe-4260-98bf-cd51dac94635"],
Cell[1527139, 40810, 617, 11, 3829, "Input", "ExpressionUUID" -> \
"fbb8c369-7f74-4347-8729-1e9c7cc62449"],
Cell[1527759, 40823, 191, 3, 3829, "Text", "ExpressionUUID" -> \
"b2436cfd-9856-4290-a110-59fc1e456123"],
Cell[1527953, 40828, 984, 22, 6453, "Input", "ExpressionUUID" -> \
"129ffa1c-4a61-4548-a41c-88d064e9f53a"],
Cell[1528940, 40852, 433, 8, 6360, "Text", "ExpressionUUID" -> \
"fbacde66-a825-4452-9307-8b9a80aac7b9"],
Cell[1529376, 40862, 1050, 23, 6453, "Input", "ExpressionUUID" -> \
"3bf318e6-670a-404b-bb03-f5ddcf4a3726"],
Cell[1530429, 40887, 400, 9, 3829, "Input", "ExpressionUUID" -> \
"45c7f46d-6797-422b-a0bc-c66c9bbf7027"],
Cell[1530832, 40898, 184, 3, 3829, "Text", "ExpressionUUID" -> \
"1dd8cde9-4586-49f8-9452-024e9ca28844"],
Cell[1531019, 40903, 1535, 32, 8979, "Input", "ExpressionUUID" -> \
"413c19bc-5951-4ae0-9b06-8e7f7f0309c4"],
Cell[1532557, 40937, 221, 5, 3829, "Text", "ExpressionUUID" -> \
"37a95ce5-dc93-4d53-a795-961090e74e0e"],
Cell[1532781, 40944, 914, 18, 3829, "Input", "ExpressionUUID" -> \
"b6dd91c8-8265-4bde-9bc3-a7a7344de044"],
Cell[1533698, 40964, 1082, 23, 6453, "Input", "ExpressionUUID" -> \
"4538b857-5277-4d33-a5c6-6689bdc05d64"],
Cell[1534783, 40989, 310, 8, 3829, "Input", "ExpressionUUID" -> \
"1bb130ed-f2cc-4fd2-9ed9-0126598e174d"],
Cell[1535096, 40999, 146, 3, 3829, "Text", "ExpressionUUID" -> \
"fca6fbcf-1393-4dec-8f34-b002d2040c51"],
Cell[1535245, 41004, 1675, 34, 8979, "Input", "ExpressionUUID" -> \
"488c4091-52a7-4878-baf1-fc73a61a1dae"],
Cell[1536923, 41040, 273, 4, 3829, "Text", "ExpressionUUID" -> \
"0440a8c1-ade8-4df6-a9ff-729597850278"],
Cell[1537199, 41046, 562, 10, 3829, "Input", "ExpressionUUID" -> \
"b6996a12-c5c1-48ae-bbf6-90592d96e5b6"],
Cell[1537764, 41058, 205, 5, 3829, "Input", "ExpressionUUID" -> \
"94db7d16-b803-4576-a6d9-0dc9ea061798"],
Cell[1537972, 41065, 843, 17, 3829, "Input", "ExpressionUUID" -> \
"6b454a69-f024-4300-b1d3-9119cefb8468"],
Cell[1538818, 41084, 775, 17, 6453, "Input", "ExpressionUUID" -> \
"b6dd4cdc-7860-4f0e-813a-295a2db78df0"],
Cell[1539596, 41103, 848, 19, 6453, "Input", "ExpressionUUID" -> \
"4545ee5a-1827-4358-be87-b93d7b6a8016"],
Cell[1540447, 41124, 517, 11, 3829, "Input", "ExpressionUUID" -> \
"7609ccec-332f-4cb4-9cc8-88c376bbe303"],
Cell[1540967, 41137, 598, 13, 3829, "Input", "ExpressionUUID" -> \
"f15a0a47-749e-450d-be48-64fd897a1e12"],
Cell[1541568, 41152, 768, 20, 11440, "Input", "ExpressionUUID" -> \
"b3cbf0a0-2aa7-4821-94ae-4bb33add19ea"],
Cell[1542339, 41174, 1688, 33, 8979, "Input", "ExpressionUUID" -> \
"54b0306e-3ba7-47fd-9623-24f99f0fca33"]
}, Closed]],
Cell[CellGroupData[{
Cell[1544064, 41212, 697, 11, 79, "Subsubsection", "ExpressionUUID" -> \
"9922fe80-95df-4d2b-8bf3-79a3ed4efffc"],
Cell[1544764, 41225, 236, 6, 3829, "Input", "ExpressionUUID" -> \
"c70be573-9d29-447b-8b46-0bc0a2493fce"],
Cell[1545003, 41233, 654, 16, 3829, "Input", "ExpressionUUID" -> \
"fbb2c6be-c1ff-4590-95f5-08f0a9609f4b"],
Cell[1545660, 41251, 246, 6, 6360, "Text", "ExpressionUUID" -> \
"eab298fa-ed83-4c14-973b-7e2c8300add3"],
Cell[1545909, 41259, 1635, 33, 6453, "Input", "ExpressionUUID" -> \
"749fa29d-7aff-430e-9816-e3eed7ee4ca9"],
Cell[1547547, 41294, 983, 22, 6453, "Input", "ExpressionUUID" -> \
"730c2d6c-8845-4793-b036-c1041ffaed63"],
Cell[1548533, 41318, 858, 22, 6453, "Input", "ExpressionUUID" -> \
"2fddaf33-16a2-498c-96ac-d4ec70de1c62"],
Cell[1549394, 41342, 175, 3, 3829, "Text", "ExpressionUUID" -> \
"db2a2416-e319-4a5b-98bd-231a2f66c1e2"],
Cell[1549572, 41347, 396, 10, 3829, "Input", "ExpressionUUID" -> \
"d2bfb77d-91b3-4e8d-9f8e-2b5305c7c19b"],
Cell[1549971, 41359, 202, 3, 3829, "Text", "ExpressionUUID" -> \
"6903a287-dd41-44d2-95c8-9a079ad72032"],
Cell[1550176, 41364, 393, 10, 3829, "Input", "ExpressionUUID" -> \
"974c83a3-687c-4b4b-b13c-f8933844ddf2"],
Cell[1550572, 41376, 297, 7, 3829, "Input", "ExpressionUUID" -> \
"736cf058-7a59-46f9-b27e-2d32482a10f2"],
Cell[1550872, 41385, 449, 11, 3829, "Input", "ExpressionUUID" -> \
"c344819e-670b-4820-974e-af21d8555557"],
Cell[1551324, 41398, 573, 14, 3829, "Input", "ExpressionUUID" -> \
"03721f7a-9725-4a5d-8565-8bd3152676c0"],
Cell[1551900, 41414, 485, 10, 8776, "Text", "ExpressionUUID" -> \
"2712cc24-e451-40e6-8bb8-1369156e78a3"],
Cell[1552388, 41426, 316, 9, 3829, "Input", "ExpressionUUID" -> \
"cf19b650-15cf-4e18-96f0-953ab39f2c62"],
Cell[1552707, 41437, 246, 4, 3829, "Text", "ExpressionUUID" -> \
"6bbcccce-f5f2-4f6d-8a74-fcd5f67ffbdc"],
Cell[1552956, 41443, 629, 17, 3829, "Input", "ExpressionUUID" -> \
"0dad8c53-ec09-4a95-8012-177a44e0ae40"],
Cell[1553588, 41462, 537, 13, 3937, "Text", "ExpressionUUID" -> \
"371f1374-bfba-4664-8f83-3e6f0141c07d"],
Cell[1554128, 41477, 595, 17, 6453, "Input", "ExpressionUUID" -> \
"40ce820b-ec01-4c17-a34a-78bf71b78ea5"],
Cell[1554726, 41496, 677, 21, 3829, "Input", "ExpressionUUID" -> \
"2485305a-016d-4050-9fe9-36359c86fdff"],
Cell[1555406, 41519, 428, 12, 3829, "Input", "ExpressionUUID" -> \
"67bc8449-4b22-47f0-bd10-c95fbde47c13"],
Cell[1555837, 41533, 172, 3, 3829, "Text", "ExpressionUUID" -> \
"fae5b7da-b490-4f65-bf31-ebfe7bc73365"],
Cell[1556012, 41538, 308, 9, 3829, "Input", "ExpressionUUID" -> \
"6f7596ea-a4b1-42ca-a0a3-bf00613857cd"],
Cell[1556323, 41549, 695, 19, 7992, "Input", "ExpressionUUID" -> \
"ce11fbc9-a0f1-4fd3-9ea1-bf9cf8b991f8"],
Cell[1557021, 41570, 155, 3, 3829, "Text", "ExpressionUUID" -> \
"a800be9a-3946-4fd1-87e3-27ae4fddbfe6"],
Cell[1557179, 41575, 311, 9, 3829, "Input", "ExpressionUUID" -> \
"1f2f70ec-e62a-44e2-b956-e33e1319d16f"],
Cell[1557493, 41586, 709, 16, 8979, "Text", "ExpressionUUID" -> \
"3093202f-8678-45e4-9bc0-acf7fb894869"],
Cell[1558205, 41604, 796, 19, 8857, "Text", "ExpressionUUID" -> \
"e2828587-b74a-4044-acbb-c9eef1c38c7e"],
Cell[1559004, 41625, 1232, 27, 8979, "Input", "ExpressionUUID" -> \
"c776cea9-d637-48b8-86f6-5324d1fc0945"],
Cell[1560239, 41654, 157, 3, 3829, "Text", "ExpressionUUID" -> \
"9bfbfc67-4482-4a55-b9a9-938020cdc860"],
Cell[1560399, 41659, 366, 10, 3829, "Input", "ExpressionUUID" -> \
"25032255-85a5-4cf1-a72a-944fda08343d"],
Cell[1560768, 41671, 167, 3, 3829, "Text", "ExpressionUUID" -> \
"42c1b3f2-b019-46e5-8e52-1738ae23412d"],
Cell[1560938, 41676, 493, 14, 3829, "Input", "ExpressionUUID" -> \
"573363cd-876f-46a4-a530-ccaa9c0c0741"],
Cell[1561434, 41692, 157, 3, 3829, "Text", "ExpressionUUID" -> \
"de7e2406-bd93-43b6-bc5b-49db17da934c"],
Cell[1561594, 41697, 659, 13, 11281, "Text", "ExpressionUUID" -> \
"d659e860-0514-4833-b72d-639ed953ee41"],
Cell[1562256, 41712, 541, 16, 6453, "Input", "ExpressionUUID" -> \
"eb36f45f-8f61-4208-ba5c-7343fc3493cd"],
Cell[1562800, 41730, 181, 4, 3829, "Input", "ExpressionUUID" -> \
"a87f6c68-3c16-40b4-b245-296494eb5331"],
Cell[1562984, 41736, 184, 3, 3829, "Text", "ExpressionUUID" -> \
"b257e41a-dfa1-4cb4-a821-1c1edc3ad7f0"],
Cell[1563171, 41741, 1008, 28, 8979, "Input", "ExpressionUUID" -> \
"dfd60295-6e52-44a6-a6ef-2d90d9306962"],
Cell[1564182, 41771, 343, 7, 6360, "Text", "ExpressionUUID" -> \
"a328d843-807e-4f1d-a8d9-852dadc099b2"],
Cell[1564528, 41780, 910, 26, 6453, "Input", "ExpressionUUID" -> \
"82534d4e-1ca2-476e-8dcd-96327b9b19cb",
 InitializationCell->True],
Cell[1565441, 41808, 110, 1, 3829, "Input", "ExpressionUUID" -> \
"caf3d8aa-0d18-4066-a1ca-43083a139e62"],
Cell[1565554, 41811, 1644, 31, 11440, "Input", "ExpressionUUID" -> \
"cd14c47f-6918-4475-ad77-de0ffe819583"],
Cell[1567201, 41844, 885, 19, 3829, "Input", "ExpressionUUID" -> \
"3e6d4383-5f8a-48fd-88a1-5ec76d3011f9"],
Cell[1568089, 41865, 215, 5, 3829, "Text", "ExpressionUUID" -> \
"6c1fbeac-b686-45bc-9dec-5353929d71dc"],
Cell[1568307, 41872, 902, 19, 3829, "Input", "ExpressionUUID" -> \
"2aa1435c-7b33-4d10-9c42-2cb94fd318e8"],
Cell[1569212, 41893, 202, 3, 3829, "Text", "ExpressionUUID" -> \
"ecea5337-85a6-43e3-a634-06428da7d117"],
Cell[1569417, 41898, 990, 25, 6453, "Input", "ExpressionUUID" -> \
"39c767bb-319e-4b13-a843-be884cd3e596"],
Cell[1570410, 41925, 4289, 85, 29209, "Input", "ExpressionUUID" -> \
"be158f9a-c659-4f4c-8579-bf84bd6e4be5"],
Cell[1574702, 42012, 606, 13, 8776, "Text", "ExpressionUUID" -> \
"007f19ef-840d-4973-be98-ace143549245"],
Cell[1575311, 42027, 463, 11, 3829, "Input", "ExpressionUUID" -> \
"16050e0e-3fdc-4bb7-90e8-81e7bf727764"],
Cell[1575777, 42040, 200, 3, 3829, "Text", "ExpressionUUID" -> \
"58ea7504-45a1-4391-a009-404efabcd5b6"],
Cell[1575980, 42045, 546, 15, 3829, "Input", "ExpressionUUID" -> \
"d83c72a7-2956-4eea-88b5-a72de907f8d3"],
Cell[1576529, 42062, 203, 3, 3829, "Text", "ExpressionUUID" -> \
"f1b8b332-d58e-40be-9a1a-4d33a0377bac"],
Cell[1576735, 42067, 471, 12, 3829, "Input", "ExpressionUUID" -> \
"05e09e51-f1b8-45be-a3be-52bea532facf"],
Cell[1577209, 42081, 177, 3, 3829, "Text", "ExpressionUUID" -> \
"8a2d62ae-31e1-4e21-b9cf-a25a7bc21224"],
Cell[1577389, 42086, 869, 29, 6453, "Input", "ExpressionUUID" -> \
"e15f32a7-9f51-499d-8dc4-ba192d75859c"],
Cell[1578261, 42117, 698, 16, 3829, "Input", "ExpressionUUID" -> \
"e9e88123-8fbd-46b6-8ee7-0ee8fd7e624c"],
Cell[1578962, 42135, 162, 3, 3829, "Text", "ExpressionUUID" -> \
"aa01fd9b-cfa1-4531-9602-2dea8f02d8ac"],
Cell[1579127, 42140, 1319, 32, 8979, "Input", "ExpressionUUID" -> \
"b9fbe3fd-bcad-4999-9a9f-6fd2541f07d0"],
Cell[1580449, 42174, 157, 3, 3829, "Text", "ExpressionUUID" -> \
"98d7f67e-f9df-47f7-afcc-8d13ac3de04b"],
Cell[1580609, 42179, 586, 15, 6453, "Input", "ExpressionUUID" -> \
"62540c6f-e230-435d-98ce-3307fe20cbbc"],
Cell[1581198, 42196, 431, 12, 3829, "Input", "ExpressionUUID" -> \
"2cfbec93-2401-4cdf-84b6-976abaffcbd7"],
Cell[1581632, 42210, 181, 4, 3829, "Input", "ExpressionUUID" -> \
"95378921-1a3c-4d24-b5b0-1574388cacbb"],
Cell[1581816, 42216, 344, 9, 3786, "Input", "ExpressionUUID" -> \
"5d647ac6-c51d-48a7-b6a1-691c13f8dc75"],
Cell[1582163, 42227, 709, 18, 6453, "Input", "ExpressionUUID" -> \
"d7fbbf74-b47c-4c0f-99e6-19eef2668833"],
Cell[1582875, 42247, 319, 8, 3829, "Input", "ExpressionUUID" -> \
"a5e27aa1-cd0a-444c-a321-46d1586d8a38"],
Cell[1583197, 42257, 294, 7, 3829, "Input", "ExpressionUUID" -> \
"38165cd1-f5a2-45be-be2b-d03fd098add9"],
Cell[1583494, 42266, 426, 8, 8776, "Text", "ExpressionUUID" -> \
"6626f8e4-c7da-4903-af08-c4729ba7c052"],
Cell[1583923, 42276, 333, 9, 3829, "Input", "ExpressionUUID" -> \
"4b86273e-2885-43fa-a17b-f7ac50d43fe8"],
Cell[1584259, 42287, 472, 13, 3829, "Input", "ExpressionUUID" -> \
"4a16e6b7-0fd8-49b8-8f68-aef17a6c28fa"],
Cell[1584734, 42302, 943, 20, 7836, "Text", "ExpressionUUID" -> \
"bd0a95ac-40ac-49a6-b120-5c4e9528dfae"],
Cell[1585680, 42324, 159, 3, 3829, "Text", "ExpressionUUID" -> \
"98d7e736-8df0-4f7f-9436-8a30e8cb76bd"],
Cell[1585842, 42329, 341, 7, 3829, "Input", "ExpressionUUID" -> \
"26417ce3-a1b8-4e61-bd84-91576a33aae8"],
Cell[1586186, 42338, 200, 4, 3829, "Text", "ExpressionUUID" -> \
"478c4f4b-379b-4160-9867-91a8239eee14"],
Cell[1586389, 42344, 586, 17, 6702, "Input", "ExpressionUUID" -> \
"0a7ae4d0-9220-4fe8-ba1b-1bafd9f394a4"],
Cell[1586978, 42363, 758, 16, 8979, "Text", "ExpressionUUID" -> \
"eb615087-42bb-44e9-8ead-d633fcc211c2"],
Cell[1587739, 42381, 719, 17, 6453, "Input", "ExpressionUUID" -> \
"d06e51bb-471b-4149-9888-f70ff40f1449"],
Cell[1588461, 42400, 343, 7, 3829, "Input", "ExpressionUUID" -> \
"2b227f72-d850-4b19-8b19-497219d43116"]
}, Closed]],
Cell[CellGroupData[{
Cell[1588841, 42412, 324, 5, 42, "Subsubsection", "ExpressionUUID" -> \
"69c45e38-1909-4af3-a48f-9a963483ed1f"],
Cell[1589168, 42419, 673, 14, 2661, "Text", "ExpressionUUID" -> \
"17323a91-a053-48fd-b39c-e305fe05340d"],
Cell[1589844, 42435, 917, 23, 1912, "Input", "ExpressionUUID" -> \
"7b79ece8-fa60-431e-9903-fa8b51632698"],
Cell[1590764, 42460, 318, 8, 1135, "Input", "ExpressionUUID" -> \
"c70a5bac-5efe-4650-a660-3c873e1981d9"],
Cell[1591085, 42470, 1007, 26, 1944, "Text", "ExpressionUUID" -> \
"7bb1a6a0-879c-4d6b-bea5-a068d0c3bb5d"],
Cell[1592095, 42498, 1750, 43, 2146, "Input", "ExpressionUUID" -> \
"9b870022-ade3-473e-9a7a-eb551c70943b"],
Cell[1593848, 42543, 352, 8, 1885, "Text", "ExpressionUUID" -> \
"a5e7ecde-783f-4cc5-847f-55eeedd596a5"],
Cell[1594203, 42553, 1704, 42, 1275, "Input", "ExpressionUUID" -> \
"999239a8-934b-4964-9b12-419fbc535399"],
Cell[1595910, 42597, 192, 3, 1135, "Text", "ExpressionUUID" -> \
"bf199497-c73f-4130-a0a8-3a478fd206a5"],
Cell[1596105, 42602, 745, 20, 1912, "Input", "ExpressionUUID" -> \
"eec2e412-124c-4030-aed5-9a1623c1e32b"],
Cell[1596853, 42624, 903, 22, 1912, "Input", "ExpressionUUID" -> \
"1498e278-b9f5-47ba-9dfb-ecccda4f65db"],
Cell[1597759, 42648, 382, 7, 1944, "Text", "ExpressionUUID" -> \
"9c1c682c-6568-4aca-b90f-119405598456"],
Cell[1598144, 42657, 765, 15, 1135, "Input", "ExpressionUUID" -> \
"cd9d7383-5546-4807-b2d5-8def33467f1d"],
Cell[1598912, 42674, 817, 16, 1135, "Input", "ExpressionUUID" -> \
"9b7979cd-a660-4a2b-8944-d591eb03643b"],
Cell[1599732, 42692, 154, 3, 1135, "Text", "ExpressionUUID" -> \
"08f40aa1-3ff7-4cfc-a625-7e67fb777da5"],
Cell[1599889, 42697, 1658, 41, 7521, "Input", "ExpressionUUID" -> \
"e264f4e7-4092-4c4c-b099-e55b1f73b2da"],
Cell[1601550, 42740, 857, 16, 2553, "Input", "ExpressionUUID" -> \
"fd1b6824-f686-4fec-8342-8fc7dfadb7ab"],
Cell[1602410, 42758, 295, 7, 4302, "Text", "ExpressionUUID" -> \
"9f981de3-3078-4e36-8648-469e359ff8d8"],
Cell[1602708, 42767, 467, 13, 2553, "Input", "ExpressionUUID" -> \
"e3a545cf-ac8f-405b-bc98-3bbe41c42ac4"],
Cell[1603178, 42782, 153, 3, 2553, "Text", "ExpressionUUID" -> \
"a82194c7-db53-4bf3-879b-3ca5177d404f"],
Cell[1603334, 42787, 617, 18, 4302, "Input", "ExpressionUUID" -> \
"ff0705e4-0253-49a1-b0e8-6962be3b8618",
 Evaluatable->False],
Cell[1603954, 42807, 749, 13, 6013, "Text", "ExpressionUUID" -> \
"6e6e46e0-300d-4d40-9e5c-cb2783bbe7cd"],
Cell[1604706, 42822, 438, 12, 2553, "Input", "ExpressionUUID" -> \
"ba69d32a-83f5-478b-a70b-08d63877f7ae"],
Cell[1605147, 42836, 473, 14, 2553, "Input", "ExpressionUUID" -> \
"020f5f1f-647f-46ac-b17a-bef187597877"],
Cell[1605623, 42852, 861, 14, 4302, "Text", "ExpressionUUID" -> \
"de64440e-d9e8-4107-b79e-5342a81b39f7"],
Cell[1606487, 42868, 563, 16, 4302, "Input", "ExpressionUUID" -> \
"ae9a9bfe-882e-4592-b103-eec0f2910798",
 Evaluatable->False],
Cell[1607053, 42886, 963, 16, 6013, "Text", "ExpressionUUID" -> \
"8a29c22e-7a4b-4dbe-8814-766de4a9e1de"],
Cell[1608019, 42904, 766, 21, 4302, "Input", "ExpressionUUID" -> \
"c9dce204-26a3-4a9c-8dfc-57e2b4c9a564"],
Cell[1608788, 42927, 380, 6, 2625, "Text", "ExpressionUUID" -> \
"816e7ee4-1055-490c-9223-dae9989a5fc9"],
Cell[1609171, 42935, 738, 19, 4302, "Input", "ExpressionUUID" -> \
"70e248e2-6a15-4f95-bf99-64e4e7a9174f"],
Cell[1609912, 42956, 328, 5, 2625, "Text", "ExpressionUUID" -> \
"ad0efcfe-bba2-441a-aece-296bbb9b639a"],
Cell[1610243, 42963, 953, 24, 4302, "Input", "ExpressionUUID" -> \
"81993aa7-330b-4fe8-910f-3d1cb3cd89f4"],
Cell[1611199, 42989, 166, 3, 2625, "Text", "ExpressionUUID" -> \
"bc1cf71c-e5a0-4c2a-b829-8f1ab2bd3908"],
Cell[1611368, 42994, 1165, 30, 4302, "Input", "ExpressionUUID" -> \
"5984ac4f-9790-4d83-9ffd-48d51b9d1589"],
Cell[1612536, 43026, 703, 11, 5851, "Text", "ExpressionUUID" -> \
"d8bae83c-3732-409b-8cd0-335bbd2dfe2e"],
Cell[1613242, 43039, 342, 9, 2553, "Input", "ExpressionUUID" -> \
"cc5f0e7d-11df-49c0-a9ca-46ae8d429900"],
Cell[1613587, 43050, 165, 3, 2625, "Text", "ExpressionUUID" -> \
"1247fc58-05c6-49e4-97db-a65e61cdc56c"],
Cell[1613755, 43055, 363, 11, 2553, "Input", "ExpressionUUID" -> \
"dc96238b-b839-4f98-b7e8-8981b25ae480"],
Cell[1614121, 43068, 308, 9, 3687, "Input", "ExpressionUUID" -> \
"3bdcbea2-bc8b-4259-9a8d-b10b09e30199"],
Cell[1614432, 43079, 324, 7, 4302, "Text", "ExpressionUUID" -> \
"3cbde6a0-1465-445b-90e0-f2a7fddb870e"],
Cell[1614759, 43088, 409, 8, 4374, "Text", "ExpressionUUID" -> \
"68ced070-ebb9-4e40-afa6-0f7c5e7349e9"],
Cell[1615171, 43098, 673, 18, 2553, "Input", "ExpressionUUID" -> \
"3eb6e59f-87c0-4bbd-8393-4fb86498aa30"],
Cell[1615847, 43118, 327, 7, 4240, "Text", "ExpressionUUID" -> \
"cf8a189e-1b74-4470-9676-f5c77d6dbdd9"],
Cell[1616177, 43127, 532, 16, 4302, "Input", "ExpressionUUID" -> \
"9f0bcdb5-a155-4632-ac30-be76fbbad5fc"],
Cell[1616712, 43145, 201, 4, 2553, "Text", "ExpressionUUID" -> \
"0ba9f1fa-2fad-4528-822d-fe5446ad7a34"],
Cell[1616916, 43151, 700, 19, 4302, "Input", "ExpressionUUID" -> \
"38489e7f-168e-4350-8386-e0cd14361cdb"],
Cell[1617619, 43172, 375, 11, 2553, "Input", "ExpressionUUID" -> \
"a0328315-edc0-4a6c-943b-f6945810fafa"],
Cell[1617997, 43185, 254, 6, 4240, "Text", "ExpressionUUID" -> \
"805df220-d5fc-407c-864c-0ac0f9304eb0"],
Cell[1618254, 43193, 767, 22, 4302, "Input", "ExpressionUUID" -> \
"29573e98-05de-493b-9105-ce4e09dcbbf8"],
Cell[1619024, 43217, 71, 0, 2553, "Text", "ExpressionUUID" -> \
"04361a78-e3b4-42e7-b66b-4fbdf4b117df"]
}, Closed]],
Cell[CellGroupData[{
Cell[1619132, 43222, 558, 9, 79, "Subsubsection", "ExpressionUUID" -> \
"1b09c752-f109-426a-bbdc-b7cd39676813"],
Cell[1619693, 43233, 221, 5, 2553, "Text", "ExpressionUUID" -> \
"615f9207-78c2-40ee-a4c0-5f4751519faf"],
Cell[1619917, 43240, 461, 16, 5224, "Input", "ExpressionUUID" -> \
"77d5ba51-4851-492b-b86b-e80f04b04d98",
 Evaluatable->False],
Cell[1620381, 43258, 169, 3, 2553, "Text", "ExpressionUUID" -> \
"9cacca62-63c0-4a77-a28c-5f990c1bd61b"],
Cell[1620553, 43263, 514, 17, 5224, "Input", "ExpressionUUID" -> \
"204d47a0-e1f9-47f2-b6e9-7900827fb982",
 Evaluatable->False],
Cell[1621070, 43282, 895, 23, 4374, "Text", "ExpressionUUID" -> \
"ce7d2f0e-11f4-4016-930a-a35a76856eb4"],
Cell[1621968, 43307, 414, 11, 2553, "Input", "ExpressionUUID" -> \
"293be2bd-1e35-497a-8083-17c7a032dc21"],
Cell[1622385, 43320, 668, 18, 2553, "Input", "ExpressionUUID" -> \
"31419d0f-5841-41d0-b277-3d6173ca6cb0"],
Cell[1623056, 43340, 1084, 29, 4302, "Input", "ExpressionUUID" -> \
"19eaac01-73ea-46de-a723-4c6c6a888078"],
Cell[1624143, 43371, 195, 3, 2553, "Text", "ExpressionUUID" -> \
"d41f07f9-4807-41a0-86a5-63b322cb11be"],
Cell[1624341, 43376, 391, 8, 2553, "Input", "ExpressionUUID" -> \
"38a329b2-3ba3-47c2-a515-2afa4e9ed089"],
Cell[1624735, 43386, 447, 12, 2553, "Input", "ExpressionUUID" -> \
"edc17631-b682-4b2b-9206-0e9911d5dfcf"],
Cell[1625185, 43400, 185, 3, 2553, "Text", "ExpressionUUID" -> \
"f006728c-5e83-4e97-b8c1-26cec375d50b"],
Cell[1625373, 43405, 593, 15, 2673, "Text", "ExpressionUUID" -> \
"3c8064c2-3ec0-4592-9f69-217a5ff0c694"],
Cell[1625969, 43422, 259, 6, 2553, "Text", "ExpressionUUID" -> \
"596c478d-cedd-4e33-bebe-e73588ac28ac"],
Cell[1626231, 43430, 1150, 27, 4302, "Input", "ExpressionUUID" -> \
"521ce8f5-8432-480f-bbe2-c7a361e04674"],
Cell[1627384, 43459, 343, 8, 5851, "Text", "ExpressionUUID" -> \
"b76c01fe-399a-47d7-a875-6c2dd62826c4"],
Cell[1627730, 43469, 497, 14, 2673, "Text", "ExpressionUUID" -> \
"ab52320a-c47f-41e9-adfd-741f7141bfa7"],
Cell[1628230, 43485, 194, 3, 2553, "Text", "ExpressionUUID" -> \
"a332f403-54ac-490f-9ce6-aee4a13ddb52"],
Cell[1628427, 43490, 516, 19, 6603, "Input", "ExpressionUUID" -> \
"923a01e4-fee6-462e-b6c5-2380c188de7a",
 Evaluatable->False],
Cell[1628946, 43511, 1562, 33, 7627, "Input", "ExpressionUUID" -> \
"d90cdb77-ee02-4cfc-99eb-c3905a6e8d3e"],
Cell[1630511, 43546, 296, 7, 4240, "Text", "ExpressionUUID" -> \
"4c320d1c-c316-4a0b-8524-5cdf0a48dfea"],
Cell[1630810, 43555, 846, 21, 5986, "Input", "ExpressionUUID" -> \
"bac9fedf-d541-457c-aa2b-8bed180a058a"],
Cell[1631659, 43578, 481, 12, 2553, "Input", "ExpressionUUID" -> \
"b1fa3d2d-6eda-4491-8142-8233250dad64"],
Cell[1632143, 43592, 591, 14, 2553, "Input", "ExpressionUUID" -> \
"97b6ec08-d47b-401d-b19e-f206ed5bb571"],
Cell[1632737, 43608, 342, 9, 3687, "Input", "ExpressionUUID" -> \
"0061528c-72c1-4f0d-914d-59a1f457ae87"],
Cell[1633082, 43619, 321, 8, 2553, "Input", "ExpressionUUID" -> \
"329410bd-0896-4b68-904b-116185a048c2"],
Cell[1633406, 43629, 529, 16, 5743, "Input", "ExpressionUUID" -> \
"d3a83006-458a-44b4-9143-fc9a4ec07143"],
Cell[1633938, 43647, 368, 9, 2553, "Input", "ExpressionUUID" -> \
"a2181e9a-de94-4096-8a07-24a60d5c73b2"],
Cell[1634309, 43658, 314, 8, 2553, "Input", "ExpressionUUID" -> \
"7e5bbd4b-85b6-4373-80d4-dee8590f4b00"],
Cell[1634626, 43668, 916, 24, 5986, "Input", "ExpressionUUID" -> \
"4dabee3e-7fbd-4db9-9cf4-1ebd5831b8f4"],
Cell[1635545, 43694, 966, 26, 7627, "Input", "ExpressionUUID" -> \
"662ddc16-6116-43ef-ba9c-091d57b77c67"],
Cell[1636514, 43722, 349, 9, 2553, "Input", "ExpressionUUID" -> \
"214a811b-30d1-445e-be2e-2963b2e4497e"],
Cell[1636866, 43733, 310, 7, 4302, "Text", "ExpressionUUID" -> \
"15a0f0ca-5580-4dd5-a442-721c404c3319"]
}, Closed]],
Cell[CellGroupData[{
Cell[1637213, 43745, 509, 9, 79, "Subsubsection", "ExpressionUUID" -> \
"8d7c5d95-b343-43e2-adb5-582904d4c0ce"],
Cell[1637725, 43756, 222, 5, 2553, "Text", "ExpressionUUID" -> \
"09346680-d161-4caa-a894-1199b563311a"],
Cell[1637950, 43763, 569, 15, 2553, "Input", "ExpressionUUID" -> \
"c2a1026c-042b-4b54-8c0d-5879ecdb890d"],
Cell[1638522, 43780, 611, 17, 2553, "Input", "ExpressionUUID" -> \
"39a21ae9-70f5-4d1f-901a-e38cf799761e"],
Cell[1639136, 43799, 258, 4, 2553, "Text", "ExpressionUUID" -> \
"ee8e4dbd-4bd0-4aff-9824-8dfc41dc7e1d"],
Cell[1639397, 43805, 174, 3, 2553, "Text", "ExpressionUUID" -> \
"b2167e35-2338-471d-88be-3732fedfd898"],
Cell[1639574, 43810, 671, 20, 4302, "Input", "ExpressionUUID" -> \
"d40fc9a1-84cd-4397-9192-dd693ef77f8e"],
Cell[1640248, 43832, 151, 3, 2553, "Text", "ExpressionUUID" -> \
"e7864f72-0750-492d-9ef2-6f053aad6322"],
Cell[1640402, 43837, 365, 10, 2553, "Input", "ExpressionUUID" -> \
"04a97338-0f8f-4383-bc42-a659be88609f"],
Cell[1640770, 43849, 234, 6, 2553, "Input", "ExpressionUUID" -> \
"e35194ca-e913-4580-b2e9-40b057dc32e3"],
Cell[1641007, 43857, 183, 3, 2553, "Text", "ExpressionUUID" -> \
"c72d03dc-3e38-4f10-89d1-9e9cc255f7ba"],
Cell[1641193, 43862, 652, 17, 3901, "Input", "ExpressionUUID" -> \
"2313227a-7cd6-41f5-8d0c-b76ed6578c36"],
Cell[1641848, 43881, 435, 12, 2553, "Input", "ExpressionUUID" -> \
"8754c8f4-2dc0-476e-befc-1065ae979884"],
Cell[1642286, 43895, 153, 3, 2553, "Text", "ExpressionUUID" -> \
"256446ec-1b53-468f-9215-0026c6fd9094"],
Cell[1642442, 43900, 1334, 42, 12669, "Input", "ExpressionUUID" -> \
"1d23317d-78ed-4fac-bd26-654ccb8a2261"],
Cell[1643779, 43944, 173, 3, 2553, "Text", "ExpressionUUID" -> \
"7ac2f25d-ea22-40c9-a154-bcb20ecf178c"],
Cell[1643955, 43949, 800, 20, 4302, "Input", "ExpressionUUID" -> \
"ecd098e4-b09b-40a8-8785-e508ae8ed258"],
Cell[1644758, 43971, 682, 19, 4302, "Input", "ExpressionUUID" -> \
"37fc42e8-0343-4b54-a3b9-a647a8d0add4"],
Cell[1645443, 43992, 298, 6, 2553, "Text", "ExpressionUUID" -> \
"24f0f175-9dfe-44fb-9cc0-1c78a00a087d"],
Cell[1645744, 44000, 375, 10, 2553, "Input", "ExpressionUUID" -> \
"53e7634d-90c3-4cfe-8135-a6b7b199944e"],
Cell[1646122, 44012, 1412, 41, 10755, "Input", "ExpressionUUID" -> \
"fc34d483-e541-4f9c-94ab-efcf984eaa05"],
Cell[1647537, 44055, 315, 6, 2553, "Text", "ExpressionUUID" -> \
"14a66347-ea9f-45fc-883c-8fb2b284a85e"],
Cell[1647855, 44063, 1070, 25, 4302, "Input", "ExpressionUUID" -> \
"8d9a67cf-217a-48b8-ae71-474e00e05b31"],
Cell[1648928, 44090, 1366, 41, 7992, "Input", "ExpressionUUID" -> \
"951d23f7-44c9-49b0-a983-c3c991067577"],
Cell[1650297, 44133, 1138, 36, 7137, "Input", "ExpressionUUID" -> \
"23de8671-9a39-4297-9a6f-333455e39163"],
Cell[1651438, 44171, 230, 4, 2553, "Text", "ExpressionUUID" -> \
"69efac00-0a20-42a9-b5f8-cd6d68f33e4e"],
Cell[1651671, 44177, 362, 9, 2553, "Input", "ExpressionUUID" -> \
"8441f82f-db2e-4844-a05b-3d3a600cb07c"],
Cell[1652036, 44188, 71, 0, 2553, "Text", "ExpressionUUID" -> \
"0352dcfc-276c-4add-88a3-f12665ad7c02"],
Cell[1652110, 44190, 198, 3, 2553, "Text", "ExpressionUUID" -> \
"b47fe0b4-84a1-402d-b626-7732d347ee1f"],
Cell[1652311, 44195, 505, 15, 2553, "Input", "ExpressionUUID" -> \
"a9c75d21-f394-444b-8166-56257f03d2b9"],
Cell[1652819, 44212, 275, 6, 4240, "Text", "ExpressionUUID" -> \
"3d6a85df-9ab0-494f-b733-aa81dd55f8a7"],
Cell[1653097, 44220, 235, 7, 2553, "Input", "ExpressionUUID" -> \
"86beec31-ccfa-49d6-beff-12d508790ac7"],
Cell[1653335, 44229, 303, 8, 2553, "Input", "ExpressionUUID" -> \
"bba7869f-7464-4421-b336-fb28868df86d"],
Cell[1653641, 44239, 218, 5, 2553, "Text", "ExpressionUUID" -> \
"80bbc702-8704-4361-9f46-6b411766d6ff"],
Cell[1653862, 44246, 450, 11, 2553, "Input", "ExpressionUUID" -> \
"a4d927fe-3b54-4b9f-a678-33476f2ef939"],
Cell[1654315, 44259, 370, 8, 4302, "Text", "ExpressionUUID" -> \
"3b1ed4e5-397e-452e-93bb-aa3380ff653f"],
Cell[1654688, 44269, 438, 13, 2553, "Text", "ExpressionUUID" -> \
"1dea2bf7-2fa1-43e1-940e-448d54f68e70"],
Cell[1655129, 44284, 167, 3, 2553, "Text", "ExpressionUUID" -> \
"10c853f4-9993-41ee-ab0b-e7924ac0c0d7"],
Cell[1655299, 44289, 423, 11, 2553, "Input", "ExpressionUUID" -> \
"205ceaf2-8c26-438f-83d1-b40106a29551"],
Cell[1655725, 44302, 874, 24, 4302, "Input", "ExpressionUUID" -> \
"7661cd99-050a-40bd-a47e-6adfba6b363d"],
Cell[1656602, 44328, 412, 9, 5851, "Text", "ExpressionUUID" -> \
"4c1076b1-038e-430b-8951-9bac0fc886c1"],
Cell[1657017, 44339, 420, 12, 2553, "Input", "ExpressionUUID" -> \
"7f9906fc-b2b9-4a67-964b-abd433366516"],
Cell[1657440, 44353, 167, 3, 2553, "Text", "ExpressionUUID" -> \
"7c4eb20d-90dd-495f-a9a3-058637ba9235"],
Cell[1657610, 44358, 358, 10, 2553, "Input", "ExpressionUUID" -> \
"097583b7-08ed-4c31-aa85-e9a6af2c2140"],
Cell[1657971, 44370, 257, 7, 2553, "Input", "ExpressionUUID" -> \
"0f7ea369-0f6b-48dd-9e05-1b28ed42ed07"],
Cell[1658231, 44379, 935, 29, 4302, "Input", "ExpressionUUID" -> \
"49ea0d24-5f02-432e-8855-397d60c0aa6a"],
Cell[1659169, 44410, 671, 21, 5986, "Input", "ExpressionUUID" -> \
"c0f211ad-870b-4496-9c81-0195cec1ced7"],
Cell[1659843, 44433, 1141, 27, 4302, "Input", "ExpressionUUID" -> \
"aae0b1db-97c8-4b79-9043-f3c7cd581027"],
Cell[1660987, 44462, 226, 3, 2553, "Text", "ExpressionUUID" -> \
"eb1a0026-db8a-4333-9c9a-8d0b1b691152"],
Cell[1661216, 44467, 779, 20, 4302, "Input", "ExpressionUUID" -> \
"d98a4683-497d-49e7-83b4-14ef020c2def"],
Cell[1661998, 44489, 208, 4, 2553, "Text", "ExpressionUUID" -> \
"454bd328-f29d-4954-b140-665c7c202521"],
Cell[1662209, 44495, 548, 15, 2553, "Input", "ExpressionUUID" -> \
"e451658d-4708-45ac-bcb1-471c6d803597"],
Cell[1662760, 44512, 168, 3, 2553, "Text", "ExpressionUUID" -> \
"941a9319-4bd7-4c5a-9963-538d3562110f"],
Cell[1662931, 44517, 354, 10, 2553, "Input", "ExpressionUUID" -> \
"bcd3333b-7feb-40ea-8e3b-1f9f98a5e2b3"],
Cell[1663288, 44529, 257, 7, 2553, "Input", "ExpressionUUID" -> \
"65401bed-9538-4f10-9065-c050c6fc64cb"],
Cell[1663548, 44538, 913, 25, 4302, "Input", "ExpressionUUID" -> \
"4e7fbaba-50c6-4044-b599-b13b91fe8a81"],
Cell[1664464, 44565, 935, 28, 7627, "Input", "ExpressionUUID" -> \
"c948cf4c-25ab-43e4-9a1c-56aac28b9c56"],
Cell[1665402, 44595, 250, 4, 2553, "Text", "ExpressionUUID" -> \
"324bccdb-a093-4d2c-bff4-6076c43add0b"],
Cell[1665655, 44601, 1097, 31, 4302, "Input", "ExpressionUUID" -> \
"36963391-5467-4766-9121-66682a7b3a4f"],
Cell[1666755, 44634, 171, 3, 2553, "Text", "ExpressionUUID" -> \
"36f48c6f-0361-4608-8c7d-393fa93b7d62"],
Cell[1666929, 44639, 1388, 33, 6246, "Input", "ExpressionUUID" -> \
"fc782331-cb2c-46be-bea7-7901bdce31c5"],
Cell[1668320, 44674, 228, 3, 2553, "Text", "ExpressionUUID" -> \
"0b124227-5a69-4a6d-9208-5e42473b77fe"],
Cell[1668551, 44679, 829, 21, 4302, "Input", "ExpressionUUID" -> \
"642d8488-aa84-414e-aec7-7122038986e5"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1669441, 44707, 693, 10, 150, "Section", "ExpressionUUID" -> \
"5f4ec5b5-2803-4131-800c-cdbb3fd48eec"],
Cell[1670137, 44719, 1819, 29, 310, "Text", "ExpressionUUID" -> \
"647dcd56-8360-40a1-9960-b041bcffd2fe"],
Cell[CellGroupData[{
Cell[1671981, 44752, 549, 8, 67, "Subsection", "ExpressionUUID" -> \
"c678b81e-38c7-47c7-917d-bd353985def1"],
Cell[1672533, 44762, 1115, 30, 83, "Text", "ExpressionUUID" -> \
"b8772e62-bc3e-4635-ad73-92c0db9be3b8"],
Cell[1673651, 44794, 909, 26, 53, "Text", "ExpressionUUID" -> \
"16d76b09-d466-4cb5-94be-e9ad2831e8a6"],
Cell[1674563, 44822, 2468, 60, 278, "Text", "ExpressionUUID" -> \
"97155085-6dc3-41b0-8542-c3ebe74123f1"],
Cell[1677034, 44884, 499, 11, 49, "Input", "ExpressionUUID" -> \
"f96e39e4-be84-42ea-9ac4-6e388fd02feb"],
Cell[1677536, 44897, 526, 13, 83, "Text", "ExpressionUUID" -> \
"015db320-63f2-402a-a81b-1f17fe170cd6"],
Cell[1678065, 44912, 1236, 25, 140, "Input", "ExpressionUUID" -> \
"501eb934-9243-4c7b-943c-e2c49f3d6469",
 InitializationCell->True],
Cell[1679304, 44939, 383, 10, 49, "Input", "ExpressionUUID" -> \
"62582ae2-370d-4eb1-ba8f-399b0803d40a"],
Cell[1679690, 44951, 815, 17, 148, "Text", "ExpressionUUID" -> \
"76687c56-cac0-4f9c-ba57-f0f36bd50249"],
Cell[1680508, 44970, 274, 7, 49, "Input", "ExpressionUUID" -> \
"00ece133-1551-4027-ab27-978276fdf90e"],
Cell[1680785, 44979, 193, 4, 49, "Input", "ExpressionUUID" -> \
"139d82f5-deff-4664-b395-629e41680ec0"],
Cell[1680981, 44985, 610, 16, 1257, "Text", "ExpressionUUID" -> \
"70f52200-9eaa-48b4-b215-45f488c9bd34"],
Cell[1681594, 45003, 493, 11, 757, "Text", "ExpressionUUID" -> \
"f492832b-211a-4c3c-9e18-8704a682a190"],
Cell[1682090, 45016, 907, 17, 757, "Input", "ExpressionUUID" -> \
"64239994-7511-4387-8413-ed8196a9b09b",
 Evaluatable->False],
Cell[1683000, 45035, 250, 5, 757, "Input", "ExpressionUUID" -> \
"90ce71c9-79ba-4ea7-93b7-5f9a8051fe28"],
Cell[1683253, 45042, 314, 8, 757, "Text", "ExpressionUUID" -> \
"53d6246b-a747-4dcd-9c91-c05eba894e66"],
Cell[1683570, 45052, 509, 11, 757, "Input", "ExpressionUUID" -> \
"fa6a7db0-86ba-4eac-81af-80280d05896b"],
Cell[1684082, 45065, 319, 8, 757, "Input", "ExpressionUUID" -> \
"976a4cdc-84d5-42ae-bc18-2dcf7eeeca6e"],
Cell[1684404, 45075, 406, 10, 757, "Input", "ExpressionUUID" -> \
"2484b126-c0ba-4aab-8a36-ec2ff53aaf49"],
Cell[1684813, 45087, 602, 17, 757, "Input", "ExpressionUUID" -> \
"b813b6d3-e37f-46e1-9528-0ee28c2de332"],
Cell[1685418, 45106, 312, 8, 757, "Input", "ExpressionUUID" -> \
"569b3e0f-2f96-4ee2-a6fc-a6dc80260ab5"],
Cell[1685733, 45116, 1122, 29, 2796, "Text", "ExpressionUUID" -> \
"78c26543-4ab3-47e5-9481-882c3f94cdbf"],
Cell[1686858, 45147, 885, 18, 1734, "Text", "ExpressionUUID" -> \
"097357c5-7c44-444e-b8aa-00c14282b4f5"],
Cell[1687746, 45167, 175, 4, 757, "Input", "ExpressionUUID" -> \
"6b33f5ce-730d-41f2-b13b-6a4dc98fbe01"],
Cell[1687924, 45173, 1383, 40, 2260, "Input", "ExpressionUUID" -> \
"f9ba31f0-ab07-4011-816c-caa8a63d47b2",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1689332, 45217, 1356, 26, 757, "Input", "ExpressionUUID" -> \
"d48a2a28-01ad-4fc2-a733-449820149796",
 InitializationCell->True],
Cell[1690691, 45245, 135, 3, 70, "Output", "ExpressionUUID" -> \
"e139839f-eb67-457a-b834-1949358f5c70"]
}, Open  ]],
Cell[1690841, 45251, 405, 9, 757, "Input", "ExpressionUUID" -> \
"512fdea8-ff6d-4604-a720-72155102f40a"],
Cell[1691249, 45262, 480, 10, 1257, "Text", "ExpressionUUID" -> \
"7e96203f-c158-46fa-ba0f-bdcaba98f11d"],
Cell[1691732, 45274, 326, 8, 757, "Input", "ExpressionUUID" -> \
"d3f4a919-8d52-4634-a656-8abf6cbeb7c8"],
Cell[1692061, 45284, 389, 10, 757, "Input", "ExpressionUUID" -> \
"430ef44a-fb50-423d-9c25-ac6fdf0ac453"],
Cell[1692453, 45296, 481, 10, 757, "Input", "ExpressionUUID" -> \
"b34773a0-58bf-426f-948f-0d7d3da94454"],
Cell[1692937, 45308, 555, 12, 757, "Input", "ExpressionUUID" -> \
"0cca0950-033e-41c6-851b-ae21b9430629"],
Cell[1693495, 45322, 382, 8, 1257, "Text", "ExpressionUUID" -> \
"b54e8b61-8797-4fd2-be6b-3b984f5a1936"],
Cell[1693880, 45332, 278, 5, 757, "Input", "ExpressionUUID" -> \
"7e32b062-d7be-48a9-8889-387deb9054ce"],
Cell[1694161, 45339, 155, 3, 757, "Input", "ExpressionUUID" -> \
"a6af18f9-b586-48d8-b7be-f07e6870854d"],
Cell[1694319, 45344, 209, 5, 757, "Input", "ExpressionUUID" -> \
"365d587d-0773-4bb7-9559-49c816b573a0"],
Cell[1694531, 45351, 402, 11, 757, "Input", "ExpressionUUID" -> \
"a8681635-e7a0-43c1-806b-906852f41016",
 InitializationCell->True],
Cell[1694936, 45364, 337, 8, 2260, "Input", "ExpressionUUID" -> \
"30eb0684-df76-4600-b000-1c9774218ef2",
 InitializationCell->True],
Cell[1695276, 45374, 275, 6, 757, "Input", "ExpressionUUID" -> \
"12b92785-0a5e-4c25-9198-50eba527879a"],
Cell[1695554, 45382, 460, 12, 757, "Input", "ExpressionUUID" -> \
"ca87e1ed-8969-4936-bb08-a489f647a37f"],
Cell[1696017, 45396, 377, 8, 757, "Input", "ExpressionUUID" -> \
"7a018e16-edd0-48eb-a516-8f965dbdd6f7"],
Cell[1696397, 45406, 266, 6, 757, "Text", "ExpressionUUID" -> \
"8a3c6f31-ff16-4f37-90aa-9d5b845fe0bf"],
Cell[1696666, 45414, 148, 4, 757, "Input", "ExpressionUUID" -> \
"67da66c2-e522-4e3d-ad6a-c40590f87d1d"],
Cell[1696817, 45420, 1377, 36, 1774, "Input", "ExpressionUUID" -> \
"3cfb39a1-1236-49ba-ba02-e7c4335091ed"],
Cell[1698197, 45458, 614, 15, 757, "Input", "ExpressionUUID" -> \
"059e2020-39b9-4201-8e3c-41723c248e73"],
Cell[1698814, 45475, 420, 10, 757, "Input", "ExpressionUUID" -> \
"0b437ae9-cca4-4985-aece-e86ed14ce3ad"],
Cell[1699237, 45487, 861, 16, 2776, "Text", "ExpressionUUID" -> \
"d114fb52-9794-496e-b15a-051e92dd326c"],
Cell[1700101, 45505, 895, 21, 1782, "Text", "ExpressionUUID" -> \
"2a4b4628-2f82-4421-9af3-c77343dd27e5"],
Cell[1700999, 45528, 825, 19, 757, "Input", "ExpressionUUID" -> \
"03d7e59d-5ba7-4cb3-b5a6-1a80497e04bc",
 Evaluatable->False],
Cell[1701827, 45549, 299, 6, 757, "Input", "ExpressionUUID" -> \
"6c8c2872-dd7a-4596-8b3d-4516a2021369"],
Cell[1702129, 45557, 289, 7, 757, "Input", "ExpressionUUID" -> \
"d4a10cc8-cfb8-466b-9df0-741c9fcdc49b"],
Cell[1702421, 45566, 686, 20, 757, "Input", "ExpressionUUID" -> \
"2d3deb2c-9358-44a6-a822-11d9edbc44b1"],
Cell[1703110, 45588, 955, 21, 1734, "Text", "ExpressionUUID" -> \
"da7fbd98-550c-4d9d-85ec-04f92d4ff066"],
Cell[1704068, 45611, 986, 27, 1275, "Input", "ExpressionUUID" -> \
"2effd100-c50a-4b8e-a9dd-2a132c718ee5"],
Cell[1705057, 45640, 247, 5, 757, "Input", "ExpressionUUID" -> \
"82bbc425-344b-4998-ac71-fbcd9b9341ed"],
Cell[1705307, 45647, 1478, 32, 1275, "Input", "ExpressionUUID" -> \
"448c40d4-7e93-40b4-b619-5a275ea7fda4",
 Evaluatable->False],
Cell[1706788, 45681, 730, 18, 757, "Input", "ExpressionUUID" -> \
"af8401c8-8eaa-488d-b5e4-a4ba53c3806a"],
Cell[1707521, 45701, 665, 15, 1275, "Input", "ExpressionUUID" -> \
"dfd2999d-f64b-4825-b36a-ecd5c32b1fee"],
Cell[1708189, 45718, 724, 15, 757, "Input", "ExpressionUUID" -> \
"f69fdbce-cc5d-405e-8154-3bbcbd669880"],
Cell[1708916, 45735, 213, 5, 757, "Input", "ExpressionUUID" -> \
"d88f98d9-603a-4e19-8b41-8db0a62a1a34"],
Cell[1709132, 45742, 356, 7, 1257, "Text", "ExpressionUUID" -> \
"7e615752-8122-4c95-ac4a-c3e382846ef6"],
Cell[1709491, 45751, 415, 12, 757, "Input", "ExpressionUUID" -> \
"58bb803d-3329-4f7a-92c4-cbeb18627b56"],
Cell[1709909, 45765, 465, 13, 757, "Input", "ExpressionUUID" -> \
"bb92c58f-3ff1-4f13-8590-d6da525ede10"],
Cell[1710377, 45780, 341, 7, 1257, "Text", "ExpressionUUID" -> \
"72ae63ed-a570-42d3-b1c5-fb41d8c67501",
 CellTags->"fund1"],
Cell[1710721, 45789, 227, 5, 757, "Input", "ExpressionUUID" -> \
"cead7f15-4d70-401c-837f-0c9f16161cd3"],
Cell[1710951, 45796, 319, 6, 757, "Text", "ExpressionUUID" -> \
"64746e18-674b-4d43-a733-fa31e4ae0ede"],
Cell[1711273, 45804, 461, 11, 757, "Input", "ExpressionUUID" -> \
"df41a4a5-b2f0-44b2-bd4a-70efe3fbc9c6"],
Cell[1711737, 45817, 197, 4, 757, "Input", "ExpressionUUID" -> \
"a984be3b-54e9-45c9-9967-05651117cb4d"],
Cell[1711937, 45823, 482, 13, 757, "Input", "ExpressionUUID" -> \
"ec73bb02-744c-44a2-8190-017c4a0fa859"],
Cell[1712422, 45838, 454, 13, 757, "Input", "ExpressionUUID" -> \
"7da094c1-63f3-4941-a7b0-aab22a48d035"],
Cell[1712879, 45853, 1647, 42, 2260, "Input", "ExpressionUUID" -> \
"eab6ddfd-bc4c-4966-9738-fc05a73efbe9"],
Cell[1714529, 45897, 1346, 34, 1774, "Input", "ExpressionUUID" -> \
"0103e7e5-5178-4c5d-9d6d-7bd936ee702a"],
Cell[1715878, 45933, 1220, 30, 1275, "Input", "ExpressionUUID" -> \
"445b5e0b-96a3-473c-935e-ad01722dd058"],
Cell[1717101, 45965, 1668, 29, 1296, "Text", "ExpressionUUID" -> \
"f504624e-141c-4923-8c5c-79fdf22df31e"],
Cell[1718772, 45996, 757, 23, 757, "Input", "ExpressionUUID" -> \
"76fd8578-c4e4-44e2-806d-cb0e2772208d",
 Evaluatable->False],
Cell[1719532, 46021, 2435, 54, 1396, "Text", "ExpressionUUID" -> \
"597aeb70-0ed9-479f-bb7c-0cfae59c018b"],
Cell[1721970, 46077, 3279, 62, 5334, "Text", "ExpressionUUID" -> \
"4cc30722-f366-4cd7-b143-6a272827153a"],
Cell[1725252, 46141, 1962, 35, 1296, "Text", "ExpressionUUID" -> \
"9927d65b-26eb-4497-8cc7-ec35d6987363"],
Cell[1727217, 46178, 2010, 42, 1774, "Input", "ExpressionUUID" -> \
"e2c7944f-b832-4a53-a82e-ffacb068e699",
 Evaluatable->False],
Cell[1729230, 46222, 277, 5, 757, "Input", "ExpressionUUID" -> \
"46eed605-c581-4601-b7bf-a33f83e1b82e"],
Cell[1729510, 46229, 551, 9, 2229, "Text", "ExpressionUUID" -> \
"48c498c0-0758-4743-82b7-0d1265609919"],
Cell[1730064, 46240, 1808, 40, 1774, "Input", "ExpressionUUID" -> \
"c9b21717-7a9a-4d2a-a9ca-14abfe309547",
 Evaluatable->False],
Cell[1731875, 46282, 326, 6, 757, "Input", "ExpressionUUID" -> \
"65db0e4d-862a-40e5-bd40-3531b74135f0"],
Cell[1732204, 46290, 287, 5, 778, "Text", "ExpressionUUID" -> \
"e36a6b53-4e65-42e4-b2e1-e511a14a4c1f"],
Cell[1732494, 46297, 206, 5, 757, "Input", "ExpressionUUID" -> \
"4002f14f-bc58-43b8-a04f-40300ca02fb8"],
Cell[1732703, 46304, 697, 17, 757, "Input", "ExpressionUUID" -> \
"c0b8be54-ae75-41cd-be95-f2cefb468c3d"],
Cell[1733403, 46323, 383, 10, 757, "Input", "ExpressionUUID" -> \
"dceb4031-274d-48c4-9e4a-7e665783d36d"],
Cell[1733789, 46335, 174, 3, 757, "Text", "ExpressionUUID" -> \
"d45704e3-7640-42c8-b8a3-4e2722b79ea1"],
Cell[1733966, 46340, 1763, 41, 1774, "Input", "ExpressionUUID" -> \
"7191e61c-986d-4619-9b42-9758f7db524e"],
Cell[1735732, 46383, 602, 12, 1296, "Text", "ExpressionUUID" -> \
"06428679-a5cb-4375-9d43-051b997d50d6"],
Cell[1736337, 46397, 756, 22, 1275, "Input", "ExpressionUUID" -> \
"b3205c90-f9de-4242-97d9-017706a98288"],
Cell[1737096, 46421, 202, 3, 757, "Text", "ExpressionUUID" -> \
"f80315e0-8b59-407f-8870-52dce8941a28"],
Cell[1737301, 46426, 176, 4, 757, "Input", "ExpressionUUID" -> \
"c9424cc9-bce5-4ce4-a6c5-c994467992fa"],
Cell[1737480, 46432, 497, 7, 778, "Text", "ExpressionUUID" -> \
"4857f664-9e02-4d44-977e-7dffbec00ff9"],
Cell[1737980, 46441, 453, 12, 757, "Input", "ExpressionUUID" -> \
"100acb7a-9238-4295-88ef-df7f962824db"],
Cell[1738436, 46455, 562, 14, 792, "Text", "ExpressionUUID" -> \
"1d5a51bb-357e-4996-925a-9bebe59c8e9f"],
Cell[1739001, 46471, 175, 4, 757, "Input", "ExpressionUUID" -> \
"2e87946a-af41-4ad8-b82f-d85d397f5ea1"],
Cell[1739179, 46477, 267, 6, 757, "Input", "ExpressionUUID" -> \
"12a33ff5-3c19-49e6-820f-5136e97493d3"],
Cell[1739449, 46485, 438, 11, 792, "Text", "ExpressionUUID" -> \
"dd35dcc3-7d5c-425f-abbe-5ef9616e0801"],
Cell[1739890, 46498, 173, 4, 757, "Input", "ExpressionUUID" -> \
"f08d47f6-0ddb-4b8c-af67-7b6cbaaa433c"],
Cell[1740066, 46504, 444, 11, 757, "Input", "ExpressionUUID" -> \
"5caf8a13-ba2e-4ca3-8b9b-b995417a913c"],
Cell[1740513, 46517, 686, 18, 757, "Input", "ExpressionUUID" -> \
"5c2a1ea4-0d62-432f-a67a-ab7274db9a9d"],
Cell[1741202, 46537, 557, 12, 757, "Text", "ExpressionUUID" -> \
"f5667d33-0686-4dd8-b02d-be4f19e866c8"],
Cell[1741762, 46551, 768, 19, 757, "Input", "ExpressionUUID" -> \
"cd8bb374-beef-4448-9b51-004e8076d8fc"],
Cell[1742533, 46572, 765, 19, 757, "Input", "ExpressionUUID" -> \
"9ff7aacb-cdaa-4f8c-9d18-9776cf203836"],
Cell[1743301, 46593, 418, 10, 757, "Input", "ExpressionUUID" -> \
"d289c1e8-f8e6-48e6-8093-ba066eefcedd"],
Cell[1743722, 46605, 252, 4, 757, "Text", "ExpressionUUID" -> \
"4e6162c4-42d8-4d6b-a61b-975e15a78084"],
Cell[1743977, 46611, 205, 4, 757, "Input", "ExpressionUUID" -> \
"19b92b45-7af9-4317-8b89-a7a7bacc5e24"],
Cell[1744185, 46617, 1103, 29, 1296, "Input", "ExpressionUUID" -> \
"c4da9fb4-9f2b-4970-af1a-d6ba8216c613"],
Cell[1745291, 46648, 161, 3, 757, "Text", "ExpressionUUID" -> \
"39dc236c-6c92-4508-9121-b889175b0fe3"]
}, Closed]],
Cell[CellGroupData[{
Cell[1745489, 46656, 670, 9, 53, "Subsection", "ExpressionUUID" -> \
"2e4a8a4e-f278-4288-b82f-376858181454"],
Cell[1746162, 46667, 604, 11, 83, "Text", "ExpressionUUID" -> \
"5c2cc25d-b509-41d9-9e8b-e2f4ea58a32e"],
Cell[1746769, 46680, 174, 4, 49, "Input", "ExpressionUUID" -> \
"efb7ea1f-46f8-416a-8b5e-2a23e2931e1d"],
Cell[1746946, 46686, 378, 9, 49, "Input", "ExpressionUUID" -> \
"a3fcfa9b-5380-4695-98c1-6b07fd16d1ae"],
Cell[CellGroupData[{
Cell[1747349, 46699, 603, 9, 53, "Subsubsection", "ExpressionUUID" -> \
"9e11b5e3-9154-4863-b121-e2b9743aaacd"],
Cell[1747955, 46710, 272, 6, 111, "Text", "ExpressionUUID" -> \
"c4038bcd-e4eb-482e-9105-9e70d27c88c7"],
Cell[1748230, 46718, 743, 17, 67, "Input", "ExpressionUUID" -> \
"efe326ea-32f3-4ea0-a448-c3c79f97dea7"],
Cell[1748976, 46737, 499, 8, 67, "Text", "ExpressionUUID" -> \
"dc443a1f-f65a-4ef4-a697-533804fe10d1",
 InitializationCell->True],
Cell[1749478, 46747, 174, 4, 67, "Input", "ExpressionUUID" -> \
"6717af7f-bb2c-46b4-b90a-4fdf2d442a4f"],
Cell[1749655, 46753, 153, 3, 67, "Text", "ExpressionUUID" -> \
"187aa895-2543-47b5-954a-4f086d5940e5"],
Cell[1749811, 46758, 329, 8, 67, "Input", "ExpressionUUID" -> \
"b798724b-8a93-4b59-a4fa-ab82d4f74fd5"],
Cell[1750143, 46768, 313, 8, 67, "Input", "ExpressionUUID" -> \
"0500925d-d422-4058-bda4-89d2a6d293c1"],
Cell[1750459, 46778, 4647, 155, 445, "Input", "ExpressionUUID" -> \
"8471c876-dae2-402d-9373-f95465b51445"],
Cell[1755109, 46935, 639, 13, 111, "Text", "ExpressionUUID" -> \
"b01f6264-7b03-4d39-bf8c-b4f213cb121d"],
Cell[1755751, 46950, 340, 9, 67, "Input", "ExpressionUUID" -> \
"b5f5a934-fb40-4dc2-9b30-21e19f909a8e"],
Cell[1756094, 46961, 191, 4, 67, "Input", "ExpressionUUID" -> \
"c2d80f76-0997-45b9-b1f2-f32a7fb43348"],
Cell[1756288, 46967, 371, 5, 67, "Text", "ExpressionUUID" -> \
"69a3fcf6-05f0-45b3-a1a2-71092e3e97d2"],
Cell[1756662, 46974, 736, 21, 67, "Input", "ExpressionUUID" -> \
"9795bfc4-b966-4869-9a47-30a687c37ebd"],
Cell[1757401, 46997, 562, 10, 111, "Text", "ExpressionUUID" -> \
"9109b17c-ce2f-4400-b88e-7811abb07c2e"],
Cell[1757966, 47009, 274, 7, 67, "Input", "ExpressionUUID" -> \
"78a50c4d-5f56-42d3-8ad8-843edaef6e69"],
Cell[1758243, 47018, 153, 3, 67, "Text", "ExpressionUUID" -> \
"447a4385-7e0f-4f00-a671-7c153a2703d9"],
Cell[1758399, 47023, 427, 12, 67, "Input", "ExpressionUUID" -> \
"b961d682-bb87-4afe-a008-1a35c90ca7ee"],
Cell[1758829, 47037, 508, 12, 70, "Text", "ExpressionUUID" -> \
"9f6db39f-e9cc-4637-990d-0526d5a66653",
 CellTags->"dtt(1)"],
Cell[1759340, 47051, 1411, 33, 228, "Input", "ExpressionUUID" -> \
"a0a1cf26-2052-48ac-8b87-e7142018e88e",
 Evaluatable->False],
Cell[1760754, 47086, 373, 7, 67, "Text", "ExpressionUUID" -> \
"98cb3cd5-c822-455d-8ab9-e54331af8221"],
Cell[1761130, 47095, 2782, 69, 243, "Input", "ExpressionUUID" -> \
"8003902a-b4a4-4c96-8846-77419f3d7ff5"],
Cell[1763915, 47166, 229, 4, 67, "Text", "ExpressionUUID" -> \
"ef7b550e-2c3b-4859-b2c2-2e18d1d9c21c"],
Cell[1764147, 47172, 608, 12, 69, "Text", "ExpressionUUID" -> \
"5cf87b02-44ae-45b7-b56f-3e2aee319898"],
Cell[1764758, 47186, 224, 5, 505, "Text", "ExpressionUUID" -> \
"79b1e99d-6897-4922-a4aa-1b3aef6602ac"],
Cell[1764985, 47193, 454, 11, 505, "Input", "ExpressionUUID" -> \
"05f46994-2e30-4215-838e-9f8e6ddb4dda"]
}, Closed]],
Cell[CellGroupData[{
Cell[1765476, 47209, 610, 9, 42, "Subsubsection", "ExpressionUUID" -> \
"e21f3bee-c927-47ce-8691-208ccf655c05"],
Cell[1766089, 47220, 1424, 33, 1296, "Text", "ExpressionUUID" -> \
"9f4cfc8f-87bb-43bc-b23e-85abab9eee39"],
Cell[1767516, 47255, 567, 16, 364, "Input", "ExpressionUUID" -> \
"f63fe126-7c27-44d5-9bce-c7fa94078afc",
 Evaluatable->False],
Cell[1768086, 47273, 621, 13, 366, "Text", "ExpressionUUID" -> \
"ef54a6d3-a474-401e-a491-11c37682de18"],
Cell[1768710, 47288, 639, 16, 364, "Input", "ExpressionUUID" -> \
"86b07100-f371-4735-9959-6a52a783ac7e",
 Evaluatable->False],
Cell[1769352, 47306, 1059, 28, 832, "Text", "ExpressionUUID" -> \
"b58f7618-c4df-4767-8fd1-4b065e8b157d"],
Cell[1770414, 47336, 1160, 37, 337, "Input", "ExpressionUUID" -> \
"dac7f6d6-9c4b-40e8-a932-b149c2c5b001",
 Evaluatable->False],
Cell[1771577, 47375, 178, 3, 337, "Text", "ExpressionUUID" -> \
"6d974933-c4ea-4ee3-970b-6e98ad7f4578"],
Cell[1771758, 47380, 547, 12, 438, "Input", "ExpressionUUID" -> \
"58fcef83-c115-42a4-a4f7-eba0efc77480"],
Cell[1772308, 47394, 183, 3, 337, "Text", "ExpressionUUID" -> \
"5b1f7b5a-513f-4e34-a2b0-e66c8980c7a5"],
Cell[1772494, 47399, 645, 18, 364, "Input", "ExpressionUUID" -> \
"45880239-f097-49f6-b26c-765c1ed92c93",
 Evaluatable->False],
Cell[1773142, 47419, 731, 18, 364, "Input", "ExpressionUUID" -> \
"e29c256f-bb9a-4010-a1cf-06a4a46532d2",
 Evaluatable->False],
Cell[1773876, 47439, 871, 24, 366, "Text", "ExpressionUUID" -> \
"a92c64d6-e5c5-4696-a4d2-0c1088750125"],
Cell[1774750, 47465, 555, 14, 378, "Input", "ExpressionUUID" -> \
"fb5b0a89-b721-4ac4-b6a8-047a0e69d8d6",
 Evaluatable->False],
Cell[1775308, 47481, 497, 12, 352, "Text", "ExpressionUUID" -> \
"790ca107-e74f-42ca-bad3-2d56a2e1a3eb"],
Cell[1775808, 47495, 422, 10, 337, "Input", "ExpressionUUID" -> \
"6237afd7-0622-4db9-ba0c-ac4580c3d53f",
 Evaluatable->False],
Cell[1776233, 47507, 192, 5, 337, "Input", "ExpressionUUID" -> \
"52c103ff-2472-4224-a30b-1495dd8b4759"],
Cell[1776428, 47514, 419, 10, 337, "Input", "ExpressionUUID" -> \
"6b7003c7-78d7-4fb6-b80f-a0e36eac6ae1"],
Cell[1776850, 47526, 159, 3, 337, "Text", "ExpressionUUID" -> \
"98887cef-1a8a-46bf-9088-18b2a0c7becc"],
Cell[1777012, 47531, 1031, 25, 378, "Input", "ExpressionUUID" -> \
"f91da7f6-8c6d-43b4-aa3c-2bd40560e6ca",
 Evaluatable->False],
Cell[1778046, 47558, 1015, 23, 595, "Text", "ExpressionUUID" -> \
"5a09168b-2444-4fb3-b22b-9bac445acacd"],
Cell[1779064, 47583, 1003, 26, 384, "Input", "ExpressionUUID" -> \
"e1821d45-05dd-4412-9534-bf9f9d914e2c",
 Evaluatable->False],
Cell[1780070, 47611, 454, 9, 559, "Text", "ExpressionUUID" -> \
"0d97f242-9668-4cfa-9ca2-7fc050f6b765"],
Cell[1780527, 47622, 1345, 37, 789, "Input", "ExpressionUUID" -> \
"d737e8fe-1cba-44ea-a61a-63f8faf2d8b5",
 Evaluatable->False],
Cell[1781875, 47661, 358, 6, 337, "Input", "ExpressionUUID" -> \
"a50ed442-315e-4373-a7f9-39bcea5bdcc0"],
Cell[1782236, 47669, 1413, 38, 789, "Input", "ExpressionUUID" -> \
"5437c38e-6a19-49a4-95c2-c6839234ff4f",
 Evaluatable->False],
Cell[1783652, 47709, 400, 7, 337, "Input", "ExpressionUUID" -> \
"d5e69197-9216-4a36-8d11-99034ec8b931"],
Cell[1784055, 47718, 389, 9, 337, "Input", "ExpressionUUID" -> \
"c354d8a2-d197-4ed9-af21-2affe1a25d63"],
Cell[1784447, 47729, 1176, 33, 789, "Input", "ExpressionUUID" -> \
"a4a5e15d-bc26-4b6f-87e0-b9097f525e8f"],
Cell[1785626, 47764, 365, 9, 337, "Text", "ExpressionUUID" -> \
"15fd1c59-c255-4ec1-baa0-9b154abc331b"],
Cell[1785994, 47775, 1105, 25, 567, "Input", "ExpressionUUID" -> \
"5f3dec69-9549-46a4-ad7d-91aa6404c29a"],
Cell[1787102, 47802, 1031, 24, 567, "Input", "ExpressionUUID" -> \
"78492d6d-ef49-4217-8b2a-4606e4f528a3"],
Cell[1788136, 47828, 650, 13, 337, "Input", "ExpressionUUID" -> \
"5ead49f2-080a-4552-aef8-9dd8f332aa9f"],
Cell[1788789, 47843, 173, 6, 559, "Text", "ExpressionUUID" -> \
"29963d93-8694-4492-97ed-91431b4b61ce"],
Cell[1788965, 47851, 345, 9, 337, "Text", "ExpressionUUID" -> \
"f5abfa98-4dda-45f0-bc47-374d3455dfbc"],
Cell[1789313, 47862, 1381, 39, 789, "Input", "ExpressionUUID" -> \
"363ae18f-d952-4779-b183-8b21c4c6be50",
 Evaluatable->False],
Cell[1790697, 47903, 252, 5, 337, "Input", "ExpressionUUID" -> \
"d1484664-7896-4e1a-a2ed-1541e3d4eca5"],
Cell[1790952, 47910, 356, 9, 337, "Text", "ExpressionUUID" -> \
"fc860fa6-4797-47f9-97b5-fe866dd9eb3d"],
Cell[1791311, 47921, 200, 3, 337, "Text", "ExpressionUUID" -> \
"e2334918-a14e-4f87-aeee-a4504fb8a990"],
Cell[1791514, 47926, 1028, 26, 789, "Input", "ExpressionUUID" -> \
"dfe75475-3779-4861-b6d9-fcb64ddc36b4"],
Cell[1792545, 47954, 556, 16, 337, "Input", "ExpressionUUID" -> \
"20b95051-36b7-4c65-8e0f-87c665a08762"],
Cell[1793104, 47972, 250, 4, 337, "Text", "ExpressionUUID" -> \
"280121e8-bbcb-4a92-bf96-17d6f8cefa38"],
Cell[1793357, 47978, 1077, 27, 789, "Input", "ExpressionUUID" -> \
"581eae12-6bd7-4ac5-9ff4-80009ffa86a7"],
Cell[1794437, 48007, 165, 3, 337, "Text", "ExpressionUUID" -> \
"3e6b5709-0e5a-45fe-b551-8b8fcfb8cbd6"],
Cell[1794605, 48012, 325, 8, 337, "Input", "ExpressionUUID" -> \
"c5925cfb-28ab-42a3-8342-23f33907fdf3"],
Cell[1794933, 48022, 187, 3, 337, "Text", "ExpressionUUID" -> \
"32bfbce0-f9a6-4bb1-b864-4ab232cfdd0e"],
Cell[1795123, 48027, 1145, 25, 337, "Input", "ExpressionUUID" -> \
"e1c35533-1930-4bfe-89a5-4f86060c9abb"],
Cell[1796271, 48054, 276, 6, 559, "Text", "ExpressionUUID" -> \
"33f7914c-3786-40ff-991c-076a2e38c8b4"],
Cell[1796550, 48062, 1519, 33, 1005, "Input", "ExpressionUUID" -> \
"cee5371a-f42a-4212-9a4a-4cccd558f18c"],
Cell[1798072, 48097, 528, 10, 337, "Input", "ExpressionUUID" -> \
"cd0cbe8f-a267-4a59-adc1-3c473e037335"],
Cell[1798603, 48109, 194, 3, 337, "Text", "ExpressionUUID" -> \
"3954121a-bb02-4c78-9d5f-ce30cad6c0db"],
Cell[1798800, 48114, 1274, 27, 789, "Input", "ExpressionUUID" -> \
"00333cc7-98e7-47bf-919d-c0e1165c2bc8"],
Cell[1800077, 48143, 593, 14, 580, "Text", "ExpressionUUID" -> \
"85267b1f-ae8d-4967-89a4-778746cb91fa"],
Cell[1800673, 48159, 423, 10, 337, "Input", "ExpressionUUID" -> \
"fb4264d2-fd28-4fc8-a41e-3ab74bd24ad7"],
Cell[1801099, 48171, 206, 5, 337, "Input", "ExpressionUUID" -> \
"659f26c3-c25c-4a46-983e-d5944c713e70"],
Cell[1801308, 48178, 292, 8, 337, "Input", "ExpressionUUID" -> \
"7ca31709-7496-4cd7-874e-11374c0f2927"],
Cell[1801603, 48188, 240, 6, 337, "Text", "ExpressionUUID" -> \
"a13fd87a-54a0-461b-8ffb-a3b41e3817de"],
Cell[1801846, 48196, 795, 23, 337, "Input", "ExpressionUUID" -> \
"ed8c3d29-8802-4393-9454-5470d1684dc7",
 Evaluatable->False],
Cell[1802644, 48221, 372, 10, 337, "Input", "ExpressionUUID" -> \
"fa062b14-8205-40af-8477-6717ca7d82ca",
 Evaluatable->False],
Cell[1803019, 48233, 708, 12, 559, "Text", "ExpressionUUID" -> \
"9a0c3c04-c20e-4550-bd94-4fe31998640e"],
Cell[1803730, 48247, 393, 10, 337, "Input", "ExpressionUUID" -> \
"1cbed6d6-a01c-4fa1-bb25-1476db106c05"],
Cell[1804126, 48259, 438, 11, 337, "Input", "ExpressionUUID" -> \
"a8afc248-6791-4728-bef8-c88c4991c865"],
Cell[1804567, 48272, 446, 12, 337, "Input", "ExpressionUUID" -> \
"285d5e33-4efb-4795-a626-e4fc192338ae"],
Cell[1805016, 48286, 1048, 22, 789, "Text", "ExpressionUUID" -> \
"d9dc683f-b3cb-4839-8819-948533834020"],
Cell[1806067, 48310, 423, 10, 337, "Input", "ExpressionUUID" -> \
"9dad46f0-ef91-4fdd-b4f8-e98999eeca5f"],
Cell[1806493, 48322, 1185, 30, 567, "Input", "ExpressionUUID" -> \
"c3dfff4d-eb05-45bb-9c84-c538e42fde72",
 InitializationCell->True],
Cell[1807681, 48354, 496, 12, 337, "Input", "ExpressionUUID" -> \
"9657f918-80bf-43e6-b44a-f67faee02173"],
Cell[1808180, 48368, 212, 4, 346, "Text", "ExpressionUUID" -> \
"271d7f86-1bc6-45f6-a54c-cb4779caa15c"],
Cell[1808395, 48374, 1246, 33, 789, "Input", "ExpressionUUID" -> \
"082edac4-a509-41ec-b754-d8197cdd88e4"],
Cell[1809644, 48409, 252, 5, 346, "Text", "ExpressionUUID" -> \
"07cdc9ad-d4a5-47eb-94cc-ed1c91a79fe8"],
Cell[1809899, 48416, 1778, 47, 1005, "Input", "ExpressionUUID" -> \
"d5741546-b8e4-48e2-a942-4a7c93d68150"],
Cell[1811680, 48465, 191, 3, 346, "Text", "ExpressionUUID" -> \
"5f1d74cc-3649-4d7a-94d1-dbe8a3b0bbff"],
Cell[1811874, 48470, 1057, 30, 567, "Input", "ExpressionUUID" -> \
"1a0f17ad-22f1-47b9-9acd-da24c5a8bf84",
 InitializationCell->True],
Cell[1812934, 48502, 408, 11, 337, "Input", "ExpressionUUID" -> \
"dfd2d8cb-15bf-41ff-8066-21236ebf6eb6"],
Cell[1813345, 48515, 166, 3, 337, "Text", "ExpressionUUID" -> \
"0414ecca-ad25-4725-909c-0a5c8388fca0"],
Cell[1813514, 48520, 1441, 35, 789, "Input", "ExpressionUUID" -> \
"1c1fc155-070d-4f16-8f51-e76c2d9a7e5f"],
Cell[1814958, 48557, 400, 10, 337, "Text", "ExpressionUUID" -> \
"44710d84-41c9-4d27-95d6-674d0ba9706d"],
Cell[1815361, 48569, 1491, 42, 1005, "Input", "ExpressionUUID" -> \
"17911ed8-5933-47b5-9576-dc4a23e8597f"],
Cell[1816855, 48613, 219, 3, 337, "Text", "ExpressionUUID" -> \
"ad2fcea6-f242-4521-88e0-5d6491aed54f"],
Cell[1817077, 48618, 533, 15, 364, "Input", "ExpressionUUID" -> \
"c9c0bf38-0920-4a90-81e8-3117b9ab6fb1",
 Evaluatable->False],
Cell[1817613, 48635, 254, 5, 337, "Text", "ExpressionUUID" -> \
"06e3e81f-d72f-4221-b1f3-418a40174a02"],
Cell[1817870, 48642, 627, 20, 364, "Input", "ExpressionUUID" -> \
"4dbc5b98-4e14-48ab-95b7-cf0a333fed83",
 Evaluatable->False],
Cell[1818500, 48664, 2467, 64, 1446, "Input", "ExpressionUUID" -> \
"a7f90dcc-5fbf-4ce2-a686-c2f0942e718c"],
Cell[1820970, 48730, 153, 3, 337, "Text", "ExpressionUUID" -> \
"f40fe4bb-56b3-4d51-8793-ec88991c301e"],
Cell[1821126, 48735, 722, 22, 364, "Input", "ExpressionUUID" -> \
"4c1a64e5-60b0-4bb3-a9e7-5abd885dbd2e",
 Evaluatable->False],
Cell[1821851, 48759, 524, 9, 576, "Text", "ExpressionUUID" -> \
"e636f093-d5e0-4e7c-993b-450f113dcd25"],
Cell[1822378, 48770, 1413, 41, 789, "Input", "ExpressionUUID" -> \
"c5190282-64e8-48c2-9e1c-c242de0e8ef4",
 Evaluatable->False],
Cell[1823794, 48813, 436, 7, 337, "Input", "ExpressionUUID" -> \
"f73b5441-39ac-4d7b-96fc-bceddfc5e08d"],
Cell[1824233, 48822, 1402, 36, 789, "Input", "ExpressionUUID" -> \
"d0610fc6-b6c8-4bc7-9f4b-70dc08100fd3",
 Evaluatable->False],
Cell[1825638, 48860, 388, 7, 337, "Input", "ExpressionUUID" -> \
"ea5c4a49-5b72-46d7-b7f7-bce2a366ec5e"],
Cell[1826029, 48869, 403, 11, 337, "Input", "ExpressionUUID" -> \
"795d2fe9-8a7c-4127-a976-30b8de37059a"],
Cell[1826435, 48882, 1266, 33, 789, "Input", "ExpressionUUID" -> \
"c0d587cc-3274-4999-bd9b-afafed352be8"],
Cell[1827704, 48917, 178, 4, 337, "Input", "ExpressionUUID" -> \
"624e183b-b91f-4070-bbaf-f65cda492347"],
Cell[1827885, 48923, 818, 22, 640, "Text", "ExpressionUUID" -> \
"3ff2888e-7b8f-466f-a45a-5d2e680de68d"],
Cell[1828706, 48947, 1440, 34, 789, "Input", "ExpressionUUID" -> \
"aade3001-e6cf-41a4-a959-d718d80c9dd5",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1830171, 48985, 365, 7, 337, "Input", "ExpressionUUID" -> \
"fcfc0797-eb18-4e53-961f-9e374c46e095",
 InitializationCell->True],
Cell[1830539, 48994, 493, 9, 70, "Print", "ExpressionUUID" -> \
"616128de-0eac-45b2-9bee-f48bf4d355da",
 CellTags->"Info873708329053-6824778"]
}, Open  ]],
Cell[1831047, 49006, 999, 29, 789, "Input", "ExpressionUUID" -> \
"c15fe460-9f86-4efb-bb36-dd988cb5a9c2",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1832071, 49039, 423, 8, 337, "Input", "ExpressionUUID" -> \
"8176e70c-804c-4510-8f93-5880654e6eb4",
 InitializationCell->True],
Cell[1832497, 49049, 405, 8, 70, "Print", "ExpressionUUID" -> \
"80527308-c6dd-4277-8ecb-d92bd0935294",
 CellTags->"Info883708329053-6824778"]
}, Open  ]],
Cell[1832917, 49060, 647, 17, 337, "Input", "ExpressionUUID" -> \
"b13cd6d9-0cb5-46be-bb44-a15a3c5a796b"],
Cell[1833567, 49079, 953, 25, 567, "Input", "ExpressionUUID" -> \
"5449cbfd-8b51-4a69-b09b-777a8f8ab3df"],
Cell[1834523, 49106, 243, 6, 559, "Text", "ExpressionUUID" -> \
"a857f704-24f9-49ee-9c38-bc3fc93affb2"],
Cell[1834769, 49114, 1075, 26, 567, "Input", "ExpressionUUID" -> \
"3f7ed0bb-65e5-49a1-92bb-a6173e71fd14"],
Cell[1835847, 49142, 187, 4, 337, "Input", "ExpressionUUID" -> \
"f0cf634f-3695-4170-b02d-dca74bcf1506"],
Cell[1836037, 49148, 769, 17, 789, "Text", "ExpressionUUID" -> \
"51c560ce-9ed9-475f-b808-189538766a6c"],
Cell[1836809, 49167, 423, 12, 397, "Input", "ExpressionUUID" -> \
"2da7ecfb-6eb9-4a2d-8cf5-746096b61db1",
 Evaluatable->False],
Cell[1837235, 49181, 377, 5, 337, "Text", "ExpressionUUID" -> \
"e570ebd8-c24b-451f-bc3e-ad2a2f41f4fd"],
Cell[1837615, 49188, 1264, 32, 789, "Input", "ExpressionUUID" -> \
"487926a8-acad-4d70-a996-bed34c36378d"],
Cell[1838882, 49222, 160, 3, 337, "Text", "ExpressionUUID" -> \
"2f91ab32-6478-41da-bbbd-c7777124bde8"],
Cell[1839045, 49227, 435, 9, 337, "Text", "ExpressionUUID" -> \
"c393565e-55f7-4806-b6ab-60db6b3bea9c"],
Cell[1839483, 49238, 1017, 26, 567, "Input", "ExpressionUUID" -> \
"f5717359-5152-4c78-af4c-6acfb506aeb7"],
Cell[1840503, 49266, 359, 9, 567, "Text", "ExpressionUUID" -> \
"d8c72afd-ec2e-46e7-a622-11b9393be8b2"],
Cell[1840865, 49277, 662, 14, 337, "Input", "ExpressionUUID" -> \
"5ede2d37-a891-4be8-b970-d9ba033475ad"],
Cell[1841530, 49293, 771, 16, 337, "Input", "ExpressionUUID" -> \
"756d6177-6ba9-47de-a77f-b5d602f9a315"],
Cell[1842304, 49311, 10890, 350, 3556, "Input", "ExpressionUUID" -> \
"c6f2c6b2-6b8e-44ab-9f02-fc1939475bf0"],
Cell[1853197, 49663, 187, 4, 337, "Input", "ExpressionUUID" -> \
"ee3db67f-288b-46c0-b2c0-93ac08881396"],
Cell[1853387, 49669, 209, 4, 337, "Input", "ExpressionUUID" -> \
"4c505ea7-47c4-4e15-9a51-c433060614a6"],
Cell[1853599, 49675, 364, 9, 567, "Text", "ExpressionUUID" -> \
"801e8a05-00a8-40cc-b104-513537c2cacc"],
Cell[1853966, 49686, 213, 5, 337, "Text", "ExpressionUUID" -> \
"f7f48f49-d925-45b2-87b1-cb29b8887d17"],
Cell[1854182, 49693, 308, 8, 337, "Input", "ExpressionUUID" -> \
"8eacf414-541e-4467-90bd-ba9a3eca2da7"],
Cell[1854493, 49703, 189, 3, 337, "Text", "ExpressionUUID" -> \
"1fb1d299-c9b5-4693-a331-a3eaa5b1497d"],
Cell[1854685, 49708, 922, 22, 567, "Input", "ExpressionUUID" -> \
"b3363579-9e3c-47ac-9a2e-ae20e932f792"],
Cell[1855610, 49732, 158, 3, 337, "Text", "ExpressionUUID" -> \
"25fa41b8-b133-49e1-9a46-df3432036eb6"],
Cell[1855771, 49737, 502, 14, 337, "Input", "ExpressionUUID" -> \
"71599fc3-8932-4b8e-a384-7e24c0c1cf5f",
 Evaluatable->False],
Cell[1856276, 49753, 254, 5, 337, "Input", "ExpressionUUID" -> \
"cd99e749-8fe3-466d-a053-5540dd002c0a"],
Cell[1856533, 49760, 442, 13, 337, "Input", "ExpressionUUID" -> \
"01fe6a2f-8817-4af5-8099-e33e2d277b24"],
Cell[1856978, 49775, 183, 3, 337, "Text", "ExpressionUUID" -> \
"200c7d31-4f69-46e7-9311-efb9e2a747be"],
Cell[1857164, 49780, 1099, 28, 567, "Input", "ExpressionUUID" -> \
"87416862-ca47-4874-872f-a565f6728bd6"],
Cell[1858266, 49810, 1134, 27, 567, "Input", "ExpressionUUID" -> \
"ddf6d83c-b55b-450d-b1f3-bf7ef8516092"],
Cell[1859403, 49839, 1002, 18, 1014, "Text", "ExpressionUUID" -> \
"16d9967c-bcc0-48f0-a79a-037fdea5bc44"],
Cell[1860408, 49859, 2927, 65, 1446, "Input", "ExpressionUUID" -> \
"6e2e4439-85bb-42c2-a412-c709cb4f90ca",
 Evaluatable->False],
Cell[1863338, 49926, 321, 6, 337, "Input", "ExpressionUUID" -> \
"0d6ac3d5-33bf-485b-b25e-7344dc50b248"],
Cell[1863662, 49934, 482, 10, 771, "Text", "ExpressionUUID" -> \
"3ec7a5f3-a8d9-4199-a814-70daf17e7080"],
Cell[1864147, 49946, 167, 4, 337, "Input", "ExpressionUUID" -> \
"3f403b69-2d41-4eaf-a104-7b8b81cd9b8e"],
Cell[1864317, 49952, 302, 8, 337, "Input", "ExpressionUUID" -> \
"acddab62-9929-4a38-98dd-1c7b00719bb1"],
Cell[1864622, 49962, 472, 12, 337, "Input", "ExpressionUUID" -> \
"e07a2f2b-c077-4820-ad9d-9da7aac42814"],
Cell[1865097, 49976, 183, 4, 337, "Input", "ExpressionUUID" -> \
"de2ac9ca-af06-4efb-8e19-d86a134c9912"],
Cell[1865283, 49982, 399, 10, 567, "Text", "ExpressionUUID" -> \
"fae62adc-1693-4555-8a73-2f9aeced3922"],
Cell[1865685, 49994, 546, 11, 337, "Input", "ExpressionUUID" -> \
"814f6ad6-73f9-4acd-aa4e-adf15fe0c6e5"],
Cell[1866234, 50007, 282, 6, 567, "Text", "ExpressionUUID" -> \
"250b861c-952f-4e15-aeb6-7cac4d5feb07"],
Cell[1866519, 50015, 420, 11, 337, "Input", "ExpressionUUID" -> \
"03e14296-bba3-4666-90be-5837b2dbcb81"],
Cell[1866942, 50028, 304, 8, 337, "Input", "ExpressionUUID" -> \
"902bc017-8509-4203-a122-6d2207cce959"],
Cell[1867249, 50038, 580, 12, 559, "Text", "ExpressionUUID" -> \
"b9a93e91-5d6b-44ec-966b-97f426f42049"],
Cell[1867832, 50052, 368, 11, 337, "Input", "ExpressionUUID" -> \
"59104804-3068-4a9c-b20c-097b2a26658d"],
Cell[1868203, 50065, 544, 13, 559, "Text", "ExpressionUUID" -> \
"1f7aaa13-8451-45f0-884d-8b40923f5b84"],
Cell[1868750, 50080, 210, 3, 337, "Text", "ExpressionUUID" -> \
"15375085-a20e-4d75-8484-000eb4246752"],
Cell[1868963, 50085, 938, 24, 789, "Input", "ExpressionUUID" -> \
"68916d8c-1697-43b2-a171-2203537b5055"],
Cell[1869904, 50111, 318, 6, 337, "Text", "ExpressionUUID" -> \
"1c4ea1d1-af35-49b2-b560-4bacde03cc30"],
Cell[1870225, 50119, 1026, 21, 337, "Input", "ExpressionUUID" -> \
"291f0e7b-d122-47ca-a241-f217158ae0ec"],
Cell[1871254, 50142, 345, 9, 337, "Input", "ExpressionUUID" -> \
"a7fa3975-2dfe-43e7-b2cf-49984957967a"],
Cell[1871602, 50153, 804, 15, 337, "Input", "ExpressionUUID" -> \
"5f04c305-190a-4411-b9de-73f3e3593e81"],
Cell[1872409, 50170, 658, 15, 337, "Input", "ExpressionUUID" -> \
"a8fd9044-3531-4cfd-8cd8-77b6501382b2"],
Cell[1873070, 50187, 249, 4, 337, "Text", "ExpressionUUID" -> \
"0c7c9300-35d1-42b4-8d87-172d9630817a"],
Cell[1873322, 50193, 515, 11, 337, "Input", "ExpressionUUID" -> \
"301da551-71d4-40bf-b94a-24af9386c8e1"],
Cell[1873840, 50206, 203, 5, 337, "Input", "ExpressionUUID" -> \
"e011af82-9076-4a7b-af9e-98911e39069d"],
Cell[1874046, 50213, 199, 4, 337, "Input", "ExpressionUUID" -> \
"d1e23a40-b7b1-4073-b5f1-565816dc189c"],
Cell[1874248, 50219, 164, 3, 337, "Text", "ExpressionUUID" -> \
"fb58dbc1-6b9f-4519-89c2-c4066b9eec11"],
Cell[1874415, 50224, 287, 6, 337, "Input", "ExpressionUUID" -> \
"9c8dac1b-0ced-488b-9e03-5eb34bac1cc5"],
Cell[1874705, 50232, 599, 12, 789, "Text", "ExpressionUUID" -> \
"1d0b20fa-bd3f-4a7a-9873-58e455dc55cb"],
Cell[1875307, 50246, 401, 12, 337, "Input", "ExpressionUUID" -> \
"91e9d36c-be0f-476f-a3f0-19fa67c92732"],
Cell[1875711, 50260, 1018, 24, 337, "Input", "ExpressionUUID" -> \
"aed68443-cfef-48fd-981f-2fbde20e59d4"],
Cell[1876732, 50286, 186, 3, 337, "Text", "ExpressionUUID" -> \
"50b3926f-09e6-4311-868f-33bb551bd5bc"],
Cell[1876921, 50291, 491, 14, 337, "Input", "ExpressionUUID" -> \
"28ac3056-cd94-4729-978d-9cf8dde47076"],
Cell[1877415, 50307, 721, 14, 337, "Input", "ExpressionUUID" -> \
"27121b49-446b-4702-80ba-688c7ca35975"],
Cell[1878139, 50323, 193, 4, 337, "Input", "ExpressionUUID" -> \
"229bde07-7409-45ff-9ba6-2995a7681ad9"],
Cell[1878335, 50329, 809, 18, 337, "Input", "ExpressionUUID" -> \
"2aa63bea-daa8-41cb-9c86-94d2eabba43b"],
Cell[1879147, 50349, 221, 4, 337, "Input", "ExpressionUUID" -> \
"18daa086-eaeb-4c96-b3c8-c850fb3ff065"],
Cell[1879371, 50355, 300, 7, 337, "Input", "ExpressionUUID" -> \
"a2907017-85c3-4462-ae7b-8280f081180b"],
Cell[CellGroupData[{
Cell[1879696, 50366, 797, 17, 337, "Input", "ExpressionUUID" -> \
"97a947fd-38dd-46a0-adc2-bd000e3cd882"],
Cell[1880496, 50385, 248696, 6888, 2147483647, "Output", "ExpressionUUID" -> \
"ee047e3c-b981-413a-86ac-5a26660b276f"],
Cell[2129195, 57275, 248677, 6889, 2147483647, "Output", "ExpressionUUID" -> \
"00896805-ccc6-40d1-acc6-d0d85649ea55"]
}, Closed]],
Cell[2377887, 64167, 389, 7, 256, "Input", "ExpressionUUID" -> \
"cf787b0e-4b47-4ba4-950a-3433bf3445a0"],
Cell[2378279, 64176, 212, 4, 337, "Text", "ExpressionUUID" -> \
"c4f1459e-4aa3-42df-aaec-8c3a11f7e906"],
Cell[2378494, 64182, 159, 3, 337, "Text", "ExpressionUUID" -> \
"1186225f-606c-4c1a-b207-53043338fd75"],
Cell[CellGroupData[{
Cell[2378678, 64189, 451, 8, 337, "Input", "ExpressionUUID" -> \
"f52722f6-a892-40b5-83bf-9bcb4ed2dfa1",
 InitializationCell->True],
Cell[2379132, 64199, 465, 9, 70, "Print", "ExpressionUUID" -> \
"18686a5e-5560-4bb2-9b0d-5684365b14c0",
 CellTags->"Info893708329053-6824778"]
}, Open  ]],
Cell[2379612, 64211, 1805, 51, 1669, "Input", "ExpressionUUID" -> \
"c32e0cdb-1298-40b3-a238-b86851f222c4",
 Evaluatable->False],
Cell[2381420, 64264, 214, 6, 337, "Input", "ExpressionUUID" -> \
"77ea0968-dd89-4730-a635-40a456422fcb"],
Cell[2381637, 64272, 384, 10, 337, "Input", "ExpressionUUID" -> \
"b7ecf55d-c013-4257-b2e4-8e14642ff808"],
Cell[2382024, 64284, 199, 5, 337, "Input", "ExpressionUUID" -> \
"74437b0a-e542-4497-86d6-f19dfb307eaf"],
Cell[2382226, 64291, 193, 4, 337, "Input", "ExpressionUUID" -> \
"32f23e2a-fa8e-4b8f-9370-710e15bc102b"],
Cell[2382422, 64297, 244, 6, 346, "Text", "ExpressionUUID" -> \
"f6d78e53-083c-4764-b837-f161825249d7"],
Cell[2382669, 64305, 475, 11, 337, "Input", "ExpressionUUID" -> \
"94e7f7dc-3d0b-4e3d-8d7e-2c132e24ef26"],
Cell[2383147, 64318, 200, 3, 337, "Text", "ExpressionUUID" -> \
"50f76b85-0efb-4729-93e0-caf06df43dec"],
Cell[2383350, 64323, 386, 10, 337, "Input", "ExpressionUUID" -> \
"b9692574-abbf-47f6-9ffa-02cd85bfcee1"],
Cell[2383739, 64335, 208, 5, 337, "Input", "ExpressionUUID" -> \
"b771f7e0-baf5-4a02-87a9-aec16be095ba"],
Cell[2383950, 64342, 315, 9, 337, "Input", "ExpressionUUID" -> \
"f95db393-dde9-474d-8177-43ce4492dafb"],
Cell[2384268, 64353, 171, 3, 337, "Text", "ExpressionUUID" -> \
"78384840-7c5c-4501-a648-62a720b09644"]
}, Closed]],
Cell[CellGroupData[{
Cell[2384476, 64361, 800, 11, 42, "Subsubsection", "ExpressionUUID" -> \
"4fc4849b-bd74-4838-adc5-d657f6126f6c"],
Cell[2385279, 64374, 539, 9, 387, "Text", "ExpressionUUID" -> \
"6b4dd21f-1889-4491-a6b9-4e9c8dc1fb3b"],
Cell[2385821, 64385, 617, 14, 163, "Input", "ExpressionUUID" -> \
"714f09aa-de32-4cd8-b855-c5c031d29d8a"],
Cell[2386441, 64401, 273, 9, 168, "Text", "ExpressionUUID" -> \
"ef13bbf3-0b25-4b95-8376-d1d25f679fd6"],
Cell[2386717, 64412, 677, 16, 163, "Input", "ExpressionUUID" -> \
"f0064214-8e5b-44be-92d6-3dbf60f62360",
 Evaluatable->False],
Cell[2387397, 64430, 565, 10, 387, "Text", "ExpressionUUID" -> \
"6aa8d685-2acf-439b-ab51-f543d32c60f8"],
Cell[2387965, 64442, 695, 16, 163, "Input", "ExpressionUUID" -> \
"314a7573-7154-4087-b49e-ba54acfc2174",
 Evaluatable->False],
Cell[2388663, 64460, 557, 14, 163, "Input", "ExpressionUUID" -> \
"7904fa50-9bf4-45a9-b676-8a62801a3862"],
Cell[2389223, 64476, 566, 13, 387, "Text", "ExpressionUUID" -> \
"2f3a2359-7867-4943-b6ed-aa3bbe77acea"],
Cell[2389792, 64491, 301, 8, 163, "Input", "ExpressionUUID" -> \
"6920750d-97e9-4968-9e52-09e40c499f42"],
Cell[2390096, 64501, 446, 12, 163, "Input", "ExpressionUUID" -> \
"5cfe9d8f-8ec2-4d7e-a31d-acd44d66801c"],
Cell[2390545, 64515, 191, 4, 163, "Input", "ExpressionUUID" -> \
"d949ea10-5b81-4b9f-a497-c024f7013b2b"],
Cell[2390739, 64521, 552, 16, 163, "Input", "ExpressionUUID" -> \
"daa5f51a-5183-48cb-947c-3063052f316e"],
Cell[2391294, 64539, 300, 8, 163, "Input", "ExpressionUUID" -> \
"1b04bcfd-542e-499e-a67b-241255cbb7b8"],
Cell[2391597, 64549, 496, 10, 279, "Text", "ExpressionUUID" -> \
"987ddbfc-4e08-4bfc-a3d1-ad84e2475e05"],
Cell[2392096, 64561, 1952, 47, 694, "Input", "ExpressionUUID" -> \
"5676ae84-17dc-4ac7-beef-97ce721ed764",
 InitializationCell->True],
Cell[2394051, 64610, 610, 13, 805, "Input", "ExpressionUUID" -> \
"21a90fa9-74a4-42bf-a79e-3c44e33da8cb",
 InitializationCell->True],
Cell[2394664, 64625, 417, 9, 163, "Input", "ExpressionUUID" -> \
"c79a4c10-e2b4-4fb9-a651-379cb7986dcd"],
Cell[2395084, 64636, 296, 8, 163, "Input", "ExpressionUUID" -> \
"28008baa-5846-4148-ac2b-9d84a1881596"],
Cell[2395383, 64646, 259, 6, 163, "Input", "ExpressionUUID" -> \
"ce2087b4-751d-443d-81a9-adac0980de6e"],
Cell[2395645, 64654, 271, 7, 168, "Text", "ExpressionUUID" -> \
"e14416b3-d6ee-4be1-9f03-4fb40525d4ea"],
Cell[2395919, 64663, 530, 14, 163, "Input", "ExpressionUUID" -> \
"2f1c3a39-3854-4ed1-82fc-4ee282c72aa8"],
Cell[2396452, 64679, 347, 7, 163, "Input", "ExpressionUUID" -> \
"c0d1e679-abd4-42db-8c8f-06f2cc6c06bb"],
Cell[2396802, 64688, 204, 3, 168, "Text", "ExpressionUUID" -> \
"cc10033c-0b6c-4011-a60c-94f7f2263410"],
Cell[2397009, 64693, 451, 11, 163, "Input", "ExpressionUUID" -> \
"0bd20ee3-33c7-4379-8061-2b7b8c8ceb4d"],
Cell[2397463, 64706, 223, 5, 168, "Text", "ExpressionUUID" -> \
"c5c8cb35-497b-4c56-83b9-3e3d06d7f837"],
Cell[2397689, 64713, 157, 3, 168, "Text", "ExpressionUUID" -> \
"1629cb4e-61f8-42b9-b7c0-bcb6a3be3360"],
Cell[2397849, 64718, 900, 22, 163, "Input", "ExpressionUUID" -> \
"52789f4d-a459-4502-a54e-23645d6c2b41"],
Cell[2398752, 64742, 432, 11, 163, "Input", "ExpressionUUID" -> \
"4555ae42-4dc4-417f-a99b-98739c59a78b"],
Cell[2399187, 64755, 704, 17, 163, "Input", "ExpressionUUID" -> \
"790f4815-5496-42de-a44e-69e5a85cd0dd"],
Cell[2399894, 64774, 316, 6, 163, "Input", "ExpressionUUID" -> \
"e366296c-130f-47ea-9fad-63d9b82c2d6c"],
Cell[2400213, 64782, 226, 5, 163, "Input", "ExpressionUUID" -> \
"fe51af70-0351-402d-ab1b-784f0f0815ed"],
Cell[2400442, 64789, 364, 8, 387, "Text", "ExpressionUUID" -> \
"aba78785-9e53-4beb-a2e9-fce63879bea1"],
Cell[2400809, 64799, 1158, 27, 279, "Input", "ExpressionUUID" -> \
"51dfc519-4fa0-4fad-95c7-fa51a7ec7d86",
 Evaluatable->False],
Cell[2401970, 64828, 208, 4, 168, "Text", "ExpressionUUID" -> \
"442758f4-b837-44f5-84a3-a24274b3c86d"],
Cell[2402181, 64834, 156, 3, 163, "Input", "ExpressionUUID" -> \
"e54d5174-d4c7-437f-8cb2-39a5e0d3f926"],
Cell[2402340, 64839, 288, 7, 168, "Text", "ExpressionUUID" -> \
"c64b70b4-0281-4f5b-9f58-bcfea9b5acab"],
Cell[2402631, 64848, 1971, 49, 391, "Input", "ExpressionUUID" -> \
"85687b17-ced2-4068-a8f8-646526d65b40",
 Evaluatable->False],
Cell[2404605, 64899, 656, 16, 279, "Text", "ExpressionUUID" -> \
"fadcbedb-84a5-4d26-a943-7b8350ccaabc"],
Cell[2405264, 64917, 1382, 31, 285, "Input", "ExpressionUUID" -> \
"48c3a4f9-e721-4b42-92c1-0c37a0cfeabe",
 Evaluatable->False],
Cell[2406649, 64950, 791, 17, 279, "Text", "ExpressionUUID" -> \
"24103ed5-dcd1-4b95-b62d-fc9b715104a4"],
Cell[2407443, 64969, 1186, 29, 208, "Input", "ExpressionUUID" -> \
"bdea39d4-3d9f-4df2-9602-aba92e688e53",
 Evaluatable->False],
Cell[2408632, 65000, 1553, 39, 366, "Input", "ExpressionUUID" -> \
"900ddc85-c4e7-4466-af67-2519ad45d693",
 Evaluatable->False],
Cell[2410188, 65041, 464, 8, 168, "Text", "ExpressionUUID" -> \
"0562415b-38d7-4724-920a-7a1ca7a58376"],
Cell[2410655, 65051, 968, 25, 208, "Input", "ExpressionUUID" -> \
"22302b5b-dee5-433a-8357-01039427801b",
 Evaluatable->False],
Cell[2411626, 65078, 220, 4, 168, "Text", "ExpressionUUID" -> \
"a71a5515-4298-48b7-8fb9-3fddd478ea91"],
Cell[2411849, 65084, 1665, 43, 285, "Input", "ExpressionUUID" -> \
"6a951e3a-6719-463a-8de3-e51034a8fc60",
 Evaluatable->False],
Cell[2413517, 65129, 796, 16, 168, "Text", "ExpressionUUID" -> \
"700ec548-0347-4f31-a0cb-5af6dcd509c1"],
Cell[2414316, 65147, 2037, 51, 324, "Input", "ExpressionUUID" -> \
"92328f1a-1c0d-4c10-bc30-0af6af3e189e",
 Evaluatable->False],
Cell[2416356, 65200, 904, 17, 279, "Text", "ExpressionUUID" -> \
"712ccddd-3856-4397-9103-97b66766db0b"],
Cell[2417263, 65219, 2818, 67, 985, "Input", "ExpressionUUID" -> \
"e9f09745-503a-42c6-b964-c1e5c81de896",
 Evaluatable->False],
Cell[2420084, 65288, 652, 13, 387, "Text", "ExpressionUUID" -> \
"f929a056-f022-45e3-bfe1-f19d729b65f0"],
Cell[2420739, 65303, 2146, 63, 501, "Input", "ExpressionUUID" -> \
"f992379c-b0c0-4e22-994f-94cb1dde1aa0",
 Evaluatable->False],
Cell[2422888, 65368, 324, 6, 163, "Input", "ExpressionUUID" -> \
"cb2a9f8e-61f7-4404-8d90-d45287d09444"],
Cell[2423215, 65376, 847, 17, 607, "Text", "ExpressionUUID" -> \
"e4ccc134-21ca-40bc-ab3c-fdd26fd53ebd"],
Cell[2424065, 65395, 1316, 31, 312, "Text", "ExpressionUUID" -> \
"a81e666f-b314-4b55-a478-cd5e35900b57"],
Cell[2425384, 65428, 736, 20, 298, "Input", "ExpressionUUID" -> \
"85c40db5-a316-444a-8259-cd86c6ac29c7",
 Evaluatable->False],
Cell[2426123, 65450, 602, 11, 499, "Text", "ExpressionUUID" -> \
"9cc2ab81-068a-4ffd-bed8-db5ea93d45ee"],
Cell[2426728, 65463, 707, 14, 499, "Text", "ExpressionUUID" -> \
"a1724591-c349-430a-8a4c-6d7bf6d5d0eb"],
Cell[2427438, 65479, 2000, 61, 724, "Input", "ExpressionUUID" -> \
"19f0426b-6709-4ec5-ad2d-59f9b9eb6a3c",
 Evaluatable->False],
Cell[2429441, 65542, 278, 5, 163, "Input", "ExpressionUUID" -> \
"2d761383-7f4e-420b-83f7-3ec46019d44f"],
Cell[2429722, 65549, 299, 8, 168, "Text", "ExpressionUUID" -> \
"aedc9154-fef2-4121-ad63-59573848bf1a"],
Cell[2430024, 65559, 732, 16, 163, "Input", "ExpressionUUID" -> \
"783f98ac-7ebc-4d68-abaa-9b1f156ff6a0"],
Cell[2430759, 65577, 439, 11, 163, "Input", "ExpressionUUID" -> \
"3db4edbe-12ad-4ffb-9a30-ffb710c2f82d"],
Cell[2431201, 65590, 441, 11, 163, "Input", "ExpressionUUID" -> \
"73d5e8a4-c2d3-4b30-a14c-1ebd0fb71822"],
Cell[2431645, 65603, 489, 11, 163, "Input", "ExpressionUUID" -> \
"afd85407-5f45-479c-a1b4-ca978aa6e38e"],
Cell[2432137, 65616, 345, 7, 279, "Text", "ExpressionUUID" -> \
"358c78ef-fd5c-4df8-b86b-de5716656d69"],
Cell[2432485, 65625, 985, 25, 279, "Input", "ExpressionUUID" -> \
"ac150b32-71ce-463f-b5a3-a401a3da31ad"],
Cell[2433473, 65652, 831, 20, 279, "Input", "ExpressionUUID" -> \
"a56c693e-6f95-439d-8d52-ae69a2eb011f"],
Cell[2434307, 65674, 808, 20, 279, "Input", "ExpressionUUID" -> \
"c8b423f4-e3bc-48dc-ae74-62920e57d2a3"],
Cell[2435118, 65696, 834, 20, 279, "Input", "ExpressionUUID" -> \
"62c2f3fc-3616-48e2-8f68-d57e8f8f2340"],
Cell[2435955, 65718, 325, 7, 279, "Text", "ExpressionUUID" -> \
"272768ae-5e32-4119-bfc3-74f8e459a280"],
Cell[2436283, 65727, 303, 8, 279, "Text", "ExpressionUUID" -> \
"e8d6dbb0-0def-4afa-a335-b97839813d0a"],
Cell[2436589, 65737, 1367, 33, 279, "Input", "ExpressionUUID" -> \
"643c1929-4c46-4166-884c-1fe099d2abda",
 Evaluatable->False],
Cell[2437959, 65772, 352, 6, 163, "Input", "ExpressionUUID" -> \
"53050f01-fffc-467f-b4b3-85c3ad7eb7f9"],
Cell[2438314, 65780, 1206, 32, 279, "Input", "ExpressionUUID" -> \
"96ec8204-0640-4586-9789-48961aaddf22",
 Evaluatable->False],
Cell[2439523, 65814, 353, 6, 163, "Input", "ExpressionUUID" -> \
"a0cdd543-b172-496b-8f5a-b5dca1e50c9f"],
Cell[2439879, 65822, 249, 6, 279, "Text", "ExpressionUUID" -> \
"8f4316b0-bfec-4966-a6c4-a616cd89ee9c"],
Cell[2440131, 65830, 890, 21, 279, "Input", "ExpressionUUID" -> \
"5a0369d3-90a3-4a3d-9946-9f9ee90c7d1d"],
Cell[2441024, 65853, 176, 3, 168, "Text", "ExpressionUUID" -> \
"fda5858b-d1c0-425f-8bdb-08d2c491e0cb"],
Cell[2441203, 65858, 1132, 28, 391, "Input", "ExpressionUUID" -> \
"264bf2a6-84cc-4880-b3c9-5c2167ec7ba6"],
Cell[2442338, 65888, 1290, 32, 501, "Input", "ExpressionUUID" -> \
"82e41dac-d387-425f-8088-df73ab7565de"],
Cell[2443631, 65922, 237, 4, 168, "Text", "ExpressionUUID" -> \
"f9490d24-422a-405a-beb0-7198ca526a67"],
Cell[2443871, 65928, 198, 4, 163, "Input", "ExpressionUUID" -> \
"443a1825-1b51-4881-a776-f51830057833"],
Cell[2444072, 65934, 289, 5, 163, "Input", "ExpressionUUID" -> \
"6c884d47-df82-4cbb-a26f-e826d4c80232"],
Cell[2444364, 65941, 1596, 37, 724, "Input", "ExpressionUUID" -> \
"63673c34-e660-481d-9bf4-8e4fb8d1de8f"],
Cell[2445963, 65980, 809, 15, 607, "Text", "ExpressionUUID" -> \
"cc2775ba-f66a-45b8-8b06-2d8c523586ae"],
Cell[2446775, 65997, 882, 19, 387, "Text", "ExpressionUUID" -> \
"88f709d3-2a57-4a95-8620-16a1a41c7e5b"],
Cell[2447660, 66018, 628, 20, 163, "Input", "ExpressionUUID" -> \
"04a4ca04-42ab-4c6a-8354-0d37bd714501",
 Evaluatable->False],
Cell[2448291, 66040, 192, 3, 168, "Text", "ExpressionUUID" -> \
"1144cbf6-2137-4165-8fac-7e3f5e2c47b2"],
Cell[2448486, 66045, 270, 7, 163, "Input", "ExpressionUUID" -> \
"a8819b17-5163-430c-8231-2f93e7332835"],
Cell[2448759, 66054, 1125, 28, 391, "Input", "ExpressionUUID" -> \
"f84ef3aa-fcc8-4f18-be81-ad3ae4602c45"],
Cell[2449887, 66084, 759, 19, 387, "Text", "ExpressionUUID" -> \
"69aa5253-08cd-4526-b4b1-1e23fcbe7e24"],
Cell[2450649, 66105, 310, 8, 163, "Input", "ExpressionUUID" -> \
"c7adce41-6692-4f43-a4cc-2b207b720af4"],
Cell[2450962, 66115, 164, 4, 163, "Input", "ExpressionUUID" -> \
"9d44baf8-3039-4177-8d69-70ee79c57b46"],
Cell[2451129, 66121, 178, 4, 163, "Input", "ExpressionUUID" -> \
"4875874a-96c8-4a0d-af48-56e4d41b14db"],
Cell[2451310, 66127, 167, 4, 163, "Input", "ExpressionUUID" -> \
"7ff4aa55-97bb-4e34-ad35-1a1cb89f3253"],
Cell[2451480, 66133, 217, 4, 168, "Text", "ExpressionUUID" -> \
"41269ff6-f411-4d94-ba06-43eaf155a58d"],
Cell[2451700, 66139, 165, 3, 168, "Text", "ExpressionUUID" -> \
"9c5277ff-351b-4dec-9e0d-77917eb7919c"],
Cell[2451868, 66144, 744, 18, 310, "Input", "ExpressionUUID" -> \
"290bdaba-278f-416a-8296-553c4afa69ab"],
Cell[2452615, 66164, 364, 9, 163, "Input", "ExpressionUUID" -> \
"b0abf5d1-855e-4207-848e-8c57c8467b8a"],
Cell[2452982, 66175, 298, 7, 279, "Text", "ExpressionUUID" -> \
"5b999392-bbe2-4087-bc40-8ffc38894e50"],
Cell[2453283, 66184, 1035, 28, 292, "Input", "ExpressionUUID" -> \
"308cb8ac-c7e5-4270-81e1-71ba719ccca2",
 Evaluatable->False],
Cell[2454321, 66214, 335, 7, 279, "Text", "ExpressionUUID" -> \
"c4799b9c-ffea-4ecb-afd5-d51b880f2d0d"],
Cell[2454659, 66223, 598, 18, 163, "Input", "ExpressionUUID" -> \
"9a6eff27-0339-4cd0-b340-1826f15dea08",
 Evaluatable->False],
Cell[2455260, 66243, 182, 3, 168, "Text", "ExpressionUUID" -> \
"e2127653-b641-4062-bbc1-aef81e0553b0"],
Cell[2455445, 66248, 467, 9, 279, "Text", "ExpressionUUID" -> \
"01da7f71-49c4-40d1-9a66-5700f5bdf2ab"],
Cell[2455915, 66259, 571, 11, 387, "Text", "ExpressionUUID" -> \
"ed42be5a-81bc-4de4-b794-cb6c60349aa3"],
Cell[2456489, 66272, 319, 8, 168, "Text", "ExpressionUUID" -> \
"1cd71d4c-d1a5-44d3-a688-f680da76af89"],
Cell[2456811, 66282, 800, 22, 279, "Input", "ExpressionUUID" -> \
"fc3ffcd7-aa38-45e3-af0c-c17112e2ad70"],
Cell[2457614, 66306, 278, 6, 279, "Text", "ExpressionUUID" -> \
"240fcfaf-9af3-434c-a1d1-3f18240e3030"],
Cell[2457895, 66314, 698, 17, 279, "Input", "ExpressionUUID" -> \
"e091e03c-6717-4212-ab2c-94fd3b84d7d4"],
Cell[2458596, 66333, 474, 14, 163, "Input", "ExpressionUUID" -> \
"0d1737d7-258f-4500-a1e6-19a142991fe7"],
Cell[2459073, 66349, 494, 11, 163, "Input", "ExpressionUUID" -> \
"7f05cf4c-50ee-4082-ab87-030837d4b077"],
Cell[2459570, 66362, 524, 11, 163, "Input", "ExpressionUUID" -> \
"b0bd2257-72ba-4691-b3dc-97eff57591dc"],
Cell[2460097, 66375, 238, 6, 163, "Input", "ExpressionUUID" -> \
"7b833cd4-f087-41bb-8cbc-6c7d8fab2ecf"],
Cell[2460338, 66383, 616, 16, 163, "Input", "ExpressionUUID" -> \
"01c506e6-5845-41cb-abed-24ba1f623ef8"],
Cell[2460957, 66401, 224, 5, 168, "Text", "ExpressionUUID" -> \
"6e3b85b9-3215-43a6-bd99-226aed196154"],
Cell[2461184, 66408, 385, 10, 163, "Input", "ExpressionUUID" -> \
"e83e3ede-ce66-4cce-81e0-442629c361d1"],
Cell[2461572, 66420, 299, 8, 163, "Input", "ExpressionUUID" -> \
"e4487f16-9bc4-4500-b739-a5c832b22620"],
Cell[2461874, 66430, 470, 9, 279, "Text", "ExpressionUUID" -> \
"7d37fd6b-a53b-4129-88c2-115c39ede2aa"]
}, Closed]],
Cell[CellGroupData[{
Cell[2462381, 66444, 897, 12, 42, "Subsubsection", "ExpressionUUID" -> \
"7ff9f871-2845-4bcc-a312-729b8838577a"],
Cell[2463281, 66458, 1136, 19, 567, "Text", "ExpressionUUID" -> \
"656789cb-f014-423d-9161-5a793bd88058"],
Cell[2464420, 66479, 452, 11, 100, "Input", "ExpressionUUID" -> \
"c851cccc-6569-4970-ab8f-a5a72777ed48"],
Cell[2464875, 66492, 178, 3, 100, "Text", "ExpressionUUID" -> \
"b574d32c-252d-448a-82f7-adf54fdfc84a"],
Cell[2465056, 66497, 255, 6, 100, "Input", "ExpressionUUID" -> \
"5fef6807-f580-4282-8f80-5c6ecb4a82a5"],
Cell[2465314, 66505, 482, 10, 166, "Text", "ExpressionUUID" -> \
"2fe02b2c-56a0-4625-b721-23b9fe0381a7"],
Cell[2465799, 66517, 5472, 108, 495, "Input", "ExpressionUUID" -> \
"870bf701-6177-426e-9d33-eceb3397be3c",
 Evaluatable->False],
Cell[2471274, 66627, 444, 8, 100, "Input", "ExpressionUUID" -> \
"891d1681-24b3-4d38-9034-727df8a8908a"],
Cell[2471721, 66637, 180, 6, 166, "Text", "ExpressionUUID" -> \
"b48f8874-bfbb-432c-a10a-9e84e9f3b9df"],
Cell[2471904, 66645, 1124, 27, 168, "Input", "ExpressionUUID" -> \
"796c0c08-2801-4389-a92e-a2df04e9737f"],
Cell[2473031, 66674, 160, 3, 100, "Text", "ExpressionUUID" -> \
"add475ba-1b8e-4512-837a-ba950f11824b"],
Cell[2473194, 66679, 1262, 28, 168, "Input", "ExpressionUUID" -> \
"c25da73b-934a-4b48-a0c4-ba04a9bef646"],
Cell[2474459, 66709, 166, 3, 100, "Text", "ExpressionUUID" -> \
"f2768431-db6d-4e17-bef6-291c335f4328"],
Cell[2474628, 66714, 1219, 28, 168, "Input", "ExpressionUUID" -> \
"63280837-9edc-4e57-8ac6-961901912688"],
Cell[2475850, 66744, 286, 7, 231, "Text", "ExpressionUUID" -> \
"2a7d9e5f-d3f8-4b96-a155-7d5976b0c353"],
Cell[2476139, 66753, 526, 12, 171, "Text", "ExpressionUUID" -> \
"61916386-fdf6-4b7f-92bc-7d00e3b12ff2"],
Cell[2476668, 66767, 1187, 23, 315, "Text", "ExpressionUUID" -> \
"8b95db23-6117-42d4-afdd-2ea737b3638d"],
Cell[2477858, 66792, 895, 21, 114, "Text", "ExpressionUUID" -> \
"d7eb01f1-723f-419b-8469-e10a04d553da"],
Cell[2478756, 66815, 427, 8, 103, "Text", "ExpressionUUID" -> \
"2213f011-2501-475a-8420-34124c5262fa"],
Cell[2479186, 66825, 393, 9, 100, "Text", "ExpressionUUID" -> \
"d357e833-552e-44da-93b8-0bbe9408ed6c"],
Cell[2479582, 66836, 325, 9, 100, "Input", "ExpressionUUID" -> \
"97cb304e-3cf7-4cfa-ba93-f23eeb6f560f",
 Evaluatable->False],
Cell[2479910, 66847, 448, 8, 234, "Text", "ExpressionUUID" -> \
"cdec83e7-2f9f-44c0-8f81-40f7e142fc33"],
Cell[2480361, 66857, 906, 25, 168, "Input", "ExpressionUUID" -> \
"1ca4c62c-203a-4bcb-b01d-23afa7946173",
 Evaluatable->False],
Cell[2481270, 66884, 585, 12, 171, "Text", "ExpressionUUID" -> \
"9eb12464-a61c-47c4-b2ce-b18a22b637fa"],
Cell[2481858, 66898, 623, 18, 100, "Input", "ExpressionUUID" -> \
"add1aa9f-1c3d-44b2-b8de-851b0c97a83a"],
Cell[2482484, 66918, 132, 3, 100, "Text", "ExpressionUUID" -> \
"f736342b-dde0-420a-b6ee-2c9d3955f1d6"],
Cell[2482619, 66923, 336, 9, 100, "Input", "ExpressionUUID" -> \
"81f03b3d-bd50-4f9b-8fe1-733b7aa8f329"],
Cell[2482958, 66934, 239, 4, 100, "Text", "ExpressionUUID" -> \
"1bacaf99-52d3-46a4-98f5-2b9d892c59fa"],
Cell[2483200, 66940, 1415, 41, 168, "Input", "ExpressionUUID" -> \
"b47a01e8-f20a-4b72-add0-73365cd45156"],
Cell[2484618, 66983, 299, 7, 166, "Text", "ExpressionUUID" -> \
"025143f2-a834-4d27-8a12-896325f97ed0"],
Cell[2484920, 66992, 1476, 36, 298, "Input", "ExpressionUUID" -> \
"c5af48c2-20d4-4444-9498-e263a3d077ee"],
Cell[2486399, 67030, 202, 6, 168, "Text", "ExpressionUUID" -> \
"55b5cd2c-9038-4002-869b-b087c8711175"],
Cell[2486604, 67038, 429, 8, 171, "Text", "ExpressionUUID" -> \
"bc617187-4751-415e-b4b9-4353ff61ea9e"],
Cell[2487036, 67048, 2897, 71, 559, "Input", "ExpressionUUID" -> \
"69541330-93a4-4d9a-bce7-d21e97b150f4"],
Cell[2489936, 67121, 351, 8, 166, "Text", "ExpressionUUID" -> \
"edd2e1b5-6a05-4da7-b094-b1fa8c84cd19"],
Cell[2490290, 67131, 1752, 41, 364, "Input", "ExpressionUUID" -> \
"509442e3-dd19-4d13-ad7a-aa484adea199"],
Cell[2492045, 67174, 593, 10, 303, "Text", "ExpressionUUID" -> \
"0f7bebd7-b264-4f33-923a-53bc2f273c1f"],
Cell[2492641, 67186, 1020, 31, 298, "Input", "ExpressionUUID" -> \
"6d279e69-069a-459d-bbbd-66d57010387c"],
Cell[2493664, 67219, 1437, 32, 364, "Text", "ExpressionUUID" -> \
"5c85aab6-0dab-402f-bd64-1d610692e125"]
}, Closed]],
Cell[CellGroupData[{
Cell[2495138, 67256, 970, 13, 42, "Subsubsection", "ExpressionUUID" -> \
"c89517ad-0d6c-466a-8865-801183c76d07"],
Cell[2496111, 67271, 1167, 24, 630, "Text", "ExpressionUUID" -> \
"dac21393-ebe5-403e-a077-e8953cebd07c"],
Cell[2497281, 67297, 404, 10, 100, "Input", "ExpressionUUID" -> \
"c9efa8cc-c175-45b5-93be-0afcd25cc9bc"],
Cell[2497688, 67309, 287, 8, 100, "Text", "ExpressionUUID" -> \
"68b85a0d-7d51-4db5-bbbc-ee5779089282"],
Cell[2497978, 67319, 570, 12, 100, "Input", "ExpressionUUID" -> \
"6786d2b3-38e9-4113-8a03-eb56ef082cde"],
Cell[2498551, 67333, 510, 13, 100, "Input", "ExpressionUUID" -> \
"1b6589b9-8524-486d-a916-89c516a063c8"],
Cell[2499064, 67348, 307, 7, 103, "Text", "ExpressionUUID" -> \
"1b0e5adb-d8f2-4f2c-a2fb-dd4d8320b909"],
Cell[2499374, 67357, 277, 8, 100, "Text", "ExpressionUUID" -> \
"9323a19a-38dc-4304-8eaa-b0d54278d31f"],
Cell[2499654, 67367, 499, 11, 100, "Input", "ExpressionUUID" -> \
"444dde31-1e04-436f-8223-e70b88cdeea7"],
Cell[2500156, 67380, 508, 13, 100, "Input", "ExpressionUUID" -> \
"8d9e4cbe-72fd-4fd3-926a-31cb8af88b43"],
Cell[2500667, 67395, 1444, 41, 342, "Input", "ExpressionUUID" -> \
"3cfaaf74-85c9-493e-b22d-df4167ed1beb"],
Cell[2502114, 67438, 1998, 57, 256, "Input", "ExpressionUUID" -> \
"4d26e2cb-729d-46d2-aa98-fad3d38af2dc"],
Cell[2504115, 67497, 1868, 53, 256, "Input", "ExpressionUUID" -> \
"684587ec-5aba-4a9e-ac9d-39eaffc0cac8"],
Cell[2505986, 67552, 193, 3, 100, "Text", "ExpressionUUID" -> \
"3b9ccfd2-0977-4013-88c1-4d0e5c56d72d"],
Cell[2506182, 67557, 2256, 62, 256, "Input", "ExpressionUUID" -> \
"499d7a80-2e79-439e-bdac-fb5d82985de2"],
Cell[2508441, 67621, 405, 11, 100, "Input", "ExpressionUUID" -> \
"3755f3b8-4cb7-4c0b-8d95-6e3e5ab6838a"],
Cell[2508849, 67634, 407, 11, 100, "Input", "ExpressionUUID" -> \
"6c7f709c-1afb-4b37-90c0-9102cf87661b"],
Cell[2509259, 67647, 744, 18, 100, "Input", "ExpressionUUID" -> \
"0e31f306-c942-4381-acc8-13f1d05ddf28"],
Cell[2510006, 67667, 198, 5, 100, "Input", "ExpressionUUID" -> \
"06ba0972-11ba-4bbf-9570-9fe1843ce8d2"],
Cell[2510207, 67674, 355, 8, 100, "Text", "ExpressionUUID" -> \
"c3f9def9-e3b1-47e9-ac01-eff9fa4912ce"],
Cell[2510565, 67684, 381, 10, 100, "Input", "ExpressionUUID" -> \
"b7e7bcfd-b2f2-476a-8961-91404faaa70f"],
Cell[2510949, 67696, 870, 22, 234, "Input", "ExpressionUUID" -> \
"e1122735-6c01-45d9-895f-16f4ed8c1fbc"],
Cell[2511822, 67720, 315, 8, 100, "Input", "ExpressionUUID" -> \
"e338d706-269e-48a3-a115-feadc35b7f2c"],
Cell[2512140, 67730, 1093, 28, 234, "Input", "ExpressionUUID" -> \
"e7f3bc11-417c-4f9f-aa83-957f95c54f7c"],
Cell[2513236, 67760, 357, 7, 166, "Text", "ExpressionUUID" -> \
"98f33cf5-7fe4-48aa-9e88-900a61f76b10"],
Cell[2513596, 67769, 776, 18, 168, "Input", "ExpressionUUID" -> \
"73ad7c2d-1227-4847-a364-1c8415ca806d"],
Cell[2514375, 67789, 443, 8, 235, "Text", "ExpressionUUID" -> \
"1fd39c81-0ef1-4541-a5db-aa22d1516b78"],
Cell[2514821, 67799, 334, 7, 100, "Input", "ExpressionUUID" -> \
"f730c8c8-3164-45e0-9e48-93eac4e874bc"],
Cell[2515158, 67808, 1780, 40, 436, "Text", "ExpressionUUID" -> \
"fa09bed2-7e44-45e5-9848-751ca7bfc5ae"],
Cell[2516941, 67850, 363, 9, 100, "Text", "ExpressionUUID" -> \
"cd4cf5fa-6caf-448c-8e88-ab3e58a5211f"],
Cell[2517307, 67861, 207, 5, 100, "Input", "ExpressionUUID" -> \
"3b084ec9-4aa1-4335-8b2a-9f4378dc56d0"],
Cell[2517517, 67868, 517, 15, 100, "Input", "ExpressionUUID" -> \
"049af2d1-fe81-4d30-bf39-529341b93352",
 InitializationCell->True],
Cell[2518037, 67885, 354, 10, 100, "Input", "ExpressionUUID" -> \
"a638c74f-df8c-4db5-89f7-30ade3805259"],
Cell[2518394, 67897, 205, 5, 100, "Input", "ExpressionUUID" -> \
"2f393dd5-9eec-4c3a-bb26-0f9597c5d84e"],
Cell[2518602, 67904, 260, 6, 166, "Text", "ExpressionUUID" -> \
"e3256b18-a200-405c-aa09-45aa13782fe8"],
Cell[2518865, 67912, 547, 14, 100, "Input", "ExpressionUUID" -> \
"1f18bc4a-879a-4645-824d-2322dccab16f"],
Cell[2519415, 67928, 423, 8, 166, "Text", "ExpressionUUID" -> \
"b38e1e8d-50fb-496a-b4bb-a031a87cd1e6"],
Cell[2519841, 67938, 686, 16, 100, "Input", "ExpressionUUID" -> \
"2c7783f8-c1b8-4f4b-812f-701b0d394f20"],
Cell[2520530, 67956, 553, 10, 235, "Text", "ExpressionUUID" -> \
"6ea6a9a8-cc30-46ae-9de0-68c7ece69104"],
Cell[2521086, 67968, 3583, 101, 333, "Input", "ExpressionUUID" -> \
"80ef18b0-4c9c-437f-9596-7215a298e764"],
Cell[2524672, 68071, 604, 10, 100, "Input", "ExpressionUUID" -> \
"731bea64-d10e-49c4-a1f2-73861028a010"],
Cell[2525279, 68083, 963, 19, 306, "Text", "ExpressionUUID" -> \
"383d6bd6-7997-4b43-a4d0-929dee2e2d86"],
Cell[2526245, 68104, 868, 24, 100, "Input", "ExpressionUUID" -> \
"c9b64ef3-d2f4-4564-a2c3-c6a25dc4798c",
 Evaluatable->False],
Cell[2527116, 68130, 594, 13, 168, "Text", "ExpressionUUID" -> \
"92bea876-5fe5-41fa-ac83-dcd1e1de86c0"],
Cell[2527713, 68145, 229, 5, 100, "Text", "ExpressionUUID" -> \
"9553c577-838b-448d-b874-37b99d2c21fa"],
Cell[2527945, 68152, 534, 15, 100, "Input", "ExpressionUUID" -> \
"45eddcba-06d9-4ceb-b76c-6e4f1fc4e74f"],
Cell[2528482, 68169, 490, 11, 100, "Input", "ExpressionUUID" -> \
"5e7e4324-0253-44e8-a2d9-54af7314cebc"],
Cell[2528975, 68182, 226, 5, 100, "Input", "ExpressionUUID" -> \
"7c0d98a3-5534-442f-b542-659f8a05f6a0"],
Cell[2529204, 68189, 684, 17, 100, "Input", "ExpressionUUID" -> \
"644a3e5a-7260-4435-ac50-b9ea42eb5fa2"],
Cell[2529891, 68208, 777, 20, 168, "Input", "ExpressionUUID" -> \
"8a05e77a-12ec-4abf-b51b-c61848343082"],
Cell[2530671, 68230, 289, 8, 100, "Text", "ExpressionUUID" -> \
"2d4beffa-6aac-4c72-9e59-26f46711aeb6"],
Cell[2530963, 68240, 238, 5, 100, "Text", "ExpressionUUID" -> \
"d832fc82-159a-440a-83a7-9a99bd754eae"],
Cell[2531204, 68247, 589, 16, 100, "Input", "ExpressionUUID" -> \
"ccc81151-81fb-418f-8752-0ea58c38e7e9"],
Cell[2531796, 68265, 638, 16, 100, "Input", "ExpressionUUID" -> \
"2c28af90-a725-434e-ae8e-e6c7ffdfb068"],
Cell[2532437, 68283, 198, 4, 100, "Text", "ExpressionUUID" -> \
"3e76af11-813e-42b3-a523-cb3880d5a1ad"],
Cell[2532638, 68289, 215, 5, 100, "Input", "ExpressionUUID" -> \
"b48e4313-cc8a-46de-af49-7f5ada6026fb"],
Cell[2532856, 68296, 476, 14, 100, "Input", "ExpressionUUID" -> \
"16225da9-f380-4b10-9d0f-06249c2847fe"],
Cell[2533335, 68312, 200, 5, 100, "Input", "ExpressionUUID" -> \
"67b23996-f7b2-4e64-8f10-afd27dd9e016"],
Cell[2533538, 68319, 262, 4, 100, "Text", "ExpressionUUID" -> \
"735a6b6c-4786-4052-884a-ccec7a69f147"],
Cell[2533803, 68325, 209, 6, 100, "Input", "ExpressionUUID" -> \
"05a72f93-665c-4bc3-902a-3799ad546f36"],
Cell[2534015, 68333, 398, 11, 100, "Input", "ExpressionUUID" -> \
"72ffa205-369f-42f4-aa1c-ac46c139a97d"],
Cell[2534416, 68346, 258, 4, 103, "Text", "ExpressionUUID" -> \
"f2d135d5-d479-47a5-b304-0396f52a7436"],
Cell[2534677, 68352, 688, 17, 100, "Input", "ExpressionUUID" -> \
"397d732c-33e8-494f-9d5c-1857097e6f74"],
Cell[2535368, 68371, 174, 3, 100, "Text", "ExpressionUUID" -> \
"60f54103-62cf-44e9-9c5a-819c509549cf"],
Cell[2535545, 68376, 207, 5, 100, "Input", "ExpressionUUID" -> \
"7b21b514-43e6-4ddc-98b2-38692468aaa0"],
Cell[2535755, 68383, 904, 23, 168, "Input", "ExpressionUUID" -> \
"055152e1-651d-4ac4-b095-42dd8ea6545b"],
Cell[2536662, 68408, 204, 3, 103, "Text", "ExpressionUUID" -> \
"b677cd3c-4ee1-439a-9897-854969464c48"],
Cell[2536869, 68413, 1211, 28, 168, "Input", "ExpressionUUID" -> \
"0c828471-c5fc-40fe-9062-718ac6b39186"],
Cell[2538083, 68443, 1555, 44, 301, "Input", "ExpressionUUID" -> \
"0e6c166f-8f2f-4618-8a2f-0fe4efc0e217"],
Cell[2539641, 68489, 1538, 39, 168, "Input", "ExpressionUUID" -> \
"6ea92b6a-6294-4b59-8f50-314a432981e9"],
Cell[2541182, 68530, 1845, 53, 402, "Input", "ExpressionUUID" -> \
"fe1afb1c-a9c3-4a6e-93dd-c7e149aa7429"],
Cell[2543030, 68585, 1006, 23, 100, "Input", "ExpressionUUID" -> \
"6cda59cb-6ba9-45da-9fcb-91d971d8b308"],
Cell[2544039, 68610, 1347, 39, 301, "Input", "ExpressionUUID" -> \
"a222c0b7-ae34-4a93-b383-c08fc80bdc88"],
Cell[2545389, 68651, 171, 3, 100, "Text", "ExpressionUUID" -> \
"99fa5435-4793-4a56-b863-0d7f0af70a3e"],
Cell[2545563, 68656, 1604, 42, 168, "Input", "ExpressionUUID" -> \
"ad37a4a4-1fdd-4333-b62b-996d4e240918"],
Cell[2547170, 68700, 405, 11, 100, "Input", "ExpressionUUID" -> \
"e9a0dbed-8da6-4569-a73a-d10ce2863fc5"],
Cell[2547578, 68713, 407, 11, 100, "Input", "ExpressionUUID" -> \
"3ce0d5a3-2874-4dfa-8f4b-f5b7b0de4706"],
Cell[2547988, 68726, 167, 3, 100, "Text", "ExpressionUUID" -> \
"3de08f69-f7c1-44f7-88cf-c1b0c8fa6814"],
Cell[2548158, 68731, 938, 21, 168, "Input", "ExpressionUUID" -> \
"da724969-080b-4cd1-99bf-c97c44e3cbab"],
Cell[2549099, 68754, 204, 5, 100, "Input", "ExpressionUUID" -> \
"e0e91eb8-08aa-4ebe-8bff-989af929619b"],
Cell[2549306, 68761, 188, 3, 100, "Text", "ExpressionUUID" -> \
"72b256f0-a708-4ea5-845d-80d8a5876450"],
Cell[2549497, 68766, 241, 6, 100, "Input", "ExpressionUUID" -> \
"a5df6f26-1d6a-4b5e-9448-4836426ef423"],
Cell[2549741, 68774, 229, 5, 100, "Text", "ExpressionUUID" -> \
"12120a50-70a8-46eb-bc47-66f665595460"],
Cell[2549973, 68781, 678, 18, 168, "Input", "ExpressionUUID" -> \
"fe4a55bb-c5b4-4ee3-b7c7-2186a6b60314"],
Cell[2550654, 68801, 587, 16, 100, "Input", "ExpressionUUID" -> \
"f9efdf84-d7a5-47a0-8d37-c74db9ddef26"],
Cell[2551244, 68819, 293, 7, 166, "Text", "ExpressionUUID" -> \
"c081089f-03aa-4b21-acb1-61b07b28e4e9"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2551586, 68832, 1004, 14, 67, "Subsection", "ExpressionUUID" -> \
"40a50a71-8646-4b05-93b0-ae0ea552bf87"],
Cell[2552593, 68848, 495, 11, 83, "Text", "ExpressionUUID" -> \
"653583f3-4e87-421a-b3a1-524165d1689d"],
Cell[2553091, 68861, 810, 20, 116, "Input", "ExpressionUUID" -> \
"6bc99560-5bf9-49eb-9dd3-f7dd287886ad"],
Cell[2553904, 68883, 1502, 22, 278, "Text", "ExpressionUUID" -> \
"5222e34d-b655-4545-8a0f-aeff98067f2b"],
Cell[CellGroupData[{
Cell[2555431, 68909, 299, 4, 53, "Subsubsection", "ExpressionUUID" -> \
"e988f97d-8174-41e9-9199-cefce8798f07"],
Cell[2555733, 68915, 986, 19, 238, "Text", "ExpressionUUID" -> \
"ea5e83f9-f7a2-434e-9285-b2f0b781bb48"],
Cell[2556722, 68936, 214, 5, 100, "Input", "ExpressionUUID" -> \
"d6594887-35a6-48b1-aebf-3e58e801b5c3"],
Cell[2556939, 68943, 883, 21, 168, "Input", "ExpressionUUID" -> \
"e2d622ac-a0fd-45c8-8526-cc437711e6da"],
Cell[2557825, 68966, 947, 16, 234, "Text", "ExpressionUUID" -> \
"d93861d5-3d76-4256-bb43-1bad13c62872"],
Cell[2558775, 68984, 7864, 250, 937, "Input", "ExpressionUUID" -> \
"1af5b437-85b2-449f-954c-6f26113d945f"],
Cell[2566642, 69236, 174, 3, 100, "Text", "ExpressionUUID" -> \
"013871ee-a7b2-47cd-897f-b33f614a1e25"],
Cell[2566819, 69241, 1253, 27, 234, "Input", "ExpressionUUID" -> \
"3307041b-54b6-4615-9291-4ff02a4cf7bc"],
Cell[2568075, 69270, 164, 3, 100, "Text", "ExpressionUUID" -> \
"bdc0e918-e6cf-4cae-9d4b-c8271b0ac676"],
Cell[2568242, 69275, 1017, 21, 100, "Input", "ExpressionUUID" -> \
"3d8415e1-a35c-44af-9c24-feeefc118288"],
Cell[2569262, 69298, 118, 3, 99, "Item", "ExpressionUUID" -> \
"8a0185f3-c0be-4420-bff8-d9676c4bd136"],
Cell[2569383, 69303, 410, 6, 100, "Text", "ExpressionUUID" -> \
"2aed746f-a564-478c-a708-7c423260638e"],
Cell[2569796, 69311, 189059, 4651, 20157, "Input", "ExpressionUUID" -> \
"4fc59df0-3eeb-4ca4-b6cf-b1d87f36c4b6"],
Cell[2758858, 73964, 1558, 36, 634, "Text", "ExpressionUUID" -> \
"28ceaf1a-7dab-465a-acf0-72e960c031fa"],
Cell[2760419, 74002, 1522, 35, 298, "Input", "ExpressionUUID" -> \
"2bdfccdd-bef4-4663-8049-7b692ef549f0"],
Cell[2761944, 74039, 220, 4, 103, "Text", "ExpressionUUID" -> \
"bf339ef3-ced5-49b5-9939-8667de9e1932"],
Cell[2762167, 74045, 600, 11, 166, "Text", "ExpressionUUID" -> \
"5787cb90-d77c-42a7-8785-464bb0760918"],
Cell[2762770, 74058, 191, 4, 100, "Input", "ExpressionUUID" -> \
"038a3519-b718-469d-9ce0-18447cbc541b"],
Cell[2762964, 74064, 342, 7, 166, "Text", "ExpressionUUID" -> \
"a9ec03c0-80ac-4c8b-a721-7645bfc66ba1"],
Cell[2763309, 74073, 3901, 87, 625, "Input", "ExpressionUUID" -> \
"e416ad43-f119-4ad9-936f-2c7d6deef16f",
 Evaluatable->False],
Cell[2767213, 74162, 286, 5, 100, "Input", "ExpressionUUID" -> \
"5eba0f85-6495-426a-8af3-f44d0facc6d5"],
Cell[2767502, 74169, 1289, 21, 550, "Text", "ExpressionUUID" -> \
"bb4db239-a730-4906-bec1-05e327915c86"],
Cell[2768794, 74192, 615, 16, 234, "Text", "ExpressionUUID" -> \
"bd92418f-9997-4b0d-af56-dee18262400f"],
Cell[2769412, 74210, 1128, 27, 234, "Input", "ExpressionUUID" -> \
"112ea72e-f4f2-49ce-bf57-a9cc17f1a810"],
Cell[2770543, 74239, 932, 16, 433, "Text", "ExpressionUUID" -> \
"ce68cda9-e540-40b5-85b2-2f65a7959144"],
Cell[2771478, 74257, 577, 10, 229, "Text", "ExpressionUUID" -> \
"be21d4a5-1115-4811-8b5f-c614092165f0"],
Cell[2772058, 74269, 1054, 25, 168, "Input", "ExpressionUUID" -> \
"9d9de78a-01e1-4ed8-97ca-b9234a11aa2d"],
Cell[2773115, 74296, 619, 15, 168, "Input", "ExpressionUUID" -> \
"4fd94716-b10e-4b91-991e-69922d7b4ee2"],
Cell[2773737, 74313, 589, 12, 298, "Text", "ExpressionUUID" -> \
"db11adaa-ede5-4622-bd3c-41a7db6acb21"]
}, Closed]],
Cell[CellGroupData[{
Cell[2774363, 74330, 276, 4, 42, "Subsubsection", "ExpressionUUID" -> \
"55e8bfae-844c-4ca9-8462-51ea40bbf34c"],
Cell[2774642, 74336, 265, 6, 67, "Input", "ExpressionUUID" -> \
"6d094cf2-3492-473a-bc23-085829dd7370"],
Cell[2774910, 74344, 249, 4, 67, "Text", "ExpressionUUID" -> \
"3e7175ac-dc8f-4834-aea9-113387d1f9ed"],
Cell[2775162, 74350, 353, 10, 67, "Input", "ExpressionUUID" -> \
"d2c8cd6a-0399-4d33-82cb-d220b8a19476"],
Cell[2775518, 74362, 696, 19, 112, "Input", "ExpressionUUID" -> \
"ab9f588a-5d3b-4971-a0eb-c58988314af1"],
Cell[2776217, 74383, 210, 5, 67, "Input", "ExpressionUUID" -> \
"a632870e-a767-4274-b4a2-1583cf673468"],
Cell[2776430, 74390, 780, 20, 112, "Input", "ExpressionUUID" -> \
"ee039290-2412-4302-b186-88ed78381426"],
Cell[2777213, 74412, 207, 5, 67, "Input", "ExpressionUUID" -> \
"d4583faa-20e9-4bb9-af52-263f2bce80a1"],
Cell[2777423, 74419, 311, 8, 67, "Input", "ExpressionUUID" -> \
"be1354bc-67c4-4e28-8b51-9e935936f7a9"],
Cell[2777737, 74429, 254, 4, 67, "Text", "ExpressionUUID" -> \
"6f9059e4-afa5-431b-9017-787482b50add"],
Cell[2777994, 74435, 883, 15, 67, "Input", "ExpressionUUID" -> \
"19fe8eb3-4c59-47a0-b1a5-546ceadf50af"],
Cell[2778880, 74452, 487, 12, 67, "Input", "ExpressionUUID" -> \
"a077aef6-1c9d-4111-bb5f-98099a0c502b"],
Cell[2779370, 74466, 241, 4, 67, "Text", "ExpressionUUID" -> \
"238b9d2a-c8f0-433c-84c8-42a0bf7601a2"],
Cell[2779614, 74472, 875, 20, 112, "Input", "ExpressionUUID" -> \
"39401fc0-f8d0-4085-8436-6474fc02e774"],
Cell[2780492, 74494, 691, 17, 67, "Input", "ExpressionUUID" -> \
"b686148d-a454-4e0c-a0df-971b89d42172"],
Cell[2781186, 74513, 469, 12, 67, "Input", "ExpressionUUID" -> \
"95744320-45a2-43e8-ae84-6429d7c545ad"],
Cell[2781658, 74527, 175, 3, 67, "Text", "ExpressionUUID" -> \
"4e30ef92-8af7-4d57-b528-61ee7fdc8457"],
Cell[2781836, 74532, 261, 7, 67, "Input", "ExpressionUUID" -> \
"73d7ff15-8abb-4284-b06c-bbc2de4d3500"],
Cell[2782100, 74541, 405, 11, 67, "Input", "ExpressionUUID" -> \
"182f5fc0-5225-42ac-bafd-e05cb6db9e71"],
Cell[2782508, 74554, 730, 12, 114, "Text", "ExpressionUUID" -> \
"53f85302-68f5-4ee4-939f-3e09300ff4b9"],
Cell[2783241, 74568, 974, 27, 198, "Input", "ExpressionUUID" -> \
"55b7acc3-2bfc-4c2d-a997-8e61d0df4397"],
Cell[2784218, 74597, 270, 6, 67, "Text", "ExpressionUUID" -> \
"76995b3f-af11-4c11-ad8c-ef0ed61345f9"],
Cell[2784491, 74605, 954, 27, 198, "Input", "ExpressionUUID" -> \
"02453e7c-f2ed-426d-a4d4-b0eb586081f0"],
Cell[2785448, 74634, 798, 25, 198, "Input", "ExpressionUUID" -> \
"5b8b959c-aff4-4006-b641-53c05ccd8de0"],
Cell[2786249, 74661, 188, 3, 67, "Text", "ExpressionUUID" -> \
"35e2dbb3-d560-4e77-ba22-2fb3d1909d7d"],
Cell[2786440, 74666, 1404, 38, 265, "Input", "ExpressionUUID" -> \
"540bad36-d1e7-416a-a8da-967f3dfbad77"]
}, Closed]],
Cell[CellGroupData[{
Cell[2787881, 74709, 383, 5, 42, "Subsubsection", "ExpressionUUID" -> \
"a1eb682c-08e4-4e9d-ac59-a19d3ece7b52"],
Cell[2788267, 74716, 413, 6, 67, "Text", "ExpressionUUID" -> \
"4a495e45-6895-4842-ba76-0c1cee23ca07"],
Cell[2788683, 74724, 240, 6, 67, "Input", "ExpressionUUID" -> \
"42f12777-bf55-48ef-b4ac-8f3906d01b9a"],
Cell[2788926, 74732, 773, 17, 112, "Input", "ExpressionUUID" -> \
"e893f4f2-16dd-46ae-96e4-e523b8dfa6ae"],
Cell[2789702, 74751, 188, 4, 67, "Input", "ExpressionUUID" -> \
"059f1574-bc1e-4bc4-af80-65bd115df8f2"],
Cell[2789893, 74757, 284, 7, 67, "Input", "ExpressionUUID" -> \
"e15c7ed2-d8ec-4c83-9e1b-f36a4c2f1b14"],
Cell[2790180, 74766, 110, 1, 67, "Input", "ExpressionUUID" -> \
"4b25a954-a8fd-4071-834f-bb56afa7e5ae"],
Cell[2790293, 74769, 151, 3, 67, "Text", "ExpressionUUID" -> \
"db94ca1b-13a5-4b85-aec1-9b0906545229"],
Cell[2790447, 74774, 683, 14, 67, "Input", "ExpressionUUID" -> \
"a36ca80e-e9ec-41e4-ba15-5e35eaf7b988"],
Cell[2791133, 74790, 185, 4, 67, "Input", "ExpressionUUID" -> \
"4e378ec7-b38a-405e-992b-5379620dbf5b"],
Cell[2791321, 74796, 150, 3, 67, "Text", "ExpressionUUID" -> \
"97313dde-5931-44f9-80b1-0aba9af2384c"],
Cell[2791474, 74801, 509, 12, 67, "Input", "ExpressionUUID" -> \
"b6b50768-8a88-47b7-b0cf-47eeea7b9c4a"],
Cell[2791986, 74815, 347, 7, 67, "Input", "ExpressionUUID" -> \
"75ab6b28-b964-4694-a40d-66925441bf94"],
Cell[2792336, 74824, 43160, 1032, 4188, "Input", "ExpressionUUID" -> \
"f8aebddc-cef9-46f7-bf87-d67e46f5f05c"],
Cell[2835499, 75858, 807, 20, 112, "Input", "ExpressionUUID" -> \
"d6d1e5dc-1956-40d0-a8ab-270f82f8bb18"],
Cell[2836309, 75880, 316, 6, 69, "Text", "ExpressionUUID" -> \
"1cbe7edd-daee-40d8-9940-4f24a36e6486"]
}, Closed]],
Cell[CellGroupData[{
Cell[2836662, 75891, 420, 6, 42, "Subsubsection", "ExpressionUUID" -> \
"728bbabc-be32-4589-adda-a2c789b5f29b"],
Cell[2837085, 75899, 441, 8, 111, "Text", "ExpressionUUID" -> \
"1765dee9-9a47-4ea4-a6c7-a1b61d3965f5"],
Cell[2837529, 75909, 175, 4, 67, "Input", "ExpressionUUID" -> \
"e0127da4-1216-4f04-add0-ffbd14f7fe21"],
Cell[2837707, 75915, 215, 5, 67, "Input", "ExpressionUUID" -> \
"69fd7302-2c58-4b1d-9e03-a929ec0b1e67"],
Cell[2837925, 75922, 752, 18, 112, "Input", "ExpressionUUID" -> \
"6cdf1d4e-e295-456b-abe5-1f3801d4a11f"],
Cell[2838680, 75942, 171, 3, 69, "Text", "ExpressionUUID" -> \
"3b523120-e1b7-4102-8664-54f75497e091"],
Cell[2838854, 75947, 932, 24, 112, "Input", "ExpressionUUID" -> \
"eb575821-e987-44c8-82b4-8676fa494f41"],
Cell[2839789, 75973, 474, 10, 67, "Input", "ExpressionUUID" -> \
"3713c19c-338c-490b-8d7b-b6134ebcda0a"],
Cell[2840266, 75985, 200, 5, 67, "Input", "ExpressionUUID" -> \
"96cc8638-c1ce-4981-a006-edaef330b695"],
Cell[2840469, 75992, 471, 11, 112, "Input", "ExpressionUUID" -> \
"55ac4805-6bd0-410f-a25a-007494fd99cc"],
Cell[2840943, 76005, 245, 5, 69, "Text", "ExpressionUUID" -> \
"df4cfd23-5db8-45d4-8c63-6e0ee5734541"],
Cell[2841191, 76012, 299, 7, 67, "Input", "ExpressionUUID" -> \
"4d5be253-bc23-4fce-afc3-a7f359eaa7af"],
Cell[2841493, 76021, 346, 9, 67, "Input", "ExpressionUUID" -> \
"946ad788-ba33-487b-a339-ce6552627d9b"],
Cell[2841842, 76032, 198, 3, 67, "Text", "ExpressionUUID" -> \
"7588c52a-fbc4-4bb8-ad76-9802c2185b57"],
Cell[2842043, 76037, 238, 6, 67, "Input", "ExpressionUUID" -> \
"4ae48c2f-381b-4f89-878e-52f64a7d2a24"],
Cell[2842284, 76045, 188, 3, 67, "Text", "ExpressionUUID" -> \
"1282d9bf-d791-4bd3-9b06-854f7cc5a839"],
Cell[2842475, 76050, 1000, 26, 112, "Input", "ExpressionUUID" -> \
"4d633deb-7134-4aa9-9e3f-84883cfa7e4c"],
Cell[2843478, 76078, 442, 13, 67, "Input", "ExpressionUUID" -> \
"28e5f663-8f1e-437a-8e24-878f52df32d8"],
Cell[2843923, 76093, 326, 9, 67, "Input", "ExpressionUUID" -> \
"3b581084-bc97-483c-8e0d-b19bf19fab92"],
Cell[2844252, 76104, 145, 3, 67, "Text", "ExpressionUUID" -> \
"1ab51a2d-79df-4232-8fde-4e08ba7be82c"],
Cell[2844400, 76109, 189, 4, 67, "Input", "ExpressionUUID" -> \
"14922d87-99d3-42bb-b814-3c226dbb0866"],
Cell[2844592, 76115, 231, 6, 67, "Text", "ExpressionUUID" -> \
"aa61a681-3549-457a-a6b8-1e173ec703f7"],
Cell[2844826, 76123, 363, 10, 67, "Input", "ExpressionUUID" -> \
"8804eddc-b863-4b9a-9cce-4a8687e52917"],
Cell[2845192, 76135, 225, 4, 67, "Text", "ExpressionUUID" -> \
"e4e98450-ebc0-4958-a05a-602e6ca29438"],
Cell[2845420, 76141, 696, 19, 112, "Input", "ExpressionUUID" -> \
"ec0e414e-dda6-4e77-9b75-16f42eb986c7"],
Cell[2846119, 76162, 322, 7, 114, "Text", "ExpressionUUID" -> \
"7183a71f-1295-4f94-98d0-3679f5ad1c87"],
Cell[2846444, 76171, 717, 19, 112, "Input", "ExpressionUUID" -> \
"64012078-6edd-4f90-93d7-3becfd85c87e"],
Cell[2847164, 76192, 188, 4, 67, "Input", "ExpressionUUID" -> \
"f221341f-c4e8-4ef5-a1a2-cd5fe99a9d7f"],
Cell[2847355, 76198, 323, 7, 69, "Text", "ExpressionUUID" -> \
"29f1d9f4-733d-4427-854d-60b16a7c5594"],
Cell[2847681, 76207, 279, 7, 67, "Input", "ExpressionUUID" -> \
"27a3970e-03da-4f19-ba0a-47332907678d"],
Cell[2847963, 76216, 145, 3, 67, "Text", "ExpressionUUID" -> \
"4dc26fb6-5646-43f3-9592-4e0275ac0a21"],
Cell[2848111, 76221, 179, 3, 69, "Text", "ExpressionUUID" -> \
"26b4accb-6f28-41b4-948d-8f23a940f344"],
Cell[2848293, 76226, 396, 8, 114, "Text", "ExpressionUUID" -> \
"742c41f9-42cf-45a3-ac30-1be66009e5ea"],
Cell[CellGroupData[{
Cell[2848714, 76238, 584, 16, 67, "Input", "ExpressionUUID" -> \
"aece0644-771d-4e59-91de-cbab9739a0df",
 InitializationCell->True],
Cell[2849301, 76256, 428, 14, 70, "Output", "ExpressionUUID" -> \
"94c01e25-f129-42f8-ab4e-057146611cb2"]
}, Open  ]],
Cell[2849744, 76273, 585, 16, 67, "Input", "ExpressionUUID" -> \
"d248d931-4a4e-4197-ad9c-0d93fe767ddd"],
Cell[2850332, 76291, 460, 12, 67, "Input", "ExpressionUUID" -> \
"5a210b5d-32c4-46a5-87e3-22e9639b5123"],
Cell[2850795, 76305, 663, 11, 157, "Text", "ExpressionUUID" -> \
"3aa90077-a5a4-4db6-9a96-3545e6f0d038"],
Cell[2851461, 76318, 274, 8, 67, "Input", "ExpressionUUID" -> \
"874a9095-22ad-47c8-86ee-410f2b65068c"],
Cell[2851738, 76328, 300, 7, 112, "Text", "ExpressionUUID" -> \
"574dfb19-346b-468e-bcc3-e0fb87483b65"],
Cell[2852041, 76337, 1133, 29, 112, "Input", "ExpressionUUID" -> \
"3d4d2f77-1859-4874-aec3-55cf5117fb57"],
Cell[2853177, 76368, 195, 5, 67, "Input", "ExpressionUUID" -> \
"3ebb2b06-8562-4c0c-9635-7379dfe82e09"],
Cell[2853375, 76375, 277, 4, 69, "Text", "ExpressionUUID" -> \
"3a3074dc-6249-4f8f-a579-196996ef6ec4"],
Cell[2853655, 76381, 415, 10, 67, "Input", "ExpressionUUID" -> \
"8d2e4add-988b-4eb0-a16a-8c26d1d8d373"],
Cell[2854073, 76393, 162, 3, 69, "Text", "ExpressionUUID" -> \
"a2547464-8808-4c15-b41b-b39c592e5557"],
Cell[2854238, 76398, 264, 5, 67, "Input", "ExpressionUUID" -> \
"e7d9a880-7687-4220-bd1d-872d817a5748"],
Cell[2854505, 76405, 177, 4, 67, "Input", "ExpressionUUID" -> \
"77c3340a-63bf-43fd-bf93-ae16f74c26db"],
Cell[2854685, 76411, 1247, 34, 112, "Input", "ExpressionUUID" -> \
"4e053b9e-dce3-43fe-8324-a958bc044ba7"],
Cell[2855935, 76447, 327, 7, 114, "Text", "ExpressionUUID" -> \
"a5e3e1db-2e20-493d-aa8e-56a655cacb3e"],
Cell[2856265, 76456, 1019, 26, 112, "Input", "ExpressionUUID" -> \
"86ba55de-d725-408f-ab22-cacebf0b82f9"],
Cell[2857287, 76484, 177, 3, 67, "Text", "ExpressionUUID" -> \
"1410afea-38bb-41b1-865b-8530e7df2e65"],
Cell[2857467, 76489, 253, 5, 67, "Input", "ExpressionUUID" -> \
"308cd7ad-b816-45e1-aac6-27525ee663b8"],
Cell[2857723, 76496, 150, 3, 67, "Text", "ExpressionUUID" -> \
"f88eff6d-a8af-4955-9638-34ede4494f50"],
Cell[2857876, 76501, 316, 7, 67, "Input", "ExpressionUUID" -> \
"07c53f48-2d51-4664-9f71-292935a670b3"],
Cell[2858195, 76510, 258, 6, 111, "Text", "ExpressionUUID" -> \
"59839482-8a63-4c60-9ed0-525f750e4953"],
Cell[2858456, 76518, 855, 22, 112, "Input", "ExpressionUUID" -> \
"062999d7-443a-461a-baf0-3a5e4e3b1c85"],
Cell[2859314, 76542, 198, 5, 67, "Input", "ExpressionUUID" -> \
"cb9c406e-c512-4114-9922-1288b002515d"],
Cell[2859515, 76549, 472, 10, 67, "Input", "ExpressionUUID" -> \
"ceb5cedc-7210-4cb4-a476-4fcfa792d8e2"],
Cell[2859990, 76561, 450, 9, 114, "Text", "ExpressionUUID" -> \
"a3bed3af-d582-4de5-ac06-f6a3d64b8576"],
Cell[2860443, 76572, 162, 4, 67, "Input", "ExpressionUUID" -> \
"73b0874f-bd7d-470d-b013-acf61c665f67"],
Cell[2860608, 76578, 298, 7, 67, "Input", "ExpressionUUID" -> \
"dce4a478-a913-4ac2-9d90-69ccd68ed23e"],
Cell[2860909, 76587, 170, 3, 67, "Text", "ExpressionUUID" -> \
"8c60d680-3606-49a7-8d37-fe31b1c394e8"],
Cell[2861082, 76592, 210, 5, 67, "Input", "ExpressionUUID" -> \
"8c070495-d3c5-43ae-b394-86a89c115e04"],
Cell[2861295, 76599, 218, 4, 67, "Text", "ExpressionUUID" -> \
"a32b6660-52a3-4234-9335-a37af7c05982"],
Cell[2861516, 76605, 324, 9, 67, "Input", "ExpressionUUID" -> \
"a77af5d3-9ae8-429f-bb79-c29d69625d9b"],
Cell[2861843, 76616, 174, 3, 67, "Text", "ExpressionUUID" -> \
"b67b384c-530a-4e45-ba64-f1994d304a05"],
Cell[2862020, 76621, 682, 13, 67, "Input", "ExpressionUUID" -> \
"a7d370ef-a692-47a8-84ee-f7ce97a42e59"],
Cell[2862705, 76636, 576, 18, 67, "Input", "ExpressionUUID" -> \
"153e612c-d9fb-4301-aaa0-119288e4084d"],
Cell[2863284, 76656, 276, 7, 67, "Input", "ExpressionUUID" -> \
"e90c86c2-63c9-44ac-af96-0102911ddbc2"],
Cell[2863563, 76665, 162, 3, 67, "Text", "ExpressionUUID" -> \
"8221d06e-bf27-4d04-b190-807775585a40"],
Cell[2863728, 76670, 287, 5, 67, "Input", "ExpressionUUID" -> \
"4b601b56-4f79-4a58-a7a4-3e49e10c400e"],
Cell[2864018, 76677, 1328, 32, 112, "Input", "ExpressionUUID" -> \
"570f3869-3a67-42bb-8134-f88db4f66efb"],
Cell[2865349, 76711, 541, 8, 67, "Text", "ExpressionUUID" -> \
"18931b9d-f893-49ec-930c-0ab59fefd9f1"],
Cell[2865893, 76721, 472, 7, 69, "Text", "ExpressionUUID" -> \
"18931b9d-f893-49ec-930c-0ab59fefd9f1"],
Cell[2866368, 76730, 182, 4, 67, "Input", "ExpressionUUID" -> \
"2766ff10-d5be-4032-8847-a0dd70275fab"],
Cell[2866553, 76736, 784, 17, 67, "Input", "ExpressionUUID" -> \
"cc2d9a55-5ece-41d9-962e-af0196a41edd"],
Cell[2867340, 76755, 595, 18, 67, "Input", "ExpressionUUID" -> \
"f6b9edc5-d121-40ca-a53b-527ea79339d1"],
Cell[2867938, 76775, 672, 21, 67, "Input", "ExpressionUUID" -> \
"60df40d6-4943-4d22-93b5-b3018d977090"],
Cell[2868613, 76798, 281, 4, 67, "Text", "ExpressionUUID" -> \
"940b4526-1b5a-41e4-8934-e44b1ac46f1a"],
Cell[2868897, 76804, 404, 8, 67, "Input", "ExpressionUUID" -> \
"ee6d3898-3d51-470e-8360-d321c8397cc7"]
}, Closed]],
Cell[CellGroupData[{
Cell[2869338, 76817, 456, 7, 42, "Subsubsection", "ExpressionUUID" -> \
"37128b40-c76e-4389-b169-e8469067489d"],
Cell[2869797, 76826, 905, 21, 112, "Input", "ExpressionUUID" -> \
"73452e63-d97d-47db-bdd8-af5c372d5a79"],
Cell[2870705, 76849, 188, 4, 67, "Input", "ExpressionUUID" -> \
"96d11544-9bb2-40c0-b61c-bf852dc7bed3"],
Cell[2870896, 76855, 554, 13, 112, "Input", "ExpressionUUID" -> \
"3a1bbf19-b3ab-4f7d-b011-6e52186a150c"],
Cell[2871453, 76870, 205, 5, 67, "Input", "ExpressionUUID" -> \
"6f0785c0-e3d0-46bf-973d-9f48cc882139"],
Cell[2871661, 76877, 360, 9, 67, "Input", "ExpressionUUID" -> \
"9807d7b9-73aa-4449-b92b-b3da30c8c934"],
Cell[2872024, 76888, 595, 12, 67, "Input", "ExpressionUUID" -> \
"a8165989-ca40-4868-99a0-3477ebcdcf71"],
Cell[2872622, 76902, 282, 5, 67, "Input", "ExpressionUUID" -> \
"484f65f1-b8db-4104-84d1-0ba3ff92356e"],
Cell[2872907, 76909, 437, 11, 67, "Input", "ExpressionUUID" -> \
"a5d01589-715b-42ee-8451-802c3b80f043"],
Cell[2873347, 76922, 782, 16, 67, "Input", "ExpressionUUID" -> \
"2b90791f-9819-4445-867e-e3d8e5e56f8c"],
Cell[2874132, 76940, 386, 7, 67, "Input", "ExpressionUUID" -> \
"eaa32585-467e-449c-a673-b216b7201f1e"],
Cell[2874521, 76949, 30639, 754, 4249, "Input", "ExpressionUUID" -> \
"18d47b08-6558-4de8-a2e3-27984588bf01"],
Cell[2905163, 77705, 626, 15, 112, "Input", "ExpressionUUID" -> \
"6017b57a-836c-41f0-b9b4-f87c6a6b9ebb"],
Cell[2905792, 77722, 578, 13, 67, "Input", "ExpressionUUID" -> \
"f02acd0e-d513-4302-85f4-d0302165b61d"],
Cell[2906373, 77737, 281, 5, 67, "Input", "ExpressionUUID" -> \
"2674b984-8698-4609-9b39-4935a5959de2"],
Cell[2906657, 77744, 511, 12, 67, "Input", "ExpressionUUID" -> \
"2ea38812-26d8-4e77-b3e7-e6312de5bbae"],
Cell[2907171, 77758, 649, 16, 67, "Input", "ExpressionUUID" -> \
"3d1c8d2d-a8fb-4901-834b-ee7bbf83d781"],
Cell[2907823, 77776, 147, 3, 67, "Text", "ExpressionUUID" -> \
"44326dc3-fb25-4eb4-a3c4-16bfa874e9a3"]
}, Closed]],
Cell[CellGroupData[{
Cell[2908007, 77784, 349, 5, 42, "Subsubsection", "ExpressionUUID" -> \
"c0c0cdde-3260-45ce-a768-ba9b42061f06"],
Cell[2908359, 77791, 600, 12, 67, "Text", "ExpressionUUID" -> \
"a491f89c-2b52-4d93-a6a5-c2919c656aff"],
Cell[2908962, 77805, 507, 9, 153, "Text", "ExpressionUUID" -> \
"cf8b2651-f7f8-41ae-8806-0b377e85804f"],
Cell[2909472, 77816, 1200, 26, 156, "Input", "ExpressionUUID" -> \
"0c0a8078-e8c9-4442-b391-59e6de9d812f"],
Cell[2910675, 77844, 443, 9, 67, "Input", "ExpressionUUID" -> \
"fd033b9a-037a-4e4d-ab08-4a242e50f181"],
Cell[2911121, 77855, 675, 15, 67, "Input", "ExpressionUUID" -> \
"a67aa883-c7b2-4e18-bace-0f92bb440341"],
Cell[2911799, 77872, 758, 16, 67, "Input", "ExpressionUUID" -> \
"6facef82-7e4f-418d-9d1f-5d7057d51ec2"],
Cell[2912560, 77890, 342, 9, 67, "Input", "ExpressionUUID" -> \
"5ffa4b13-8aaa-49f5-937d-a4a0214bf3c7"],
Cell[2912905, 77901, 221, 4, 67, "Text", "ExpressionUUID" -> \
"321969ff-edea-476e-8de5-965b8cf8d597"],
Cell[2913129, 77907, 1040, 21, 112, "Input", "ExpressionUUID" -> \
"aa5fb0ca-fef5-4308-82b8-d64581ce6246"],
Cell[2914172, 77930, 447, 9, 67, "Input", "ExpressionUUID" -> \
"7a94795c-1ebb-488a-af6c-8ee623c1f9b3"],
Cell[2914622, 77941, 676, 14, 67, "Input", "ExpressionUUID" -> \
"3aeaeca2-0f8c-4e8f-884a-dffc4b58eb22"],
Cell[2915301, 77957, 757, 15, 67, "Input", "ExpressionUUID" -> \
"9280e6f9-1d44-4e59-a3ac-daa089e54457"],
Cell[2916061, 77974, 342, 9, 67, "Input", "ExpressionUUID" -> \
"91f894b0-934d-4755-9cfa-5d2c203d981a"],
Cell[2916406, 77985, 210, 3, 67, "Text", "ExpressionUUID" -> \
"0b3702ef-2c3b-411f-85a0-047ee2a39424"],
Cell[2916619, 77990, 314, 9, 67, "Input", "ExpressionUUID" -> \
"451c89fd-ed04-42f5-ac64-9f45ab0e8a7d"],
Cell[2916936, 78001, 1106, 21, 67, "Input", "ExpressionUUID" -> \
"3c4e158d-ba6f-4f98-94c1-010165f7fa66"],
Cell[2918045, 78024, 183, 4, 67, "Input", "ExpressionUUID" -> \
"559244f9-5333-4f9f-a424-7341a7a8e3e8"],
Cell[2918231, 78030, 479, 14, 67, "Input", "ExpressionUUID" -> \
"09d83441-a927-4214-bd8a-cb77f0fe6984"],
Cell[2918713, 78046, 295, 7, 67, "Input", "ExpressionUUID" -> \
"f7a84d57-c5de-430e-82c7-51e7f129a08c"],
Cell[2919011, 78055, 903, 17, 67, "Input", "ExpressionUUID" -> \
"bdb5845e-634a-41d7-8e95-a4e7797e1424"],
Cell[2919917, 78074, 806, 15, 67, "Input", "ExpressionUUID" -> \
"21793380-d3c3-4027-82f2-9135aed3483e"],
Cell[2920726, 78091, 342, 9, 67, "Input", "ExpressionUUID" -> \
"c137f2d1-79c6-45d8-9229-4ed5a17d4f7d"],
Cell[2921071, 78102, 149, 3, 67, "Text", "ExpressionUUID" -> \
"25b7d99f-a8cb-4f59-ac2b-4af6fc76caaa"],
Cell[2921223, 78107, 388, 10, 67, "Text", "ExpressionUUID" -> \
"78aa0109-2f90-4af6-b460-05cf4c6d6953"],
Cell[2921614, 78119, 184, 4, 67, "Input", "ExpressionUUID" -> \
"a1178c97-677a-4090-85bf-73acab95b659"],
Cell[2921801, 78125, 183, 3, 67, "Text", "ExpressionUUID" -> \
"0c8c45f8-e93a-4d24-a0ae-f15be38dfe3a"],
Cell[2921987, 78130, 161, 4, 67, "Input", "ExpressionUUID" -> \
"315817e1-6e96-45fd-997c-a2bb85667cbc"],
Cell[2922151, 78136, 280, 6, 67, "Input", "ExpressionUUID" -> \
"b4b38cdc-6280-4b3d-9a5e-d7eed74f91db"],
Cell[2922434, 78144, 612, 14, 67, "Input", "ExpressionUUID" -> \
"b409b026-38c7-47a9-af4c-68dde17fc341"],
Cell[2923049, 78160, 967, 21, 112, "Input", "ExpressionUUID" -> \
"abe34939-3d87-4174-96e5-ff422f182507"],
Cell[2924019, 78183, 208, 5, 67, "Input", "ExpressionUUID" -> \
"ce52c4ee-4e55-4aeb-a7e3-249b551bb708"],
Cell[2924230, 78190, 781, 16, 67, "Input", "ExpressionUUID" -> \
"3690ed52-3224-425d-a382-e6d3294637c5"],
Cell[2925014, 78208, 205, 5, 67, "Input", "ExpressionUUID" -> \
"8afa14ed-0819-40a6-b8cd-9980eab18a27"],
Cell[2925222, 78215, 313, 8, 67, "Input", "ExpressionUUID" -> \
"3a63e82c-8fd0-41d3-9402-9cdd276ad8a0"],
Cell[2925538, 78225, 343, 7, 67, "Text", "ExpressionUUID" -> \
"900289b0-d1d3-4f85-b79e-756e2e04474a"],
Cell[2925884, 78234, 682, 14, 67, "Input", "ExpressionUUID" -> \
"18bbc1d1-ac09-4cde-9bf2-ce9e8c91a812"],
Cell[2926569, 78250, 358, 7, 67, "Input", "ExpressionUUID" -> \
"a07836ae-e627-45be-8e50-752c619c5040"],
Cell[2926930, 78259, 214, 5, 67, "Input", "ExpressionUUID" -> \
"0a8ed1d4-6cad-48f4-a713-efd1e91518ba"],
Cell[2927147, 78266, 915, 18, 67, "Input", "ExpressionUUID" -> \
"cb458bf9-4d65-4bf0-8b29-a9d164b907cd"],
Cell[2928065, 78286, 224, 4, 67, "Text", "ExpressionUUID" -> \
"7b062bfe-3b2e-492e-b200-783cb4e9cec8"],
Cell[2928292, 78292, 312, 7, 67, "Input", "ExpressionUUID" -> \
"7af3e15a-dc73-440f-a327-206645185ac2"],
Cell[2928607, 78301, 284, 6, 67, "Text", "ExpressionUUID" -> \
"bf29d98a-f41e-4201-85a8-59314c884f79"],
Cell[2928894, 78309, 1190, 18, 67, "Input", "ExpressionUUID" -> \
"7f336d98-423d-40e5-9a5f-d950b129e2c1"],
Cell[2930087, 78329, 191, 4, 67, "Input", "ExpressionUUID" -> \
"61208584-6c85-45a7-95b6-5893ff79e6e1"],
Cell[2930281, 78335, 192, 3, 67, "Text", "ExpressionUUID" -> \
"82d8260f-e618-4c71-b4f6-a529f9153829"],
Cell[2930476, 78340, 262, 6, 67, "Input", "ExpressionUUID" -> \
"88d64aca-b541-4cfb-865b-d9f7c670abf2"],
Cell[2930741, 78348, 1378, 26, 112, "Input", "ExpressionUUID" -> \
"167dcc8c-4c00-481b-854b-1a587553932d"],
Cell[2932122, 78376, 233, 4, 67, "Text", "ExpressionUUID" -> \
"cfdc8903-3d02-4b6f-affa-f58d8629ca0a"],
Cell[2932358, 78382, 517, 11, 67, "Input", "ExpressionUUID" -> \
"21e2ee3b-718e-4be7-a187-0974cf1d5616"],
Cell[2932878, 78395, 206, 4, 67, "Input", "ExpressionUUID" -> \
"bdafcf63-664a-42a3-af6e-abc3465214dd"],
Cell[2933087, 78401, 427, 10, 67, "Input", "ExpressionUUID" -> \
"a25279fa-40bc-4b4e-924f-aaf46388fcfd"],
Cell[2933517, 78413, 178, 4, 67, "Input", "ExpressionUUID" -> \
"30f2a3da-7f8e-4de3-b4ae-86d4e4976d4c"],
Cell[2933698, 78419, 392, 9, 67, "Input", "ExpressionUUID" -> \
"91b5f31a-3fd9-4e3a-864a-5309d6991efd"],
Cell[2934093, 78430, 403, 8, 111, "Text", "ExpressionUUID" -> \
"f23c3d8a-81f7-451d-8e4d-b2f7817500ca"],
Cell[2934499, 78440, 587, 14, 112, "Input", "ExpressionUUID" -> \
"6bd226a3-93f1-4ba9-943e-025510a726af"],
Cell[2935089, 78456, 208, 5, 67, "Input", "ExpressionUUID" -> \
"25f15049-3740-47ad-bfd2-890eaffbbad3"],
Cell[2935300, 78463, 377, 9, 67, "Input", "ExpressionUUID" -> \
"66bd38f0-fd78-49a7-b780-7c03e094019b"],
Cell[2935680, 78474, 1537, 27, 112, "Input", "ExpressionUUID" -> \
"9303857b-3524-4feb-879f-b8f85b4f9fa4"],
Cell[2937220, 78503, 473, 12, 67, "Input", "ExpressionUUID" -> \
"d1cfd486-a03f-47f4-9210-626afea3818d"],
Cell[2937696, 78517, 260, 6, 67, "Input", "ExpressionUUID" -> \
"d21fa9db-af3a-4deb-9c56-7adc902c6868"],
Cell[2937959, 78525, 456, 13, 67, "Input", "ExpressionUUID" -> \
"9032958c-b8ca-4b05-9e40-c74f9ac318a6"],
Cell[2938418, 78540, 519, 10, 112, "Text", "ExpressionUUID" -> \
"ffae198d-b10a-4808-844e-c6d2f8c27170"],
Cell[2938940, 78552, 498, 11, 67, "Input", "ExpressionUUID" -> \
"27454928-6115-433f-a4f7-dbc61613a8e5"],
Cell[2939441, 78565, 535, 13, 67, "Input", "ExpressionUUID" -> \
"6507299f-a404-43a2-bd11-33102d07d309"],
Cell[2939979, 78580, 147, 3, 67, "Text", "ExpressionUUID" -> \
"6ccac870-edda-492a-847b-fb797c49f510"],
Cell[2940129, 78585, 666, 13, 67, "Text", "ExpressionUUID" -> \
"0ef79e79-de06-423d-9bd8-ad685224f2e3"],
Cell[2940798, 78600, 177, 4, 67, "Input", "ExpressionUUID" -> \
"9500e185-f5e1-42bb-a1fc-db86362f538c"],
Cell[2940978, 78606, 239, 6, 67, "Input", "ExpressionUUID" -> \
"e8fd0b2b-44b1-4a27-9688-b307a6c050f5"],
Cell[2941220, 78614, 485, 14, 67, "Input", "ExpressionUUID" -> \
"a4b22c85-956e-4e27-894e-7662b843b615"],
Cell[2941708, 78630, 608, 15, 112, "Input", "ExpressionUUID" -> \
"f6d736b7-9ad1-4116-a665-fe92da5be9cd"],
Cell[2942319, 78647, 210, 5, 67, "Text", "ExpressionUUID" -> \
"3b482510-a982-4c34-bd56-06fc3984f514"],
Cell[2942532, 78654, 694, 16, 112, "Input", "ExpressionUUID" -> \
"cc24ffdc-243a-4a41-9b9c-23189bca01a1"],
Cell[2943229, 78672, 204, 3, 67, "Text", "ExpressionUUID" -> \
"b64a256b-152f-4790-a59d-544aa010ab42"],
Cell[2943436, 78677, 852, 22, 156, "Input", "ExpressionUUID" -> \
"726f1b77-5929-4857-9939-809623666c1c"],
Cell[2944291, 78701, 175, 3, 67, "Text", "ExpressionUUID" -> \
"3df20ee9-149e-4576-b7e4-03231ded255b"],
Cell[2944469, 78706, 217, 4, 67, "Text", "ExpressionUUID" -> \
"f977eb2b-aaf3-49ba-9760-43fd3bdd9630"],
Cell[2944689, 78712, 798, 19, 112, "Input", "ExpressionUUID" -> \
"459287d9-4426-485c-bef5-eeebdd373050"],
Cell[2945490, 78733, 466, 10, 67, "Input", "ExpressionUUID" -> \
"4b853b8b-55c7-41c8-8de4-67762e1842a1"],
Cell[2945959, 78745, 183, 4, 67, "Input", "ExpressionUUID" -> \
"47c4d343-93e8-49ed-9901-22b45b63ff42"],
Cell[2946145, 78751, 580, 14, 67, "Input", "ExpressionUUID" -> \
"67b7ac97-57ba-4c98-95f3-facfb4531ffb"],
Cell[2946728, 78767, 360, 8, 67, "Input", "ExpressionUUID" -> \
"47d4e09e-40c0-406c-9f18-d83c3069b672"],
Cell[2947091, 78777, 205, 3, 67, "Text", "ExpressionUUID" -> \
"ce281940-477b-42f9-8ec6-bb4fd9951a85"],
Cell[2947299, 78782, 965, 24, 156, "Input", "ExpressionUUID" -> \
"8c0a9494-402a-4adb-a7cd-68934503b2cc"],
Cell[2948267, 78808, 177, 3, 67, "Text", "ExpressionUUID" -> \
"d4c9e92c-9ac0-4bb3-9f6b-314310947faa"],
Cell[2948447, 78813, 1021, 25, 156, "Input", "ExpressionUUID" -> \
"e9889ad6-33dd-48cb-9ed5-1f1e4034f039"],
Cell[2949471, 78840, 307, 8, 67, "Input", "ExpressionUUID" -> \
"60e3b735-7996-4e8b-b982-9a078f8b923d"],
Cell[2949781, 78850, 539, 14, 67, "Input", "ExpressionUUID" -> \
"5a4c921b-6053-4346-9281-d34d563a00d5"],
Cell[2950323, 78866, 486, 14, 67, "Input", "ExpressionUUID" -> \
"ec38d85b-68fd-447c-afe2-394f023e3997"],
Cell[2950812, 78882, 147, 3, 67, "Text", "ExpressionUUID" -> \
"6c7543da-33f7-4d12-9d0b-bb09d6baaf07"],
Cell[2950962, 78887, 622, 12, 67, "Text", "ExpressionUUID" -> \
"375fb261-0a77-44ed-b863-38f4e376f3da"],
Cell[2951587, 78901, 532, 13, 111, "Text", "ExpressionUUID" -> \
"6d1242e5-5562-4ccd-99d7-8507fc6faa9d"],
Cell[2952122, 78916, 211, 6, 67, "Input", "ExpressionUUID" -> \
"969f0546-2009-42db-aaed-28a108d5a8b6"],
Cell[2952336, 78924, 224, 3, 67, "Text", "ExpressionUUID" -> \
"d0c54d18-d6c3-4532-ac52-d090c75f5bcc"],
Cell[2952563, 78929, 690, 12, 67, "Input", "ExpressionUUID" -> \
"443d36e7-168b-4293-ba7a-e7e54f362a1a"],
Cell[2953256, 78943, 1119, 23, 112, "Input", "ExpressionUUID" -> \
"9c924071-c4d2-402e-889e-d547b1061ef1"],
Cell[2954378, 78968, 848, 16, 67, "Input", "ExpressionUUID" -> \
"f801c683-07a0-4381-9e9a-4f32b3178fee"],
Cell[2955229, 78986, 711, 17, 112, "Input", "ExpressionUUID" -> \
"d2647a66-8b7b-4c78-b446-df0447098788"],
Cell[2955943, 79005, 262, 7, 67, "Input", "ExpressionUUID" -> \
"52e3d48d-afcd-483c-80fb-a07e91faa225"],
Cell[2956208, 79014, 205, 3, 67, "Text", "ExpressionUUID" -> \
"b69c14d5-151b-48d5-b1db-899e1cc9c930"],
Cell[2956416, 79019, 690, 12, 67, "Input", "ExpressionUUID" -> \
"c6c96354-b36b-43a5-9fd6-67a5e29a0eff"],
Cell[2957109, 79033, 1386, 31, 156, "Input", "ExpressionUUID" -> \
"82aef66a-ffb1-4625-9c5a-0c60fb70d95c"],
Cell[2958498, 79066, 877, 17, 67, "Input", "ExpressionUUID" -> \
"e7966a5e-bee2-4ce6-b616-ba957f0f31f4"],
Cell[2959378, 79085, 935, 24, 112, "Input", "ExpressionUUID" -> \
"fddb8e6f-118c-4258-9d28-69d499cee746"],
Cell[2960316, 79111, 396, 10, 67, "Input", "ExpressionUUID" -> \
"44141c61-5f54-446a-844a-56291d8e2889"],
Cell[2960715, 79123, 147, 3, 67, "Text", "ExpressionUUID" -> \
"ac6e1023-d466-42d1-b3d0-74e140706606"],
Cell[2960865, 79128, 711, 13, 67, "Text", "ExpressionUUID" -> \
"6f06c8f3-ef9d-49b7-a8d4-409f1506de85"],
Cell[2961579, 79143, 431, 6, 67, "Text", "ExpressionUUID" -> \
"b4e918e0-5221-496b-8ba3-62d5512d8e31"],
Cell[2962013, 79151, 183, 4, 67, "Input", "ExpressionUUID" -> \
"ec47b269-ddcf-4e0c-8841-d0288f6660e0"],
Cell[2962199, 79157, 322, 8, 67, "Input", "ExpressionUUID" -> \
"f1277c26-6793-4cfc-8995-886794d81165"],
Cell[2962524, 79167, 452, 12, 67, "Input", "ExpressionUUID" -> \
"60c06642-fbb4-43a5-9251-40173b87b7a6"],
Cell[2962979, 79181, 1487, 38, 112, "Input", "ExpressionUUID" -> \
"375ae5ee-701e-4d1e-ba6d-cc02aa9c8776"],
Cell[2964469, 79221, 220, 6, 67, "Input", "ExpressionUUID" -> \
"410f9bd3-6bae-442c-8be6-5de1c5439f55"],
Cell[2964692, 79229, 604, 16, 67, "Input", "ExpressionUUID" -> \
"aca4aa83-4457-4713-a6f9-4939da1acd47"],
Cell[2965299, 79247, 446, 8, 67, "Text", "ExpressionUUID" -> \
"deb83465-c89f-4944-8a82-0a63bfa2fc16"],
Cell[2965748, 79257, 157, 4, 67, "Input", "ExpressionUUID" -> \
"0360f823-e82d-421b-acf8-60038d2acd58"],
Cell[2965908, 79263, 608, 11, 67, "Input", "ExpressionUUID" -> \
"9d9c5d1d-d32e-4379-a569-172ad94cd99c"],
Cell[2966519, 79276, 327, 6, 67, "Text", "ExpressionUUID" -> \
"6006e6ee-fd20-4e6a-9802-fb6a7a7c6c3b"],
Cell[2966849, 79284, 414, 11, 67, "Input", "ExpressionUUID" -> \
"edf3bf77-f5b5-4eb5-be3f-9be68d65d6fb"],
Cell[2967266, 79297, 324, 7, 111, "Text", "ExpressionUUID" -> \
"6898518c-393e-4aae-9be4-67a1db505513"],
Cell[2967593, 79306, 1431, 31, 156, "Input", "ExpressionUUID" -> \
"6d176526-8e49-4aa5-9a5d-e88f80fab0ec"],
Cell[2969027, 79339, 1326, 26, 112, "Input", "ExpressionUUID" -> \
"c132b4d8-d6bd-4097-9675-18767b8d3e05"],
Cell[2970356, 79367, 786, 20, 112, "Input", "ExpressionUUID" -> \
"f5d295d2-0c94-40f4-871c-54ca024367c5"],
Cell[2971145, 79389, 491, 14, 67, "Input", "ExpressionUUID" -> \
"ba639552-d5d7-4216-aca8-91d68f292183"],
Cell[2971639, 79405, 145, 3, 67, "Text", "ExpressionUUID" -> \
"54de9c56-f3dc-4bca-8309-8426697398cf"],
Cell[2971787, 79410, 1315, 27, 202, "Text", "ExpressionUUID" -> \
"616e33e6-ea8d-4853-ba60-c79e2aac6b56"],
Cell[2973105, 79439, 329, 8, 111, "Text", "ExpressionUUID" -> \
"b7b7252a-caf1-48ba-b43b-5bf794f8aa94"],
Cell[2973437, 79449, 236, 6, 67, "Input", "ExpressionUUID" -> \
"f88d29d3-485c-47b7-a204-f345ea0dbbd3",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2973734, 79462, 458, 7, 77, "Subtitle", "ExpressionUUID" -> \
"1dfa043f-985f-4a7c-b0bd-c155d7a2464d"],
Cell[2974195, 79471, 405, 7, 105, "Text", "ExpressionUUID" -> \
"65bf0289-6f9e-448e-839f-5f73100803ab",
 CellTags->"B-R"],
Cell[2974603, 79480, 664, 13, 137, "Text", "ExpressionUUID" -> \
"6f602b7a-8edb-4aca-b794-b3546bcf47a4",
 CellTags->"Gray"],
Cell[2975270, 79495, 924, 17, 137, "Text", "ExpressionUUID" -> \
"908b18fe-110a-4406-a977-97e60173a74f",
 CellTags->"Gray2"],
Cell[2976197, 79514, 588, 9, 137, "Text", "ExpressionUUID" -> \
"049f0a6e-0111-4ebc-a240-f8c4afe3e8c2",
 CellTags->"Gray3"],
Cell[2976788, 79525, 329, 6, 105, "Text", "ExpressionUUID" -> \
"dec11f5f-9442-4c48-a891-2fb4ba8aee05",
 CellTags->"Kr"],
Cell[2977120, 79533, 347, 6, 105, "Text", "ExpressionUUID" -> \
"de314de3-1604-44a0-a4e1-8fbc5ee257be",
 CellTags->"K-N1"],
Cell[2977470, 79541, 472, 8, 105, "Text", "ExpressionUUID" -> \
"14dd576f-2729-4679-99e8-9735f1080024",
 CellTags->"OS3"],
Cell[CellGroupData[{
Cell[2977967, 79553, 233, 5, 44, "Subsubtitle", "ExpressionUUID" -> \
"d1296356-b7f5-4e88-a6b7-4d9623b9db66"],
Cell[2978203, 79560, 392, 8, 50, "Text", "ExpressionUUID" -> \
"21937272-7853-4df9-9b41-b6bdf51bc994"],
Cell[2978598, 79570, 181, 3, 50, "Text", "ExpressionUUID" -> \
"8dc6725b-d8d3-4bf4-b0ae-f32188d9b450"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

